from robot.api import logger
import sys
import os
import inspect
import re

class IxHLRobot:
	def __init__(self, ixiangpfPath, ixNetworkPath, api="ngpf"):
		""" Initialize the IXIA robot library
			Args:
				ixiangpfPath = path to ixia high level python library
				ixNetworkPath = path to ixia ixnetwork low level python library
				api=ngpf or classic
		"""
		self.__version__ = '0.1.0.1'
		sys.path.append(ixiangpfPath)
		sys.path.append(ixNetworkPath)

		from ixiatcl import IxiaTcl
		from ixiahlt import IxiaHlt
		from ixiangpf import IxiaNgpf
		from IxNetwork import IxNet

		self.__api = api;

		if os.name == 'nt':
			self._ixiatcl = IxiaTcl()
		else:
			# unix dependencies
			tcl_dependencies = [
				'/home/user/ixia/ixos/lib',
				'/home/user/ixia/ixnet/IxTclProtocol',
				'/home/user/ixia/ixnet/IxTclNetwork'
			]
			self._ixiatcl = IxiaTcl(tcl_autopath=tcl_dependencies)
		
		self._ixiahlt = IxiaHlt(self._ixiatcl, use_legacy_api=1)
		self._ixiangpf = IxiaNgpf(self._ixiahlt)
		self._ixnet = IxNet()

		self._keywords = {}
		for classic in dir(self._ixiahlt):
			if self._is_keyword_valid(classic):
				self._keywords[classic] = {'keyword': classic, 'support': 'api=classic'}
		for ngpf in dir(self._ixiangpf):
			if self._is_keyword_valid(ngpf):
				if ngpf in self._keywords:
					self._keywords[ngpf]['support'] = 'api=classic|ngpf'
				else:
					self._keywords[ngpf] = {'keyword': ngpf, 'support': 'api=ngpf'}

	def _is_keyword_valid(self, keyword):
		if keyword.startswith("_") == True or keyword == "NONE" or keyword == 'ixiahlt' or keyword == 'ixnet' or keyword == 'FAIL' or keyword == 'SUCCESS' or keyword == 'INTERACTIVE':
			return False
		return True

	def _run_keyword(self, keyword, kwargs):
		keywordData = self._keywords[keyword]
		library = self._ixiangpf
		if keyword != 'connect':
			if keywordData['support'] == 'api=classic' or(keywordData['support'] == 'api=classic|ngpf'  and self.__api == 'classic'):
				library = self._ixiahlt
				logger.info('using classic HL library to execute ' + keyword)
			else:
				logger.info('using NGPF HL library to execute ' + keyword)
		kwargs.pop('api', None)
		result = getattr(library, keyword)(**kwargs)
		logger.info(result)
		if result['status'] == '0':
			from ixiaerror import IxiaError
			raise IxiaError(IxiaError.COMMAND_FAIL, result['log'])
		else:		
			return result

	def ixnet(self, func_name, *args):
		""" execute a low level ixnet command
			Synopsis:
				ixNet setAttribute
				ixNet setMultiAttribute
				ixNet getList
				ixNet add
				ixNet remove
				ixNet commit
			Args:
			Returns:
		"""
		try:
			return getattr(self._ixnet, func_name)(*args)
		except:
			e = sys.exc_info()[1]
			from ixiaerror import IxiaError
			raise IxiaError(IxiaError.IXNET_ERROR, e.message)


	def capture_packets(self, **kwargs):
		""" x   This command configures the capture filter and trigger, starting and
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: capture_packets
			x	-port_handle          ANY
			x	[-start               ANY]
			x	[-stop                ANY]
			x	[-filter              ANY]
			x	[-get_all_packets     ANY]
			x	[-get_packets         ANY]
			x	[-packet_size         ANY]
			x	[-source_ipv4_address ANY]
			x	[-source_ipv6_address ANY]
		
		Arguments:
			x	-port_handle
			x		List of ports where the capture will take place.
			x	-start
			x		Start packet capture on the specified interface list.
			x	-stop
			x		Stop packet capture on the specified interface list.
			x	-filter
			x		Before starting the packet capture, you can configure the capture buffer to filter packets based on their source IP address or packet size. This prevents other packets like protocol hellos or keepalives from being captured.
			x		Valid choices are:
			x   		x -
			x	-get_all_packets
			x		When true, it will return all packets captured.
			x	-get_packets
			x		When capture is done (that is, capture started and stopped), you can use this option to grab packets from the capture buffer. You must specify a number of packets to get from the buffer.
			x	-packet_size
			x		For option "filter" set to packet_size, this option specifies the size of the packets to filter.
			x	-source_ipv4_address
			x		For option "filter" set to source_ipv4_address, this option specifies the value of the IPv4 source IP address.
			x	-source_ipv6_address
			x		For option "filter" set to source_ipv6_address, this option specifies the value of the IPv6 source IP address.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log     value:On status of failure, gives detailed information.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("capture_packets", kwargs)

	def cleanup_session(self, **kwargs):
		""" This command disconnects from chassis, IxNetwork Tcl Server and Tcl Server, resets to factory defaults, and removes ownership from a list of ports. This command can be used after a script is run.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: cleanup_session
			x	[-port_handle                  REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-maintain_lock                CHOICES 1 0
			                                CHOICES 0 1]
			x	[-clear_csv                    CHOICES 0 1]
			x	[-skip_wait_pending_operations FLAG]
			x	[-reset                        FLAG]
			n	[-handle                       ANY]
		
		Arguments:
			x	-port_handle
			x		List ports to release.
			x		When using IxTclHal, IxTclProtocol or IxTclAccess, -port_handle option
			x		should always be present, otherwise only the disconnect part will be
			x		completed.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-maintain_lock
			 		When using IxNetwork with the -reset option, this parameter will be
			 		ignored.
			 		Valid choices are:
			    		1 - Do not unlock test ports. Use this value at beginning of tests.
			    		0 - Unlock test ports. Use this value at end of tests.
			x	-clear_csv
			x		Valid choices are:
			x		0 - The CSV files are not deleted after cleanup_session procedure is called
			x		1 - The CSV files created after calling traffic_stats are deleted
			x	-skip_wait_pending_operations
			x		If there are any disconnect operations issued, this flag will prevent
			x		procedure from waiting for them to end. If this flag is used then
			x		there is no warrantythat the disconnect operations have ended and
			x		exiting the script with these operations still running can be the
			x		source of errors.
			x	-reset
			x		Reset the ports to factory defaults before releasing them.
			x		When using IxTclHal and IxTclProtocol, -port_handle option should be
			x		present also, otherwise the reset will not be completed.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			n	-handle
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log     value:On status of failure, gives detailed information.
		
		Examples:
		See the file Streams_IPv4_stats.tcl in the Samples subdirectory for a specific example of the usage of this command. See Appendix A, "Example APIs," for further examples.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("cleanup_session", kwargs)

	def clear_ixiangpf_cache(self, **kwargs):
		""" this method will clean the multivalue_config cache
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: clear_ixiangpf_cache
		
		Arguments:
		
		Return Values:
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("clear_ixiangpf_cache", kwargs)

	def connect(self, **kwargs):
		""" This command connects to the Ixia Chassis, takes ownership of selected ports, and optionally loads a configuration on the chassis or resets the targeted ports to factory defaults. When using an HLTSET that loads a network only version (*NO or *P2NO + ixnetwork_tcl_server present) it is possible to resume a previously configured session.         This feature is triggered if the -reset parameter is missing and the following scenarios are possible:                              - Connect to IxNetwork Tcl Server (-ixnetwork_tcl_server) and pull the existing configuration. The current configuration will be returned as a keyed list (see the Return Values section).                 - Connect to IxNetwork Tcl Server (-ixnetwork_tcl_server), load an ixncfg (-config_file) and pull the configuration into HLT. The current configuration will be returned as a keyed list (see the Return Values section).                 - Connect to IxNetwork Tcl Server (-ixnetwork_tcl_server), load an ixncfg (-config_file), load an hlt configuration file (-config_file_hlt).         The configuration will not be returned because it is assumed that the handles were initialized in a previous session.         The hardware from IxNetwork must be the same as the one from the 'config_file_hlt', otherwise the information from the config file will not match the information from IxNetwork Tcl Server and it will result in unpredictable errors.                 - Save the current configuration using -mode save. If -config_file parameter is specified, the ixncfg file will be saved in the 'config_file' file. If config_file_hlt parameter is specified, the hlt configuration file will be saved in the 'config_file_hlt' file. At least one of these parameters must be specified.                                            <b>Notes:</b>                              - If the -device and -port_list parameters are specified they will be mapped over the chassis and ports detected on IxNetwork Tcl Server (available only if -config_file_hlt is not specified). Otherwise, the hardware found on ixnetwork tcl server will be used for configuration.                 - Session resume is performed only on the first connect call from the script. Subsequent calls will not load the configuration from the IxNetwork Tcl Server.                 - When using Unix, loading an ixncfg (-config_file) works only if HLT commands are executed locally, on the Unix client machine.                      
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: connect
			 	[-port_list                     REGEXP ^({*(\[0-9\]+/\[0-9\]+\[\\\ \]*)*}*\[\\\ \]*)+$]
			x	[-aggregation_mode              CHOICES normal
			x                                CHOICES mixed
			x                                CHOICES not_supported
			x                                CHOICES single_mode_aggregation
			x                                CHOICES dual_mode_aggregation
			x                                CHOICES hundred_gig_non_fan_out
			x                                CHOICES novus_hundred_gig_non_fan_out
			x                                CHOICES forty_gig_aggregation
			x                                CHOICES forty_gig_fan_out
			x                                CHOICES forty_gig_normal_mode
			x                                CHOICES four_by_twenty_five_gig_non_fan_out
			x                                CHOICES two_by_twenty_five_gig_non_fan_out
			x                                CHOICES ten_gig_aggregation
			x                                CHOICES ten_gig_fan_out
			x                                CHOICES three_by_ten_gig_fan_out
			x                                CHOICES four_by_ten_gig_fan_out
			x                                CHOICES eight_by_ten_gig_fan_out
			x                                CHOICES one_by_fifty_gig_non_fan_out
			x                                CHOICES novus_two_by_fifty_gig_non_fan_out
			x                                CHOICES novus_four_by_twenty_five_gig_non_fan_out
			x                                CHOICES novus_one_by_forty_gig_non_fan_out
			x                                CHOICES novus_four_by_ten_gig_non_fan_out
			x                                CHOICES one_by_four_hundred_gig_non_fan_out
			x                                CHOICES two_by_two_hundred_gig_fan_out
			x                                CHOICES four_by_one_hundred_gig_fan_out
			x                                CHOICES eight_by_fifty_gig_fan_out]
			x	[-aggregation_resource_mode     CHOICES normal
			x                                CHOICES dual_mode_aggregation
			x                                CHOICES single_mode_aggregation
			x                                CHOICES forty_gig_aggregation
			x                                CHOICES hundred_gig_non_fan_out
			x                                CHOICES novus_hundred_gig_non_fan_out
			x                                CHOICES forty_gig_fan_out
			x                                CHOICES forty_gig_normal_mode
			x                                CHOICES four_by_twenty_five_gig_non_fan_out
			x                                CHOICES two_by_twenty_five_gig_non_fan_out
			x                                CHOICES ten_gig_aggregation
			x                                CHOICES ten_gig_fan_out
			x                                CHOICES eight_by_ten_gig_fan_out
			x                                CHOICES three_by_ten_gig_fan_out
			x                                CHOICES four_by_ten_gig_fan_out
			x                                CHOICES one_by_fifty_gig_non_fan_out
			x                                CHOICES novus_two_by_fifty_gig_non_fan_out
			x                                CHOICES novus_four_by_twenty_five_gig_non_fan_out
			x                                CHOICES novus_one_by_forty_gig_non_fan_out
			x                                CHOICES novus_four_by_ten_gig_non_fan_out
			x                                CHOICES one_by_four_hundred_gig_non_fan_out
			x                                CHOICES one_by_two_hundred_gig_non_fan_out
			x                                CHOICES two_by_one_hundred_gig_fan_out
			x                                CHOICES four_by_fifty_gig_fan_out
			x                                CHOICES two_by_two_hundred_gig_fan_out
			x                                CHOICES four_by_one_hundred_gig_fan_out
			x                                CHOICES eight_by_fifty_gig_fan_out]
			 	[-device                        ANY]
			 	[-break_locks                   CHOICES 0 1
			                                 DEFAULT 1]
			 	[-close_server_on_disconnect    CHOICES 0 1
			                                 DEFAULT 1]
			x	[-config_file                   ANY]
			 	[-config_file_hlt               ANY]
			x	[-connect_timeout               NUMERIC
			x                                DEFAULT 10]
			x	[-enable_win_tcl_server         CHOICES 0 1
			x                                DEFAULT 0]
			x	[-guard_rail                    CHOICES statistics none
			x                                DEFAULT none]
			x	[-protocol_stacking_mode        CHOICES parallel sequential]
			x	[-interactive                   CHOICES 0 1]
			x	[-ixnetwork_tcl_server          ANY]
			x	[-user_name                     ANY]
			x	[-user_password                 ANY]
			x	[-session_id                    NUMERIC]
			x	[-api_key                       ANY]
			x	[-api_key_file                  ANY]
			x	[-ixnetwork_license_servers     ANY]
			x	[-ixnetwork_license_type        CHOICES perpetual
			x                                CHOICES mixed
			x                                CHOICES subscription
			x                                CHOICES subscription_tier0
			x                                CHOICES subscription_tier1
			x                                CHOICES subscription_tier2
			x                                CHOICES subscription_tier3
			x                                CHOICES subscription_tier3-10g
			x                                CHOICES mixed_tier0
			x                                CHOICES mixed_tier1
			x                                CHOICES mixed_tier2
			x                                CHOICES mixed_tier3
			x                                CHOICES mixed_tier3-10g]
			x	[-logging                       CHOICES hltapi_calls]
			x	[-log_path                      ANY]
			x	[-ixnetwork_tcl_proxy           ANY]
			x	[-master_device                 ANY]
			x	[-chain_sequence                ANY]
			x	[-chain_cables_length           ANY]
			x	[-chain_type                    CHOICES none daisy star
			x                                DEFAULT none]
			 	[-reset                         FLAG]
			x	[-session_resume_keys           CHOICES 0 1
			x                                CHOICES 0 1
			x                                DEFAULT 1]
			x	[-session_resume_include_filter ANY
			x                                DEFAULT {}]
			 	[-sync                          CHOICES 0 1
			                                 DEFAULT 1]
			 	[-tcl_proxy_username            ANY]
			x	[-proxy_connect_timeout         ANY]
			x	[-tcl_server                    ANY]
			 	[-username                      ANY
			                                 DEFAULT \]
			x	[-mode                          CHOICES connect
			x                                CHOICES disconnect
			x                                CHOICES reconnect_ports
			x                                CHOICES save
			x                                DEFAULT connect]
			x	[-vport_count                   RANGE 1-600]
			x	[-vport_list                    REGEXP ^\[0-9\]+/\[0-9\]+/\[0-9\]
			x	[-execution_timeout             NUMERIC
			x                                DEFAULT 0]
			x	[-return_detailed_handles       CHOICES 0 1
			x                                DEFAULT 1]
			n	[-timeout                       ANY]
			n	[-nobios                        ANY]
			n	[-forceload                     ANY]
		
		Arguments:
			 	-port_list
			 		List of Ixia ports of which to take ownership.If multiple devices are
			 		specified, then this is a list of lists.A single item is of the
			 		form card number / port number.So card 2, port 4 would look like 2/4.
			 		This parameter depends on 'vport_list' and 'vport_count' parameters. More details
			 		are available in the description for parameter 'device'.
			x	-aggregation_mode
			x		This parameter represents the aggregation mode that can be set on the card.
			x		Valid choices are:
			x   		normal - default (all the ports can be used, except the 40Gig ones)
			x   		mixed - using this mode, you can set different aggregation modes on each aggregation group
			x   		not_supported - the card does not support aggregation
			x   		ten_gig_aggregation - 10Gig aggregation mode
			x   		ten_gig_fan_out - 10Gig aggregation mode for Multis cards (aka 1X10G in IxNetwork GUI).
			x   		three_by_ten_gig_fan_out - 10Gig aggregation mode for Multis cards (aka 3X10G in IxNetwork GUI).
			x   		four_by_ten_gig_fan_out - 10Gig aggregation mode for Multis cards (aka 4X10G in IxNetwork GUI).
			x   		eight_by_ten_gig_fan_out - 10Gig aggregation mode for Multis cards (aka 8X10G in IxNetwork GUI).
			x   		four_by_twenty_five_gig_non_fan_out - 25Gig aggregation mode for Multis cards (aka 4X25G in IxNetwork GUI).
			x   		two_by_twenty_five_gig_non_fan_out - 25Gig aggregation mode for Multis cards (aka 2X25G in IxNetwork GUI).
			x   		forty_gig_aggregation - 40Gig aggregation mode
			x   		forty_gig_fan_out - 40Gig aggregation for Multis cards with FAN out (aka 3x40G in IxNetwork GUI).
			x   		forty_gig_normal_mode - 40Gig aggregation for Multis cards with FAN out (aka 1x40G mode in IxNetwork GUI).
			x   		one_by_fifty_gig_non_fan_out - 50Gig aggregation for Multis cards with no out (aka 1x50G mode in IxNetwork GUI).
			x   		hundred_gig_non_fan_out - 100Gig aggregation mode for Multis cards with no FAN out.
			x   		novus_hundred_gig_non_fan_out - 100Gig aggregation mode for Novus cards with no FAN out.
			x   		novus_four_by_twenty_five_gig_non_fan_out - 4x25Gig aggregation mode for Novus cards with no FAN out.
			x   		novus_two_by_fifty_gig_non_fan_out - 2x50Gig aggregation mode for Novus cards with no FAN out.
			x   		novus_one_by_forty_gig_non_fan_out - 1x40Gig aggregation mode for Novus cards with no FAN out.
			x   		novus_four_by_ten_gig_non_fan_out - 4x10Gig aggregation mode for Novus cards with no FAN out.
			x   		one_by_four_hundred_gig_non_fan_out - 1x400Gig aggregation mode for K400/Titan400G cards with no FAN out.
			x   		two_by_two_hundred_gig_fan_out - 2x200Gig aggregation mode for Titan400G cards with FAN out.
			x   		four_by_one_hundred_gig_fan_out - 4x100Gig aggregation mode for Titan400G cards with FAN out.
			x   		eight_by_fifty_gig_fan_out - 8x50Gig aggregation mode for Titan400G cards with FAN out.
			x   		single_mode_aggregation - Single Mode aggregation (supported both with IxNetwork and IxTclProtocol)
			x   		dual_mode_aggregation - Dual Mode aggregation (supported both with IxNetwork and IxTclProtocol)
			x	-aggregation_resource_mode
			x		This parameter represents the aggregation mode on each resource group on the card.
			x		Valid choices are:
			x   		normal - default (all the ports can be used, except the 40Gig ones)
			x   		ten_gig_aggregation - 10Gig aggregation mode
			x   		ten_gig_fan_out - 10Gig aggregation mode for Multis cards (aka 1X10G in IxNetwork GUI).
			x   		three_by_ten_gig_fan_out - 10Gig aggregation mode for Multis cards (aka 3X10G in IxNetwork GUI).
			x   		four_by_ten_gig_fan_out - 10Gig aggregation mode for Multis cards (aka 4X10G in IxNetwork GUI).
			x   		eight_by_ten_gig_fan_out - 10Gig aggregation mode for Multis cards (aka 8X10G in IxNetwork GUI).
			x   		four_by_twenty_five_gig_non_fan_out - 25Gig aggregation mode for Multis cards (aka 4X25G in IxNetwork GUI).
			x   		two_by_twenty_five_gig_non_fan_out - 25Gig aggregation mode for Multis cards (aka 2X25G in IxNetwork GUI).
			x   		forty_gig_aggregation - 40Gig aggregation mode
			x   		forty_gig_fan_out - 40Gig aggregation for Multis cards with FAN out (aka 3x40G in IxNetwork GUI).
			x   		forty_gig_normal_mode - 40Gig aggregation for Multis cards with FAN out (aka 1x40G mode in IxNetwork GUI).
			x   		one_by_fifty_gig_non_fan_out - 50Gig aggregation for Multis cards with no out (aka 1x50G mode in IxNetwork GUI).
			x   		hundred_gig_non_fan_out - 100Gig aggregation mode for Multis cards with no FAN out.
			x   		novus_hundred_gig_non_fan_out - 100Gig aggregation mode for Novus cards with no FAN out.
			x   		novus_four_by_twenty_five_gig_non_fan_out - 4x25Gig aggregation mode for Novus cards with no FAN out.
			x   		novus_two_by_fifty_gig_non_fan_out - 2x50Gig aggregation mode for Novus cards with no FAN out.
			x   		novus_one_by_forty_gig_non_fan_out - 1x40Gig aggregation mode for Novus cards with no FAN out.
			x   		novus_four_by_ten_gig_non_fan_out - 4x10Gig aggregation mode for Novus cards with no FAN out.
			x   		one_by_four_hundred_gig_non_fan_out - 1x400Gig aggregation mode for K400/Titan400G cards with no FAN out.
			x   		one_by_two_hundred_gig_non_fan_out - 1x200Gig aggregation mode for K400 cards with no FAN out.
			x   		two_by_one_hundred_gig_fan_out - 2x100Gig aggregation mode for K400 cards with FAN out.
			x   		four_by_fifty_gig_fan_out - 4x50Gig aggregation mode for K400 cards with FAN out.
			x   		two_by_two_hundred_gig_fan_out - 2x200Gig aggregation mode for Titan400G cards with FAN out.
			x   		four_by_one_hundred_gig_fan_out - 4x100Gig aggregation mode for Titan400G cards with FAN out.
			x   		eight_by_fifty_gig_fan_out - 8x50Gig aggregation mode for Titan400G cards with FAN out.
			x   		single_mode_aggregation - Single Mode aggregation (supported both with IxNetwork and IxTclProtocol)
			x   		dual_mode_aggregation - Dual Mode aggregation (supported both with IxNetwork and IxTclProtocol)
			 	-device
			 		IP address or name of the chassis. May contain a list of devices. When
			 		IxNetwork Tcl API is used this parameter can have one of the following 4
			 		meanings:
			 		1. When 'vport_list' and 'vport_count' parameters are missing, a new chassis
			 		is added, virtual ports are created and connected to
			 		the real ports specified with 'port_list' parameter.
			 		2. When 'vport_count' is specified this parameter is ignored and 'vport_count'
			 		virtual ports are created. They will not be connected.
			 		3. When 'vport_list' exists and -mode is 'connect' a connection to the
			 		'device' chassis will be established. The real ports specified
			 		with 'port_list' will be connected to the virtual ports specified
			 		with 'vport_list'. The length and structure of the parameters
			 		'port_list' and 'vport_list' must be the same
			 		(e.g. -port_list {{2/3 2/4} {1/2 1/3 1/4}} -vport_list {{0/0/1 0/0/2} {0/0/3 0/0/4 0/0/5}}).
			 		4. When 'vport_list' exists and -mode is 'disconnect' this parameter will be
			 		ignored and the virtual ports specified with 'vport_list' will be
			 		disconnected from the real ports they are currently connected to.
			 	-break_locks
			 		 Valid choices are: 
			 		
			 			0 - Force option is not used.

			 			1 - Force option is used when taking ownership.

			 		
			 	-close_server_on_disconnect
			 		When connecting to an IxNetwork Proxy Server this flag will be used to
			 		determine if the IxNetwork session will be closed (shutdown) after the user
			 		disconnects or it will remain Idle to allow future session resume.
			 		 This parameter is ignored when not connecting to a IxNetwork Proxy Server
			 		using IxTclNetwork (new API). 
			x	-config_file
			x		and/or the hlt configuration to the file specified with -config_file_hlt.
			 	-config_file_hlt
			 		Name of a file containing HLT configuration information. Valid only with an IxNetwork HLTSET
			 		as part of the session resume capabilities.
			x	-connect_timeout
			x		Timeout in seconds to wait before failing connection to chassis when using IxNetwork TCL API is used.
			x		 From IxNetwork the connection to chassis is performed when
			x		::<namespace>::interface_config procedure is called. The timeout will not apply to
			x		the chassis connection performed in ::<namespace>::connect procedure by IxTclHal. 
			x	-enable_win_tcl_server
			x		Enables running entire HLT API commands on Tcl Server's
			x		machine. Valid only on Windows platforms.
			x	-guard_rail
			x		This parameter will protect the application from exceeding the memory limits and
			x		by limiting the maximum number of views and statistics provided to the user.
			x		Valid choices are:
			x   		statistics - limit the maximum number of views and statistics
			x   		none - no guard rail
			x	-protocol_stacking_mode
			x		This parameter enables the parallel/sequential start/stop of protocol layers when multiple protocols
			x		are stacked together.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		parallel - The operation on one layer of a device is triggered as soon as the operation on the previous layer of this device is completed.
This behavior provides a more realistic emulation of real world scenarios and it is currently supported only for NGPF access protocols.
			x   		sequential - The operation on one layer must complete on all devices before the same operation is triggered on the next layer.
This is the default behavior of NGPF protocols.
			x	-interactive
			x		This argument is used to specify whether the console in which the
			x		script is run will work in the interactive mode or not.
			x	-ixnetwork_tcl_server
			x		IP address or name of the IxNetwork TCL server, followed optionally by
			x		port number.
			x		When using IxTclProtocol (old API), this parameter is ignored on both
			x		Windows and Unix platforms.
			x		When using IxTclNetwork (new API), on Windows platform, if
			x		both ixnetwork_tcl_server and tcl_server are not specified, the
			x		default value for ixnetwork_tcl_server is 127.0.0.1:8009.
			x		Otherwise, if tcl_server option is present and in use, the default
			x		value is equal to tcl_server:8009.
			x		When using IxTclNetwork (new API), on Unix platform, if
			x		ixnetwork_tcl_server is not specified, the default value is equal to
			x		tcl_server:8009. This means that, on Unix, if ixnetwork_tcl_server is
			x		not specified, then tcl_server must be specified.
			x		Ixia now supports IPv6 address which can be given as [ipv6address]:port or
			x		for ex: [FF02::2:2]:8009.
			x	-user_name
			x		User name of IxNetwork API Server
			x	-user_password
			x		User password of IxNetwork API Server
			x	-session_id
			x		Session ID where you want to reconnect
			x	-api_key
			x		api_key of the REST API Server
			x	-api_key_file
			x		api_key_file where store api_key of the REST API Server
			x	-ixnetwork_license_servers
			x		If set this will set the central license server from where you can request a license.
			x		Any computer where Ixia Licensing Utility is installed can act as a License Server. Multiple servers can be provided as a list.
			x	-ixnetwork_license_type
			x		Valid if ixnetwork_license_servers argument is used. This argument is used to specify which type of license is used.
			x		Valid choices are:
			x   		perpetual - In this mode licenses are checked out from the individual chassis. You cannot install perpetual licenses for a chassis on a different license server.
You can use any number of ports on the given chassis as the license is node locked (locked to a specific chassis) and unlimited.
Here the core license is checked when the chassis is connected. If there are no core licenses, the port fails to connect and an error is displayed.
Perpetual mode is available for Hardware ports only.
Perpetual Mode is the legacy licensing mode.
Changing modes between modes can only be done when all the ports are released.
			x   		subscription - VM licensing model. 
For details on the limitations, please refer to IxNetwork User Guide.
When this option is used the tier level will not be changed.
			x   		mixed - Mixed mode reffers to mixed HW/VM licensing model.
For details on the limitations, please refer to IxNetwork User Guide.
When this option is used the tier level will not be changed.
			x   		subscription_tier0 - Interfaces only support.
For details on the limitations, please refer to IxNetwork User Guide.
			x   		subscription_tier1 - It is the most restrictive, with only a few protocols and sessions support available per protocol.
For details on the limitations, please refer to IxNetwork User Guide.
			x   		subscription_tier2 - It provides unlimited protocol and session support for Hardware ports and limited protocol and session support for VM ports.
For details on the limitations, please refer to IxNetwork User Guide.
			x   		subscription_tier3 - It provides unlimited protocol and session support and also the premium features.
			x   		subscription_tier3-10g - It enables 10G support and provides unlimited protocol and session support and also the premium features.
			x   		mixed_tier0 - Interfaces only support.
For details on the limitations, please refer to IxNetwork User Guide.
			x   		mixed_tier1 - It is the most restrictive, with only a few protocols and sessions support available per protocol.
For details on the limitations, please refer to IxNetwork User Guide.
			x   		mixed_tier2 - It provides unlimited protocol and session support for Hardware ports and limited protocol and session support for VM ports.
For details on the limitations, please refer to IxNetwork User Guide.
			x   		mixed_tier3 - It provides unlimited protocol and session support and also the premium features.
			x   		mixed_tier3-10g - It enables 10G support and provides unlimited protocol and session support and also the premium features.
			x	-logging
			x		This parameter enables logging HLTAPI commands.
			x		Valid choices are:
			x   		hltapi_calls -
			x	-log_path
			x		Sets the path for hltapi logs, when parameter -logging is used.
			x	-ixnetwork_tcl_proxy
			x		The presence of this flag loads the IxTclNetworkConnector package and
			x		enables connection to the IxNetwork TCL Proxy Server. This parameter is
			x		valid only when using IxTclNetwork (new API).The address for
			x		the TCL proxy will be the value specified by the ixnetwork_tcl_server
			x		parameter.
			x	-master_device
			x		IP address or name of the master chassis, if -device is a slave chassis.
			x		May contain a list of devices. In this case, the string "none" can be
			x		added when the master chassis IP is not applicable.
			x	-chain_sequence
			x		SequenceID for chassis chain. Only valid for slave chassis when master_device parameter is used.
			x		For more info please consult Ixia chassis chaining user guide from IxOS or IxNetwork products.
			x	-chain_cables_length
			x		Cable length in ft used for the chassis chain. This can be a value of a list of values for each slave chassis.
			x		Valid values are: '0' (not applicabale), '3' (3 ft) or '6' (6 ft). Only valid for slave chassis when master_device parameter is used. If not specified it will default to 3 for each slave chassis.
			x	-chain_type
			x		This optional parameter specifices the chassis chain type used by IxNetwork.
			x		Valid choices are:
			x   		none - No chassis chain is used. The chain type present in IxNetwork will not be changed in this case.
			x   		daisy - Daisy chain. This is the default option when master_device argument is present.
This refers to a set of Ixia chassis that have been cabled together through their Sync In/Sync Out ports.
			x   		star - This refers to a set of Ixia chassis that have been cabled together using a star topology. In this mode all slave chassis will have a cable connected directly in the master chassis.
			 	-reset
			 		Resets the card to factory defaults.
			 		 When IxTclNetwork is used, the presence of this flag will reset all
			 		previous connections to chassis and ports. If this flag is missing and this
			 		is the first connect call from the script, the configuration will be imported from
			 		the IxNetwork Tcl Server and will be returned as keyed list (see Return Values section). 
			x	-session_resume_keys
			x		Using this parameter when loading an ixncfg file allows you to choose
			x		whether to show the session resume keys or not. This parameter is valid only
			x		when using IxTclNetwork. If global parameter ::<namespace>::session_resume_keys does not
			x		exist, it will be overwritten by ::<namespace>::connect local parameter -session_resume_keys.
			x		Valid choices are:
			x   		0 - do not show the session resume keys
			x   		1 - show the session resume keys
			x	-session_resume_include_filter
			x		May contains a list of value that specify an inclusion filter for the returned session resume
			x		dictionary keys when -session_resume_keys is 1. The keys that have items in <typepath> are dependent on
			x		the command that generated that kind of typepath. Generally the procedure that generated those objects has
			x		the same name as the first part in the key.
			x		 Eg. in emulation_bgp_route_config.bgp_sites.<vport/protocols/bgp/neighborRange/l2Site> objects of type
			x		vport/protocols/bgp/neighborRange/l2Site are generated by the emulation_bgp_route_config command. 
			x		 Valid values are: 
			x		
			x		-  connect
			x		-  connect.vport_list 
			x		-  interface_config 
			x		-  interface_config.interface_handle 
			x		-  interface_config.routed_interface_handle 
			x		-  interface_config.gre_interface_handle 
			x		-  interface_config.atm_endpoints 
			x		-  interface_config.fr_endpoints 
			x		-  interface_config.ip_endpoints 
			x		-  interface_config.lan_endpoints 
			x		-  interface_config.ig_endpoints
			x		-  emulation_bfd_config 
			x		-  emulation_bfd_config.router_handles 
			x		-  emulation_bfd_config.router_interface_handles 
			x		-  emulation_bfd_config.router_interface_handles.<vport/protocols/bfd/router 
			x		-  emulation_bfd_config.interface_handles 
			x		-  emulation_bfd_config.interface_handles.<vport/protocols/bfd/router> 
			x		-  emulation_bfd_session_config.session_handles 
			x		-  emulation_bgp_config 
			x		-  emulation_bgp_config.handles 
			x		-  emulation_bgp_route_config 
			x		-  emulation_bgp_route_config.bgp_routes 
			x		-  emulation_bgp_route_config.bgp_sites 
			x		-  emulation_bgp_route_config.bgp_sites.<vport/protocols/bgp/neighborRange/l2Site> 
			x		-  emulation_bgp_route_config.bgp_sites.<vport/protocols/bgp/neighborRange/l3Site> 
			x		-  emulation_cfm_config 
			x		-  emulation_cfm_config.handle 
			x		-  emulation_cfm_config.interface_handles 
			x		-  emulation_cfm_custom_tlv_config 
			x		-  emulation_cfm_custom_tlv_config.handle 
			x		-  emulation_cfm_links_config 
			x		-  emulation_cfm_links_config.handle 
			x		-  emulation_cfm_md_meg_config 
			x		-  emulation_cfm_md_meg_config.handle 
			x		-  emulation_cfm_mip_mep_config 
			x		-  emulation_cfm_mip_mep_config.handle 
			x		-  emulation_cfm_vlan_config 
			x		-  emulation_cfm_vlan_config.handle 
			x		-  emulation_cfm_vlan_config.mac_range_handles 
			x		-  emulation_cfm_vlan_config.mac_range_handles.<vport/protocols/cfm/bridge/vlans> 
			x		-  emulation_dhcp_config 
			x		-  emulation_dhcp_config.handle 
			x		-  emulation_dhcp_group_config 
			x		-  emulation_dhcp_group_config.handle 
			x		-  emulation_dhcp_server_config 
			x		-  emulation_dhcp_server_config.handle 
			x		-  emulation_dhcp_server_config.handle 
			x		-  dhcp_client_extension_config 
			x		-  dhcp_client_extension_config.handle 
			x		-  dhcp_server_extension_config 
			x		-  dhcp_server_extension_config.handle 
			x		-  emulation_efm_config 
			x		-  emulation_efm_config.information_oampdu_id 
			x		-  emulation_efm_config.event_notification_oampdu_id 
			x		-  emulation_efm_org_var_config 
			x		-  emulation_efm_org_var_config.handle 
			x		-  emulation_eigrp_config 
			x		-  emulation_eigrp_config.router_handles 
			x		-  emulation_eigrp_config.interface_handles 
			x		-  emulation_eigrp_route_config 
			x		-  emulation_eigrp_route_config.session_handles 
			x		-  emulation_igmp_config 
			x		-  emulation_igmp_config.handle 
			x		-  emulation_igmp_group_config 
			x		-  emulation_igmp_group_config.handle 
			x		-  emulation_igmp_group_config.source_handle 
			x		-  emulation_igmp_group_config.group_pool_handle 
			x		-  emulation_igmp_group_config.source_pool_handle 
			x		-  emulation_isis_config 
			x		-  emulation_isis_config.handle 
			x		-  emulation_isis_topology_route_config 
			x		-  emulation_isis_topology_route_config.elem_handle 
			x		-  emulation_isis_topology_route_config.stub 
			x		-  emulation_isis_topology_route_config.external 
			x		-  emulation_isis_topology_route_config.grid 
			x		-  emulation_isis_topology_route_config.grid.connected_session.<vport/protocols/isis/router>.row 
			x		-  emulation_isis_topology_route_config.grid.connected_session.<vport/protocols/isis/router>.col 
			x		-  l2tp_config 
			x		-  l2tp_config.handles 
			x		-  emulation_lacp_link_config 
			x		-  emulation_lacp_link_config.handle 
			x		-  emulation_ldp_config 
			x		-  emulation_ldp_config.handle 
			x		-  emulation_ldp_route_config 
			x		-  emulation_ldp_route_config.lsp_handle 
			x		-  emulation_ldp_route_config.lsp_intf 
			x		-  emulation_ldp_route_config.lsp_vc_range_handles 
			x		-  emulation_ldp_route_config.lsp_vc_ip_range_handles 
			x		-  emulation_ldp_route_config.lsp_vc_mac_range_handles 
			x		-  emulation_mld_config 
			x		-  emulation_mld_config.handle 
			x		-  emulation_mld_group_config 
			x		-  emulation_mld_group_config.handle 
			x		-  emulation_mld_group_config.group_pool_handle 
			x		-  emulation_mld_group_config.source_pool_handles 
			x		-  emulation_oam_config_msg 
			x		-  emulation_oam_config_msg.handle 
			x		-  emulation_oam_config_topology 
			x		-  emulation_oam_config_topology.handle 
			x		-  emulation_oam_config_topology.traffic_handles 
			x		-  emulation_ospf_config 
			x		-  emulation_ospf_config.handle 
			x		-  emulation_ospf_topology_route_config 
			x		-  emulation_ospf_topology_route_config.elem_handle 
			x		-  emulation_pbb_config 
			x		-  emulation_pbb_config.handle 
			x		-  emulation_pbb_config.interface_handles 
			x		-  emulation_pbb_trunk_config 
			x		-  emulation_pbb_trunk_config.trunk_handle 
			x		-  emulation_pbb_trunk_config.mr_handle 
			x		-  emulation_pim_config 
			x		-  emulation_pim_config.handle 
			x		-  emulation_pim_config.interfaces 
			x		-  emulation_pim_group_config 
			x		-  emulation_pim_group_config.handle 
			x		-  emulation_pim_group_config.group_pool_handle 
			x		-  emulation_pim_group_config.source_pool_handles 
			x		-  pppox_config 
			x		-  pppox_config.handles 
			x		-  emulation_rip_config 
			x		-  emulation_rip_config.handle 
			x		-  emulation_rip_route_config 
			x		-  emulation_rip_route_config.route_handle 
			x		-  emulation_rsvp_config 
			x		-  emulation_rsvp_config.handles 
			x		-  emulation_rsvp_config.router_interface_handle 
			x		-  emulation_rsvp_tunnel_config 
			x		-  emulation_rsvp_tunnel_config.tunnel_handle 
			x		-  emulation_rsvp_tunnel_config.tunnel_leaves_handle 
			x		-  emulation_rsvp_tunnel_config.tunnel_leaves_handle.<vport/protocols/rsvp/neighborPair/destinationRange> 
			x		-  emulation_rsvp_tunnel_config.tunnel_leaves_handle.<vport/protocols/rsvp/neighborPair/destinationRange>/ingress 
			x		-  emulation_rsvp_tunnel_config.routed_interfaces 
			x		-  emulation_stp_msti_config 
			x		-  emulation_stp_msti_config.handle 
			x		-  emulation_stp_bridge_config 
			x		-  emulation_stp_bridge_config.bridge_handle 
			x		-  emulation_stp_bridge_config.bridge_interface_handles 
			x		-  emulation_stp_bridge_config.bridge_interface_handles.<vport/protocols/stp/bridge> 
			x		-  emulation_stp_bridge_config.interface_handles 
			x		-  emulation_stp_bridge_config.interface_handles.<vport/protocols/stp/bridge> 
			x		-  emulation_twamp_config 
			x		-  emulation_twamp_config.handle 
			x		-  emulation_twamp_control_range_config 
			x		-  emulation_twamp_control_range_config.handle 
			x		-  emulation_twamp_test_range_config 
			x		-  emulation_twamp_test_range_config.handle 
			x		-  emulation_twamp_server_range_config 
			x		-  emulation_twamp_server_range_config.handle 
			x		-  emulation_ancp_config 
			x		-  emulation_ancp_config.handle 
			x		-  emulation_ancp_subscriber_lines_config 
			x		-  emulation_ancp_subscriber_lines_config.handle 
			x		-  fc_client_config 
			x		-  fc_client_config.handle 
			x		-  fc_fport_config 
			x		-  fc_fport_config.handle 
			x		-  fc_fport_vnport_config 
			x		-  fc_fport_vnport_config.handle 
			x		-  traffic_config 
			x		-  traffic_config.stream_id 
			x		-  traffic_config.traffic_item 
			x		-  emulation_multicast_group_config 
			x		-  emulation_multicast_source_config 
			x		
			 	-sync
			 		If enabled, the ixClearTimeStamps routine is called for the
			 		reserved port list.
			 	-tcl_proxy_username
			 		Username for logging in IxNetwork Tcl Proxy server.
			 		 This parameter is ignored when IxNetwork Tcl Proxy server is not used for connecting
			 		to IxNetwork. In this case, the username will be configured
			 		automatically at ::<namespace>::interface_config and will have the value
			 		'IxNetwork/$(COMPUTERNAME)/$(USERNAME)'. 
			 		 However, when connecting to an IxNetwork Tcl Proxy Server this parameter is used
			 		to determine the username of the IxNetwork instance to which the Proxy Server
			 		will connect to. 
			x	-proxy_connect_timeout
			x		Timeout in seconds to wait for an IxNetwork instance to be reserved for this session when using IxNetwork Connection Manager.
			x		This means the time we will wait when all instances (that are matching our connect criteria) are in use or in a busy state (like stopping, disconnecting from other existing sessions).
			x		Once an IxNetwork session is reserved, the connect command will wait for the IxNetwork session to be available (session logon, start IxNetwork process, etc.). The maximum time to wait for the starting of IxNetwork session can be configured from Connection Manager and is not affected by this setting.
			x	-tcl_server
			x		IP address or name of the ixTclServer.
			x		When using IxTclProtocol (old API), this parameter is ignored on
			x		Windows platforms. On Unix platforms, the default value is the
			x		first item in option "device" list.
			x		When using IxTclNetwork (new API) on Windows platform, if
			x		both tcl_server and ixnetwork_tcl_server
			x		are not specified, the default value is 127.0.0.1. If
			x		ixnetwork_tcl_server is present, the default value is equal to
			x		ixnetwork_tcl_server and if this fails it will fallback to the value
			x		of the first item in option "device" list.
			x		When using IxTclNetwork (new API) on Unix platform, if
			x		tcl_server is not specified, the default value is equal to
			x		ixnetwork_tcl_server. This means that, on Unix, if tcl_server is
			x		not specified, then ixnetwork_tcl_server must be specified.
			x		Ixia now supports IPv6 address which can be given as [ipv6address]:port or
			x		for ex: [FF02::2:2]:8009.
			 	-username
			 		Username for logging on to the chassis.
			 		 This parameter is ignored when using IxTclNetwork (new API). In this case,
			 		the username will be configured automatically at ::<namespace>::interface_config
			 		and will have the value 'IxNetwork/$(COMPUTERNAME)/$(USERNAME)'. 
			x	-mode
			x		This parameter depends on 'vport_list' and 'vport_count' parameters. More details
			x		are available in the description for parameter 'device'.
			x		This parameter is valid only when IxNetwork Tcl API is used.
			x		Valid choices are:
			x   		connect - (DEFAULT) connect virtual ports specified with 'vport_list' parameter tothe real ports specified with 'port_list' parameter.
			x   		disconnect - disconnect virtual ports specified with 'vport_list' parameter from the real ports they are currently connected to.
			x   		reconnect_ports - This mode will force reloading the port configuration on all used chassis ports by releasing all ports curently assigned and then connect them back with the same vport assignment.
This mode accepts no other arguments (any other argument in this mode will be ignored).
Valid only for IxTclNetwork. This mode is required when connecting to an IxNetwork configuration that uses PCPU traffic configuration for HL compatibility.

NOTE: <i>When this reload happens all the port configurations that are not present in IxNetwork will be lost (eg.: IxTclHal low level commands, HL commands using P HLTSET, HL commands using IxTclHal implementation).
</i>
			x   		save - save the current ixnetwork configuration (ixncfg) to the file specified with at least one of the parameters file_name or file_ixncfg.
			x	-vport_count
			x		More details are available in the description for parameter 'device'.
			x		This parameter is valid only when IxNetwork Tcl API is used and it configures
			x		the number of virtual ports to be created. When this parameter is specified
			x		the parameters 'device' , 'port_list', 'vport_list', 'mode' are ignored. The
			x		virtual port handles created are returned with 'vport_handle' key.
			x	-vport_list
			x		More details are available in the description for parameter 'device'.
			x		This parameter is valid only when IxNetwork Tcl API is used. When parameter
			x		'mode' is 'disconnect', the virtual ports specified will be disconnected from
			x		the real ports they are connected to. Parameters 'device' and 'port_list' are
			x		ignored. When parameter 'mode' is 'connect' parameters 'device' and 'port_list'
			x		are mandatory. The virtual ports specified with 'vport_list' will be connected
			x		to the real ports specified with 'port_list' and 'device'.
			x	-execution_timeout
			x		This is the timeout for each individual HLT command. Applies to all HLT commands.
			x		The setting is in seconds.
			x		Setting this setting to 60 it will mean that each command (ex: interface_config) must complete in under 60 seconds.
			x		If the command will last more than 60 seconds the command will be terminated by force.
			x		This flag can be used to guard against dead locks occurring in IxNetwork.
			x		Default is 0, meaning no execution timeout.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by ixiangpf commands.
			x		This applies to all HLT commands from the current session.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution. Individual item handles can still be retrieved
			x		using the protocol_info command with -mode handles.
			x		The default is 1, meaning all possible handles will be returned.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			n	-timeout
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-nobios
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-forceload
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                                                         value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                                                                            value:On status of failure, gives detailed information.
		Port in the form of c/l/p.
			 key:port_handle.$device.$port                                                                      value:Port in the form of c/l/p.
		List of virtual port handles.
			 key:vport_list                                                                                     value:List of virtual port handles.
		keyed list with the following keys "vport_list"
			 key:$port_handle.connect                                                                           value:keyed list with the following keys "vport_list"
		keyed list with the following keys "router_handles router_interface_handles.__parent interface_handles.__parent"
			 key:$port_handle.emulation_bfd_config                                                              value:keyed list with the following keys "router_handles router_interface_handles.__parent interface_handles.__parent"
		keyed list with the following keys "session_handles"
			 key:$port_handle.emulation_bfd_session_config                                                      value:keyed list with the following keys "session_handles"
		keyed list with the following keys "handles"
			 key:$port_handle.emulation_bgp_config                                                              value:keyed list with the following keys "handles"
		keyed list with the following keys "bgp_routes bgp_sites.__parent bgp_sites.__parent"
			 key:$port_handle.emulation_bgp_route_config                                                        value:keyed list with the following keys "bgp_routes bgp_sites.__parent bgp_sites.__parent"
		keyed list with the following keys "handle interface_handles"
			 key:$port_handle.emulation_cfm_config                                                              value:keyed list with the following keys "handle interface_handles"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_cfm_custom_tlv_config                                                   value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_cfm_links_config                                                        value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_cfm_md_meg_config                                                       value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_cfm_mip_mep_config                                                      value:keyed list with the following keys "handle"
		keyed list with the following keys "handle mac_range_handles.__parent"
			 key:$port_handle.emulation_cfm_vlan_config                                                         value:keyed list with the following keys "handle mac_range_handles.__parent"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_dhcp_config                                                             value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_dhcp_group_config                                                       value:keyed list with the following keys "handle"
		keyed list with the following keys "handle handle.dhcp_handle"
			 key:$port_handle.emulation_dhcp_server_config                                                      value:keyed list with the following keys "handle handle.dhcp_handle"
		keyed list with the following keys "information_oampdu_id event_notification_oampdu_id"
			 key:$port_handle.emulation_efm_config                                                              value:keyed list with the following keys "information_oampdu_id event_notification_oampdu_id"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_efm_org_var_config                                                      value:keyed list with the following keys "handle"
		keyed list with the following keys "router_handles interface_handles __parent.connected_interface_handles __parent.gre_interface_handles"
			 key:$port_handle.emulation_eigrp_config                                                            value:keyed list with the following keys "router_handles interface_handles __parent.connected_interface_handles __parent.gre_interface_handles"
		keyed list with the following keys "session_handles"
			 key:$port_handle.emulation_eigrp_route_config                                                      value:keyed list with the following keys "session_handles"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_igmp_config                                                             value:keyed list with the following keys "handle"
		keyed list with the following keys "handle source_handle"
			 key:$port_handle.emulation_igmp_group_config                                                       value:keyed list with the following keys "handle source_handle"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_isis_config                                                             value:keyed list with the following keys "handle"
		keyed list with the following keys "elem_handle version route_range stub.num_networks external.num_networks grid.connected_session__parent.row grid.connected_session__parent.col grid.connected_session.__parent.row grid.connected_session.__parent.col"
			 key:$port_handle.emulation_isis_topology_route_config                                              value:keyed list with the following keys "elem_handle version route_range stub.num_networks external.num_networks grid.connected_session__parent.row grid.connected_session__parent.col grid.connected_session.__parent.row grid.connected_session.__parent.col"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_lacp_link_config                                                        value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_ldp_config                                                              value:keyed list with the following keys "handle"
		keyed list with the following keys "lsp_handle lsp_intf lsp_vc_range_handles lsp_vc_ip_range_handles lsp_vc_mac_range_handles"
			 key:$port_handle.emulation_ldp_route_config                                                        value:keyed list with the following keys "lsp_handle lsp_intf lsp_vc_range_handles lsp_vc_ip_range_handles lsp_vc_mac_range_handles"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_mld_config                                                              value:keyed list with the following keys "handle"
		keyed list with the following keys "handle group_pool_handle source_pool_handles"
			 key:$port_handle.emulation_mld_group_config                                                        value:keyed list with the following keys "handle group_pool_handle source_pool_handles"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_oam_config_msg                                                          value:keyed list with the following keys "handle"
		keyed list with the following keys "handle traffic_handles"
			 key:$port_handle.emulation_oam_config_topology                                                     value:keyed list with the following keys "handle traffic_handles"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_ospf_config                                                             value:keyed list with the following keys "handle"
		keyed list with the following keys "elem_handle"
			 key:$port_handle.emulation_ospf_topology_route_config                                              value:keyed list with the following keys "elem_handle"
		keyed list with the following keys "handle interface_handles"
			 key:$port_handle.emulation_pbb_config                                                              value:keyed list with the following keys "handle interface_handles"
		keyed list with the following keys "trunk_handle mr_handle"
			 key:$port_handle.emulation_pbb_trunk_config                                                        value:keyed list with the following keys "trunk_handle mr_handle"
		keyed list with the following keys "handle interfaces"
			 key:$port_handle.emulation_pim_config                                                              value:keyed list with the following keys "handle interfaces"
		keyed list with the following keys "handle group_pool_handle source_pool_handles"
			 key:$port_handle.emulation_pim_group_config                                                        value:keyed list with the following keys "handle group_pool_handle source_pool_handles"
		keyed list with the following keys "handle handle"
			 key:$port_handle.emulation_rip_config                                                              value:keyed list with the following keys "handle handle"
		keyed list with the following keys "route_handle"
			 key:$port_handle.emulation_rip_route_config                                                        value:keyed list with the following keys "route_handle"
		keyed list with the following keys "handles router_interface_handle.__parent"
			 key:$port_handle.emulation_rsvp_config                                                             value:keyed list with the following keys "handles router_interface_handle.__parent"
		keyed list with the following keys "tunnel_handle tunnel_leaves_handle.__parent/ingress routed_interfaces.__parent/ingress tunnel_leaves_handle.__parent"
			 key:$port_handle.emulation_rsvp_tunnel_config                                                      value:keyed list with the following keys "tunnel_handle tunnel_leaves_handle.__parent/ingress routed_interfaces.__parent/ingress tunnel_leaves_handle.__parent"
		keyed list with the following keys "bridge_handle bridge_interface_handles.__parent interface_handles.__parent"
			 key:$port_handle.emulation_stp_bridge_config                                                       value:keyed list with the following keys "bridge_handle bridge_interface_handles.__parent interface_handles.__parent"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_stp_msti_config                                                         value:keyed list with the following keys "handle"
		keyed list with the following keys "interface_handle routed_interface_handle gre_interface_handle"
			 key:$port_handle.interface_config                                                                  value:keyed list with the following keys "interface_handle routed_interface_handle gre_interface_handle"
		keyed list with the following keys "handles"
			 key:$port_handle.l2tp_config                                                                       value:keyed list with the following keys "handles"
		keyed list with the following keys "handles"
			 key:$port_handle.pppox_config                                                                      value:keyed list with the following keys "handles"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_twamp_config                                                            value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_twamp_control_range_config                                              value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_twamp_test_range_config                                                 value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_twamp_server_range_config                                               value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_ancp_config                                                             value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:$port_handle.emulation_ancp_subscriber_lines_config                                            value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:$port_handle.fc_client_config                                                                  value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:$port_handle.fc_fport_config                                                                   value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:$port_handle.fc_fport_vnport_config                                                            value:keyed list with the following keys "handle"
		a list having as elements the names of the existing traffic items (the name of the traffic item is normally returned when traffic_config creates a new traffic item by the stream_id key)
			 key:traffic_config                                                                                 value:a list having as elements the names of the existing traffic items (the name of the traffic item is normally returned when traffic_config creates a new traffic item by the stream_id key)
		keyed list with all the keys that the traffic_config procedure would return when configuring the $stream_id traffic item
			 key:$stream_id.traffic_config                                                                      value:keyed list with all the keys that the traffic_config procedure would return when configuring the $stream_id traffic item
		keyed list containing the vport protocols handle
			 key:vport_protocols_handle                                                                         value:keyed list containing the vport protocols handle
		The IxNetwork version found on client
			 key:connection.client_version                                                                      value:The IxNetwork version found on client
		The hostname of the chassis
			 key:connection.chassis.$device.hostname                                                            value:The hostname of the chassis
		The ip address of the chassis
			 key:connection.chassis.$device.ip                                                                  value:The ip address of the chassis
		The IxNetwork Protocols version found on the chassis
			 key:connection.chassis.$device.chassis_protocols_version                                           value:The IxNetwork Protocols version found on the chassis
		The type of the chassis
			 key:connection.chassis.$device.chassis_type                                                        value:The type of the chassis
		The IxOS version found on the chassis
			 key:connection.chassis.$device.chassis_version                                                     value:The IxOS version found on the chassis
		keyed list with the following keys "vport_list"
			 key:<port_handle>.connect                                                                          value:keyed list with the following keys "vport_list"
		keyed list with the following keys "router_handles router_interface_handles.<parent> interface_handles.<parent>". Where <parent> is an object of type /vport/protocols/bfd/router.
			 key:<port_handle>.emulation_bfd_config                                                             value:keyed list with the following keys "router_handles router_interface_handles.<parent> interface_handles.<parent>". Where <parent> is an object of type /vport/protocols/bfd/router.
		keyed list with the following keys "session_handles"
			 key:<port_handle>.emulation_bfd_session_config                                                     value:keyed list with the following keys "session_handles"
		keyed list with the following keys "handles"
			 key:<port_handle>.emulation_bgp_config                                                             value:keyed list with the following keys "handles"
		keyed list with the following keys "bgp_routes bgp_sites.<parent>". Where <parent> is an object of type /vport/protocols/bgp/neighborRange/l2Site, or /vport/protocols/bgp/neighborRange/l3Site.
			 key:<port_handle>.emulation_bgp_route_config                                                       value:keyed list with the following keys "bgp_routes bgp_sites.<parent>". Where <parent> is an object of type /vport/protocols/bgp/neighborRange/l2Site, or /vport/protocols/bgp/neighborRange/l3Site.
		keyed list with the following keys "handle interface_handles"
			 key:<port_handle>.emulation_cfm_config                                                             value:keyed list with the following keys "handle interface_handles"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_cfm_custom_tlv_config                                                  value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_cfm_links_config                                                       value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_cfm_md_meg_config                                                      value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_cfm_mip_mep_config                                                     value:keyed list with the following keys "handle"
		keyed list with the following keys "handle mac_range_handles.<parent>". Where <parent> is an object of type /vport/protocols/cfm/bridge/vlans.
			 key:<port_handle>.emulation_cfm_vlan_config                                                        value:keyed list with the following keys "handle mac_range_handles.<parent>". Where <parent> is an object of type /vport/protocols/cfm/bridge/vlans.
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_dhcp_config                                                            value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_dhcp_group_config                                                      value:keyed list with the following keys "handle"
		keyed list with the following keys "handle handle.dhcp_handle"
			 key:<port_handle>.emulation_dhcp_server_config                                                     value:keyed list with the following keys "handle handle.dhcp_handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.dhcp_client_extension_config                                                     value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.dhcp_server_extension_config                                                     value:keyed list with the following keys "handle"
		keyed list with the following keys "information_oampdu_id event_notification_oampdu_id"
			 key:<port_handle>.emulation_efm_config                                                             value:keyed list with the following keys "information_oampdu_id event_notification_oampdu_id"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_efm_org_var_config                                                     value:keyed list with the following keys "handle"
		keyed list with the following keys "router_handles interface_handles"
			 key:<port_handle>.emulation_eigrp_config                                                           value:keyed list with the following keys "router_handles interface_handles"
		keyed list with the following keys "uni_handles interface_handles uni_status_handles bw_profile_handles evc_handles ce_vlan_id_range_handles"
			 key:<port_handle>.emulation_elmi_config                                                            value:keyed list with the following keys "uni_handles interface_handles uni_status_handles bw_profile_handles evc_handles ce_vlan_id_range_handles"
		keyed list with the following keys "session_handles"
			 key:<port_handle>.emulation_eigrp_route_config                                                     value:keyed list with the following keys "session_handles"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_igmp_config                                                            value:keyed list with the following keys "handle"
		keyed list with the following keys "handle source_handle"
			 key:<port_handle>.emulation_igmp_group_config                                                      value:keyed list with the following keys "handle source_handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_isis_config                                                            value:keyed list with the following keys "handle"
		keyed list with the following keys "elem_handle version route_range stub.num_networks external.num_networks grid.connected_session<parent>.row grid.connected_session<parent>.col". Where <parent> is an object of type /vport/protocols/isis/router.
			 key:<port_handle>.emulation_isis_topology_route_config                                             value:keyed list with the following keys "elem_handle version route_range stub.num_networks external.num_networks grid.connected_session<parent>.row grid.connected_session<parent>.col". Where <parent> is an object of type /vport/protocols/isis/router.
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_lacp_link_config                                                       value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_ldp_config                                                             value:keyed list with the following keys "handle"
		keyed list with the following keys "lsp_handle lsp_intf lsp_vc_range_handles lsp_vc_ip_range_handles lsp_vc_mac_range_handles"
			 key:<port_handle>.emulation_ldp_route_config                                                       value:keyed list with the following keys "lsp_handle lsp_intf lsp_vc_range_handles lsp_vc_ip_range_handles lsp_vc_mac_range_handles"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_mld_config                                                             value:keyed list with the following keys "handle"
		keyed list with the following keys "handle group_pool_handle source_pool_handles"
			 key:<port_handle>.emulation_mld_group_config                                                       value:keyed list with the following keys "handle group_pool_handle source_pool_handles"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_oam_config_msg                                                         value:keyed list with the following keys "handle"
		keyed list with the following keys "handle traffic_handles"
			 key:<port_handle>.emulation_oam_config_topology                                                    value:keyed list with the following keys "handle traffic_handles"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_ospf_config                                                            value:keyed list with the following keys "handle"
		keyed list with the following keys "elem_handle"
			 key:<port_handle>.emulation_ospf_topology_route_config                                             value:keyed list with the following keys "elem_handle"
		keyed list with the following keys "handle interface_handles"
			 key:<port_handle>.emulation_pbb_config                                                             value:keyed list with the following keys "handle interface_handles"
		keyed list with the following keys "trunk_handle mr_handle"
			 key:<port_handle>.emulation_pbb_trunk_config                                                       value:keyed list with the following keys "trunk_handle mr_handle"
		keyed list with the following keys "handle interfaces"
			 key:<port_handle>.emulation_pim_config                                                             value:keyed list with the following keys "handle interfaces"
		keyed list with the following keys "handle group_pool_handle source_pool_handles"
			 key:<port_handle>.emulation_pim_group_config                                                       value:keyed list with the following keys "handle group_pool_handle source_pool_handles"
		keyed list with the following keys "handle handle"
			 key:<port_handle>.emulation_rip_config                                                             value:keyed list with the following keys "handle handle"
		keyed list with the following keys "route_handle"
			 key:<port_handle>.emulation_rip_route_config                                                       value:keyed list with the following keys "route_handle"
		keyed list with the following keys "handles"
			 key:<port_handle>.emulation_rsvp_config                                                            value:keyed list with the following keys "handles"
		keyed list with the following keys "tunnel_handle tunnel_leaves_handle.<parent>/ingress tunnel_leaves_handle.<parent>". Where <parent> is an object of type /vport/protocols/rsvp/neighborPair/destinationRange.
			 key:<port_handle>.emulation_rsvp_tunnel_config                                                     value:keyed list with the following keys "tunnel_handle tunnel_leaves_handle.<parent>/ingress tunnel_leaves_handle.<parent>". Where <parent> is an object of type /vport/protocols/rsvp/neighborPair/destinationRange.
		keyed list with the following keys "bridge_handle bridge_interface_handles.<parent> interface_handles.<parent>". Where <parent> is an object of type /vport/protocols/stp/bridge.
			 key:<port_handle>.emulation_stp_bridge_config                                                      value:keyed list with the following keys "bridge_handle bridge_interface_handles.<parent> interface_handles.<parent>". Where <parent> is an object of type /vport/protocols/stp/bridge.
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_stp_msti_config                                                        value:keyed list with the following keys "handle"
		keyed list with the following keys "interface_handle routed_interface_handle gre_interface_handle"
			 key:<port_handle>.interface_config                                                                 value:keyed list with the following keys "interface_handle routed_interface_handle gre_interface_handle"
		keyed list with the following keys "handles"
			 key:<port_handle>.l2tp_config                                                                      value:keyed list with the following keys "handles"
		keyed list with the following keys "handles"
			 key:<port_handle>.pppox_config                                                                     value:keyed list with the following keys "handles"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_twamp_config                                                           value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_twamp_control_range_config                                             value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_twamp_test_range_config                                                value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_twamp_server_range_config                                              value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_ancp_config                                                            value:keyed list with the following keys "handle"
		keyed list with the following keys "handle". These profiles are used on <port_handle>
			 key:<port_handle>.emulation_ancp_subscriber_lines_config                                           value:keyed list with the following keys "handle". These profiles are used on <port_handle>
		keyed list with the following keys "handle". These profiles are present in the configuration
			 key:globals.emulation_ancp_subscriber_lines_config                                                 value:keyed list with the following keys "handle". These profiles are present in the configuration
		keyed list with the following keys "handle"
			 key:<port_handle>.fc_client_config                                                                 value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.fc_fport_config                                                                  value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.fc_fport_vnport_config                                                           value:keyed list with the following keys "handle"
		keyed list with all the keys that the traffic_config procedure would return when configuring the $stream_id traffic item
			 key:<stream_id>.traffic_config                                                                     value:keyed list with all the keys that the traffic_config procedure would return when configuring the $stream_id traffic item
		keyed list with the following keys "num_groups ip_addr_start ip_addr_step ip_prefix_len"
			 key:emulation_multicast_group_config                                                               value:keyed list with the following keys "num_groups ip_addr_start ip_addr_step ip_prefix_len"
		keyed list with the following keys "num_sources ip_addr_start ip_addr_step ip_prefix_len"
			 key:emulation_multicast_source_config                                                              value:keyed list with the following keys "num_sources ip_addr_start ip_addr_step ip_prefix_len"
		Boolean value indicating if the IxNetwork process was started using tcl proxy feature of not
			 key:connection.using_tcl_proxy                                                                     value:Boolean value indicating if the IxNetwork process was started using tcl proxy feature of not
		this is the PID of the IxNetwork process
			 key:connection.process_id                                                                          value:this is the PID of the IxNetwork process
		id of the Tcl Proxy session [used for join/resume functionality]
			 key:connection.session_id                                                                          value:id of the Tcl Proxy session [used for join/resume functionality]
		name of the user owning the IxNetwork instance
			 key:connection.tcl_proxy_username                                                                  value:name of the user owning the IxNetwork instance
		The IxNetwork version found on server
			 key:connection.server_version                                                                      value:The IxNetwork version found on server
		TCL server port of the IxNetwork instance
			 key:connection.port                                                                                value:TCL server port of the IxNetwork instance
		Boolean value indicating if the IxN process was started using RDP feature of not
			 key:connection.rdp                                                                                 value:Boolean value indicating if the IxN process was started using RDP feature of not
		ENUM, current state of the process
			 key:connection.state                                                                               value:ENUM, current state of the process
		IxNetwork proxy start time
			 key:connection.start_time                                                                          value:IxNetwork proxy start time
		Hostname of the IxNetwork server
			 key:connection.hostname                                                                            value:Hostname of the IxNetwork server
		Username of the IxNetwork server
			 key:connection.username                                                                            value:Username of the IxNetwork server
		Boolean value indicating if the "ixNet disconnect" call will also shutdown IxNetwork process
			 key:connection.close_server_on_disconnect                                                          value:Boolean value indicating if the "ixNet disconnect" call will also shutdown IxNetwork process
		a list of traffic item handles of the existing L47 AppLib traffic items
			 key:traffic_l47_config.traffic_l47_handle                                                          value:a list of traffic item handles of the existing L47 AppLib traffic items
		a list of all the applib profiles under the <traffic_l47_handle>. Where <traffic_l47_handle> is an object of type /traffic/trafficItem.
			 key:traffic_l47_config.<traffic_l47_handle>.applib_profile                                         value:a list of all the applib profiles under the <traffic_l47_handle>. Where <traffic_l47_handle> is an object of type /traffic/trafficItem.
		a list of flows existing under the <applib_profile>. Where <applib_profile> is an object of type /traffic/trafficItem/appLibProfile.
			 key:traffic_l47_config.<traffic_l47_handle>.<applib_profile>.applib_flow                           value:a list of flows existing under the <applib_profile>. Where <applib_profile> is an object of type /traffic/trafficItem/appLibProfile.
		a list of parameters existing under the <applib_flow>. Where the <applib_flow> is an object of type /traffic/trafficItem/appLibProfile/appLibFlow.
			 key:traffic_l47_config.<traffic_l47_handle>.<applib_profile>.<applib_flow>.parameter               value:a list of parameters existing under the <applib_flow>. Where the <applib_flow> is an object of type /traffic/trafficItem/appLibProfile/appLibFlow.
		a list of connections existing under the <applib_flow>. Where the <applib_flow> is an object of type /traffic/trafficItem/appLibProfile/appLibFlow.
			 key:traffic_l47_config.<traffic_l47_handle>.<applib_profile>.<applib_flow>.connection              value:a list of connections existing under the <applib_flow>. Where the <applib_flow> is an object of type /traffic/trafficItem/appLibProfile/appLibFlow.
		a list of parameters existing under the <connection>. Where the <connection> is an object of type /traffic/trafficItem/appLibProfile/appLibFlow/connection.
			 key:traffic_l47_config.<traffic_l47_handle>.<applib_profile>.<applib_flow>.<connection>.parameter  value:a list of parameters existing under the <connection>. Where the <connection> is an object of type /traffic/trafficItem/appLibProfile/appLibFlow/connection.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1. Coded versus functional specification.
		2. Once a vport_handle or port_handle is returned, the handle will not change if the
		virtual port is disconnected and connected to another real port.
		Example1: '::<namespace>::connect -device X -port_list 1/1'. This call returns the port handle 0/1/1
		and virtual port handle 0/1/1.
		'::<namespace>::connect -device Y -port_list 2/1 -vport_list 0/1/1 -mode connect'. This call returns
		the port_handle 0/1/1 and virtual port handle 0/1/1.
		Conclusion: even if the device and real port has changed, the port handle hasn't changed.
		Example2: '::<namespace>::connect -vport_count 1'. This call does not return a port handle but it returns
		the virtual port handle '0/0/1'.
		'::<namespace>::connect -device X -port_list 4/2 -vport_list 0/0/1'. This call returns port handle 0/0/1
		and virtual port handle 0/0/1.
		3. Session resume will be done only for the first ::<namespace>::connect call from the script. Subsequent
		calls will not perform session resume, even if -reset flag is not specified
		4. Available only for *NO HLTSET
		5. Only when HLT commands are executed locally (not sent to tclServer)
		6. The following protocols cannot be restored when the configuration is autodetected by
		HLT (not loaded from an config_file_hlt file)
		6.1 OAM - configurations done with emulation_oam_* procedures
		6.2 Multicast sources and group handles will not be available anymore. They need to be recreated
		6.3 Autogenerated protocols cannot be restored: DCBX, FcOE, FCF, ESMC (ESync)
		7. Port handles that were "shuffled" are not supported (e.g. port 0/2/1 is disconnected and reconnected to
		0/2/2; or vport 0/0/1 is created, then connected to 0/3/1). Port handle for ports that are connected
		will be $ch/$ca/$po. Port handles for unconnected ports will be 0/0/$vport_item (e.g. the third
		virtual port that is not connected will have handle 0/0/2)
		1. Coded versus functional specification.
		2. Once a vport_handle or port_handle is returned, the handle will not change if the virtual port is disconnected and connected to another real port.Example1: '::<namespace>::connect -device X -port_list 1/1'. This call returns the port handle 0/1/1 and virtual port handle 0/1/1.'::<namespace>::connect -device Y -port_list 2/1 -vport_list 0/1/1 -mode connect'. This call returns the port_handle 0/1/1 and virtual port handle 0/1/1. Conclusion: even if the device and real port has changed, the port handle hasn't changed.Example2: '::<namespace>::connect -vport_count 1'. This call does not return a port handle but it returns the virtual port handle '0/0/1'.'::<namespace>::connect -device X -port_list 4/2 -vport_list 0/0/1'. This call returns port handle 0/0/1 and virtual port handle 0/0/1.
		3. Session resume will be done only for the first ::<namespace>::connect call from the script. Subsequent calls will not perform session resume, even if -reset flag is not specified.
		4. Available only for *NO HLTSET
		5. Only when HLT commands are executed locally (not sent to tclServer)
		6. The following protocols cannot be restored when the configuration is autodetected byHLT (not loaded from an config_file_hlt file)
		6.1 OAM - configurations done with emulation_oam_* procedures
		6.2 Multicast sources and group handles will not be available anymore. They need to be recreated
		6.3 Autogenerated protocols cannot be restored: DCBX, FcOE, FCF, ESMC (ESync)
		7. Port handles that were "shuffled" are not supported (e.g. port 0/2/1 is disconnected and reconnected to 0/2/2; or vport 0/0/1 is created, then connected to 0/3/1). Port handle for ports that are connected will be $ch/$ca/$po. Port handles for unconnected ports will be 0/0/$vport_item (e.g. the third virtual port that is not connected will have handle 0/0/2)
		
		See Also:
		
		"""
		return self._run_keyword("connect", kwargs)

	def convert_porthandle_to_vport(self, **kwargs):
		""" Converts a port handle to vport
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: convert_porthandle_to_vport
			 	[-port_handle ANY]
		
		Arguments:
			 	-port_handle
			 		Port handle to convert
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, contains more information
			 key:log     value:If status is failure, contains more information
		a vport associated with the given port handle
			 key:handle  value:a vport associated with the given port handle 
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("convert_porthandle_to_vport", kwargs)

	def convert_portname_to_vport(self, **kwargs):
		""" Converts a port name to vport
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: convert_portname_to_vport
			 	[-port_name ANY]
		
		Arguments:
			 	-port_name
			 		Port name to convert
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, contains more information
			 key:log     value:If status is failure, contains more information
		a vport associated with the given port handle
			 key:handle  value:a vport associated with the given port handle 
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("convert_portname_to_vport", kwargs)

	def convert_vport_to_porthandle(self, **kwargs):
		""" Converts vport to port handle
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: convert_vport_to_porthandle
			 	[-vport ANY]
		
		Arguments:
			 	-vport
			 		Vport to convert
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, contains more information
			 key:log     value:If status is failure, contains more information
		a port handle associated with the given vport
			 key:handle  value:a port handle associated with the given vport
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("convert_vport_to_porthandle", kwargs)

	def dcbxrange_config(self, **kwargs):
		""" Performs dcbxrange configuration
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: dcbxrange_config
			x	[-mode                            ANY]
			x	[-parent_handle                   ANY]
			x	[-handle                          ANY]
			x	[-style                           ANY]
			x	[-chassis_id                      ANY]
			x	[-control_tlv_max_version         ANY]
			x	[-dcbx_enable                     ANY]
			x	[-dcbx_subtype                    ANY]
			x	[-dest_mac_address                ANY]
			x	[-enabled                         ANY]
			x	[-fast_init_enable                ANY]
			x	[-hold_time                       ANY]
			x	[-mac_range_count                 ANY]
			x	[-mac_range_enabled               ANY]
			x	[-mac_range_increment_by          ANY]
			x	[-mac_range_mac                   ANY]
			x	[-mac_range_mtu                   ANY]
			x	[-mac_range_name                  ANY]
			x	[-name                            ANY]
			x	[-oui                             ANY]
			x	[-port_id_interface_name          ANY]
			x	[-port_id_mac_address             ANY]
			x	[-port_id_sub_type                ANY]
			x	[-tx_delay                        ANY]
			x	[-tx_interval                     ANY]
			x	[-vlan_range_enabled              ANY]
			x	[-vlan_range_first_id             ANY]
			x	[-vlan_range_id_incr_mode         ANY]
			x	[-vlan_range_increment            ANY]
			x	[-vlan_range_increment_step       ANY]
			x	[-vlan_range_inner_enable         ANY]
			x	[-vlan_range_inner_first_id       ANY]
			x	[-vlan_range_inner_increment      ANY]
			x	[-vlan_range_inner_increment_step ANY]
			x	[-vlan_range_inner_priority       ANY]
			x	[-vlan_range_inner_tpid           ANY]
			x	[-vlan_range_inner_unique_count   ANY]
			x	[-vlan_range_name                 ANY]
			x	[-vlan_range_priority             ANY]
			x	[-vlan_range_tpid                 ANY]
			x	[-vlan_range_unique_count         ANY]
			x	[-vlan_range_vlan_id_info         ANY]
		
		Arguments:
			x	-mode
			x		The operation this command will execute
			x		Valid choices are:
			x   		create - creates and configures a new object
			x   		add - adds a child object to the one specified by the -handle param
			x   		modify - modified attributes on the given object by the -handle param
			x   		delete - deletes the object given by the -handle param
			x	-parent_handle
			x		The parent handle used for creating this object. Has the form: //vport
			x	-handle
			x		A handle returned via a ::<namespace>::dcbxrange_config command. This is used for mode modify
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x	-chassis_id
			x		Represents the chassis identification for the device that transmitted the LLDP frame. The receiving LLDP agent combines the Chassis ID and Port ID to represent the entity connected to the port where the frame was received.
			x		Chassis identification for the
			x		device that transmitted the LLDP frame.
			x	-control_tlv_max_version
			x		Highest DCBX protocol version supported by the system.
			x	-dcbx_enable
			x		Enable DCBX TLVs.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-dcbx_subtype
			x		Organizationally defined subtype.
			x		Valid choices are:
			x   		1 - Intel 1.0
			x   		2 - IEEE 1.01
			x   		3 - 802.1Qaz
			x	-dest_mac_address
			x		The destination MAC address value.
			x	-enabled
			x		Disabled ranges won't be configured nor validated.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fast_init_enable
			x		Enable fast initial retransmission.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-hold_time
			x		Multiplier to get actual TTL value used in an LLDPDU.
			x	-mac_range_count
			x		The total number of interfaces to be created for the range.
			x	-mac_range_enabled
			x		Disabled ranges won't be configured nor validated.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-mac_range_increment_by
			x		When a range of multiple MACs is created with this plugin, this value
			x		is the incrementor used to create the addresses in the range.
			x		This property is used in conjunction with 'MAC Address' as a base value.
			x		Incrementor used when the plugin creates a range of MACs.
			x	-mac_range_mac
			x		When a range of multiple MACs is created with this plugin, this value
			x		is the base value used to create the addresses in the range.
			x		This property is used in conjunction with 'Increment' as an incrementor.
			x		Base value used when the plugin creates a MAC address.
			x	-mac_range_mtu
			x		Maximum Transmission Unit.
			x		The largest packet that a given network medium can carry.
			x		Ethernet, for example, has a fixed MTU of 1500 bytes without and 9500 bytes with Jumbo frame support.
			x		ATM has a fixed MTU of 48 bytes and PPP has a negotiated MTU that is usually between 500 and 2000 bytes.
			x	-mac_range_name
			x		Name of range
			x	-name
			x		Name of range
			x	-oui
			x		The vendor identifier value.
			x	-port_id_interface_name
			x		Port identification for the device that sent the LLDP frame.
			x		Port identification for the device that sent the LLDP frame.
			x	-port_id_mac_address
			x		<pre />
			x	-port_id_sub_type
			x		<pre />
			x		Valid choices are:
			x   		0 - MAC Address
			x   		1 - Interface Name
			x	-tx_delay
			x		Minimum delay between successive LLDP packets.
			x	-tx_interval
			x		This parameter indicates the interval at which LLDP frames are transmitted on behalf of this LLDP agent.
			x	-vlan_range_enabled
			x		Disabled ranges won't be configured nor validated.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-vlan_range_first_id
			x		The first ID to be used for the first VLAN tag.
			x	-vlan_range_id_incr_mode
			x		Method used to increment VLAN IDs.
			x		May take the following values: 0 (First VLAN first), 1 (Last VLAN first), 2 (All).
			x		Valid choices are:
			x   		0 - Outer First
			x   		1 - Inner First
			x   		2 - All
			x	-vlan_range_increment
			x		Amount of increment per increment step for first VLAN. E.g. increment step = 10 and increment = 2 means increment VLAN ID by 2 for every 10 IPs
			x	-vlan_range_increment_step
			x		Frequency of first VLAN ID increment. E.g., value of 10 means increment VLAN ID once for every 10 IP addresses.
			x	-vlan_range_inner_enable
			x		Enable the inner VLAN.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-vlan_range_inner_first_id
			x		The first ID to be used for the inner VLAN tag.
			x	-vlan_range_inner_increment
			x		Amount of increment per increment step for Inner VLAN. E.g. increment step = 10 and increment = 2 means increment VLAN ID by 2 for every 10 IPs
			x	-vlan_range_inner_increment_step
			x		Frequency of inner VLAN ID increment. E.g., value of 10 means increment VLAN ID once for every 10 IP addresses.
			x	-vlan_range_inner_priority
			x		The 802.1Q priority to be used for the inner VLAN tag.
			x	-vlan_range_inner_tpid
			x		The TPID value in the inner VLAN Tag.
			x		Valid choices are:
			x   		0x8100 - 0x8100
			x   		0x88a8 - 0x88a8
			x   		0x9100 - 0x9100
			x   		0x9200 - 0x9200
			x   		0x9300 - 0x9300
			x	-vlan_range_inner_unique_count
			x		Number of unique inner VLAN IDs to use.
			x	-vlan_range_name
			x		Name of range
			x	-vlan_range_priority
			x		The 802.1Q priority to be used for the outer VLAN tag.
			x	-vlan_range_tpid
			x		The TPID value in the outer VLAN Tag.
			x		Valid choices are:
			x   		0x8100 - 0x8100
			x   		0x88a8 - 0x88a8
			x   		0x9100 - 0x9100
			x   		0x9200 - 0x9200
			x   		0x9300 - 0x9300
			x	-vlan_range_unique_count
			x		Number of unique first VLAN IDs to use.
			x	-vlan_range_vlan_id_info
			x		Contains extra VLANs
			x		Is a subelement of type: VlanIdInfo
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log      value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles  value:The returned handle(s) of the  config command.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("dcbxrange_config", kwargs)

	def dcbxrange_control(self, **kwargs):
		""" Perform control plane operations on an endpoint created by a ::<namespace>::dcbxrange_config command
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: dcbxrange_control
			x	[-handle ANY]
			x	[-action ANY]
		
		Arguments:
			x	-handle
			x		A handle returned via a ::<namespace>::dcbxrange_config command. This is the object on which the action will take place.
			x	-action
			x		Action to be executed.
			x		Valid choices are:
			x   		abort - abort all sessions on the same port with the target endpoint designated by -handle. The control is returned when the operation is completed.
			x   		abort_async - abort all sessions on the same port with the target endpoint designated by -handle. The control is returned immediately. The operation is executed in the background.
			x   		start - start and/or negotiate session for the target endpoint designated by -handle.
			x   		connect - start and/or negotiate session for the target endpoint designated by -handle.
			x   		stop - stop and/or release session for the target endpoint designated by -handle.
			x   		disconnect - stop and/or release session for the target endpoint designated by -handle.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status         value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log            value:Error message if command returns {status 0}
		The result(s) of the  control action.
			 key:inner_results  value:The result(s) of the  control action.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("dcbxrange_control", kwargs)

	def dcbxrange_stats(self, **kwargs):
		""" Retrieve statistics plane on an endpoint created by a ::<namespace>::dcbxrange_config command
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: dcbxrange_stats
			x	[-port_handle ANY]
		
		Arguments:
			x	-port_handle
			x		The port handle for which the dcbxrange stats need to be retrieved
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                       value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log                                                          value:Error message if command returns {status 0}
		Sessions Initiated
			 key:<port_handle>.gen.sessions_initiated                         value:Sessions Initiated
		Sessions Succeeded
			 key:<port_handle>.gen.sessions_succeeded                         value:Sessions Succeeded
		Sessions Failed
			 key:<port_handle>.gen.sessions_failed                            value:Sessions Failed
		DCBX Mismatches Detected
			 key:<port_handle>.gen.dcbx_mismatches_detected                   value:DCBX Mismatches Detected
		DCBX Invalid PDU
			 key:<port_handle>.gen.dcbx_invalid_pdu                           value:DCBX Invalid PDU
		LLDP Tx
			 key:<port_handle>.gen.lldp_tx                                    value:LLDP Tx
		LLDP Rx
			 key:<port_handle>.gen.lldp_rx                                    value:LLDP Rx
		LLDP Age Out Count
			 key:<port_handle>.gen.lldp_age_out_count                         value:LLDP Age Out Count
		LLDP Error Rx
			 key:<port_handle>.gen.lldp_error_rx                              value:LLDP Error Rx
		LLDP Unrecognized TLV Rx
			 key:<port_handle>.gen.lldp_unrecognized_tlv_rx                   value:LLDP Unrecognized TLV Rx
		LLDP Neighbor Count
			 key:<port_handle>.gen.lldp_neighbor_count                        value:LLDP Neighbor Count
		DCBX Tx
			 key:<port_handle>.gen.dcbx_tx                                    value:DCBX Tx
		DCBX Rx
			 key:<port_handle>.gen.dcbx_rx                                    value:DCBX Rx
		DCBX Control TLV Tx
			 key:<port_handle>.gen.dcbx_control_tlv_tx                        value:DCBX Control TLV Tx
		DCBX Control TLV Rx
			 key:<port_handle>.gen.dcbx_control_tlv_rx                        value:DCBX Control TLV Rx
		DCBX Priority Groups TLV Tx
			 key:<port_handle>.gen.dcbx_priority_groups_tlv_tx                value:DCBX Priority Groups TLV Tx
		DCBX Priority Groups TLV Rx
			 key:<port_handle>.gen.dcbx_priority_groups_tlv_rx                value:DCBX Priority Groups TLV Rx
		DCBX PFC TLV Tx
			 key:<port_handle>.gen.dcbx_pfc_tlv_tx                            value:DCBX PFC TLV Tx
		DCBX PFC TLV Rx
			 key:<port_handle>.gen.dcbx_pfc_tlv_rx                            value:DCBX PFC TLV Rx
		DCBX FCoE TLV Tx
			 key:<port_handle>.gen.dcbx_fcoe_tlv_tx                           value:DCBX FCoE TLV Tx
		DCBX FCoE TLV Rx
			 key:<port_handle>.gen.dcbx_fcoe_tlv_rx                           value:DCBX FCoE TLV Rx
		DCBX FCoE Logical Link Status TLV Tx
			 key:<port_handle>.gen.dcbx_fcoe_logical_link_status_tlv_tx       value:DCBX FCoE Logical Link Status TLV Tx
		DCBX FCoE Logical Link Status TLV Rx
			 key:<port_handle>.gen.dcbx_fcoe_logical_link_status_tlv_rx       value:DCBX FCoE Logical Link Status TLV Rx
		DCBX LAN Logical Link Status TLV Tx
			 key:<port_handle>.gen.dcbx_lan_logical_link_status_tlv_tx        value:DCBX LAN Logical Link Status TLV Tx
		DCBX LAN Logical Link Status TLV Rx
			 key:<port_handle>.gen.dcbx_lan_logical_link_status_tlv_rx        value:DCBX LAN Logical Link Status TLV Rx
		DCBX Customized TLV Tx
			 key:<port_handle>.gen.dcbx_customized_tlv_tx                     value:DCBX Customized TLV Tx
		DCBX Customized TLV Rx
			 key:<port_handle>.gen.dcbx_customized_tlv_rx                     value:DCBX Customized TLV Rx
		Port Name
			 key:<port_handle>.gen.port_name                                  value:Port Name
		DCBX Duplicate TLVs Received
			 key:<port_handle>.gen.dcbx_duplicate_tlvs_received               value:DCBX Duplicate TLVs Received
		DCBX Duplicate Apps Received
			 key:<port_handle>.gen.dcbx_duplicate_apps_received               value:DCBX Duplicate Apps Received
		LLDP Port Description TLV Tx
			 key:<port_handle>.gen.lldp_port_description_tlv_tx               value:LLDP Port Description TLV Tx
		LLDP Port Description TLV Rx
			 key:<port_handle>.gen.lldp_port_description_tlv_rx               value:LLDP Port Description TLV Rx
		LLDP System Name TLV Tx
			 key:<port_handle>.gen.lldp_system_name_tlv_tx                    value:LLDP System Name TLV Tx
		LLDP System Name TLV Rx
			 key:<port_handle>.gen.lldp_system_name_tlv_rx                    value:LLDP System Name TLV Rx
		LLDP System Description TLV Tx
			 key:<port_handle>.gen.lldp_system_description_tlv_tx             value:LLDP System Description TLV Tx
		LLDP System Description TLV Rx
			 key:<port_handle>.gen.lldp_system_description_tlv_rx             value:LLDP System Description TLV Rx
		LLDP Management Address TLV Tx
			 key:<port_handle>.gen.lldp_management_address_tlv_tx             value:LLDP Management Address TLV Tx
		LLDP Management Address TLV Rx
			 key:<port_handle>.gen.lldp_management_address_tlv_rx             value:LLDP Management Address TLV Rx
		LLDP Organizationally Specific TLV Tx
			 key:<port_handle>.gen.lldp_organizationally_specific_tlv_tx      value:LLDP Organizationally Specific TLV Tx
		LLDP Organizationally Specific TLV Rx
			 key:<port_handle>.gen.lldp_organizationally_specific_tlv_rx      value:LLDP Organizationally Specific TLV Rx
		DCBX NIV TLV Tx
			 key:<port_handle>.gen.dcbx_niv_tlv_tx                            value:DCBX NIV TLV Tx
		DCBX NIV TLV Rx
			 key:<port_handle>.gen.dcbx_niv_tlv_rx                            value:DCBX NIV TLV Rx
		DCBX 802.1Qaz ETS Configuration TLV Tx
			 key:<port_handle>.gen.dcbx_802_1qaz_ets_configuration_tlv_tx     value:DCBX 802.1Qaz ETS Configuration TLV Tx
		DCBX 802.1Qaz ETS Configuration TLV Rx
			 key:<port_handle>.gen.dcbx_802_1qaz_ets_configuration_tlv_rx     value:DCBX 802.1Qaz ETS Configuration TLV Rx
		DCBX 802.1Qaz ETS Recommendation TLV Tx
			 key:<port_handle>.gen.dcbx_802_1qaz_ets_recommendation_tlv_tx    value:DCBX 802.1Qaz ETS Recommendation TLV Tx
		DCBX 802.1Qaz ETS Recommendation TLV Rx
			 key:<port_handle>.gen.dcbx_802_1qaz_ets_recommendation_tlv_rx    value:DCBX 802.1Qaz ETS Recommendation TLV Rx
		DCBX 802.1Qaz PFC TLV Tx
			 key:<port_handle>.gen.dcbx_802_1qaz_pfc_tlv_tx                   value:DCBX 802.1Qaz PFC TLV Tx
		DCBX 802.1Qaz PFC TLV Rx
			 key:<port_handle>.gen.dcbx_802_1qaz_pfc_tlv_rx                   value:DCBX 802.1Qaz PFC TLV Rx
		DCBX 802.1Qaz Application Priority TLV Tx
			 key:<port_handle>.gen.dcbx_802_1qaz_application_priority_tlv_tx  value:DCBX 802.1Qaz Application Priority TLV Tx
		DCBX 802.1Qaz Application Priority TLV Rx
			 key:<port_handle>.gen.dcbx_802_1qaz_application_priority_tlv_rx  value:DCBX 802.1Qaz Application Priority TLV Rx
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("dcbxrange_stats", kwargs)

	def dcbxtlvqaz_config(self, **kwargs):
		""" Performs dcbxtlvqaz configuration
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: dcbxtlvqaz_config
			x	[-mode                                                        ANY]
			x	[-parent_handle                                               ANY]
			x	[-handle                                                      ANY]
			x	[-style                                                       ANY]
			x	[-enabled                                                     ANY]
			x	[-feature_type                                                ANY]
			x	[-name                                                        ANY]
			x	[-tlv_settings_dcbx_tlv_app_qaz                               ANY]
			x	[-tlv_settings_dcbx_tlv_app_qaz_dcbx_app_priority_att         ANY]
			x	[-tlv_settings_dcbx_tlv_bcn                                   ANY]
			x	[-tlv_settings_dcbx_tlv_bcn_feature_tlv                       ANY]
			x	[-tlv_settings_dcbx_tlv_custom                                ANY]
			x	[-tlv_settings_dcbx_tlv_custom_feature_tlv                    ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz                               ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_cbs                           ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_max_tcs                       ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_tc_group_bw_percent_map       ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_tc_group_priority_map         ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_tc_group_tsa_map              ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_tlv_send_order                ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_tlv_send_restriction          ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_willing                       ANY]
			x	[-tlv_settings_dcbx_tlv_fcoe_ieee                             ANY]
			x	[-tlv_settings_dcbx_tlv_fcoe_ieee_application_protocol_id     ANY]
			x	[-tlv_settings_dcbx_tlv_fcoe_ieee_dcbx_app_protocol_att       ANY]
			x	[-tlv_settings_dcbx_tlv_fcoe_ieee_priority_map                ANY]
			x	[-tlv_settings_dcbx_tlv_fcoe_intel                            ANY]
			x	[-tlv_settings_dcbx_tlv_fcoe_intel_priority_map               ANY]
			x	[-tlv_settings_dcbx_tlv_logical_link                          ANY]
			x	[-tlv_settings_dcbx_tlv_logical_link_logical_link_status      ANY]
			x	[-tlv_settings_dcbx_tlv_niv_ieee                              ANY]
			x	[-tlv_settings_dcbx_tlv_niv_ieee_control_vif_id               ANY]
			x	[-tlv_settings_dcbx_tlv_niv_intel                             ANY]
			x	[-tlv_settings_dcbx_tlv_niv_intel_control_vif_id              ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_ieee                              ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_ieee_priority_map                 ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_ieee_tcs_supported                ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_intel                             ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_intel_priority_map                ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_qaz                               ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_qaz_mbc                           ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_qaz_pfc_capability                ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_qaz_pfc_enable_vector             ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_qaz_willing                       ANY]
			x	[-tlv_settings_dcbx_tlv_pg_ieee                               ANY]
			x	[-tlv_settings_dcbx_tlv_pg_ieee_priority_group_id_map         ANY]
			x	[-tlv_settings_dcbx_tlv_pg_ieee_priority_group_percentage_map ANY]
			x	[-tlv_settings_dcbx_tlv_pg_ieee_tcs_supported                 ANY]
			x	[-tlv_settings_dcbx_tlv_pg_intel                              ANY]
			x	[-tlv_settings_dcbx_tlv_pg_intel_bw_group_percentage_map      ANY]
			x	[-tlv_settings_dcbx_tlv_pg_intel_dcbx_bandwidth_att           ANY]
		
		Arguments:
			x	-mode
			x		The operation this command will execute
			x		Valid choices are:
			x   		create - creates and configures a new object
			x   		add - adds a child object to the one specified by the -handle param
			x   		modify - modified attributes on the given object by the -handle param
			x   		delete - deletes the object given by the -handle param
			x	-parent_handle
			x		The parent handle used for creating this object. Has the form: /vport/protocolStack/ethernet/dcbxEndpoint/range/dcbxRange
			x	-handle
			x		A handle returned via a ::<namespace>::dcbxtlvqaz_config command. This is used for mode modify
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x	-enabled
			x		Specifies if this TLV is used in the configuration.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-feature_type
			x		Type code of the DCB Feature.
			x		The codes translate to:
			x		2 - Priority Group
			x		3 - PFC
			x		4 - Application (IEEE 1.01) / Custom(BCN) (Intel 1.0)
			x		5 - Custom (IEEE 1.01) / FCoE (Intel 1.0)
			x		6 - Custom (IEEE 1.01) / Logical Link (Intel 1.0)
			x		7 - NIV
			x		8 - Custom (IEEE 1.01 / Intel 1.0)
			x		9/10 - Custom (IEEE 1.01 / Intel 1.0) / ETS Configuration/Recommendation (802.1Qaz)
			x		11 - Custom (IEEE 1.01 / Intel 1.0) / PFC (802.1Qaz)
			x		12 - Custom (IEEE 1.01 / Intel 1.0) / Application Priority (802.1Qaz)
			x		13 to 127 - Custom (IEEE 1.01 / Intel 1.0)
			x	-name
			x		Name of TLV
			x	-tlv_settings_dcbx_tlv_app_qaz
			x		DCBX Application Priority TLV for 802.1Qaz.
			x		Is a subelement of type: DcbxTlvAppQaz
			x	-tlv_settings_dcbx_tlv_app_qaz_dcbx_app_priority_att
			x		Application Priority mapping for 802.1Qaz Application Priority TLV.
			x		Is a subelement of type: DcbxAppPriorityAttributes
			x	-tlv_settings_dcbx_tlv_bcn
			x		Custom DCBX BCN TLV.
			x		Is a subelement of type: DcbxTlvBcn
			x	-tlv_settings_dcbx_tlv_bcn_feature_tlv
			x		Custom feature TLV
			x	-tlv_settings_dcbx_tlv_custom
			x		Custom DCBX TLV.
			x		Is a subelement of type: DcbxTlvCustom
			x	-tlv_settings_dcbx_tlv_custom_feature_tlv
			x		Custom feature TLV
			x	-tlv_settings_dcbx_tlv_ets_qaz
			x		DCBX ETS Configuration/Recommendation TLV for 802.1Qaz.
			x		Is a subelement of type: DcbxTlvEtsQaz
			x	-tlv_settings_dcbx_tlv_ets_qaz_cbs
			x		Indicates whether the stationsupports credit-based shaper transmission selection algorithm or not.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-tlv_settings_dcbx_tlv_ets_qaz_max_tcs
			x		Number of traffic classes supported by device.
			x	-tlv_settings_dcbx_tlv_ets_qaz_tc_group_bw_percent_map
			x		Bandwidth percentage
			x	-tlv_settings_dcbx_tlv_ets_qaz_tc_group_priority_map
			x		<pre />
			x	-tlv_settings_dcbx_tlv_ets_qaz_tc_group_tsa_map
			x		Transmission selection algorithm
			x		Valid choices are:
			x   		0 - Strict Priority
			x   		1 - Credit Based Shaper
			x   		2 - Enhanced Transmission Selection
			x   		255 - Vendor Specific
			x	-tlv_settings_dcbx_tlv_ets_qaz_tlv_send_order
			x		The order in which the ETS Configuration/Recommendation TLVs are sent
			x		Valid choices are:
			x   		0 - Configuration First
			x   		1 - Recommendation First
			x	-tlv_settings_dcbx_tlv_ets_qaz_tlv_send_restriction
			x		Transmission selection algorithm
			x		Valid choices are:
			x   		3 - Both
			x   		1 - Configuration
			x   		2 - Recommendation
			x	-tlv_settings_dcbx_tlv_ets_qaz_willing
			x		Indicates whether this feature accepts its configuration from the peer or not.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-tlv_settings_dcbx_tlv_fcoe_ieee
			x		DCBX FCoE TLV for IEEE 1.01.
			x		Is a subelement of type: DcbxTlvFcoeIeee
			x	-tlv_settings_dcbx_tlv_fcoe_ieee_application_protocol_id
			x		Identifies protocol supported by DCB node.
			x		Valid choices are:
			x   		35078 - FCoE (0x8906)
			x   		35092 - FIP (0x8914)
			x   		0 - Other
			x	-tlv_settings_dcbx_tlv_fcoe_ieee_dcbx_app_protocol_att
			x		Application Protocol Id
			x		Is a subelement of type: DcbxAppProtocolIdAttributes
			x	-tlv_settings_dcbx_tlv_fcoe_ieee_priority_map
			x		<pre />
			x	-tlv_settings_dcbx_tlv_fcoe_intel
			x		DCBX FCoE TLV for Intel 1.0.
			x		Is a subelement of type: DcbxTlvFcoeIntel
			x	-tlv_settings_dcbx_tlv_fcoe_intel_priority_map
			x		<pre />
			x	-tlv_settings_dcbx_tlv_logical_link
			x		Logical link status DCBX TLV for Intel 1.0.
			x		Is a subelement of type: DcbxTlvLogicalLink
			x	-tlv_settings_dcbx_tlv_logical_link_logical_link_status
			x		Signifies whether the Logical Link Status of the network is up or not.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-tlv_settings_dcbx_tlv_niv_ieee
			x		DCBX Network Interface Virtualization TLV for IEEE 1.01.
			x		Is a subelement of type: DcbxTlvNivIeee
			x	-tlv_settings_dcbx_tlv_niv_ieee_control_vif_id
			x		Control Channel VIF-ID
			x	-tlv_settings_dcbx_tlv_niv_intel
			x		DCBX Network Interface Virtualization TLV for Intel 1.0.
			x		Is a subelement of type: DcbxTlvNivIntel
			x	-tlv_settings_dcbx_tlv_niv_intel_control_vif_id
			x		Control Channel VIF-ID
			x	-tlv_settings_dcbx_tlv_pfc_ieee
			x		DCBX Priority Flow Control TLV for IEEE 1.01.
			x		Is a subelement of type: DcbxTlvPfcIeee
			x	-tlv_settings_dcbx_tlv_pfc_ieee_priority_map
			x		<pre />
			x	-tlv_settings_dcbx_tlv_pfc_ieee_tcs_supported
			x		Number of traffic classes supported by device.
			x	-tlv_settings_dcbx_tlv_pfc_intel
			x		DCBX Priority Flow Control TLV for Intel 1.0.
			x		Is a subelement of type: DcbxTlvPfcIntel
			x	-tlv_settings_dcbx_tlv_pfc_intel_priority_map
			x		<pre />
			x	-tlv_settings_dcbx_tlv_pfc_qaz
			x		DCBX Priority-based Flow Control Configuration TLV for 802.1Qaz.
			x		Is a subelement of type: DcbxTlvPfcQaz
			x	-tlv_settings_dcbx_tlv_pfc_qaz_mbc
			x		MACsec Bypass Capability Bit. Indicates whether the station is capable of bypassing MACsec when MACsec is disabled.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-tlv_settings_dcbx_tlv_pfc_qaz_pfc_capability
			x		How many traffic classes may simultaneously support PFC.
			x	-tlv_settings_dcbx_tlv_pfc_qaz_pfc_enable_vector
			x		enable/disable PFC for each priority.
			x	-tlv_settings_dcbx_tlv_pfc_qaz_willing
			x		Indicates whether this feature accepts its configuration from the peer or not.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-tlv_settings_dcbx_tlv_pg_ieee
			x		DCBX Priority Groups TLV for IEEE 1.01.
			x		Is a subelement of type: DcbxTlvPgIeee
			x	-tlv_settings_dcbx_tlv_pg_ieee_priority_group_id_map
			x		Priority group ID associated to each priority.
			x	-tlv_settings_dcbx_tlv_pg_ieee_priority_group_percentage_map
			x		Percentage associated to each priority group id.
			x	-tlv_settings_dcbx_tlv_pg_ieee_tcs_supported
			x		Number of traffic classes supported by device.
			x	-tlv_settings_dcbx_tlv_pg_intel
			x		DCBX Priority Groups TLV for Intel 1.0.
			x		Is a subelement of type: DcbxTlvPgIntel
			x	-tlv_settings_dcbx_tlv_pg_intel_bw_group_percentage_map
			x		Percentage associated to each bandwidth group id.
			x	-tlv_settings_dcbx_tlv_pg_intel_dcbx_bandwidth_att
			x		Bandwidth group attributes for Intel 1.0 Priority Groups TLV.
			x		Is a subelement of type: DcbxBandwidthGroupAttributes
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log      value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles  value:The returned handle(s) of the  config command.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("dcbxtlvqaz_config", kwargs)

	def dcbxtlv_config(self, **kwargs):
		""" Performs dcbxtlv configuration
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: dcbxtlv_config
			x	[-mode                                                        ANY]
			x	[-parent_handle                                               ANY]
			x	[-handle                                                      ANY]
			x	[-style                                                       ANY]
			x	[-enabled                                                     ANY]
			x	[-error                                                       ANY]
			x	[-error_override                                              ANY]
			x	[-feature_enable                                              ANY]
			x	[-feature_type                                                ANY]
			x	[-max_version                                                 ANY]
			x	[-name                                                        ANY]
			x	[-sub_type                                                    ANY]
			x	[-tlv_settings_dcbx_tlv_app_qaz                               ANY]
			x	[-tlv_settings_dcbx_tlv_app_qaz_dcbx_app_priority_att         ANY]
			x	[-tlv_settings_dcbx_tlv_bcn                                   ANY]
			x	[-tlv_settings_dcbx_tlv_bcn_feature_tlv                       ANY]
			x	[-tlv_settings_dcbx_tlv_custom                                ANY]
			x	[-tlv_settings_dcbx_tlv_custom_feature_tlv                    ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz                               ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_cbs                           ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_max_tcs                       ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_tc_group_bw_percent_map       ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_tc_group_priority_map         ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_tc_group_tsa_map              ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_tlv_send_order                ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_tlv_send_restriction          ANY]
			x	[-tlv_settings_dcbx_tlv_ets_qaz_willing                       ANY]
			x	[-tlv_settings_dcbx_tlv_fcoe_ieee                             ANY]
			x	[-tlv_settings_dcbx_tlv_fcoe_ieee_application_protocol_id     ANY]
			x	[-tlv_settings_dcbx_tlv_fcoe_ieee_dcbx_app_protocol_att       ANY]
			x	[-tlv_settings_dcbx_tlv_fcoe_ieee_priority_map                ANY]
			x	[-tlv_settings_dcbx_tlv_fcoe_intel                            ANY]
			x	[-tlv_settings_dcbx_tlv_fcoe_intel_priority_map               ANY]
			x	[-tlv_settings_dcbx_tlv_logical_link                          ANY]
			x	[-tlv_settings_dcbx_tlv_logical_link_logical_link_status      ANY]
			x	[-tlv_settings_dcbx_tlv_niv_ieee                              ANY]
			x	[-tlv_settings_dcbx_tlv_niv_ieee_control_vif_id               ANY]
			x	[-tlv_settings_dcbx_tlv_niv_intel                             ANY]
			x	[-tlv_settings_dcbx_tlv_niv_intel_control_vif_id              ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_ieee                              ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_ieee_priority_map                 ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_ieee_tcs_supported                ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_intel                             ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_intel_priority_map                ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_qaz                               ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_qaz_mbc                           ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_qaz_pfc_capability                ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_qaz_pfc_enable_vector             ANY]
			x	[-tlv_settings_dcbx_tlv_pfc_qaz_willing                       ANY]
			x	[-tlv_settings_dcbx_tlv_pg_ieee                               ANY]
			x	[-tlv_settings_dcbx_tlv_pg_ieee_priority_group_id_map         ANY]
			x	[-tlv_settings_dcbx_tlv_pg_ieee_priority_group_percentage_map ANY]
			x	[-tlv_settings_dcbx_tlv_pg_ieee_tcs_supported                 ANY]
			x	[-tlv_settings_dcbx_tlv_pg_intel                              ANY]
			x	[-tlv_settings_dcbx_tlv_pg_intel_bw_group_percentage_map      ANY]
			x	[-tlv_settings_dcbx_tlv_pg_intel_dcbx_bandwidth_att           ANY]
			x	[-willing                                                     ANY]
		
		Arguments:
			x	-mode
			x		The operation this command will execute
			x		Valid choices are:
			x   		create - creates and configures a new object
			x   		add - adds a child object to the one specified by the -handle param
			x   		modify - modified attributes on the given object by the -handle param
			x   		delete - deletes the object given by the -handle param
			x	-parent_handle
			x		The parent handle used for creating this object. Has the form: /vport/protocolStack/ethernet/dcbxEndpoint/range/dcbxRange
			x	-handle
			x		A handle returned via a ::<namespace>::dcbxtlv_config command. This is used for mode modify
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x	-enabled
			x		Specifies if this TLV is used in the configuration.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-error
			x		Indicates that an error has occurred during the configuration exchange with the peer.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-error_override
			x		True to override the error bit.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-feature_enable
			x		Indicates whether the DCB feature is enabled or not.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-feature_type
			x		Type code of the DCB Feature.
			x		The codes translate to:
			x		2 - Priority Group
			x		3 - PFC
			x		4 - Application (IEEE 1.01) / Custom(BCN) (Intel 1.0)
			x		5 - Custom (IEEE 1.01) / FCoE (Intel 1.0)
			x		6 - Custom (IEEE 1.01) / Logical Link (Intel 1.0)
			x		7 - NIV
			x		8 - Custom (IEEE 1.01 / Intel 1.0)
			x		9/10 - Custom (IEEE 1.01 / Intel 1.0) / ETS Configuration/Recommendation (802.1Qaz)
			x		11 - Custom (IEEE 1.01 / Intel 1.0) / PFC (802.1Qaz)
			x		12 - Custom (IEEE 1.01 / Intel 1.0) / Application Priority (802.1Qaz)
			x		13 to 127 - Custom (IEEE 1.01 / Intel 1.0)
			x	-max_version
			x		Highest feature version supported by the system.
			x	-name
			x		Name of TLV
			x	-sub_type
			x		Indicates specific types of network traffic.
			x	-tlv_settings_dcbx_tlv_app_qaz
			x		DCBX Application Priority TLV for 802.1Qaz.
			x		Is a subelement of type: DcbxTlvAppQaz
			x	-tlv_settings_dcbx_tlv_app_qaz_dcbx_app_priority_att
			x		Application Priority mapping for 802.1Qaz Application Priority TLV.
			x		Is a subelement of type: DcbxAppPriorityAttributes
			x	-tlv_settings_dcbx_tlv_bcn
			x		Custom DCBX BCN TLV.
			x		Is a subelement of type: DcbxTlvBcn
			x	-tlv_settings_dcbx_tlv_bcn_feature_tlv
			x		Custom feature TLV
			x	-tlv_settings_dcbx_tlv_custom
			x		Custom DCBX TLV.
			x		Is a subelement of type: DcbxTlvCustom
			x	-tlv_settings_dcbx_tlv_custom_feature_tlv
			x		Custom feature TLV
			x	-tlv_settings_dcbx_tlv_ets_qaz
			x		DCBX ETS Configuration/Recommendation TLV for 802.1Qaz.
			x		Is a subelement of type: DcbxTlvEtsQaz
			x	-tlv_settings_dcbx_tlv_ets_qaz_cbs
			x		Indicates whether the stationsupports credit-based shaper transmission selection algorithm or not.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-tlv_settings_dcbx_tlv_ets_qaz_max_tcs
			x		Number of traffic classes supported by device.
			x	-tlv_settings_dcbx_tlv_ets_qaz_tc_group_bw_percent_map
			x		Bandwidth percentage
			x	-tlv_settings_dcbx_tlv_ets_qaz_tc_group_priority_map
			x		<pre />
			x	-tlv_settings_dcbx_tlv_ets_qaz_tc_group_tsa_map
			x		Transmission selection algorithm
			x		Valid choices are:
			x   		0 - Strict Priority
			x   		1 - Credit Based Shaper
			x   		2 - Enhanced Transmission Selection
			x   		255 - Vendor Specific
			x	-tlv_settings_dcbx_tlv_ets_qaz_tlv_send_order
			x		The order in which the ETS Configuration/Recommendation TLVs are sent
			x		Valid choices are:
			x   		0 - Configuration First
			x   		1 - Recommendation First
			x	-tlv_settings_dcbx_tlv_ets_qaz_tlv_send_restriction
			x		Transmission selection algorithm
			x		Valid choices are:
			x   		3 - Both
			x   		1 - Configuration
			x   		2 - Recommendation
			x	-tlv_settings_dcbx_tlv_ets_qaz_willing
			x		Indicates whether this feature accepts its configuration from the peer or not.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-tlv_settings_dcbx_tlv_fcoe_ieee
			x		DCBX FCoE TLV for IEEE 1.01.
			x		Is a subelement of type: DcbxTlvFcoeIeee
			x	-tlv_settings_dcbx_tlv_fcoe_ieee_application_protocol_id
			x		Identifies protocol supported by DCB node.
			x		Valid choices are:
			x   		35078 - FCoE (0x8906)
			x   		35092 - FIP (0x8914)
			x   		0 - Other
			x	-tlv_settings_dcbx_tlv_fcoe_ieee_dcbx_app_protocol_att
			x		Application Protocol Id
			x		Is a subelement of type: DcbxAppProtocolIdAttributes
			x	-tlv_settings_dcbx_tlv_fcoe_ieee_priority_map
			x		<pre />
			x	-tlv_settings_dcbx_tlv_fcoe_intel
			x		DCBX FCoE TLV for Intel 1.0.
			x		Is a subelement of type: DcbxTlvFcoeIntel
			x	-tlv_settings_dcbx_tlv_fcoe_intel_priority_map
			x		<pre />
			x	-tlv_settings_dcbx_tlv_logical_link
			x		Logical link status DCBX TLV for Intel 1.0.
			x		Is a subelement of type: DcbxTlvLogicalLink
			x	-tlv_settings_dcbx_tlv_logical_link_logical_link_status
			x		Signifies whether the Logical Link Status of the network is up or not.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-tlv_settings_dcbx_tlv_niv_ieee
			x		DCBX Network Interface Virtualization TLV for IEEE 1.01.
			x		Is a subelement of type: DcbxTlvNivIeee
			x	-tlv_settings_dcbx_tlv_niv_ieee_control_vif_id
			x		Control Channel VIF-ID
			x	-tlv_settings_dcbx_tlv_niv_intel
			x		DCBX Network Interface Virtualization TLV for Intel 1.0.
			x		Is a subelement of type: DcbxTlvNivIntel
			x	-tlv_settings_dcbx_tlv_niv_intel_control_vif_id
			x		Control Channel VIF-ID
			x	-tlv_settings_dcbx_tlv_pfc_ieee
			x		DCBX Priority Flow Control TLV for IEEE 1.01.
			x		Is a subelement of type: DcbxTlvPfcIeee
			x	-tlv_settings_dcbx_tlv_pfc_ieee_priority_map
			x		<pre />
			x	-tlv_settings_dcbx_tlv_pfc_ieee_tcs_supported
			x		Number of traffic classes supported by device.
			x	-tlv_settings_dcbx_tlv_pfc_intel
			x		DCBX Priority Flow Control TLV for Intel 1.0.
			x		Is a subelement of type: DcbxTlvPfcIntel
			x	-tlv_settings_dcbx_tlv_pfc_intel_priority_map
			x		<pre />
			x	-tlv_settings_dcbx_tlv_pfc_qaz
			x		DCBX Priority-based Flow Control Configuration TLV for 802.1Qaz.
			x		Is a subelement of type: DcbxTlvPfcQaz
			x	-tlv_settings_dcbx_tlv_pfc_qaz_mbc
			x		MACsec Bypass Capability Bit. Indicates whether the station is capable of bypassing MACsec when MACsec is disabled.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-tlv_settings_dcbx_tlv_pfc_qaz_pfc_capability
			x		How many traffic classes may simultaneously support PFC.
			x	-tlv_settings_dcbx_tlv_pfc_qaz_pfc_enable_vector
			x		enable/disable PFC for each priority.
			x	-tlv_settings_dcbx_tlv_pfc_qaz_willing
			x		Indicates whether this feature accepts its configuration from the peer or not.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-tlv_settings_dcbx_tlv_pg_ieee
			x		DCBX Priority Groups TLV for IEEE 1.01.
			x		Is a subelement of type: DcbxTlvPgIeee
			x	-tlv_settings_dcbx_tlv_pg_ieee_priority_group_id_map
			x		Priority group ID associated to each priority.
			x	-tlv_settings_dcbx_tlv_pg_ieee_priority_group_percentage_map
			x		Percentage associated to each priority group id.
			x	-tlv_settings_dcbx_tlv_pg_ieee_tcs_supported
			x		Number of traffic classes supported by device.
			x	-tlv_settings_dcbx_tlv_pg_intel
			x		DCBX Priority Groups TLV for Intel 1.0.
			x		Is a subelement of type: DcbxTlvPgIntel
			x	-tlv_settings_dcbx_tlv_pg_intel_bw_group_percentage_map
			x		Percentage associated to each bandwidth group id.
			x	-tlv_settings_dcbx_tlv_pg_intel_dcbx_bandwidth_att
			x		Bandwidth group attributes for Intel 1.0 Priority Groups TLV.
			x		Is a subelement of type: DcbxBandwidthGroupAttributes
			x	-willing
			x		Indicates whether this feature accepts its configuration from the peer or not.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log      value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles  value:The returned handle(s) of the  config command.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("dcbxtlv_config", kwargs)

	def device_info(self, **kwargs):
		""" This command return informations about given ports. This procedure is implemented only on IxTclHal and IxTclProtocols.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: device_info
			 	[-fspec_version ANY]
			 	[-port_handle   ANY]
			 	[-ports         ANY]
		
		Arguments:
			 	-fspec_version
			 		0 - Do not return key fspec_version.1 - fspec_version key appear in return list.
			 	-port_handle
			 		Queries general information for modules/ports in the system, such as their availabilities and the interface types supported.
			 	-ports
			 		Request that the port name is returned from the port_handle. The port_handle can be supplied as a single handle or as multiple handles.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                               value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                  value:On status of failure, gives detailed information.
		version of Functional Specification used for this implementation.
			 key:fspec_version                        value:version of Functional Specification used for this implementation.
		return port type for available ports (without owner)
			 key:<device>.available.<port>.type       value:return port type for available ports (without owner)
		return port type for owned ports
			 key:<device>.inuse.<port>.type           value:return port type for owned ports
		show owner of ports in use
			 key:<device>.inuse.<port>.owner          value:show owner of ports in use
		name of port
			 key:port_handle.<port_handle>.port_name  value:name of port
		
		Examples:
		See the file Device_Info.tcl in the Samples subdirectory for a specific example of the usage of this command.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("device_info", kwargs)

	def dhcp_client_extension_config(self, **kwargs):
		""" Configures DHCPv6 client extension for the specified protocol stack
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: dhcp_client_extension_config
			x	-handle                                       ANY
			x	[-dhcp6_client_range_duid_enterprise_id       RANGE 1-2147483647
			x                                              DEFAULT 10]
			x	[-dhcp6_client_range_duid_type                CHOICES duid_en duid_llt duid_ll
			x                                              DEFAULT duid_llt]
			x	[-dhcp6_client_range_duid_vendor_id           RANGE 1-2147483647
			x                                              DEFAULT 10]
			x	[-dhcp6_client_range_duid_vendor_id_increment RANGE 1-2147483647
			x                                              DEFAULT 1]
			x	[-dhcp6_client_range_param_request_list       ANY]
			x	[-dhcp6_client_range_use_vendor_class_id      ANY]
			x	[-dhcp6_client_range_vendor_class_id          ANY]
			x	[-dhcp6_global_rel_max_rc                     RANGE 1-100
			x                                              DEFAULT 10]
			x	[-dhcp6_global_reb_max_rt                     RANGE 1-10000
			x                                              DEFAULT 30]
			x	[-dhcp6_global_reb_timeout                    RANGE 1-100
			x                                              DEFAULT 10]
			x	[-dhcp6_global_max_outstanding_requests       ANY]
			x	[-dhcp6_global_setup_rate_increment           ANY]
			x	[-dhcp6_global_setup_rate_initial             ANY]
			x	[-dhcp6_global_setup_rate_max                 ANY]
			x	[-dhcp6_pgdata_max_outstanding_requests       RANGE 1-100000
			x                                              DEFAULT 20]
			x	[-dhcp6_pgdata_override_global_setup_rate     CHOICES 0 1
			x                                              DEFAULT 0]
			x	[-dhcp6_pgdata_setup_rate_increment           ANY]
			x	[-dhcp6_pgdata_setup_rate_initial             RANGE 1-100000
			x                                              DEFAULT 10]
			x	[-dhcp6_pgdata_setup_rate_max                 ANY]
			x	[-dhcp6_pgdata_associates                     ANY]
			x	[-mode                                        CHOICES add
			x                                              CHOICES remove
			x                                              CHOICES enable
			x                                              CHOICES disable
			x                                              CHOICES modify
			x                                              DEFAULT add]
			x	[-dhcp6_global_echo_ia_info                   CHOICES 0 1
			x                                              DEFAULT 0]
			n	[-dhcp6_global_max_outstanding_releases       ANY]
			x	[-dhcp6_global_rel_timeout                    RANGE 1-100
			x                                              DEFAULT 1]
			x	[-dhcp6_global_ren_max_rt                     RANGE 1-10000
			x                                              DEFAULT 600]
			x	[-dhcp6_global_ren_timeout                    RANGE 1-100
			x                                              DEFAULT 10]
			x	[-dhcp6_global_req_max_rc                     RANGE 1-100
			x                                              DEFAULT 10]
			x	[-dhcp6_global_req_max_rt                     RANGE 1-10000
			x                                              DEFAULT 30]
			x	[-dhcp6_global_req_timeout                    RANGE 1-100
			x                                              DEFAULT 1]
			x	[-dhcp6_global_sol_max_rc                     RANGE 1-100
			x                                              DEFAULT 3]
			x	[-dhcp6_global_sol_max_rt                     RANGE 1-10000
			x                                              DEFAULT 120]
			x	[-dhcp6_global_sol_timeout                    RANGE 1-100
			x                                              DEFAULT 4]
			n	[-dhcp6_global_teardown_rate_increment        ANY]
			n	[-dhcp6_global_teardown_rate_initial          ANY]
			n	[-dhcp6_global_teardown_rate_max              ANY]
			n	[-dhcp6_global_wait_for_completion            ANY]
			x	[-dhcp6_pgdata_max_outstanding_releases       RANGE 1-100000
			x                                              DEFAULT 500]
			x	[-dhcp6_pgdata_override_global_teardown_rate  CHOICES 0 1
			x                                              DEFAULT 0]
			n	[-dhcp6_pgdata_teardown_rate_increment        ANY]
			x	[-dhcp6_pgdata_teardown_rate_initial          RANGE 1-100000
			x                                              DEFAULT 50]
			n	[-dhcp6_pgdata_teardown_rate_max              ANY]
		
		Arguments:
			x	-handle
			x		The protocol stack on top of which DHCpv6 client extension is to be
			x		created (for -mode add).
			x		The DHCpv6 client extension that needs to be modified/removed/enabled/disabled
			x		(for -mode modify/remove/enable/disable).
			x		When -handle is provided with the /globals value the arguments that configure global protocol
			x		setting accept both multivalue handles and simple values.
			x		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
			x		that configure global settings will only accept simple values. In this situation, these arguments will
			x		configure only the settings of the parent device group or the ports associated with the parent topology.
			x	-dhcp6_client_range_duid_enterprise_id
			x		Define the vendors registered Private Enterprise Number as maintained by IANA.
			x		Valid when dhcp6_client_range_duid_type is 'duid_en'.
			x	-dhcp6_client_range_duid_type
			x		Define the DHCP unique identifier type.
			x		Valid choices are:
			x   		duid_en - duid_en
			x   		duid_llt - (DEFAULT) duid_llt
			x   		duid_ll - duid_ll
			x	-dhcp6_client_range_duid_vendor_id
			x		Define the vendor-assigned unique ID for this range. This ID is incremented
			x		automatically for each DHCP client.
			x		Dependencies: Valid when dhcp6_client_range_duid_type is duid_en.
			x	-dhcp6_client_range_duid_vendor_id_increment
			x		Define the step to increment the vendor ID for each DHCP client.
			x		Dependencies: Valid when dhcp6_client_range_duid_type is duid_en.
			x	-dhcp6_client_range_param_request_list
			x		Accepts list of values. Define the list of options in a message between a client and a server. (DEFAULT = {2 7 23 24})
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_client_range_use_vendor_class_id
			x		Enable using vendor class id.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-dhcp6_client_range_vendor_class_id
			x		This option is used by a client to identify the vendor that manufactured the hardware on which the client is running. (DEFAULT = 'Ixia DHCP Client')Dependencies: Valid when dhcp6_client_range_use_vendor_class_id is 1.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_global_rel_max_rc
			x		RFC 3315 max request retry attempts.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x	-dhcp6_global_reb_max_rt
			x		RFC 3315 max request timeout value in secons.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x	-dhcp6_global_reb_timeout
			x		RFC 3315 initial request timeout value in secons.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x	-dhcp6_global_max_outstanding_requests
			x		The maximum number of requests to be sent by all DHCP clients during session startup. This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_global_setup_rate_increment
			x		This value represents the increment value for setup rate. This value is applied every second and can be negative. This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_global_setup_rate_initial
			x		Setup rate is the number of clients to start in each second. This value represents the initial value for setup rate. This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_global_setup_rate_max
			x		This value represents the final value for setup rate. The setup rate will not change after this value is reached. This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_max_outstanding_requests
			x		The maximum number of requests to be sent by all DHCP clients during session
			x		startup. This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or
			x		dual_stack.
			x	-dhcp6_pgdata_override_global_setup_rate
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter
			x		applies at the port level.
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role is
			x		access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_pgdata_setup_rate_increment
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'. Parameter dhcp6_pgdata_override_global_setup_rate is '1'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_setup_rate_initial
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter
			x		applies at the port level.
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x		is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x		Parameter dhcp6_pgdata_override_global_setup_rate is 1
			x	-dhcp6_pgdata_setup_rate_max
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'. Parameter dhcp6_pgdata_override_global_setup_rate is '1'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_associates
			x		This parameter refers to the DHCPv6 Client Port Group Data associates. This parameter applies at the port level. (DEFAULT = {})Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'. Parameter dhcp6_pgdata_override_global_teardown_rate is '1'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-mode
			x		The action to be performed: add, modify, remove, enable, disable.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		add -
			x   		remove -
			x   		enable -
			x   		disable -
			x   		modify -
			x	-dhcp6_global_echo_ia_info
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			n	-dhcp6_global_max_outstanding_releases
			x	-dhcp6_global_rel_timeout
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_global_ren_max_rt
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_global_ren_timeout
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_global_req_max_rc
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_global_req_max_rt
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_global_req_timeout
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_global_sol_max_rc
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_global_sol_max_rt
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_global_sol_timeout
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			n	-dhcp6_global_teardown_rate_increment
			n   	-dhcp6_global_teardown_rate_initial
			n       	-dhcp6_global_teardown_rate_max
			n           	-dhcp6_global_wait_for_completion
			x               	-dhcp6_pgdata_max_outstanding_releases
			x                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x               	-dhcp6_pgdata_override_global_teardown_rate
			x                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			n               	-dhcp6_pgdata_teardown_rate_increment
			x                   	-dhcp6_pgdata_teardown_rate_initial
			x                       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			n                   	-dhcp6_pgdata_teardown_rate_max
		                   
		                   Return Values:
		                       A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x                       key:handle   value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		                       $::SUCCESS | $::FAILURE
			                        key:status   value:$::SUCCESS | $::FAILURE
		                       <dhcpv6 client extension handles>
			                        key:handles  value:<dhcpv6 client extension handles>
		                       When status is failure, contains more information
			                        key:log      value:When status is failure, contains more information
		                   
		                   Examples:
		                       See files in the Samples/IxNetwork/DHCPv6 Client Extension subdirectory.
		                   
		                   Sample Input:
		                   
		                   Sample Output:
		                   
		                   Notes:
		                       When -handle is provided with the /globals value the arguments that configure global protocol
		                       setting accept both multivalue handles and simple values.
		                       When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
		                       that configure global settings will only accept simple values. In this situation, these arguments will
		                       configure only the settings of the parent device group or the ports associated with the parent topology.
		                       If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		                   
		                   See Also:
		                   
		"""
		return self._run_keyword("dhcp_client_extension_config", kwargs)

	def dhcp_extension_stats(self, **kwargs):
		""" Retrieves statistics for the DHCPv6PD sessions configured on thespecified test port.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: dhcp_extension_stats
			 	-mode         CHOICES aggregate session
			               DEFAULT aggregate
			 	[-port_handle REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle      ANY]
		
		Arguments:
			 	-mode
			 		Specifies statistics retrieval mode as either aggregate for all
			 		configured sessions or on a per session basis.
			 		Valid choices are:
			    		aggregate - Retrieve statistics for all the sessions.
			    		session - Retrieve dhcp client or dhcp server statistics per session
			 	-port_handle
			 		The port handle for which the DHCPv6 sessions statistics needs to be
			 		retrieved. Valid only when using IxNetwork.
			 	-handle
			 		The port for which the DHCPv6 sessions statistics needs to be
			 		retrieved. The statistics will be retrieved
			 		for the port where that handle belongs.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                            value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                                                               value:If status is failure, detailed information provided.
		The stats can be used with or without <port_handle>. These stats are only available with IxNetwork.
			 key:AGGREGATE STATS:                                                  value:The stats can be used with or without <port_handle>. These stats are only available with IxNetwork.
		Server Solicits Received
			 key:[<port_handle.>].aggregate.dhcpv6_solicits_received               value:Server Solicits Received
		Server Advertisements Sent
			 key:[<port_handle.>].aggregate.dhcpv6_advertisements_sent             value:Server Advertisements Sent
		Server Requests Received
			 key:[<port_handle.>].aggregate.dhcpv6_requests_received               value:Server Requests Received
		Server Confirms Received
			 key:[<port_handle.>].aggregate.dhcpv6_confirms_received               value:Server Confirms Received
		Server Renewals Received
			 key:[<port_handle.>].aggregate.dhcpv6_renewals_received               value:Server Renewals Received
		Server Rebinds Received
			 key:[<port_handle.>].aggregate.dhcpv6_rebinds_received                value:Server Rebinds Received
		Server Replies Sent
			 key:[<port_handle.>].aggregate.dhcpv6_replies_sent                    value:Server Replies Sent
		Server Releases Received
			 key:[<port_handle.>].aggregate.dhcpv6_releases_received               value:Server Releases Received
		Server Declines Received
			 key:[<port_handle.>].aggregate.dhcpv6_declines_received               value:Server Declines Received
		Server Information-Requests Received
			 key:[<port_handle.>].aggregate.dhcpv6_information_requests_received   value:Server Information-Requests Received
		Server Total Prefixes Allocated
			 key:[<port_handle.>].aggregate.dhcpv6_total_prefixes_allocated        value:Server Total Prefixes Allocated
		Server Total Prefixes Renewed
			 key:[<port_handle.>].aggregate.dhcpv6_total_prefixes_renewed          value:Server Total Prefixes Renewed
		Server Current Prefixes Allocated
			 key:[<port_handle.>].aggregate.dhcpv6_current_prefixes_allocated      value:Server Current Prefixes Allocated
		Client Addresses Discovered
			 key:[<port_handle.>].aggregate.dhcpv6_addresses_discovered            value:Client Addresses Discovered
		Client Advertisements Ignored
			 key:[<port_handle.>].aggregate.dhcpv6_advertisements_ignored          value:Client Advertisements Ignored
		Client Advertisements Received
			 key:[<port_handle.>].aggregate.dhcpv6_advertisements_received         value:Client Advertisements Received
		Client Enabled Interfaces
			 key:[<port_handle.>].aggregate.dhcpv6_enabled_interfaces              value:Client Enabled Interfaces
		Client Rebinds Sent
			 key:[<port_handle.>].aggregate.dhcpv6_rebinds_sent                    value:Client Rebinds Sent
		Client Releases Sent
			 key:[<port_handle.>].aggregate.dhcpv6_releases_sent                   value:Client Releases Sent
		Client Renews Sent
			 key:[<port_handle.>].aggregate.dhcpv6_renews_sent                     value:Client Renews Sent
		Client Replies Received
			 key:[<port_handle.>].aggregate.dhcpv6_replies_received                value:Client Replies Received
		Client Requests Sent
			 key:[<port_handle.>].aggregate.dhcpv6_requests_sent                   value:Client Requests Sent
		Client Sessions Failed
			 key:[<port_handle.>].aggregate.dhcpv6_sessions_failed                 value:Client Sessions Failed
		Client Sessions Initiated
			 key:[<port_handle.>].aggregate.dhcpv6_sessions_initiated              value:Client Sessions Initiated
		Client Sessions Succeeded
			 key:[<port_handle.>].aggregate.dhcpv6_sessions_succeeded              value:Client Sessions Succeeded
		Client Setup Success Rate
			 key:[<port_handle.>].aggregate.dhcpv6_setup_success_rate              value:Client Setup Success Rate
		Client Solicits Sent
			 key:[<port_handle.>].aggregate.dhcpv6_solicits_sent                   value:Client Solicits Sent
		Client Teardown Fail
			 key:[<port_handle.>].aggregate.dhcpv6_teardown_fail                   value:Client Teardown Fail
		Client Teardown Initiated
			 key:[<port_handle.>].aggregate.dhcpv6_teardown_initiated              value:Client Teardown Initiated
		Client Teardown Success
			 key:[<port_handle.>].aggregate.dhcpv6_teardown_success                value:Client Teardown Success
		Client Information Requests Sent
			 key:[<port_handle.>].aggregate.dhcpv6_information_requests_sent       value:Client Information Requests Sent
		Client Min Establishment Time
			 key:[<port_handle.>].aggregate.dhcpv6_min_establishment_time          value:Client Min Establishment Time
		Client Avg Establishment Time
			 key:[<port_handle.>].aggregate.dhcpv6_avg_establishment_time          value:Client Avg Establishment Time
		Client Max Establishment Time
			 key:[<port_handle.>].aggregate.dhcpv6_max_establishment_time          value:Client Max Establishment Time
		These stats are only available with IxNetwork.
			 key:SESSION STATS:                                                    value:These stats are only available with IxNetwork.
		Lease Name
			 key:session.server.<session ID>.dhcpv6_lease_name                     value:Lease Name
		Offer Count
			 key:session.server.<session ID>.dhcpv6_offer_count                    value:Offer Count
		Bind Count
			 key:session.server.<session ID>.dhcpv6_bind_count                     value:Bind Count
		Bind Rapid Commit Count
			 key:session.server.<session ID>.dhcpv6_bind_rapid_commit_count        value:Bind Rapid Commit Count
		Renew Count
			 key:session.server.<session ID>.dhcpv6_renew_count                    value:Renew Count
		Release Count
			 key:session.server.<session ID>.dhcpv6_release_count                  value:Release Count
		Information-Requests Received
			 key:session.server.<session ID>.dhcpv6_information_request_received   value:Information-Requests Received
		Replies Sent
			 key:session.server.<session ID>.dhcpv6_replies_sent                   value:Replies Sent
		Lease State
			 key:session.server.<session ID>.dhcpv6_lease_state                    value:Lease State
		Lease Address
			 key:session.server.<session ID>.dhcpv6_lease_address                  value:Lease Address
		Valid Time
			 key:session.server.<session ID>.dhcpv6_valid_time                     value:Valid Time
		Prefered Time
			 key:session.server.<session ID>.dhcpv6_prefered_time                  value:Prefered Time
		Renew Time
			 key:session.server.<session ID>.dhcpv6_renew_time                     value:Renew Time
		Rebind Time
			 key:session.server.<session ID>.dhcpv6_rebind_time                    value:Rebind Time
		Client ID
			 key:session.server.<session ID>.dhcpv6_client_id                      value:Client ID
		Remote ID
			 key:session.server.<session ID>.dhcpv6_remote_id                      value:Remote ID
		Session Name
			 key:session.client.<session ID>.dhcpv6_session_name                   value:Session Name
		Solicits Sent
			 key:session.client.<session ID>.dhcpv6_solicits_sent                  value:Solicits Sent
		Advertisements Received
			 key:session.client.<session ID>.dhcpv6_advertisements_received        value:Advertisements Received
		Advertisements Ignored
			 key:session.client.<session ID>.dhcpv6_advertisements_ignored         value:Advertisements Ignored
		Requests Sent
			 key:session.client.<session ID>.dhcpv6_requests_sent                  value:Requests Sent
		Replies Received
			 key:session.client.<session ID>.dhcpv6_replies_received               value:Replies Received
		Renews Sent
			 key:session.client.<session ID>.dhcpv6_renews_sent                    value:Renews Sent
		Rebinds Sent
			 key:session.client.<session ID>.dhcpv6_rebinds_sent                   value:Rebinds Sent
		Releases Sent
			 key:session.client.<session ID>.dhcpv6_releases_sent                  value:Releases Sent
		IP Prefix
			 key:session.client.<session ID>.dhcpv6_ip_prefix                      value:IP Prefix
		Gateway Address
			 key:session.client.<session ID>.dhcpv6_gateway_address                value:Gateway Address
		DNS Server List
			 key:session.client.<session ID>.dhcpv6_dns_server_list                value:DNS Server List
		Prefix Lease Time
			 key:session.client.<session ID>.dhcpv6_prefix_lease_time              value:Prefix Lease Time
		Information Requests Sent
			 key:session.client.<session ID>.dhcpv6_onformation_requests_sent      value:Information Requests Sent
		DNS Search List
			 key:session.client.<session ID>.dhcpv6_dns_search_list                value:DNS Search List
		Solicits w/ Rapid Commit Sent
			 key:session.client.<session ID>.dhcpv6_solicits_rapid_commit_sent     value:Solicits w/ Rapid Commit Sent
		Replies w/ Rapid Commit Received
			 key:session.client.<session ID>.dhcpv6_replies_rapid_commit_received  value:Replies w/ Rapid Commit Received
		Lease w/ Rapid Commit
			 key:session.client.<session ID>.dhcpv6_lease_rapid_commit             value:Lease w/ Rapid Commit
		Lease w/ Rapid Commit
			 key:session.client.<session ID>.dhcpv6_lease_rapid_commit             value:Lease w/ Rapid Commit                                  
		
		Examples:
		See files in the Samples/IxNetwork/L2TP subdirectory.
		
		Sample Input:
		.
		
		Sample Output:
		.
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("dhcp_extension_stats", kwargs)

	def dhcp_server_extension_config(self, **kwargs):
		""" Configures DHCPv6 server extension for the specified protocol stack
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: dhcp_server_extension_config
			x	-handle                                      ANY
			x	[-dhcp6_pgdata_max_outstanding_releases      ANY]
			x	[-dhcp6_pgdata_max_outstanding_requests      ANY]
			x	[-dhcp6_pgdata_override_global_setup_rate    ANY]
			x	[-dhcp6_pgdata_override_global_teardown_rate ANY]
			x	[-dhcp6_pgdata_setup_rate_increment          ANY]
			x	[-dhcp6_pgdata_setup_rate_initial            ANY]
			x	[-dhcp6_pgdata_setup_rate_max                ANY]
			x	[-dhcp6_pgdata_teardown_rate_increment       ANY]
			x	[-dhcp6_pgdata_teardown_rate_initial         ANY]
			x	[-dhcp6_pgdata_teardown_rate_max             ANY]
			x	[-dhcp6_server_range_dns_domain_search_list  ANY
			x                                             DEFAULT 100]
			x	[-dhcp6_server_range_first_dns_server        IP]
			x	[-dhcp6_server_range_second_dns_server       IP]
			x	[-dhcp6_server_range_subnet_prefix           NUMERIC]
			x	[-dhcp6_server_range_start_pool_address      IP]
			x	[-mode                                       CHOICES add
			x                                             CHOICES remove
			x                                             CHOICES enable
			x                                             CHOICES disable
			x                                             CHOICES modify
			x                                             DEFAULT add]
		
		Arguments:
			x	-handle
			x		The protocol stack on top of which DHCPv6 server extension is to be
			x		created (for -mode add).
			x		The DHCpv6 server extension that needs to be modified/removed/enabled/disabled
			x		(for -mode modify/remove/enable/disable).
			x		When -handle is provided with the /globals value the arguments that configure global protocol
			x		setting accept both multivalue handles and simple values.
			x		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
			x		that configure global settings will only accept simple values. In this situation, these arguments will
			x		configure only the settings of the parent device group or the ports associated with the parent topology.
			x	-dhcp6_pgdata_max_outstanding_releases
			x		The maximum number of requests to be sent by all DHCP clients during session teardown. This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_max_outstanding_requests
			x		The maximum number of requests to be sent by all DHCP clients during session startup. This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_override_global_setup_rate
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level.Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_override_global_teardown_rate
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level.Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_setup_rate_increment
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'. Parameter dhcp6_pgdata_override_global_setup_rate is '1'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_setup_rate_initial
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'. Parameter dhcp6_pgdata_override_global_setup_rate is '1'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_setup_rate_max
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'. Parameter dhcp6_pgdata_override_global_setup_rate is '1'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_teardown_rate_increment
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'. Parameter dhcp6_pgdata_override_global_teardown_rate is '1'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_teardown_rate_initial
			x		Description This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'. Parameter dhcp6_pgdata_override_global_teardown_rate is '1'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_teardown_rate_max
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'. Parameter dhcp6_pgdata_override_global_teardown_rate is '1'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_server_range_dns_domain_search_list
			x		Specifies the domain that the client will use when resolving host names with DNS.
			x	-dhcp6_server_range_first_dns_server
			x		The first DNS server associated with this address pool. This is the first DNS
			x		address that will be assigned to any client that is allocated an IP address from this
			x		pool.
			x	-dhcp6_server_range_second_dns_server
			x		The second DNS server associated with this address pool. This is the second (of
			x		two) DNS addresses that will be assigned to any client that is allocated an IP
			x		address from this pool.
			x	-dhcp6_server_range_subnet_prefix
			x		The prefix value used to subnet the addresses specified in the address pool. This
			x		is the subnet prefix length advertised in DHCPv6PD Offer and Reply messages.
			x	-dhcp6_server_range_start_pool_address
			x		The starting IPv6 address for this DHCPv6 address pool.
			x	-mode
			x		The action to be performed: add, modify, remove, enable, disable.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		add -
			x   		remove -
			x   		enable -
			x   		disable -
			x   		modify -
		
		Return Values:
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:handle   value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		<dhcpv6 server extension handles>
			 key:handles  value:<dhcpv6 server extension handles>
		When status is failure, contains more information
			 key:log      value:When status is failure, contains more information
		
		Examples:
		See files in the Samples/IxNetwork/DHCPv6 Client Extension subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		When -handle is provided with the /globals value the arguments that configure global protocol
		setting accept both multivalue handles and simple values.
		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
		that configure global settings will only accept simple values. In this situation, these arguments will
		configure only the settings of the parent device group or the ports associated with the parent topology.
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		
		See Also:
		
		"""
		return self._run_keyword("dhcp_server_extension_config", kwargs)

	def emulation_ancp_config(self, **kwargs):
		""" This procedure will configure ANCP devices on an Ixia port.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ancp_config
			x	[-access_aggregation                     ANY]
			x	[-access_aggregation_dsl_inner_vlan      ANY]
			x	[-access_aggregation_dsl_inner_vlan_type ANY]
			x	[-access_aggregation_dsl_outer_vlan      ANY]
			x	[-access_aggregation_dsl_outer_vlan_type ANY]
			x	[-access_aggregation_dsl_vci             ANY]
			x	[-access_aggregation_dsl_vpi             ANY]
			x	[-access_aggregation_dsl_vci_type        ANY]
			x	[-access_aggregation_dsl_vpi_type        ANY]
			 	[-ancp_standard                          CHOICES ietf-ancp-protocol5 rfc6320
			                                          DEFAULT rfc6320]
			x	[-circuit_id                             ANY]
			 	[-device_count                           ANY]
			x	[-distribution_alg_percentage            ANY]
			x	[-dsl_profile_capabilities               ANY]
			x	[-dsl_resync_profile_capabilities        ANY]
			 	[-encap_type                             ANY]
			 	[-events_per_interval                    ANY]
			 	[-gateway_ip_addr                        IPV4
			                                          DEFAULT 0.0.0.0]
			 	[-gateway_ip_prefix_len                  ANY]
			 	[-gateway_ip_step                        IPV4
			                                          DEFAULT 0.0.0.0]
			x	[-gateway_incr_mode                      ANY]
			x	[-global_port_down_rate_enabled          CHOICES 0 1]
			x	[-global_port_down_rate                  RANGE 1-10000
			x                                         DEFAULT 50]
			x	[-global_port_down_rate_interval         RANGE 1-65535
			x                                         DEFAULT 1000]
			x	[-global_port_down_rate_max_outstanding  RANGE 1-999999
			x                                         DEFAULT 400]
			x	[-global_port_down_rate_scale_mode       CHOICES port device_group
			x                                         DEFAULT port]
			x	[-global_port_up_rate_enabled            CHOICES 0 1]
			x	[-global_port_up_rate                    RANGE 1-10000
			x                                         DEFAULT 10]
			x	[-global_port_up_rate_interval           RANGE 1-65535
			x                                         DEFAULT 1000]
			x	[-global_port_up_rate_max_outstanding    RANGE 1-999999
			x                                         DEFAULT 400]
			x	[-global_port_up_rate_scale_mode         CHOICES port device_group
			x                                         DEFAULT port]
			x	[-global_start_rate_enabled              CHOICES 0 1]
			x	[-global_start_rate                      RANGE 1-10000
			x                                         DEFAULT 200]
			x	[-global_start_rate_interval             RANGE 1-65535
			x                                         DEFAULT 1000]
			x	[-global_start_rate_max_outstanding      RANGE 1-999999
			x                                         DEFAULT 400]
			x	[-global_start_rate_scale_mode           CHOICES port device_group
			x                                         DEFAULT port]
			x	[-global_stop_rate_enabled               CHOICES 0 1]
			x	[-global_stop_rate                       RANGE 1-10000
			x                                         DEFAULT 200]
			x	[-global_stop_rate_interval              RANGE 1-65535
			x                                         DEFAULT 1000]
			x	[-global_stop_rate_max_outstanding       RANGE 1-999999
			x                                         DEFAULT 400]
			x	[-global_stop_rate_scale_mode            CHOICES port device_group
			x                                         DEFAULT port]
			x	[-global_resync_rate                     ANY]
			 	[-gsmp_standard                          ANY]
			 	[-handle                                 ANY]
			 	[-interval                               ANY]
			 	[-intf_ip_addr                           IPV4
			                                          DEFAULT 10.10.10.2]
			 	[-intf_ip_prefix_len                     RANGE 0-32
			                                          DEFAULT 16]
			 	[-intf_ip_step                           IPV4
			                                          DEFAULT 0.0.0.1]
			 	[-keep_alive                             RANGE 1-255
			                                          DEFAULT 250]
			x	[-keep_alive_retries                     RANGE 1-10
			x                                         DEFAULT 3]
			x	[-unlimited_redial                       CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-max_redial_attempts                    RANGE 1-100
			x                                         DEFAULT 3]
			 	[-line_config                            CHOICES 0 1
			                                          DEFAULT 0]
			x	[-remote_loopback                        CHOICES 0 1
			x                                         DEFAULT 0]
			 	[-local_mac_addr                         MAC
			                                          DEFAULT 000a.0a00.0200]
			x	[-local_mac_addr_auto                    ANY]
			 	[-local_mac_step                         MAC
			                                          DEFAULT 0000.0000.0001]
			x	[-local_mss                              ANY]
			x	[-local_mtu                              ANY]
			 	[-mode                                   CHOICES create
			                                          CHOICES modify
			                                          CHOICES delete
			                                          CHOICES enable
			                                          CHOICES disable
			                                          CHOICES enable_all
			                                          CHOICES disable_all
			                                          DEFAULT create]
			x	[-port_down_rate                         ANY]
			x	[-port_resync_rate                       ANY]
			x	[-port_up_rate                           ANY]
			 	[-port_handle                            ANY]
			x	[-port_override_globals                  ANY]
			x	[-pvc_incr_mode                          ANY]
			x	[-qinq_incr_mode                         ANY]
			 	[-sut_ip_addr                            IPV4
			                                          DEFAULT 20.20.0.1]
			 	[-sut_ip_step                            IPV4
			                                          DEFAULT 0.0.0.0]
			x	[-sut_service_port                       RANGE 1-65535
			x                                         DEFAULT 6068]
			 	[-topology_discovery                     CHOICES 0 1
			                                          DEFAULT 1]
			x	[-transactional_multicast                CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-vci                                    ANY]
			x	[-vci_count                              ANY]
			x	[-vci_repeat                             ANY]
			x	[-vci_step                               ANY]
			 	[-vlan_id                                RANGE 0-4095]
			 	[-vlan_id_count                          ANY]
			 	[-vlan_id_count_inner                    ANY]
			 	[-vlan_id_inner                          RANGE 0-4095]
			 	[-vlan_id_repeat                         ANY]
			 	[-vlan_id_repeat_inner                   ANY]
			 	[-vlan_id_step                           RANGE 0-4095
			                                          DEFAULT 1]
			 	[-vlan_id_step_inner                     RANGE 0-4095
			                                          DEFAULT 1]
			x	[-vlan_user_priority                     RANGE 0-7
			x                                         DEFAULT 0]
			x	[-vlan_user_priority_inner               RANGE 0-7
			x                                         DEFAULT 0]
			x	[-vpi                                    ANY]
			x	[-vpi_count                              ANY]
			x	[-vpi_repeat                             ANY]
			x	[-vpi_step                               ANY]
			n	[-gateway_ip_prefix                      ANY]
			n	[-gateway_ip_repeat                      ANY]
			n	[-gateway_ipv6_step                      ANY]
			n	[-gateway_ipv6_addr                      ANY]
			n	[-gateway_ipv6_prefix                    ANY]
			n	[-gateway_ipv6_prefix_len                ANY]
			n	[-gateway_ipv6_repeat                    ANY]
			n	[-intf_ip_prefix                         ANY]
			n	[-intf_ip_repeat                         ANY]
			n	[-local_mac_repeat                       ANY]
			n	[-remote_mac_addr                        ANY]
			n	[-remote_mac_repeat                      ANY]
			n	[-remote_mac_step                        ANY]
			n	[-return_receipt                         ANY]
			n	[-session_count                          ANY]
			n	[-sut_ip_prefix                          ANY]
			n	[-sut_ip_prefix_len                      ANY]
			n	[-sut_ip_repeat                          ANY]
			x	[-partition_id                           ANY]
			x	[-trigger_access_loop_events             CHOICES 0 1
			x                                         DEFAULT 0]
		
		Arguments:
			x	-access_aggregation
			x		Enables the addition of the optional Access-Aggregation-Circuit-ID-Binary (0x06) TLV field in Port Up and Port Down packetsEnables the addition of the optional Access-Aggregation-Circuit-ID-Binary (0x06) TLV field in Port Up and Port Down packetsThis parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-access_aggregation_dsl_inner_vlan
			x		The inner VLAN ID that will be used for all the subscriber packets in the ANCP range. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-access_aggregation_dsl_inner_vlan_type
			x		The type of aggregation for inner vlan. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		actual_dsl_subscriber_vlan - The TLV will use the actual inner VLAN ID of the DSL subscriber (identified by PPPoE session, DHCP lease, or IP interface). If inner VLAN is disabled for the correspondent PPP/DHCP/IP structure, 0 will be set in the TLV.
			x   		custom - The inner VLAN ID that is specified by -access_aggregation_dsl_inner_vlan will be used for all the subscriber packets in the ANCP range.
			x	-access_aggregation_dsl_outer_vlan
			x		The outer VLAN ID that will be used for all the subscriber packets in the ANCP range. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-access_aggregation_dsl_outer_vlan_type
			x		The type of aggregation for outer vlan. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		actual_dsl_subscriber_vlan - The TLV will use the actual outer VLAN ID of the DSL subscriber (identified by PPPoE session, DHCP lease, or IP interface). If outer VLAN is disabled for the correspondent PPP/DHCP/IP structure, 0 will be set in the TLV.
			x   		custom - The outer VLAN ID that is specified by -access_aggregation_dsl_outer_vlan will be used for all the subscriber packets in the ANCP range.
			x	-access_aggregation_dsl_vci
			x		The VCI that will be used for all the subscriber packets in the ANCP range. This parameter is supported using the following APIs:
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-access_aggregation_dsl_vpi
			x		The VPI that will be used for all the subscriber packets in the ANCP range. This parameter is supported using the following APIs:
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-access_aggregation_dsl_vci_type
			x		The type of aggregation for VCI. This parameter is supported using the following APIs: IxTclNetwork
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		actual_dsl_subscriber_vci - The TLV will use the actual VCI of the DSL subscriber (identified by PPPoA session, DHCP lease, or IP interface).
			x   		custom - The VCI that is specified by -access_aggregation_dsl_vci will be used for all the subscriber packets in the ANCP range.
			x	-access_aggregation_dsl_vpi_type
			x		The type of aggregation for VPI. This parameter is supported using the following APIs: IxTclNetwork
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		actual_dsl_subscriber_vpi - the TLV will use the actual VPI of the DSL subscriber (identified by PPPoA session, DHCP lease, or IP interface).
			x   		custom - The VPI that is specified by -access_aggregation_dsl_vpi will be used for all the subscriber packets in the ANCP range.
			 	-ancp_standard
			 		Access Node Control Protocol (ANCP) Standard followed by implementation. For Ixia this is either
			 		ietf-ancp-protocol5 or rfc6320. This parameter is supported using the following
			 		APIs: IxTclNetwork.
			 		(DEFAULT = rfc6320)
			 		Valid choices are:
			    		ietf-ancp-protocol5 - ietf-ancp-protocol5
			    		rfc6320 - RFC6320
			x	-circuit_id
			x		Defines one or more circuit IDs for the subscribers in the specific ANCP range. Circuit IDs enable the NAS to associate individual subscribers with distinct QoS requirements. Circuit ID is a string value, from 0 to 63 characters in length. The format strings can include normal alpha-numeric characters interspersed with instances of %-prefixed specifications. There are 5 %-prefixed specifications that can be used. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		%L - Outer VLAN ID: Inserts the two-digit outer VLAN ID into the field. For example: "vlan%L" will generate vlan01 for clients on VLAN 1 and vlan02 for clients on VLAN 2. Use only with ethernet ports.
			x   		%I - Inner VLAN ID: Inserts the two-digit inner VLAN ID into the field. For example: "vlan%I" will generate vlan01 for clients on INNER VLAN 1 and vlan02 for clients on INNER VLAN 2. Use only with ethernet ports.
			x   		%v - VPI: Inserts the two-digit VPI into the field. For example: "vpi%v" will generate vpi01 for clients on VPI 1 and vpi02 for clients on VPI 2. Use only with atm ports.
			x   		%V - VCI: Inserts the two-digit VCI into the field. For example: "vci%V"will generate vci01 for clients on VCI 1 and vci02 for clients on VCI 2. Use only with atm ports.
			x   		%i - This is the most flexible of the commands, allowing an incrementing value to be specified. Three parameters control the operation of this option. 
			
			Start Value: The Start-width value is the first value to be used. Its width will be preserved when values are incremented. For example: `%001i' will generate 001, 002, 003, and so forth.
			
			Count: The Count value specifies how many values will be generated before the first value is repeated. For example: `%001:3i' will generate 001, 002, 003, 001, 002, 003, 001, and so forth. That is, count values will be generated and then the start value will be repeated.  
			
			Repeat Count: The Repeat value specifies how many times each value will be repeated. For example: `%001::2i' will generate 001, 001, 002, 002, 003, 003, and so forth.
			 	-device_count
			 		Used in create mode only to specify number of individual ANCP devices to be created. This parameter is supported using the following APIs: IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-distribution_alg_percentage
			x		Defines the percentage of deviation from a uniform distribution of DSL subscribers-to-access nodes. With the default value of 0%, the DSL subscribers are distributed among the access nodes according to the following algorithm: If the division of the number of subscribers by the number of access nodes produces a remainder of zero, the DSL subscribers are equally distributed among the access nodes. For example, if you have four access nodes and 80 subscribers, the default value of 0% results in an equal allocation of 20 subscribers to each access node. 
			x		If the division of the number of subscribers by the number of access nodes produces a non-zero remainder, the DSL subscribers are equally distributed among the access nodes, with the remaining number of nodes distributed equally, beginning with the first access node. For example, with eight subscribers and three access nodes, the distribution will be as follows: access node 1 will receive subscribers 0, 1, and 2; access node 2 will receive subscribers 3, 4, and 5; and access node 3 will receive subscribers 6 and 7. 
			x		If you set Distribution Algorithm Percentage to a value greater than zero, the distribution is accomplished according to the following algorithm: 1. First, IxNetwork calculates an even distribution of subscribers, using the method described above. 2. Next, IxNetwork groups the access nodes into pairs. If there is an odd number of access nodes, the last access node will keep its currently-allocated subscribers. 3. For each pair of access nodes, IxNetwork uses the percent of deviation to calculate the number of subscribers to move from the first access node to the second access node. For example, if you have four access nodes, 80 subscribers, and a Distribution Algorithm Percentage value of 50%, IxNetwork will move 50% of the subscribers from the first access node in each pair to the second access node. In this example, the first access node in each pair will have 10 subscribers, and the second access node will have 30 subscribers. The default is 0%, the minimum is 0%, and the maximum is 100%. Note: The accuracy of the DSL profile distribution increases as the number of emulated DSL subscribers grows. If you have between 50 and 100 subscribers, you may experience an deviation of 10 to 15 percent from the model. This parameter is supported using the following APIs: IxTclNetwork.  
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dsl_profile_capabilities
			x		List of <dsl_profile>,<dsl_profile_percentage> elements.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dsl_resync_profile_capabilities
			x		List of <dsl_resync_profile>,<dsl_resync_profile_percentage> elements.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-encap_type
			 		Framing mode for encapsulated ANCP device. Ixia supports ETHERNETII, VccMuxIPV4Routed, VccMuxBridgedEthernetFCS, VccMuxBridgedEthernetNoFCS, VccMuxIPV6Routed, SNAP, LLCBridgedEthernetFCS, LLCBridgedEthernetNoFCS, LLCPPPoA, VccMuxPPPoA. This parameter is supported using the following APIs: IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-events_per_interval
			 		When only events_per_interval is present, this represents the number of Port Up and Port Down event messages to send each second. This is a port level setting. This parameter is supported using the following APIs: IxTclNetwork. If is necessary to configure separate Port Up and Port Down frequency please use global_port_up_rate and global_port_down_rate,or port_up_rate and port_down_rate and port_override_globals. Default behavior is port_override_globals 1, port_up_rate 50 and port_down_rate 50.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gateway_ip_addr
			 		The Gateway IP address of the Access Node. This parameter is supported
			 		using the following APIs: IxTclNetwork.
			 		(DEFAULT = 0.0.0.0)
			 	-gateway_ip_prefix_len
			 		The prefix length for the IP address of the interface address (Access Node address). This parameter is supported using the following APIs: IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gateway_ip_step
			 		The incrementing step for the Gateway IP address. This parameter is
			 		supported using the following APIs: IxTclNetwork.
			 		(DEFAULT = 0.0.0.0)
			x	-gateway_incr_mode
			x		The incrementing mode for Gateway address of an Access Node. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		every_subnet - Increment the gateway on every new subnet.
			x   		every_interface - Increment the gateway on every new interface.
			x	-global_port_down_rate_enabled
			x		Enable Port Down rate settings
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_port_down_rate
			x		The number of Port Down event messages to send each second. This is a
			x		global level setting. When events_per_interval is present, then this
			x		option is ignored. This parameter is supported using the following
			x		APIs: IxTclNetwork.
			x		(DEFAULT = 50)
			x	-global_port_down_rate_interval
			x		Port down rate interval in milliseconds
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_port_down_rate_max_outstanding
			x		Port down rate max outstanding
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_port_down_rate_scale_mode
			x		Indicates whether the control is specified per port or per device group
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		port - port
			x   		device_group - device_group
			x	-global_port_up_rate_enabled
			x		Enable Port Up rate settings
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_port_up_rate
			x		The number of Port Up event messages to send each second. This is a
			x		global level setting.When events_per_interval is present, then this
			x		option is ignored. This parameter is supported using the following
			x		APIs: IxTclNetwork.
			x		(DEFAULT = 10)
			x	-global_port_up_rate_interval
			x		Port Up rate interval in milliseconds
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_port_up_rate_max_outstanding
			x		Port Up rate max outstanding
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_port_up_rate_scale_mode
			x		Indicates whether the control is specified per port or per device group
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		port - port
			x   		device_group - device_group
			x	-global_start_rate_enabled
			x		Enable ANCP Start rate settings
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_start_rate
			x		ANCP Start rate
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_start_rate_interval
			x		ANCP Start rate interval in milliseconds
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_start_rate_max_outstanding
			x		ANCP Start rate max outstanding
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_start_rate_scale_mode
			x		Indicates whether the control is specified per port or per device group
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		port - port
			x   		device_group - device_group
			x	-global_stop_rate_enabled
			x		Enable ANCP Stop rate settings
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_stop_rate
			x		ANCP Stop rate
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_stop_rate_interval
			x		ANCP Stop rate interval in milliseconds
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_stop_rate_max_outstanding
			x		ANCP Start rate max outstanding
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_stop_rate_scale_mode
			x		Indicates whether the control is specified per port or per device group
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		port -
			x   		device_group -
			x	-global_resync_rate
			x		The number of Port Up event messages to send each second, to simulate DSL Resync events. This is a global level setting. When events_per_interval is present, then this option is ignored. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-gsmp_standard
			 		Implementation will followed by selected GSMP v3 standard as ANCP Protocol Base. For Ixia, this will always be gsmp-v3-base. This parameter is supported using the following APIs: IxTclNetwork. (DEFAULT = gsmp-v3-base)
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-handle
			 		When mode is create this is the parent handle used for creating this object.
			 		It can be a topology, or a device group, or an ethernet or an ipv4.
			 		Other modes require an ancp handle returned by ::ixngpf::emulation_ancp_config.
			 	-interval
			 		The interval (in seconds) for topology discovery message will be sent in bursts. Ixia supports only value 1 (one second). This parameter is supported using the following APIs: IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-intf_ip_addr
			 		The IP address of the Access Node. It doesn't support a list of IP
			 		Addresses. This parameter is supported using the following APIs:
			 		IxTclNetwork.
			 		(DEFAULT = 10.10.10.2)
			 	-intf_ip_prefix_len
			 		The prefix length for the IP address of the interface address (Access
			 		Node address). This parameter is supported using the following APIs:
			 		IxTclNetwork.
			 		(DEFAULT = 16)
			 	-intf_ip_step
			 		Step value for incrementing interface address. This parameter is
			 		supported using the following APIs: IxTclNetwork.
			 		(DEFAULT = 0.0.0.1)
			 	-keep_alive
			 		The time period (in hundreads of milli seconds) between the sending two keep alive
			 		messages. Specify the value in multiple of 1000. This parameter is
			 		supported using the following APIs: IxTclNetwork.
			 		(DEFAULT = 10000)
			x	-keep_alive_retries
			x		The number of NAS Keep-Alive retries. If a Keep-Alive times out, the
			x		emulated access node will re-send it the number of times specified by
			x		this parameter before determining that the connection to the NAS has
			x		gone down. This parameter is supported using the following APIs:
			x		IxTclNetwork.
			x		(DEFAULT = 3)
			x	-unlimited_redial
			x		Limit the Number of attempts to establish ANCP adjacency in case connection is lost
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-max_redial_attempts
			x		Number of attempts to establish ANCP adjacency in case connection is lost
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-line_config
			 		To enable/disable line configuration capabilities. For Ixia, this is
			 		always 0. This parameter is supported using the following APIs:
			 		IxTclNetwork.
			 		(DEFAULT = 0)
			x	-remote_loopback
			x		Enable/Disable DSL Remote Line Conectivity Testing Capability
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-local_mac_addr
			 		Defines starting local MAC address (Access Node MAC address). This
			 		parameter is supported using the following APIs: IxTclNetwork.
			 		(DEFAULT = 000a.0a00.0200)
			x	-local_mac_addr_auto
			x		Enable/Disable the suto generation of the local MAC address. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		0 - The local MAC address can be specified through the local_mac_... parameters.
			x   		1 - An auto generated MAC address will be used for the Access Node.
			 	-local_mac_step
			 		Incrementing step for local MAC address (Access Node MAC address). This
			 		parameter is supported using the following APIs: IxTclNetwork.
			 		(DEFAULT = 0000.0000.0001)
			x	-local_mss
			x		The Maximum Segment Size. The MSS is the largest amount of data, specified in bytes, that the IP device can transmit as a single, unfragmented unit. The TCP MSS equals the MTU minus the TCP header size, minus the IP header size. Stack Manager supports jumbo frames. Therefore the maximum value is 9460. This option configures the MSS value for the Access Node.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-local_mtu
			x		Maximum Transmission Unit (MTU) is the largest packet that a given network medium can carry. Ethernet, for example, has a fixed MTU of 1500 bytes, ATM has a fixed MTU of 48 bytes, and PPP has a negotiated MTU that is usually between 500 and 2000 bytes. The parameter defines the MTU value for the Access Node. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-mode
			 		Action to perform. This parameter is supported using the following
			 		APIs: IxTclNetwork.
			 		(DEFAULT = create) Valid choices are:
			 		create - Create new ANCP range on -port_handle or -handle(DHCP,
			 		PPP, IP endpoint).Parameter -port_handle takes priority when both
			 		Valid choices are:
			    		create -
			    		modify -
			    		delete -
			    		enable -
			    		disable -
			    		enable_all -
			    		disable_all -
			x	-port_down_rate
			x		The number of Port Down event messages to send each second. This is a port level setting. When events_per_interval is present, then this option is ignored. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-port_resync_rate
			x		The number of Port Up event messages to send each second, to simulate DSL Resync events. This is a port level setting. When events_per_interval is present, then this option is ignored. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-port_up_rate
			x		The number of Port Down event messages to send each second. This is a port level setting. When events_per_interval is present, then this option is ignored. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-port_handle
			 		The port handle for which the configuration will be made. Valid only for -mode create, and takes priority over -handle. This parameter is supported using the following APIs: IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-port_override_globals
			x		If selected, all the rate settings defined at the global level will be overridden by the rate settings defined on this port. For example, if you have set the Port Up rate to 100 on the global level, and you have defined two ports, these 100 events will be evenly distributed across the ports (50 for each). If you then enable Override Global Rate, you can modify the number of events for each of the ports (such as changing the distribution from 50-50 to 60-40). This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-pvc_incr_mode
			x		The incrementing mode for VCI/VPI. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		vci - The VCI is incremented first.
			x   		vpi - The VPI vlan is incremented first.both - Both vlan tags are incremented.
			x	-qinq_incr_mode
			x		The incrementing mode for Stacked Vlan. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		inner - The inner vlan is incremented first.
			x   		outer - The outer vlan is incremented first.both - Both vlan tags are incremented.
			 	-sut_ip_addr
			 		SUT address of the test interface/emulated ANCP. The IP address of the
			 		NAS to which the emulated access node is connected. It cannot support
			 		a list of IP addresses. This parameter is supported using the following
			 		APIs: IxTclNetwork.
			 		(DEFAULT = 20.20.0.1)
			 	-sut_ip_step
			x	-sut_service_port
			x		The NAS ANCP TCP service port number. This parameter is supported using
			x		the following APIs: IxTclNetwork.
			x		(DEFAULT = 6068)
			 	-topology_discovery
			 		Enable/disable topology discovery functionality. For Ixia, this will
			 		always be 1. This parameter is supported using the following APIs:
			 		IxTclNetwork.
			 		(DEFAULT = 1)
			x	-transactional_multicast
			x		Enable/Disable advertise Transactional Multicast capability
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-vci
			x		The VCI value when configuring ATM interfaces.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vci_count
			x		The number of unique VCI values.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vci_repeat
			x		The repeat value for the VCI of the interface.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vci_step
			x		The incrementing step for the VCI of the interface.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-vlan_id
			 		Vlan ID for Access Node. Doesn't support a list of vlan IDs. This
			 		parameter is supported using the following APIs: IxTclNetwork.
			 	-vlan_id_count
			 		Defines the number of Vlan IDs. This parameter is supported using the following APIs: IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vlan_id_count_inner
			 		Defines the number of Inner Vlan IDs. This parameter is supported using the following APIs: IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vlan_id_inner
			 		Defines the Inner Vlan ID for Access Node. Doesn't support a list of
			 		vlan IDs. This parameter is supported using the following APIs:
			 		IxTclNetwork.
			 	-vlan_id_repeat
			 		Defines the repeat count of VLAN ID. This parameter is supported using the following APIs: IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vlan_id_repeat_inner
			 		Defines the repeat count of Inner VLAN ID. This parameter is supported using the following APIs: IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vlan_id_step
			 		Defines the Vlan ID incrementing step. This parameter is supported
			 		using the following APIs: IxTclNetwork.
			 		(DEFAULT = 1)
			 	-vlan_id_step_inner
			 		Defines the Inner Vlan ID incrementing step. This parameter is
			 		supported using the following APIs: IxTclNetwork.
			 		(DEFAULT = 1)
			x	-vlan_user_priority
			x		Defines the Vlan user priority for Access Node. This parameter is
			x		supported using the following APIs: IxTclNetwork.
			x		(DEFAULT = 0)
			x	-vlan_user_priority_inner
			x		Defines the Inner Vlan user priority for Access Node. This parameter is
			x		supported using the following APIs: IxTclNetwork.
			x		(DEFAULT = 0)
			x	-vpi
			x		The VPI value when configuring ATM interfaces.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vpi_count
			x		The number of unique VPI values.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vpi_repeat
			x		The repeat value for the VPI of the interface.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vpi_step
			x		The incrementing step for the VPI of the interface.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			n	-gateway_ip_prefix
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-gateway_ip_repeat
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-gateway_ipv6_step
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-gateway_ipv6_addr
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-gateway_ipv6_prefix
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-gateway_ipv6_prefix_len
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-gateway_ipv6_repeat
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-intf_ip_prefix
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-intf_ip_repeat
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-local_mac_repeat
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-remote_mac_addr
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-remote_mac_repeat
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-remote_mac_step
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-return_receipt
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-session_count
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-sut_ip_prefix
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-sut_ip_prefix_len
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-sut_ip_repeat
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-partition_id
			x		Partition ID to be used in adjacency negotiation
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-trigger_access_loop_events
			x		Enable sending Port Up/Port Down events when AN is Started/Stopped.
			x		Does not apply if flapping is enabled on the Access Loop.
			x		This parameter is supported using the following APIs:
			x		IxTclNetwork.
			x		(DEFAULT = 0)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		A list containing the ancp protocol stack handles that were added by the command (if any).
			xkey:ancp_handle  value:A list containing the ancp protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE Status of procedure call.
			 key:status       value:$::SUCCESS | $::FAILURE Status of procedure call.
		When status is failure, contains more information.
			 key:log          value:When status is failure, contains more information.
		The list of ANCP handles configured. Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:handle       value:The list of ANCP handles configured. Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		The list of ANCP handles configured.
			 key:handle       value:The list of ANCP handles configured.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) Unsupported parameters or unsupported parameter options will be
		silently ignored. If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		1) Unsupported parameters or unsupported parameter options will be silently ignored.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_ancp_config", kwargs)

	def emulation_ancp_control(self, **kwargs):
		""" This procedure controls ANCP actions.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ancp_control
			 	[-action_control      ANY]
			 	-action               CHOICES send-reset
			                       CHOICES enable
			                       CHOICES disable
			                       CHOICES abort
			                       CHOICES reset
			                       CHOICES flap_start
			                       CHOICES flap_start_resync
			                       CHOICES flap_stop
			                       CHOICES send_port_up
			                       CHOICES send_port_down
			x	[-action_control_type ANY]
			 	[-ancp_handle         ANY]
			 	[-ancp_subscriber     ANY]
			n	[-batch_size          ANY]
			 	[-interval            ANY]
			 	[-interval_unit       ANY]
			x	[-iteration_count     ANY]
			n	[-job_handle          ANY]
			n	[-peer_count          ANY]
		
		Arguments:
			 	-action_control
			 		This is a mandatory argument. Used to start or stop for the action provided using parameter -action. This parameter is supported using the following APIs: IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 		Valid choices are:
			    		abort -Aborts all ANCP sessions including the underlying protocol.
			    		bring_up_dsl_subscribers- Bring up DSL subscribers.
			    		decoupled_start- Starts ANCP without starting any underlying protocol (deprecated).
			    		decoupled_stop- Stops ANCP without tempering with the underlying protocol (deprecated).
			    		start-Start ANCP emulation and underlying protocol (IP, PP, DHCP, etc).
			    		start_adjacency- Start ANCP adjacency.
			    		start_resync- Send port up message.
			    		stop-Stop ANCP emulation and underlying protocol (IP, PP, DHCP, etc).
			    		stop_adjacency-Stop ANCP adjacency.
			    		tear_down_dsl_subscribers-Teardown DSL subscribers.
			 	-action
			 		This is a mandatory argument. Used to select the task to perform.
			 		Flapping is applicable for line subscriber devices only.
			 		Valid choices are:
			    		send-reset - Send RSTACK packet from the AN passed in ancp_handle
			    		enable - Enable ANCP protocol
			    		disable - Disable ANCP configuration.
			    		abort - Abort ANCP protocol.
			    		reset - Not Supported.
			    		flap_start - Start RESET flapping mode
			    		flap_start_resync - Start RESYNC flapping mode
			    		flap_stop - Stop flapping
			    		send_port_up - Send PORT-UP event
			    		send_port_down - Send PORT-DOWN event
			x	-action_control_type
			x		Execute action_control async (return control immeadiately and execute operation in the background) or sync (wait until the operation is completed to return control).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-ancp_handle
			 		ANCP range to start|stop ANCP emulation on. Emulation is started |
			 		stopped for all ANCP ranges on port. This parameter is supported using
			 		the following APIs: IxTclNetwork.
			 	-ancp_subscriber
			 		Used to specify the ANCP line subscriber device handle.
			n	-batch_size
			n		Used to specify the number of instances executed per interval for ANCP Line subscriber only.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-interval
			 		Used to specify the interval. By default it is in second. To change the unit use interval_unit option. Everything less than 1 second will be rounded to second. This is used for -action_control start_resync. This parameter is supported using the following APIs: IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-interval_unit
			 		Used to specify the interval unit. This is used for -action_control start_resync. Choices: second | millisecond | microsecond.Everything less than 1 second will be rounded to second. This parameter is supported using the following APIs: IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-iteration_count
			x		Used to specify the number of iterations. This is used for -action_control start_resync. This parameter is supported using the following APIs: IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			n	-job_handle
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-peer_count
		
		Return Values:
		$::SUCCESS | $::FAILURE Status of procedure call.
			 key:status  value:$::SUCCESS | $::FAILURE Status of procedure call.
		When status is failure, contains more information.
			 key:log     value:When status is failure, contains more information.
		ANCP device handles.
			 key:handle  value:ANCP device handles.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) Unsupported parameters or unsupported parameter options will be
		silently ignored.
		1) Unsupported parameters or unsupported parameter options will be silently ignored.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_ancp_control", kwargs)

	def emulation_ancp_stats(self, **kwargs):
		""" This procedure retrieves ANCP stats.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ancp_stats
			 	[-mode        CHOICES instance
			               CHOICES device
			               CHOICES per_dg
			               CHOICES per_port
			               DEFAULT per_port]
			 	[-handle      ANY]
			x	[-port_handle ANY]
			 	[-reset       FLAG]
		
		Arguments:
			 	-mode
			 		Specify what level of statistics to poll
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		instance - retrieves statistics per Access Node instance (ANCP per Session statistics).
			    		device - retrieves statistics per Access Loop session (per dsl line).
			    		per_dg - retrieves aggregate statistics per Device Group.
			    		per_port - retrieves aggregate statistics per Port.
			 	-handle
			 		ANCP range for which to retrieve stats. The stats are retrived for the
			 		port on which this ANCP handle belongs. This parameter is supported
			 		using the following APIs: IxTclNetwork.
			x	-port_handle
			x		Parameter -port_handle specifies the port on which the ANCP stats are
			x		retrieved. This parameter is supported using the following APIs:
			x		IxTclNetwork.
			 	-reset
			 		Used to reset ANCP client device statistics. This parameter is
			 		supported using the following APIs: IxTclNetwork.
		
		Return Values:
		$::SUCCESS | $::FAILURE Status of procedure call.
			 key:status                                            value:$::SUCCESS | $::FAILURE Status of procedure call.
		When status is failure, contains more information.
			 key:log                                               value:When status is failure, contains more information.
			 key:rx_total_pkts                                     value:
			 key:port_handle.rx_adj_syn_pkts                       value:
			 key:port_handle.rx_adj_syn_ack_pkts                   value:
			 key:rx_adj_ack_pkts                                   value:
			 key:rx_adj_rst_ack_pkts                               value:
			nkey:rx_top_disc_receipt_pkts                          value:
			nkey:rx_line_config_req                                value:
			 key:rx_dropped_sub_not_found                          value:
			nkey:rx_dropped_no_cap                                 value:
			nkey:rx_dropped_adj_not_stsab                          value:
			 key:rx_dropped_malformed                              value:
			 key:tx_total_pkts                                     value:
			 key:port_handle.tx_adj_syn_pkts                       value:
			 key:port_handle.tx_adj_syn_ack_pkts                   value:
			 key:tx_adj_ack_pkts                                   value:
			 key:tx_adj_rst_ack_pkts                               value:
			 key:port_handle.tx_top_disc_port_up_events            value:
			 key:tx_top_disc_port_down_events                      value:
			nkey:tx_line_config_receipts                           value:
			nkey:adj_estab_time_min                                value:
			nkey:adj_estab_time_avg                                value:
			nkey:adj_estab_time_max                                value:
			 key:adj_estab_count                                   value:
			nkey:adj_estab_percent                                 value:
			nkey:adj_estab_rate                                    value:
			 key:agg_sub_line_down_bw                              value:
			 key:agg_sub_line_up_bw                                value:
			 key:port_handle.ancp_adjacency.ans_established        value:
			 key:port_handle.ancp_adjacency.tx.pkts                value:
			 key:port_handle.ancp_adjacency.rx.pkts                value:
			 key:port_handle.ancp_adjacency.tx.bytes               value:
			 key:port_handle.ancp_adjacency.rx.bytes               value:
			 key:port_handle.ancp_adjacency.tx.syn                 value:
			 key:port_handle.ancp_adjacency.rx.syn                 value:
			 key:port_handle.ancp_adjacency.tx.ack                 value:
			 key:port_handle.ancp_adjacency.rx.ack                 value:
			 key:port_handle.ancp_adjacency.tx.synack              value:
			 key:port_handle.ancp_adjacency.rx.synack              value:
			 key:port_handle.ancp_adjacency.tx.rstack              value:
			 key:port_handle.ancp_adjacency.rx.rstack              value:
			 key:port_handle.ancp_general.ans_established          value:
			 key:port_handle.ancp_general.port_name                value:
			 key:port_handle.ancp_general.dsl_lines_up             value:
			 key:port_handle.ancp_general.tx.pkts                  value:
			 key:port_handle.ancp_general.rx.pkts                  value:
			 key:port_handle.ancp_general.tx.bytes                 value:
			 key:port_handle.ancp_general.rx.bytes                 value:
			 key:port_handle.ancp_port_event.dsl_lines_up          value:
			 key:port_handle.ancp_port_event.tx.port_up            value:
			 key:port_handle.ancp_port_event.tx.port_down          value:
			 key:port_handle.ancp_port_event.tx.event_pkts         value:
			 key:port_handle.ancp_port_event.tx.event_bytes        value:
			xkey:port_handle.adj_estab_rate_avg                    value:
			xkey:port_handle.adj_teardown_rate_avg                 value:
			xkey:port_handle.capability_not_supported              value:
			xkey:port_handle.dynamic_topology_discovery            value:
			xkey:port_handle.invalid_request_message               value:
			xkey:port_handle.invalid_tlv_contents                  value:
			xkey:port_handle.line_configuration                    value:
			xkey:port_handle.line_configuration_success_sent       value:
			xkey:port_handle.line_configuration_failed_sent        value:
			xkey:port_handle.rx_line_config_pkts                   value:
			xkey:port_handle.mandatory_tlv_missing                 value:
			xkey:port_handle.oam_success_sent                      value:
			xkey:port_handle.oam_failed_sent                       value:
			xkey:port_handle.oam_invalid_test_param                value:
			xkey:port_handle.oam_messages_received                 value:
			xkey:port_handle.partition_id_mismatch                 value:
			xkey:port_handle.receiver_instance_mismatch            value:
			xkey:port_handle.receiver_name_mismatch                value:
			xkey:port_handle.receiver_port_mismatch                value:
			xkey:port_handle.remote_loopback                       value:
			xkey:port_handle.request_message_type_not_implemented  value:
			xkey:port_handle.rx_adj_rstack_pkts                    value:
			xkey:port_handle.tx_adj_rstack_pkts                    value:
			xkey:port_handle.sender_instance_mismatch              value:
			xkey:port_handle.sender_name_mismatch                  value:
			xkey:port_handle.sender_port_mismatch                  value:
			xkey:port_handle.sessions_down                         value:
			xkey:port_handle.sessions_not_started                  value:
			xkey:port_handle.sessions_total                        value:
			xkey:port_handle.sessions_up                           value:
			xkey:port_handle.some_ports_down                       value:
			xkey:port_handle.syn_invalid_m_flag                    value:
			xkey:port_handle.version_mismatch                      value:
			xkey:port_handle.transactional_multicast               value:
			 key:rx_adj_syn_pkts                                   value:
			 key:rx_adj_syn_ack_pkts                               value:
			 key:tx_adj_syn_pkts                                   value:
			 key:tx_adj_syn_ack_pkts                               value:
			 key:tx_top_disc_port_up_events                        value:
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) Unsupported parameters or unsupported parameter options will be
		silently ignored.
		1) Unsupported parameters or unsupported parameter options will be silently ignored.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_ancp_stats", kwargs)

	def emulation_ancp_subscriber_lines_config(self, **kwargs):
		""" Used to configure simulating subscriber lines behind an ANCP enabled Access Node.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ancp_subscriber_lines_config
			 	-mode                                         CHOICES create
			                                               CHOICES modify
			                                               CHOICES delete
			                                               CHOICES enable
			                                               CHOICES disable
			                                               CHOICES enable_all
			                                               CHOICES disable_all
			x	[-profile_type                                ANY]
			x	[-enable_actual_rate_downstream               ANY]
			 	[-actual_rate_downstream                      NUMERIC]
			 	[-actual_rate_downstream_step                 NUMERIC]
			x	[-actual_rate_downstream_end                  ANY]
			x	[-enable_actual_rate_upstream                 ANY]
			 	[-actual_rate_upstream                        NUMERIC]
			 	[-actual_rate_upstream_step                   NUMERIC]
			x	[-actual_rate_upstream_end                    ANY]
			 	[-ancp_client_handle                          ANY]
			 	[-circuit_id                                  ANY
			                                               DEFAULT circuit]
			 	[-circuit_id_suffix                           ANY]
			 	[-circuit_id_suffix_repeat                    ANY]
			 	[-circuit_id_suffix_step                      ANY]
			 	[-data_link                                   ANY]
			 	[-downstream_act_interleaving_delay           ANY]
			 	[-downstream_attainable_rate                  ANY]
			 	[-downstream_max_interleaving_delay           ANY]
			 	[-downstream_max_rate                         ANY]
			 	[-downstream_min_low_power_rate               ANY]
			 	[-downstream_min_rate                         ANY]
			x	[-tech_type                                   CHOICES dsl pon
			x                                              DEFAULT dsl]
			x	[-enable_dsl_type                             ANY]
			 	[-dsl_type                                    CHOICES adsl1
			                                               CHOICES adsl2
			                                               CHOICES adsl2_plus
			                                               CHOICES vdsl1
			                                               CHOICES vdsl2
			                                               CHOICES sdsl
			                                               CHOICES unknown
			                                               DEFAULT adsl1]
			x	[-enable_pon_type                             CHOICES 0 1]
			x	[-pon_type                                    CHOICES gpon
			x                                              CHOICES xgpon1
			x                                              CHOICES twdmpon
			x                                              CHOICES xgspon
			x                                              CHOICES wdmpon
			x                                              CHOICES other
			x                                              DEFAULT gpon]
			 	[-encap1                                      ANY]
			 	[-encap2                                      ANY]
			 	[-handle                                      ANY]
			 	[-include_encap                               ANY]
			x	[-enable_remote_id                            ANY]
			 	[-remote_id                                   ANY
			                                               DEFAULT remote]
			 	[-upstream_act_interleaving_delay             ANY]
			 	[-upstream_attainable_rate                    ANY]
			 	[-upstream_max_interleaving_delay             ANY]
			 	[-upstream_max_rate                           ANY]
			 	[-upstream_min_low_power_rate                 ANY]
			 	[-upstream_min_rate                           ANY]
			x	[-actual_rate_upstream_min_value              ANY]
			x	[-actual_rate_downstream_min_value            ANY]
			x	[-upstream_min_rate_min_value                 ANY]
			x	[-downstream_min_rate_min_value               ANY]
			x	[-upstream_attainable_rate_min_value          ANY]
			x	[-downstream_attainable_rate_min_value        ANY]
			x	[-upstream_max_rate_min_value                 ANY]
			x	[-downstream_max_rate_min_value               ANY]
			x	[-upstream_min_low_power_rate_min_value       ANY]
			x	[-downstream_min_low_power_rate_min_value     ANY]
			x	[-upstream_max_interleaving_delay_min_value   ANY]
			x	[-upstream_act_interleaving_delay_min_value   ANY]
			x	[-downstream_max_interleaving_delay_min_value ANY]
			x	[-downstream_act_interleaving_delay_min_value ANY]
			x	[-percentage                                  ANY]
			n	[-actual_rate_downstream_repeat               ANY]
			n	[-actual_rate_upstream_repeat                 ANY]
			 	[-customer_vlan_id                            RANGE 1-4094
			                                               DEFAULT 1]
			n	[-customer_vlan_id_repeat                     ANY]
			 	[-customer_vlan_id_step                       ANY
			                                               DEFAULT 0]
			 	[-downstream_rate_tolerance                   RANGE 0-100
			                                               DEFAULT 10]
			n	[-enable_c_vlan                               ANY]
			 	[-flap_mode                                   CHOICES none reset resynchronize stop
			                                               DEFAULT none]
			n	[-remote_id_suffix                            ANY]
			n	[-remote_id_suffix_repeat                     ANY]
			n	[-remote_id_suffix_step                       ANY]
			 	[-service_vlan_id                             RANGE 1-4094
			                                               DEFAULT 1]
			n	[-service_vlan_id_repeat                      ANY]
			 	[-service_vlan_id_step                        ANY
			                                               DEFAULT 0]
			 	[-subscriber_line_down_time                   RANGE 100-3600000
			                                               DEFAULT 3000]
			 	[-subscriber_line_up_time                     RANGE 100-3600000
			                                               DEFAULT 3000]
			 	[-subscriber_lines_per_access_node            ANY
			                                               DEFAULT 1]
			 	[-upstream_rate_tolerance                     RANGE 0-100
			                                               DEFAULT 10]
			 	[-vlan_allocation_model                       CHOICES disabled N_1 1_1
			                                               DEFAULT disabled]
		
		Arguments:
			 	-mode
			 		Used to specify the action that the function will perform on the given ANCP Client
			 		session handle. Every mode except create, enable_all, and disable_all requires a
			 		valid AN Subscriber Line Pool handle. Modes create, enable_all, and disable_all
			 		will perform on any given ANCP Client handle
			 		Valid choices are:
			    		create - ancp_client_handle returned by emulation_ancp_config is mandatory.
This mode will create a DSL Profile and DSL Resync profile and add it to
the profiles used by the ANCP Client. If an identical profile already exists
it will be used instead of creating a new one
			    		modify - handle returned by emulation_ancp_subscriber_lines_config is
mandatory. All the TLVs will be removed from this profile and new ones
will be added according to the procedure parameters. In this case the
parameters will not accept lists (single values only)
			    		delete - handle returned by emulation_ancp_subscriber_lines_config is
mandatory. The DSL Profile specified with -handle will be removed
			    		enable - ancp_client_handle returned by emulation_ancp_config and
handle returned by emulation_ancp_subscriber_lines_config are
mandatory. The ANCP client specified with ancp_client_handle will
use the DSL Profile specified with -handle parameter.
			    		disable - ancp_client_handle returned by emulation_ancp_config and
handle returned by emulation_ancp_subscriber_lines_config are
mandatory. The ANCP client specified with ancp_client_handle will
stop using the DSL Profile specified with -handle parameter
			    		enable_all - ancp_client_handle returned by emulation_ancp_config is
mandatory. The ANCP client specified with ancp_client_handle will
use all DSL Profiles available
			    		disable_all - ancp_client_handle returned by emulation_ancp_config is
mandatory. The ANCP client specified with ancp_client_handle will
not use any DSL Profiles
			x	-profile_type
			x		This parameter is used to specify what kind of DSL profile should be created.Default: bothDependencies: None
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		dsl_sync - Create only a DSL sync profile.
			x   		dsl_resync - Create only a DSL resync profile.
			x   		both - Create both DSL sync and resync profiles.
			x	-enable_actual_rate_downstream
			x		Enable Actual-Net-Data-Rate-Downstream TLV
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-actual_rate_downstream
			 		Used to set emulated actual DSL sync rate (kbps) downstream. It may be a list of
			 		rate values.
			 		Default: None
			 		Dependencies: maximum 63 digits
			 	-actual_rate_downstream_step
			 		Step for actual_rate_downstream. The DSL TLV Resync Profile will be configured
			 		as trend starting from actual_rate_downstream with a step of
			 		actual_rate_downstream_step and ending at -actual_rate_downstream_end.
			x	-actual_rate_downstream_end
			x		Last value for actual_rate_downstream. The DSL TLV Resync Profile will be configured as trend starting from actual_rate_downstream with a step of actual_rate_downstream_step and ending at -actual_rate_downstream_end.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-enable_actual_rate_upstream
			x		Enable Actual-Net-Data-Rate-Upstream TLV
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-actual_rate_upstream
			 		Used to set emulated actual DSL sync rate (kbps) upstream. It may be a list of rate values.
			 		Default: None
			 		Dependencies: maximum 63 digits
			 	-actual_rate_upstream_step
			 		Step for actual_rate_upstream. The DSL TLV Resync Profile will be configured
			 		as trend starting from actual_rate_upstream with a step of
			 		actual_rate_upstream_step and ending at actual_rate_upstream_end.
			x	-actual_rate_upstream_end
			x		Last value for actual_rate_upstream. The DSL TLV Resync Profile will be configured as trend starting from actual_rate_upstream with a step of actual_rate_upstream_step and ending at -actual_rate_upstream_end.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-ancp_client_handle
			 		This parameter is used to specify the ANCP Client session handle on which
			 		ANCP Subscriber Line Pool will be added. This handle is returned by procedure
			 		emulation_ancp_config.
			 		May be a list, in which case all the handles are configured with the same parameters.
			 		Default: None
			 		Dependencies: None
			 	-circuit_id
			 		Used to set circuit id.
			 		May be a list, needs to have the same length as ancp_client_handle.
			 		Dependencies: None
			 	-circuit_id_suffix
			 		Configure the suffix to append to the circuit ID common string. It may be a list of suffix value.May be a list, needs to have the same length as ancp_client_handle.Default: None Dependencies: -mode create
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-circuit_id_suffix_repeat
			 		Used to set the repeat value for circuit IDDefault: None May be a list, needs to have the same length as ancp_client_handle.Dependencies: -mode create
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-circuit_id_suffix_step
			 		Used to set the step value for circuit IDDefault: None May be a list, needs to have the same length as ancp_client_handle.Dependencies:-mode create
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-data_link
			 		Define the Access Loop Data Link.Default: None Dependencies: -include_encap set to 1.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-downstream_act_interleaving_delay
			 		Optionally define the value corresponding to the interleaving setting (ms).Default: None Dependencies: maximum 63 digits
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-downstream_attainable_rate
			 		Optionally define the maximum net downstream rate that can be attained on the DSL line (kbps).Default: None Dependencies: maximum 63 digits
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-downstream_max_interleaving_delay
			 		Optionally define the maximum one way interleaving delay (ms).Default: None Dependencies: maximum 63 digits
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-downstream_max_rate
			 		Optionally define the maximum net data rate desired by the operator (kbps).Default: None Dependencies: maximum 63 digits
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-downstream_min_low_power_rate
			 		Optionally define the net data rate desired by the operator in low power state (kbps).Default: None Dependencies: maximum 63 digits
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-downstream_min_rate
			 		Optionally define the minimum net data rate desired by the operator (kbps).Default: None Dependencies: maximum 63 digits
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-tech_type
			x		Type of Access Loop Technology
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_dsl_type
			x		Enable DSL Type TLV
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-dsl_type
			 		Used to set the type of DSL transmission system in use.
			 		Dependencies: maximum 63 digits
			x	-enable_pon_type
			x		Enable PON Type TLV
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pon_type
			x		PON Type value for PON Type TLV
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-encap1
			 		Define the Access Loop Encapsulation 1.Default: None Dependencies: -include_encap set to 1.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-encap2
			 		Define the Access Loop Encapsulation 2Default: None Dependencies: -include_encap set to 1.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-handle
			 		Used to modify, enable, disable or delete AN Subscriber Line Pool handle.
			 		This handle is returned by emulation_ancp_subscriber_lines_config procedure.
			 		Default: None
			 		Dependencies: None
			 	-include_encap
			 		Optionally include Access Loop Encapsulation TLV in ANCP message.Default: None Dependencies: None
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-enable_remote_id
			x		Enable Access-Loop-Remote-ID TLV
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-remote_id
			 		Used to set remote id. This parameter is also use to enable Remote Id option.
			 		Hence, if and only if the switch remote_id is specified, Remote Id option will be
			 		enabled.
			 		Dependencies: maximum 63 digits
			 	-upstream_act_interleaving_delay
			 		Optionally define the value corresponding to the interleaving setting (ms)Default: None Dependencies: maximum 63 digits
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-upstream_attainable_rate
			 		Optionally define the maximum net upstream rate that can be attained on the DSL line (kbps).Default: None Dependencies: maximum 63 digits
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-upstream_max_interleaving_delay
			 		Optionally define the maximum one way interleaving delay (ms)Default: None Dependencies: maximum 63 digits
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-upstream_max_rate
			 		Optionally define the maximum net data rate desired by the operator (kbps ).Default: None Dependencies: maximum 63 digits
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-upstream_min_low_power_rate
			 		Optionally define the net data rate desired by the operator in low power state (kbps).Default: None Dependencies: maximum 63 digits
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-upstream_min_rate
			 		Optionally define the minimum net data rate desired by the operator (kbps).Default: None Dependencies: maximum 63 digits
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-actual_rate_upstream_min_value
			x		Define the minimum value that actual_rate_upstream can have in resync profiles, mode "random".This parameter may be a list of values.Default: NoneDependencies: maximum 63 digits
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-actual_rate_downstream_min_value
			x		Define the minimum value that actual_rate_downstream can have in resync profiles, mode "random".This parameter may be a list of values.Default: NoneDependencies: maximum 63 digits
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-upstream_min_rate_min_value
			x		Define the minimum value that upstream_min_rate can have in resync profiles, mode "random".This parameter may be a list of values.Default: NoneDependencies: maximum 63 digits
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-downstream_min_rate_min_value
			x		Define the minimum value that downstream_min_rate can have in resync profiles, mode "random".This parameter may be a list of values.Default: NoneDependencies: maximum 63 digits
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-upstream_attainable_rate_min_value
			x		Define the minimum value that upstream_attainable_rate can have in resync profiles, mode "random".This parameter may be a list of values.Default: NoneDependencies: maximum 63 digits
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-downstream_attainable_rate_min_value
			x		Define the minimum value that downstream_attainable_rate can have in resync profiles, mode "random".This parameter may be a list of values.Default: NoneDependencies: maximum 63 digits
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-upstream_max_rate_min_value
			x		Define the minimum value that upstream_max_rate can have in resync profiles, mode "random".This parameter may be a list of values.Default: NoneDependencies: maximum 63 digits
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-downstream_max_rate_min_value
			x		Define the minimum value that downstream_max_rate can have in resync profiles, mode "random".This parameter may be a list of values.Default: NoneDependencies: maximum 63 digits
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-upstream_min_low_power_rate_min_value
			x		Define the minimum value that upstream_min_low_power_rate can have in resync profiles, mode "random".This parameter may be a list of values.Default: NoneDependencies: maximum 63 digits
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-downstream_min_low_power_rate_min_value
			x		Define the minimum value that downstream_min_low_power_rate can have in resync profiles, mode "random".This parameter may be a list of values.Default: NoneDependencies: maximum 63 digits
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-upstream_max_interleaving_delay_min_value
			x		Define the minimum value that upstream_max_interleaving_delay can have in resync profiles, mode "random".This parameter may be a list of values.Default: NoneDependencies: maximum 63 digits
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-upstream_act_interleaving_delay_min_value
			x		Define the minimum value that upstream_act_interleaving_delay can have in resync profiles, mode "random".This parameter may be a list of values.Default: NoneDependencies: maximum 63 digits
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-downstream_max_interleaving_delay_min_value
			x		Define the minimum value that downstream_max_interleaving_delay can have in resync profiles, mode "random".This parameter may be a list of values.Default: NoneDependencies: maximum 63 digits
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-downstream_act_interleaving_delay_min_value
			x		Define the minimum value that downstream_act_interleaving_delay can have in resync profiles, mode "random".This parameter may be a list of values.Default: NoneDependencies: maximum 63 digits
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-percentage
			x		Percent of subscribers that will use each profile. Valid only for -mode 'create'.May be a list, needs to have the following format: {x1 x2 x3 y1 y2 y3...} where x, y are the percentages for multiple profiles (needs to have the same length as actual_rate_upstream, for example).The number of such groups needs to be the same as the length of ancp_client_handle.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			n	-actual_rate_downstream_repeat
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-actual_rate_upstream_repeat
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-customer_vlan_id
			 		Inner VLAN ID for vlan_allocation_model N_1 and 1_1 VLAN mapping in Access-Aggregation-Circuit-ID-Binary TLV
			n	-customer_vlan_id_repeat
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-customer_vlan_id_step
			 		Step for customer_vlan_id
			 	-downstream_rate_tolerance
			 		Percentage for variation of Actual Net Data Rate Downstream TLV
			 		value when sending port-up messages in flapping behavior
			n	-enable_c_vlan
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-flap_mode
			 		Enable a flapping profile
			 		Valid choices are:
			    		none - Flapping disabled
			    		reset - Send Port-Up followed by Port-Down messages, one message every 'Flap Interval' seconds
			    		resynchronize - Send Port-Up messages, one message every 'Flap Interval' seconds
			    		stop - Disable flapping, and Send Port-Up if line state is SILENT
			n	-remote_id_suffix
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-remote_id_suffix_repeat
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-remote_id_suffix_step
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-service_vlan_id
			 		Outer VLAN ID for vlan_allocation_model 1_1 VLAN mapping in Access-Aggregation-Circuit-ID-Binary TLV
			n	-service_vlan_id_repeat
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-service_vlan_id_step
			 		Step for service_vlan_id
			 	-subscriber_line_down_time
			 		Interval in milliseconds to wait after sending port-down message when flapping is enabled
			 	-subscriber_line_up_time
			 		Interval in milliseconds to wait after sending port-up message when flapping is enabled
			 	-subscriber_lines_per_access_node
			 		Number of subscriber lines to create per Access Node
			 	-upstream_rate_tolerance
			 		Percentage for variation of Actual Net Data Rate Upstream TLV
			 		value when sending port-up messages in flapping behavior
			 	-vlan_allocation_model
			 		Access-Aggregation-Circuit-ID-Binary TLV disable, enable N:1 vlan allocation model or 1:1 vlan allocation model
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		disabled - TLV disabled
			    		N_1 - Enable N:1 model
			    		1_1 - Enable 1:1 model
		
		Return Values:
		A list containing the ancp subscriber lines protocol stack handles that were added by the command (if any).
			xkey:ancp_subscriber_lines_handle  value:A list containing the ancp subscriber lines protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE, Status of procedure call.
			 key:status                        value:$::SUCCESS | $::FAILURE, Status of procedure call.
		When status is failure, contains more information.
			 key:log                           value:When status is failure, contains more information.
		<ancp_subscriber_lines_handle> Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:handle                        value:<ancp_subscriber_lines_handle> Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		<ancp_subscriber_lines_handle>
			 key:handle                        value:<ancp_subscriber_lines_handle>
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) Unsupported parameters or unsupported parameter options will be
		silently ignored. If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		1) Unsupported parameters or unsupported parameter options will be silently ignored.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_ancp_subscriber_lines_config", kwargs)

	def emulation_bfd_config(self, **kwargs):
		""" This command is used to create/modify/delete/enable/disable a BFD router.  Each BFD router can have multiple BFD router interfaces.  Each router interface is associated with a protocol interface. By specifying the intf_... parameters there will be created a number of interfaces equal to intf_count of directly connected interfaces per BFD router. By specifying the loopback_... parameters there will be created a number of interfaces equal to loopback_count of unconnected interfaces per connected interface. By specifying the gre_... parameters there will be created a number of interfaces equal to gre_count of unconnected interfaces per connected interface(if no loopback_... parameters are specified) or per unconnected interface(if loopback_... parameters are specified). At the end the number of BFD router interfaces per BFD router will be: intf_count * loopback_count * gre_count. Each BFD router interface will be associated to: - a directly connected interface, if the user specifies only the intf_... parameters- an unconnected/loopback interface, if the user specifies the intf_... and the loopback_... parameters- a GRE tunnel, if the user specifies:         - the intf_... and the loopback_... and gre_... parameters- the intf_ and the gre_... parameters
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_bfd_config
			 	[-atm_encapsulation             ANY]
			 	[-control_interval              ANY]
			 	[-count                         NUMERIC
			                                 DEFAULT 1]
			 	[-echo_rx_interval              RANGE 0-4294967295
			                                 DEFAULT 0]
			 	[-echo_timeout                  RANGE 0-4294967295
			                                 DEFAULT 1500]
			 	[-echo_tx_interval              RANGE 0-4294967295
			                                 DEFAULT 0]
			 	[-control_plane_independent     CHOICES 0 1
			                                 DEFAULT 0]
			 	[-enable_demand_mode            CHOICES 0 1
			                                 DEFAULT 0]
			 	[-flap_tx_interval              RANGE 0-4294967295
			                                 DEFAULT 0]
			 	[-gre_count                     ANY]
			 	[-gre_ip_addr                   ANY]
			 	[-gre_ip_addr_step              ANY]
			 	[-gre_ip_addr_lstep             ANY]
			 	[-gre_ip_addr_cstep             ANY]
			 	[-gre_ip_prefix_length          ANY]
			 	[-gre_ipv6_addr                 ANY]
			 	[-gre_ipv6_addr_step            ANY]
			 	[-gre_ipv6_addr_lstep           ANY]
			 	[-gre_ipv6_addr_cstep           ANY]
			 	[-gre_ipv6_prefix_length        ANY]
			 	[-gre_dst_ip_addr               ANY]
			 	[-gre_dst_ip_addr_step          ANY]
			 	[-gre_dst_ip_addr_lstep         ANY]
			 	[-gre_dst_ip_addr_cstep         ANY]
			 	[-gre_checksum_enable           ANY]
			 	[-gre_key_enable                ANY]
			 	[-gre_key_in                    ANY]
			 	[-gre_key_in_step               ANY]
			 	[-gre_key_out                   ANY]
			 	[-gre_key_out_step              ANY]
			 	[-gre_seq_enable                ANY]
			 	[-gre_src_ip_addr_mode          ANY]
			 	[-handle                        ANY]
			 	[-intf_count                    ANY]
			 	[-gateway_ip_addr               IPV4
			                                 DEFAULT 0.0.0.0]
			 	[-gateway_ipv6_addr             IPV6
			                                 DEFAULT 0:0:0:0:0:0:0:0]
			 	[-gateway_ip_addr_step          IPV4
			                                 DEFAULT 0.0.1.0]
			 	[-gateway_ipv6_addr_step        IPV6
			                                 DEFAULT 0:0:0:1::0]
			 	[-intf_ip_addr                  IPV4]
			 	[-intf_ip_addr_step             IPV4
			                                 DEFAULT 0.0.1.0]
			 	[-intf_ip_prefix_length         RANGE 1-32
			                                 DEFAULT 24]
			 	[-intf_ipv6_addr                IPV6]
			 	[-intf_ipv6_addr_step           IPV6
			                                 DEFAULT 0:0:0:1::0]
			 	[-intf_ipv6_prefix_length       RANGE 1-128
			                                 DEFAULT 64]
			 	[-loopback_count                ANY]
			 	[-loopback_ip_addr              IPV4
			                                 DEFAULT 0.0.0.0]
			 	[-loopback_ip_addr_step         IPV4
			                                 DEFAULT 0.0.0.1]
			 	[-loopback_ip_addr_cstep        ANY]
			 	[-loopback_ip_prefix_length     RANGE 0-128
			                                 DEFAULT 24]
			 	[-loopback_ipv6_addr            IPV6]
			 	[-loopback_ipv6_addr_step       IPV6
			                                 DEFAULT 0:0:0:1::0]
			 	[-loopback_ipv6_addr_cstep      ANY]
			 	[-loopback_ipv6_prefix_length   RANGE 0-128
			                                 DEFAULT 64]
			 	[-local_mac_addr                MAC
			                                 DEFAULT 0000.0000.0001]
			 	[-local_mac_addr_step           MAC
			                                 DEFAULT 0000.0000.0001]
			 	[-min_rx_interval               RANGE 0-4294967295
			                                 DEFAULT 1000]
			 	-mode                           CHOICES create
			                                 CHOICES modify
			                                 CHOICES delete
			                                 CHOICES enable
			                                 CHOICES disable
			                                 DEFAULT create]
			 	[-mtu                           NUMERIC
			                                 DEFAULT 1500]
			 	[-detect_multiplier             RANGE 1-255
			                                 DEFAULT 3]
			 	[-override_existence_check      ANY]
			 	[-override_tracking             ANY]
			 	[-pkts_per_control_interval     ANY]
			 	[-poll_interval                 RANGE 0-4294967295
			                                 DEFAULT 0]
			 	[-port_handle                   ANY]
			x	[-reset                         ANY]
			 	[-router_id                     IPV4
			                                 DEFAULT 100.0.0.1]
			 	[-router_id_step                IPV4
			                                 DEFAULT 0.0.0.1]
			 	[-tx_interval                   RANGE 50-4294967295
			                                 DEFAULT 1000]
			 	[-vlan                          CHOICES 0 1
			                                 DEFAULT 0]
			 	[-vlan_id1                      RANGE 0-4095
			                                 DEFAULT 1]
			 	[-vlan_id2                      RANGE 0-4095
			                                 DEFAULT 1]
			 	[-vlan_id_step1                 RANGE 0-4096
			                                 DEFAULT 0]
			 	[-vlan_id_step2                 RANGE 0-4096
			                                 DEFAULT 0]
			 	[-vlan_user_priority1           RANGE 0-7
			                                 DEFAULT 0]
			 	[-vlan_user_priority2           RANGE 0-7
			                                 DEFAULT 0]
			 	[-vlan_ether_type1              CHOICES 0x8100
			                                 CHOICES 0x88a8
			                                 CHOICES 0x88A8
			                                 CHOICES 0x9100
			                                 CHOICES 0x9200
			                                 CHOICES 0x9300
			                                 DEFAULT 0x8100]
			 	[-vlan_ether_type2              CHOICES 0x8100
			                                 CHOICES 0x88a8
			                                 CHOICES 0x88A8
			                                 CHOICES 0x9100
			                                 CHOICES 0x9200
			                                 CHOICES 0x9300
			                                 DEFAULT 0x8100]
			 	[-vlan_id_mode1                 CHOICES fixed increment
			                                 DEFAULT increment]
			 	[-vlan_id_mode2                 CHOICES fixed increment
			                                 DEFAULT increment]
			x	[-configure_echo_source_ip      CHOICES 0 1
			x                                DEFAULT 0]
			x	[-echo_source_ip4               IPV4
			x                                DEFAULT 0.0.0.0]
			x	[-echo_source_ip6               IPV6
			x                                DEFAULT 0:0:0:0:0:0:0:0]
			x	[-ip_diff_serv                  RANGE 0-4294967295
			x                                DEFAULT 0]
			x	[-interface_active              CHOICES 0 1
			x                                DEFAULT 1]
			x	[-interface_name                ALPHA]
			x	[-router_active                 CHOICES 0 1
			x                                DEFAULT 1]
			x	[-router_name                   ALPHA]
			 	[-vpi                           ANY]
			 	[-vci                           ANY]
			 	[-vpi_step                      ANY]
			 	[-vci_step                      ANY]
			 	[-session_count                 NUMERIC
			                                 DEFAULT 1]
			 	[-enable_auto_choose_source     CHOICES 0 1
			                                 DEFAULT 1]
			 	[-enable_learned_remote_disc    CHOICES 0 1
			                                 DEFAULT 1]
			 	-ip_version                     CHOICES 4 6
			                                 DEFAULT 4]
			 	[-session_discriminator         RANGE 1-4294967295
			                                 DEFAULT 1]
			 	[-session_discriminator_step    RANGE 0-4294967294
			                                 DEFAULT 1]
			 	[-remote_discriminator          RANGE 1-4294967295
			                                 DEFAULT 1]
			 	[-remote_discriminator_step     RANGE 0-4294967294
			                                 DEFAULT 1]
			x	[-source_ip_addr                ANY
			x                                DEFAULT 0.0.0.0]
			x	[-source_ip_addr_step           ANY
			x                                DEFAULT 0.0.0.1]
			 	[-remote_ip_addr                IPV4
			                                 DEFAULT 0.0.0.0]
			 	[-remote_ip_addr_step           IPV4
			                                 DEFAULT 0.0.0.1]
			x	[-source_ipv6_addr              ANY
			x                                DEFAULT 0:0:0:0:0:0:0:0]
			x	[-source_ipv6_addr_step         ANY
			x                                DEFAULT 0:0:0:1:0:0:0:0]
			 	[-remote_ipv6_addr              IPV6
			                                 DEFAULT 0:0:0:0:0:0:0:0]
			 	[-remote_ipv6_addr_step         IPV6
			                                 DEFAULT 0:0:0:1:0:0:0:0]
			x	[-session_handle                ANY]
			 	[-hop_mode                      CHOICES singlehop multiplehop
			                                 DEFAULT singlehop]
			x	[-session_active                CHOICES 0 1
			x                                DEFAULT 1]
			x	[-session_name                  ALPHA]
			x	[-ip_ttl                        ANY]
			x	[-enable_ovsdb_communication    ANY]
			x	[-remote_mac                    ANY]
			x	[-aggregate_bfd_session         CHOICES 0 1
			x                                DEFAULT 0]
			 	[-enable_ctrl_plane_independent ANY]
			 	[-interface_handle              ANY]
			 	[-intf_gw_ip_addr               ANY]
			 	[-intf_gw_ip_addr_step          ANY]
			 	[-mac_address_init              ANY]
			 	[-mac_address_step              ANY]
			 	[-multiplier                    ANY]
			 	[-vlan_id                       ANY]
			 	[-vlan_id_step                  ANY]
			 	[-vlan_user_priority            ANY]
		
		Arguments:
			 	-atm_encapsulation
			 		This parameter specifies the ATM encapsulation for an ATM router interface. The options are VccMuxIPV4Routed, VccMuxIPV6Routed, VccMuxBridgedEthernetFCS, VccMuxBridgedEthernetNoFCS, LLCRoutedCLIP, LLCBridgedEthernetFCS, LLCBridgedEthernetNoFCS.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-control_interval
			 		Sets the rate control interval at port level. If the control interval is set using multiple calls to emulation_bfd_config, the last value will be the one set.This option is valid only when -mode is create or -mode is modify.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-count
			 		The number of BFD routers that need to be created.
			 		This option is valid only when -mode is create.
			 		(DEFAULT = 1)
			 	-echo_rx_interval
			 		This is the minimum interval, in microseconds, between received BFD
			 		Echo packets that this system is capable of supporting. If this value
			 		is zero, the transmitting system does not support the receipt of BFD
			 		Echo packets. The supported range is 0-4,294,967,295, and the enable
			 		range is 50-4,294,967,295. All values between 1-49 will be considered
			 		as the minimum timer of 50.
			 		When the Echo function is active, a stream of BFD Echo packets is
			 		transmitted in such a way as to have the other system loop them back
			 		through its forwarding path( same source and destination IP in the Echo
			 		packet sent on a specific UDP Port No ). If a number of packets of the
			 		echoed data streamare not received, the session is declared to be
			 		down.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is provided.
			 		(DEFAULT = 0)
			 	-echo_timeout
			 		The value must be chosen in such a way so that the session liveliness
			 		should be verified by Echo conveniently. Remember, since Echo Time Out
			 		is configurable, it is possible that the session may have a higher Echo
			 		Time Out than BFD Control Time Out. On expiry of Echo Time Out the
			 		session will be deleted and the entire process of BFD session
			 		establishment will happen from the DOWN state. The supported range
			 		is 0-4,294,967,295, and the enable range is 50-4,294,967,295. All
			 		values between 1-49 will be considered as the minimum timer of 50.
			 		When the Echo function is active, a stream of BFD Echo packets is
			 		transmitted in such a way as to have the other system loop them back
			 		through its forwarding path( same source and destination IP in the Echo
			 		packet sent on a specific UDP Port No ). If a number of packets of the
			 		echoed data streamare not received, the session is declared to be
			 		down.
			 		This option is valid only when -echo_tx_interval is present and has a
			 		value greater than or equal to 50 and -mode is create or -mode is modify
			 		and -handle is provided.
			 		(DEFAULT = 1500)
			 	-echo_tx_interval
			 		If Echo Tx interval is configured, Echo packets will be sent at an
			 		interval of Echo Tx interval. If the configurable Echo Tx interval is
			 		not set to a value greater than 50, the transmitter will use the Echo
			 		Rx interval of the connected device to send its Echo Packets. The
			 		supported range is 0-4,294,967,295, and the enable range
			 		is 50-4,294,967,295. All values between 1-49 will be considered as the
			 		minimum timer of 50.
			 		When the Echo function is active, a stream of BFD Echo packets is
			 		transmitted in such a way as to have the other system loop them back
			 		through its forwarding path( same source and destination IP in the Echo
			 		packet sent on a specific UDP Port No ). If a number of packets of the
			 		echoed data streamare not received, the session is declared to be
			 		down.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is provided.
			 		(DEFAULT = 0)
			 	-control_plane_independent
			 		If set, the transmitting system's BFD implementation does not share
			 		fate with its control plane (in other words, BFD is implemented in the
			 		forwarding plane and can continue to function through disruptions in
			 		the control plane). If clear, the transmitting system's BFD
			 		implementation shares fate with its control plane. The use of this bit
			 		is application dependent and is outside the scope of this specification.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is provided.
			 		(DEFAULT = 0)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-enable_demand_mode
			 		BFD has two operating modes which may be selected, as well as an
			 		additional function that can be used in combination with the two modes,
			 		the echo function.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is provided.
			 		(DEFAULT = 0) Valid choices are:
			 		0, Asynchronous mode - In this mode, thesystems periodically send
			 		BFD Control packets to one another, and if a number of those
			 		packets in a row are not received by the other system, the session is
			 		declared to be down. If -enable_demand_mode is set to 0, the system
			 		will be in asynchronous mode.
			 		1, Demand mode - In this mode, once a BFD session is established, the
			 		systems stop sending BFD Control packets, except when either system
			 		feels the need to verify connectivity explicitly, in whichcase a
			 		short sequence of BFD Control packets is sent, and then the
			 		protocol again stops sending Control packets. If enable_demand_mode
			 		is set to 1, the system will be in demand mode.
			 	-flap_tx_interval
			 		BFD sessions will flap every flap_tx_interval (ms).
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is provided.
			 		(DEFAULT = 0)
			 	-gre_count
			 		The number of GRE tunnels to be created per directly connected interface or per loopback interface. The presence/absence of loopback_... parameters specifies whether the source of the GRE tunnel is the directly connected interface or the loopback interface. If the loopback_... parameters are present the GRE interface will be connected through the loopback interface, otherwise it will be connected through the directly connected interface.This option is valid only when -mode is create and -gre_ip_addr and/or -gre_ipv6_addr are present.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_ip_addr
			 		The first GRE tunnel IPv4 address that will be configured.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_ip_addr_step
			 		The IPv4 address incrementing step of the GRE tunnels that will be configured.This option is valid only when -mode is create and -gre_ip_addr is present.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_ip_addr_lstep
			 		The IPv4 address incrementing step of the GRE tunnels that will be configured when passing from one loopback interface to another.
			 		This option is valid only when -mode is create and -gre_ip_addr is present.
			 		When gre_src_ip_addr_mode is routed, then both gre_ip_addr_cstep and gre_ip_addr_lstep must be present if this kind of incrementing is wanted. If only one of them is present, the two parameters are ignored and only gre_ip_addr_step is taken into account. 
			 		When gre_src_ip_addr_mode is connected, then only gre_ip_addr_cstep will be considered. If gre_ip_addr_cstep is not present, the incrementing is based on gre_ip_addr_step.
			 		Example:
			 		- The GRE tunnels have the loopback interfaces as source.
			 		intf_count2
			 		loopback_count2
			 		gre_count3
			 		gre_src_ip_addr_moderouted
			 		gre_ip_addr1.0.0.1
			 		gre_ip_addr_step0.0.0.1
			 		gre_ip_addr_lstep0.0.1.0
			 		gre_ip_addr_cstep0.1.0.0
			 		The following list of GRE IP addresses will be generated:
			 		Connected1, Loopback1,GRE1- 1.0.0.1; 
			 		Connected1, Loopback1,GRE2- 1.0.0.2; 
			 		Connected1, Loopback1,GRE3- 1.0.0.3;
			 		Connected1, Loopback2,GRE4- 1.0.1.1; 
			 		Connected1, Loopback2,GRE5- 1.0.1.2; 
			 		Connected1, Loopback2,GRE6- 1.0.1.3;
			 		Connected2, Loopback1,GRE7- 1.1.0.1; 
			 		Connected2, Loopback1,GRE8- 1.1.0.2; 
			 		Connected2, Loopback1,GRE9- 1.1.0.3;
			 		Connected2, Loopback2,GRE10 - 1.1.1.1; 
			 		Connected2, Loopback2,GRE11 - 1.1.1.2; 
			 		Connected2, Loopback2,GRE12 - 1.1.1.3;
			 		- The GRE tunnels have the connected interfaces as source
			 		intf_count2
			 		gre_count3
			 		gre_src_ip_addr_mode connected
			 		gre_ip_addr1.0.0.1
			 		gre_ip_addr_step0.0.0.1
			 		gre_ip_addr_cstep0.1.0.0
			 		The following list of GRE IP addresses will be generated:
			 		Connected1, GRE1 - 1.0.0.1; 
			 		Connected1, GRE2 - 1.0.0.2; 
			 		Connected1, GRE3 - 1.0.0.3;
			 		Connected2, GRE7 - 1.1.0.1; 
			 		Connected2, GRE8 - 1.1.0.2; 
			 		Connected2, GRE9 - 1.1.0.3;
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_ip_addr_cstep
			 		The IPv4 address incrementing step of the GRE tunnels that will be configured when passing from one connected interface to another.This option is valid only when -mode is create and -gre_ip_addr is present.When gre_src_ip_addr_mode is routed, then both gre_ip_addr_cstep and gre_ip_addr_lstep must be present if this kind of incrementing is wanted. If only one of them is present, the two parameters are ignored and only gre_ip_addr_step is taken into account. When gre_src_ip_addr_mode is connected, then only gre_ip_addr_cstep will be considered. If gre_ip_addr_cstep is not present, the incrementing is based on gre_ip_addr_step.See example under gre_ip_addr_lstep.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_ip_prefix_length
			 		The IPv4 address prefix of the GRE interfaces that will be configured.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_ipv6_addr
			 		The first GRE IPv6 address that will be configured.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_ipv6_addr_step
			 		The IPv6 address incrementing step of the GRE interfaces that will be configured.This option is valid only when -mode is create and -gre_ipv6_addr is present.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_ipv6_addr_lstep
			 		The IPv4 address incrementing step of the GRE tunnels that will be configured when passing from one loopback interface to another.This option is valid only when -mode is create and -gre_ipv6_addr is present.When gre_src_ip_addr_mode is routed, then both gre_ipv6_addr_cstep and gre_ipv6_addr_lstep must be present if this kind of incrementing is wanted. If only one of them is present, the two parameters are ignored and only gre_ipv6_addr_step is taken into account. When gre_src_ip_addr_mode is connected, then only gre_ipv6_addr_cstep will be considered. If gre_ipv6_addr_cstep is not present, the incrementing is based on gre_ipv6_addr_step.See example under gre_ip_addr_lstep.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_ipv6_addr_cstep
			 		The IPv4 address incrementing step of the GRE tunnels that will be configured when passing from one connected interface to another.This option is valid only when -mode is create and -gre_ipv6_addr is present.When gre_src_ip_addr_mode is routed, then both gre_ipv6_addr_cstep and gre_ipv6_addr_lstep must be present if this kind of incrementing is wanted. If only one of them is present, the two parameters are ignored and only gre_ipv6_addr_step is taken into account. When gre_src_ip_addr_mode is connected, then only gre_ipv6_addr_cstep will be considered. If gre_ipv6_addr_cstep is not present, the incrementing is based on gre_ipv6_addr_step.See example under gre_ip_addr_lstep.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_ipv6_prefix_length
			 		The IPv6 address prefix of the GREinterfaces that will be configured.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_dst_ip_addr
			 		The first GRE tunnel destination IPv4/6 address that will be configured.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_dst_ip_addr_step
			 		The destination IPv4/6 address incrementing step of the GRE tunnels that will be configured.This option is valid only when -mode is create.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_dst_ip_addr_lstep
			 		The IPv4 address incrementing step of the GRE tunnels that will be configured when passing from one loopback interface to another.This option is valid only when -mode is create and -gre_dst_ip_addr is present.When gre_src_ip_addr_mode is routed, then both gre_dst_ip_addr_cstep and gre_dst_ip_addr_lstep must be present if this kind of incrementing is wanted. If only one of them is present, the two parameters are ignored and only gre_dst_ip_addr_step is taken into account. When gre_src_ip_addr_mode is connected, then only gre_ip_addr_cstep will be considered. If gre_dst_ip_addr_cstep is not present, the incrementing is based on gre_dst_ip_addr_step.See example under gre_ip_addr_lstep.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_dst_ip_addr_cstep
			 		The IPv4 address incrementing step of the GRE tunnels that will be configured when passing from one connected interface to another.This option is valid only when -mode is create and -gre_dst_ip_addr is present.When gre_src_ip_addr_mode is routed, then both gre_dst_ip_addr_cstep and gre_dst_ip_addr_lstep must be present if this kind of incrementing is wanted. If only one of them is present, the two parameters are ignored and only gre_dst_ip_addr_step is taken into account. When gre_src_ip_addr_mode is connected, then only gre_ip_addr_cstep will be considered. If gre_dst_ip_addr_cstep is not present, the incrementing is based on gre_dst_ip_addr_step.See example under gre_ip_addr_lstep.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_checksum_enable
			 		This parameter enables/disables the checksum on a GRE interface.Valid options are: 0 - disable, 1 - enable.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_key_enable
			 		This parameter enables/disables the in/out keys on a GRE interface.Valid options are: 0 - disable, 1 - enable.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_key_in
			 		This parameter represents the GRE tunnel in key. The range of values is between 0 and 4,294,967,295.This option is valid only when -mode is create and -gre_enable_key is 1 or -mode is modify and -handle is a BFD router interface and -gre_enable_key is 1.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_key_in_step
			 		This parameter represents the GRE tunnel in key step. The range of values is between 0 and 4,294,967,295.This option is valid only when -mode is create.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_key_out
			 		This parameter represents the GRE tunnel out key. The range of values is between 0 and 4,294,967,295.This option is valid only when -mode is create and -gre_enable_key is 1 or -mode is modify and -handle is a BFD router interface and -gre_enable_key is 1.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_key_out_step
			 		This parameter represents the GRE tunnel out key step. The range of values is between 0 and 4,294,967,295.This option is valid only when -mode is create.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gre_seq_enable
			 		This parameter enables/disables the sequencingon a GRE interface.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 		Valid choices are:
			    		0 - disable
			    		1 - enable
			 	-gre_src_ip_addr_mode
			 		This parameter specifies whether the source of the GRE tunnel is a loopback interface or a connected interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 		Valid choices are:
			    		routed -
			    		connected -
			 	-handle
			 		The BFD router handle returned by a previous call to
			 		emulation_bfd_config with -mode create. This option is mandatory
			 		when -mode is modify/enable/disable/delete.
			 	-intf_count
			 		The number of directly connected protocol interfaces to be created per BFD router. This option is valid only when -mode is create.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-gateway_ip_addr
			 		The gateway IP address for the router interface that is going to be
			 		created.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 0.0.0.0)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-gateway_ipv6_addr
			 		The gateway IPv6 address for the router interface that is going to be created.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 0:0:0:0:0:0:0:0)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-gateway_ip_addr_step
			 		The gateway IP address incrementing step for the router interface that
			 		is going to be created.
			 		This option is valid only when -mode is create.
			 		(DEFAULT = 0.0.1.0)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-gateway_ipv6_addr_step
			 		The gateway IP address incrementing step for the router interface that
			 		is going to be created.
			 		This option is valid only when -mode is create.
			 		(DEFAULT = 0:0:0:1::0)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-intf_ip_addr
			 		The first IPv4 address of the first BFD router interface that will be
			 		configured.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 	-intf_ip_addr_step
			 		The IPv4 address incrementing step of the BFD router interfaces that
			 		will be configured.
			 		This option is valid only when -mode is create.
			 		(DEFAULT = 0.0.1.0)
			 	-intf_ip_prefix_length
			 		The IPv4 address prefix of the BFD router interfaces that will be
			 		configured.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 24)
			 	-intf_ipv6_addr
			 		The first IPv6 address of the first BFD router interface that will be
			 		configured.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 	-intf_ipv6_addr_step
			 		The IPv6 address incrementing step of the BFD router interfaces that
			 		will be configured.
			 		This option is valid only when -mode is create.
			 		(DEFAULT = 0:0:0:1::0)
			 	-intf_ipv6_prefix_length
			 		The IPv6 address prefix of the BFD router interfaces that will be
			 		configured.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 64)
			 	-loopback_count
			 		The number of loopback interfaces that will be configured for each directly connected protocol interface.This option is valid only when -mode is create.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-loopback_ip_addr
			 		The first loopback IPv4 address of the first BFD router that will be
			 		configured.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 	-loopback_ip_addr_step
			 		The IPv4 address incrementing step of the loopback interfaces that will
			 		be configured.
			 		This option is valid only when -mode is create.
			 		(DEFAULT = 0.0.0.1)
			 	-loopback_ip_addr_cstep
			 		The IPv4 address incrementing step of the loopback interfaces that will be configured when passing from a connected interface to another.If this option is not present, only the loopback_ip_addr_step will be used.This option is valid only when -mode is create.Please see example 2 from gre_ip_addr_lstep.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-loopback_ip_prefix_length
			 		The IPv4 address prefix of the loopbackinterfaces that will be
			 		configured.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 24)
			 	-loopback_ipv6_addr
			 		The first loopback IPv6 address of the first BFD router that will be
			 		configured.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 	-loopback_ipv6_addr_step
			 		The IPv6 address incrementing step of the loopback interfaces that will
			 		be configured.
			 		This option is valid only when -mode is create.
			 		(DEFAULT = 0:0:0:1::0)
			 	-loopback_ipv6_addr_cstep
			 		The IPv6 address incrementing step of the loopback interfaces that will be configured when passing from a connected interface to another.If this option is not present, only the loopback_ipv6_addr_step will be used.This option is valid only when -mode is create.Please see example 2 from gre_ip_addr_lstep.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-loopback_ipv6_prefix_length
			 		The IPv6 address prefix of the loopbackinterfaces that will be
			 		configured.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 64)
			 	-local_mac_addr
			 		The first MAC address of the first directly connected interface that
			 		will be configured.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 0000.0000.0001)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-local_mac_addr_step
			 		The incrementing step of the directly connected interface that
			 		will be configured. This option is valid only when -mode is create.
			 		(DEFAULT = 0000.0000.0001)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-min_rx_interval
			 		This is the minimum interval, in microseconds, between received BFD
			 		Control packets that this system is capable of supporting. If this
			 		value is zero, the transmitting system does not want the remote system
			 		to send any periodic BFD Control packets. Any value between 1 and 49
			 		will be set to the minimum value of 50. The range is 0-4,294,967,295.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 1000)
			 	-mode
			 		The operation that will be executed. This option has the following dependencies:
			 		when mode is create, -port_handle is required
			 		when mode is modify/enable/disable/delete, -handle is required
			 		(DEFAULT = create) Valid choices are:
			 		create - create BFD router(s)
			 		modify - modify BFD router(s)
			 		enable - enable BFD router(s)
			 		disable - disable BFD router(s)
			 		delete - delete BFD router(s)
			 		Valid choices are:
			    		create -
			    		modify -
			    		delete -
			    		enable -
			    		disable -
			 	-mtu
			 		The MTU value for the directly connected interfaces.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 1500)
			 	-detect_multiplier
			 		Detection time multiplier. The negotiated transmit interval, multiplied
			 		by this value, provides the detection time for the transmitting system
			 		in Asynchronous mode. Range 1-255.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 3)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-override_existence_check
			 		If this option is enabled, the interface existence check is skipped but the list of interfaces is still created and maintained in order to keep track of existing interfaces if required. Using this option will speed up the the creation of the interfaces.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-override_tracking
			 		If this option is enabled, the list of interfaces will not be created and maintained anymore, thus, speeding up the interfaces' creation even more. Also, it will enable -override_existence_check in case it was not already enabled because checking for interface existence becomes impossible if the the list of interfaces does not exist anymore.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-pkts_per_control_interval
			 		Sets the numbers of packets to be transmitted per rate control interval at port level.This option is valid only when -mode is create or -mode is modify.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-poll_interval
			 		If in Demand Mode, polling will take place every poll_interval
			 		interval. Range 0-4,294,967,295.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 0)
			 	-port_handle
			 		The port where the action will take place.Mandatory when -mode is create, ignored otherwise.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-reset
			x		If this flag is present all the BFD configuration on that specific port
			x		is erased. This option is requires -mode create and -port_handle to be
			x		provided.
			 	-router_id
			 		The router ID in IPv4 format for the BFD router.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is provided.
			 		(DEFAULT = 100.0.0.1)
			 	-router_id_step
			 		The router ID step in IPv4 format for the BFD router.
			 		This option is valid only when -mode is create.
			 		(DEFAULT = 0.0.0.1)
			 	-tx_interval
			 		This is the minimum interval, in microseconds, that the local system
			 		would like to use when transmitting BFD Control packets.
			 		Range 50 - 4,294,967,295.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 1000)
			 	-vlan
			 		Enables vlan on the directly connected BFD router interface.
			 		Valid options are: 0 - disable, 1 - enable.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 0)
			 	-vlan_id1
			 		Sets the vlan ID on the directly connected BFD router interface.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 1)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_id2
			 		Sets the outer vlan ID on the directly connected BFD router interface.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 1)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_id_step1
			 		The incrementing step for vlan ID when creating directly connected
			 		protocol interfaces. This option is valid only when -mode is create.
			 		When vlan_id_step1 causes the vlan_id value to exceed its maximum value the
			 		increment will be done modulo <number of possible vlan ids>.
			 		Examples: vlan_id1 = 4094; vlan_id_step1 = 2-> new vlan_id1 value = 0
			 		vlan_id1 = 4095; vlan_id_step1 = 11 -> new vlan_id1 value = 10
			 		(DEFAULT = 1)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_id_step2
			 		The incrementing step for outer vlan ID when creating directly connected
			 		protocol interfaces. This option is valid only when -mode is create.
			 		When vlan_id_step2 causes the vlan_id2 value to exceed its maximum value the
			 		increment will be done modulo <number of possible vlan ids>.
			 		Examples: vlan_id2 = 4094; vlan_id_step2 = 2-> new vlan_id2 value = 0
			 		vlan_id2 = 4095; vlan_id_step2 = 11 -> new vlan_id2 value = 10
			 		(DEFAULT = 1)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_user_priority1
			 		Sets the vlan ID1 user priority on the directly connected BFD router
			 		interfaces.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 0)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_user_priority2
			 		Sets the vlan ID2 user priority on the directly connected BFD router
			 		interfaces.
			 		This option is valid only when -mode is create or -mode is modify
			 		and -handle is a BFD router interface.
			 		(DEFAULT = 0)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_ether_type1
			 		Sets the vlan ID1 ethertype
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		0x8100 -
			    		0x88a8 -
			    		0x88A8 -
			    		0x9100 -
			    		0x9200 -
			    		0x9300 -
			 	-vlan_ether_type2
			 		Sets the vlan ID2 ethertype
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		0x8100 -
			    		0x88a8 -
			    		0x88A8 -
			    		0x9100 -
			    		0x9200 -
			    		0x9300 -
			 	-vlan_id_mode1
			 		If the user configures more than one interface on the Ixia with
			 		VLAN, he can choose to automatically increment the VLAN tag or
			 		leave it idle for each interface.
			 		(DEFAULT = increment)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		fixed -
			    		increment -
			 	-vlan_id_mode2
			 		If the user configures more than one interface on the Ixia with
			 		VLAN, he can choose to automatically increment the VLAN tag or
			 		leave it idle for each interface.
			 		(DEFAULT = increment)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		fixed -
			    		increment -
			x	-configure_echo_source_ip
			x		ability to configure the source address IP of echo message
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-echo_source_ip4
			x		If configure Echo source IP is selected, the IPv4 source address of the Echo Message.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-echo_source_ip6
			x		If configure Echo source IP is selected, the IPv6 source address of the Echo Message.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ip_diff_serv
			x		If configure ip diff value
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_active
			x		Activate or Deactivate Configuration
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_name
			x		Longer, more descriptive name for element it is not guaranteed to be unique like interface_name-, but maybe offers more context
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-router_active
			x		Activate or Deactivate Configuration
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-router_name
			x		Name of Bfd Router stack in the scenario.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-vpi
			 		Sets the VPI value on the directly connected BFD router interfaces.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vci
			 		Sets the VCI value on the directly connected BFD router interfaces.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vpi_step
			 		The incrementing step for VPI when creating directly connected protocol interfaces.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.When vpi_step causes the vpi value to exceed its maximum value the increment will be done modulo <number of possible vpi ids>.Examples: vpi = 254; vpi_step = 2-> new vpi value = 0vpi = 255; vpi_step = 11 -> new vpi value = 10
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vci_step
			 		The incrementing step for VCI when creating directly connected protocol interfaces. When vci_step causes the vci value to exceed its maximum value the increment will be done modulo <number of possible vci ids>.
			 		Examples:
			 		- vci = 65534; vci_step = 2-> new vci value = 0- vci = 65535; vci_step = 11 -> new vci value = 10
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_count
			 		No of Sessions per interface
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-enable_auto_choose_source
			 		Setting this parameter to 1,
			 		enables the session to automatically choose the source IP address for the BFD session.
			 		In this case, the local_ip_addr parameter is ignored. Setting this parameter to 0,
			 		enables the local_ip_addr parameter.This option is valid only when -mode is create
			 		and -handle is provided or -mode is modify and -session_handle is provided.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-enable_learned_remote_disc
			 		Enables the ability of this BFD session to learn the value
			 		of the discriminator of the far end of the BFD session. If
			 		this option is set to 1, the remote_disc option will be ignored.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ip_version
			 		The IP version of the interface.Choices are:4, 6
			 		(DEFAULT = 4)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		4 -
			    		6 -
			 	-session_discriminator
			 		A unique, nonzero discriminator value generated by the interface,
			 		used to de-multiplex multiple BFD sessions between the same pair of systems.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-session_discriminator_step
			 		The local session discriminator step. Used when creating multiple BFD sessions.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-remote_discriminator
			 		The discriminator received from the corresponding remote system.
			 		This field reflects back the received value of local_disc, or is zero if that value is unknown.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-remote_discriminator_step
			 		The step for the remote discriminator, when creating multiple sessions.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-source_ip_addr
			x		The IPv4 address of the source in the BFD session.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-source_ip_addr_step
			x		The IPv4 address step of the source ip in the BFD session, when creating multiple BFD sessions.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-remote_ip_addr
			 		The IPv4 address of the remote router in the BFD session.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-remote_ip_addr_step
			 		The IPv4 address step of the remote router in the BFD session, when creating multiple BFD sessions.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-source_ipv6_addr
			x		The IPv6 address of the source in the BFD session.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-source_ipv6_addr_step
			x		The IPv6 address step of the source in the BFD session, when creating multiple BFD sessions.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-remote_ipv6_addr
			 		The IPv6 address of the remote router in the BFD session.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-remote_ipv6_addr_step
			 		The IPv6 address step of the remote router in the BFD session, when creating multiple BFD sessions.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-session_handle
			x		session handle value
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-hop_mode
			 		BGFD hop mode, defines the type of BFD session. Can be single or multi hop.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		singlehop -
			    		multiplehop -
			x	-session_active
			x		Activate or Deactivate Session Configuration
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-session_name
			x		Longer, more descriptive name for element it is not guaranteed to be unique like session_name-, but maybe offers more context
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ip_ttl
			x		TTL value of inner ip of BFDoVXLAN packet
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_ovsdb_communication
			x		Selecting this check box enables the ability to communicate the remote IP and MAC address of BFD Session
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-remote_mac
			x		Remote MAC Address of Peer
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-aggregate_bfd_session
			x		If Enabled , all interfaces except on VNI 0 will be disabled and grayed -out
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-enable_ctrl_plane_independent
			 		If set, the transmitting system's BFD implementation does not share fate with its control plane (in other words, BFD is implemented in the forwarding plane and can continue to function through disruptions in the control plane). If clear, the transmitting system's BFD implementation shares fate with its control plane. The use of this bit is application dependent and is outside the scope of this specification. This option is valid only when -mode is create or -mode is modify and -handle is provided.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-interface_handle
			 		The protocol interface handle(s) obtained with a previous interface_config call. The BFD router(s) will be associated with these interface(s). The number of interfaces in the list must be equal to:<count> * <intf_count> * <loopback_count> * <gre_count>.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-intf_gw_ip_addr
			 		The gateway IP address for the router interface that is going to be created.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-intf_gw_ip_addr_step
			 		The gateway IP address incrementing step for the router interface that is going to be created.This option is valid only when -mode is create.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-mac_address_init
			 		The first MAC address of the first directly connected interface that will be configured.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-mac_address_step
			 		The incrementing step of the directly connected interface that will be configured. This option is valid only when -mode is create.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-multiplier
			 		Detection time multiplier. The negotiated transmit interval, multiplied by this value, provides the detection time for the transmitting system in Asynchronous mode. Range 1-255.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vlan_id
			 		Sets the vlan ID on the directly connected BFD router interface.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vlan_id_step
			 		The incrementing step for vlan ID when creating directly connected protocol interfaces. This option is valid only when -mode is create.When vlan_id_step causes the vlan_id value to exceed its maximum value the increment will be done modulo <number of possible vlan ids>.Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vlan_user_priority
			 		Sets the vlan ID user priority on the directly connected BFD router interfaces.This option is valid only when -mode is create or -mode is modify and -handle is a BFD router interface.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
		
		Return Values:
		A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
			xkey:ipv4_loopback_handle       value:A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
		A list containing the ipv6 loopback protocol stack handles that were added by the command (if any).
			xkey:ipv6_loopback_handle       value:A list containing the ipv6 loopback protocol stack handles that were added by the command (if any).
		A list containing the ipv4 protocol stack handles that were added by the command (if any).
			xkey:ipv4_handle                value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		A list containing the ipv6 protocol stack handles that were added by the command (if any).
			xkey:ipv6_handle                value:A list containing the ipv6 protocol stack handles that were added by the command (if any).
		A list containing the ethernet protocol stack handles that were added by the command (if any).
			xkey:ethernet_handle            value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		A list containing the bfd router protocol stack handles that were added by the command (if any).
			xkey:bfd_router_handle          value:A list containing the bfd router protocol stack handles that were added by the command (if any).
		A list containing the bfd v4 interface protocol stack handles that were added by the command (if any).
			xkey:bfd_v4_interface_handle    value:A list containing the bfd v4 interface protocol stack handles that were added by the command (if any).
		A list containing the bfd v6 interface protocol stack handles that were added by the command (if any).
			xkey:bfd_v6_interface_handle    value:A list containing the bfd v6 interface protocol stack handles that were added by the command (if any).
		A list containing the bfd v4 session protocol stack handles that were added by the command (if any).
			xkey:bfd_v4_session_handle      value:A list containing the bfd v4 session protocol stack handles that were added by the command (if any).
		A list containing the bfd v6 session protocol stack handles that were added by the command (if any).
			xkey:bfd_v6_session_handle      value:A list containing the bfd v6 session protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:handle                     value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:interfaces                 value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		$::SUCCESS | $::FAILURE
			 key:status                     value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                        value:On status of failure, gives detailed information.
		On mode create, list of router handles
			 key:router_handles             value:On mode create, list of router handles
		On mode create, list of router interface handles for a specific <router_handle>
			 key:router_interface_handles.  value:On mode create, list of router interface handles for a specific <router_handle>
		On mode create, list of protocol interface handles for a specific <router_handle>
			 key:interface_handles.         value:On mode create, list of protocol interface handles for a specific <router_handle>
		
		Examples:
		See files starting with BFD_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) This protocol is available only when using IxNetwork Tcl API. If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle, interfaces
		1) This protocol is available only when using IxNetwork Tcl API.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_bfd_config", kwargs)

	def emulation_bfd_control(self, **kwargs):
		""" This procedure starts/stops a BFD configuration.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_bfd_control
			 	-mode             CHOICES start
			                   CHOICES stop
			                   CHOICES restart
			                   CHOICES abort
			                   CHOICES resume_pdu
			                   CHOICES stop_pdu
			                   CHOICES demand_mode_disable
			                   CHOICES demand_mode_enable
			                   CHOICES initiate_poll
			                   CHOICES set_admin_down
			                   CHOICES set_admin_up
			                   CHOICES set_diagnostic_state
			 	[-port_handle     ANY]
			 	[-handle          ANY]
			x	[-protocol_name   CHOICES isis
			x                  CHOICES bfd
			x                  CHOICES ospf
			x                  CHOICES ospfv3
			x                  CHOICES pim
			x                  CHOICES bgp
			x                  CHOICES ldp
			x                  CHOICES rsvp
			x                  DEFAULT bfd]
			x	[-diagnostic_code CHOICES administratively_down
			x                  CHOICES concatenated_path_down
			x                  CHOICES control_detection_time_expired
			x                  CHOICES echo_function_failed
			x                  CHOICES forwarding_plane_reset
			x                  CHOICES neighbour_signaled_session_down
			x                  CHOICES path_down
			x                  CHOICES reserved
			x                  CHOICES reverse_concatenated_path_down
			x                  DEFAULT control_detection_time_expired]
		
		Arguments:
			 	-mode
			 		The action to take on the handle provided: start/stop the protocol.
			 		Valid choices are:
			    		start -
			    		stop -
			    		restart -
			    		abort -
			    		resume_pdu -
			    		stop_pdu -
			    		demand_mode_disable -
			    		demand_mode_enable -
			    		initiate_poll -
			    		set_admin_down -
			    		set_admin_up -
			    		set_diagnostic_state -
			 	-port_handle
			 		The port where BFD emulation will be started/stopped. One of the two parameters is required: port_handle/handle.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-handle
			 		The router handle or router interface handle or session handle where
			 		BFD emulation will be started/stopped. This action will be applied to
			 		the port where -handle was created.
			 		One of the two parameters is required: handle.
			x	-protocol_name
			x		This is session used by protocol
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		isis -
			x   		bfd -
			x   		ospf -
			x   		ospfv3 -
			x   		pim -
			x   		bgp -
			x   		ldp -
			x   		rsvp -
			x	-diagnostic_code
			x		This is the diagnostic code
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		administrativelyDown -
			x   		concatenated_path_down -
			x   		control_detection_time_expired -
			x   		echo_function_failed -
			x   		forwarding_plane_reset -
			x   		neighbour_signaled_session_down -
			x   		path_down -
			x   		reserved -
			x   		reverse_concatenated_path_down -
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log     value:On status of failure, gives detailed information.
		
		Examples:
		See files starting with BFD_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_bfd_control", kwargs)

	def emulation_bfd_info(self, **kwargs):
		""" This procedure retrieves information about the BFD sessions.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_bfd_info
			 	-mode         CHOICES aggregate
			               CHOICES stats_per_device_group
			               CHOICES stats_per_session
			               CHOICES learned_info
			               CHOICES clear_stats
			               DEFAULT aggregate
			 	-handle       ANY]
			 	-port_handle  ANY
		
		Arguments:
			 	-mode
			 		The action that should be taken. Valid choices are:
			 		aggregate_stats - retrieve stats aggregated per port
			 		learned_info - retrieve learned information by the BFD protocol
			 		clear_stats - clear stats
			 		Valid choices are:
			    		aggregate -
			    		stats_per_device_group -
			    		stats_per_session -
			    		learned_info -
			    		clear_stats -
			 	-handle
			 		For -mode aggregate, this parameter should be provided with a
			 		handle, but the command will return per port
			 		aggregated stats. For -mode learned_info, this parameters should be provided
			 		with a interface (for the emulated router) and the
			 		command will return per interface learned CRP.
			 	-port_handle
			 		The ports from which to extract BFD session data. One of the two parameters is required: port_handle/handle.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                                  value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                                                     value:On status of failure, gives detailed information.
		BFD stats port_name
			 key:port_name                                                               value:BFD stats port_name
		BFD number of sessions configured
			 key:sessions_configured                                                     value:BFD number of sessions configured
		BFD number of sessions auto configured
			 key:sessions_auto_created                                                   value:BFD number of sessions auto configured
		BFD number of sessions configured up
			 key:sessions_configured_up                                                  value:BFD number of sessions configured up
		BFD number of sessions auto configured up
			 key:sessions_auto_created_up                                                value:BFD number of sessions auto configured up
		BFD sessions flap count
			 key:session_flap_cnt                                                        value:BFD sessions flap count
		BFD control packet tx count
			 key:control_pkts_tx                                                         value:BFD control packet tx count
		BFD control packet rx count
			 key:control_pkts_rx                                                         value:BFD control packet rx count
		BFD echo packet tx count
			 key:echo_self_pkts_tx                                                       value:BFD echo packet tx count
		BFD echo packet rx count
			 key:echo_self_pkts_rx                                                       value:BFD echo packet rx count
		BFD echo dut packet tx count
			 key:echo_dut_pkts_tx                                                        value:BFD echo dut packet tx count
		BFD echo dut packet rx count
			 key:echo_dut_pkts_rx                                                        value:BFD echo dut packet rx count
		BFD mpls pdu tx count
			 key:mpls_tx                                                                 value:BFD mpls pdu tx count
		BFD mpls pdu rx count
			 key:mpls_rx                                                                 value:BFD mpls pdu rx count
		the source IP address for the session
			 key:<handle>.<bfd_learned_info>.local_ip_addr                               value:the source IP address for the session
		the remote IP address
			 key:<handle>.<bfd_learned_info>.remote_ip_addr                              value:the remote IP address
		the local discriminator
			 key:<handle>.<bfd_learned_info>.local_disc                                  value:the local discriminator
		the session type: single hop or multihop
			 key:<handle>.<bfd_learned_info>.session_type                                value:the session type: single hop or multihop
		the session state
			 key:<handle>.<bfd_learned_info>.session_state                               value:the session state
		the protocol which is using the session
			 key:<handle>.<bfd_learned_info>.protocol_using_session                      value:the protocol which is using the session
		the up time for the remote router
			 key:<handle>.<bfd_learned_info>.session_up_time                             value:the up time for the remote router
		the remote discriminator
			 key:<handle>.<bfd_learned_info>.remote_disc                                 value:the remote discriminator
		the state of the remote router
			 key:<handle>.<bfd_learned_info>.remote_state                                value:the state of the remote router
		the required minimum receive interval
			 key:<handle>.<bfd_learned_info>.rcvd_min_rx_interval                        value:the required minimum receive interval
		the minimum transmit interval desired for that that session
			 key:<handle>.<bfd_learned_info>.rcvd_tx_interval                            value:the minimum transmit interval desired for that that session
		the required minimum echo interval
			 key:<handle>.<bfd_learned_info>.rcvd_multiplier                             value:the required minimum echo interval
		the remote flags
			 key:<handle>.<bfd_learned_info>.remote_flags                                value:the remote flags
		the minimum transmit interval desired for that that session
			 key:<port_handle>.<router_handle>.session.<number>.desired_min_tx_interval  value:the minimum transmit interval desired for that that session
		the local discriminator
			 key:<port_handle>.<router_handle>.session.<number>.local_disc               value:the local discriminator
		the source IP address for the session
			 key:<port_handle>.<router_handle>.session.<number>.local_ip_addr            value:the source IP address for the session
		the remote discriminator
			 key:<port_handle>.<router_handle>.session.<number>.remote_disc              value:the remote discriminator
		the remote flags
			 key:<port_handle>.<router_handle>.session.<number>.remote_flags             value:the remote flags
		the remote IP address
			 key:<port_handle>.<router_handle>.session.<number>.remote_ip_addr           value:the remote IP address
		the state of the remote router
			 key:<port_handle>.<router_handle>.session.<number>.remote_state             value:the state of the remote router
		the up time for the remote router
			 key:<port_handle>.<router_handle>.session.<number>.remote_up_time           value:the up time for the remote router
		the protocol which is using the session
			 key:<port_handle>.<router_handle>.session.<number>.protocol_using_session   value:the protocol which is using the session
		the required minimum echo interval
			 key:<port_handle>.<router_handle>.session.<number>.req_min_echo_interval    value:the required minimum echo interval
		the required minimum receive interval
			 key:<port_handle>.<router_handle>.session.<number>.req_min_rx_interval      value:the required minimum receive interval
		the session state
			 key:<port_handle>.<router_handle>.session.<number>.session_state            value:the session state
		the session type: single hop or multihop
			 key:<port_handle>.<router_handle>.session.<number>.session_type             value:the session type: single hop or multihop
			 key:<port_handle>.aggregate.routers_configured                              value:
			 key:<port_handle>.aggregate.routers_running                                 value:
			 key:<port_handle>.aggregate.control_pkts_tx                                 value:
			 key:<port_handle>.aggregate.echo_self_pkts_tx                               value:
			 key:<port_handle>.aggregate.echo_self_pkts_rx                               value:
			 key:<port_handle>.aggregate.echo_dut_pkts_tx                                value:
			 key:<port_handle>.aggregate.echo_dut_pkts_rx                                value:
			 key:<port_handle>.aggregate.sessions_configured                             value:
			 key:<port_handle>.aggregate.sessions_auto_created                           value:
			 key:<port_handle>.aggregate.sessions_configured_up                          value:
			 key:<port_handle>.aggregate.sessions_auto_created_up                        value:
		
		Examples:
		See files starting with BFD_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) For many handles specified as parameters this procedure will return a keyed
		list formatted as follows: <handle>.aggregate.<key_name> when mode is aggregate,
		or learned_info.<handle>.<key_name>, learned_info.<handle>.<key_name>
		when mode is learned_info.
		2) MVPN parameters are not supported with IxTclNetwork API (new API).
		
		See Also:
		
		"""
		return self._run_keyword("emulation_bfd_info", kwargs)

	def emulation_bfd_session_config(self, **kwargs):
		""" This command is used to create/modify/delete/enable/disable a BFD session on a BFD router interface previously created with ::<namespace>::emulation_bfd_config. One BFD session can be added to all router interfaces or just to a specific router interface.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_bfd_session_config
			 	[-count                      ANY]
			 	[-enable_auto_choose_source  ANY]
			 	[-enable_learned_remote_disc ANY]
			 	[-handle                     ANY]
			 	[-ip_version                 ANY]
			 	[-local_disc                 ANY]
			 	[-local_disc_step            ANY]
			 	[-local_ip_addr              ANY]
			 	[-local_ip_addr_step         ANY]
			 	[-mode                       ANY]
			 	[-remote_disc                ANY]
			 	[-remote_disc_step           ANY]
			 	[-remote_ip_addr             ANY]
			 	[-remote_ip_addr_step        ANY]
			 	[-session_handle             ANY]
			 	[-session_type               ANY]
		
		Arguments:
			 	-count
			 		The number of BFD sessions to create for a provided -handle parameter. If the provided -handle is a list of BFD routers, then -count sessions will be created for each BFD router interface. If the provided -handle is a list of BFD router interface, then -count sessions will be created for each BFD router interface in the list.This option is valid only when -mode is create and -handle is provided.
			 	-enable_auto_choose_source
			 		Setting this parameter to 1, enables the session to automatically choose the source IP address for the BFD session. In this case, the local_ip_addr parameter is ignored. Setting this parameter to 0, enables the local_ip_addr parameter.This option is valid only when -mode is create and -handle is provided or -mode is modify and -session_handle is provided.
			 	-enable_learned_remote_disc
			 		Enables the ability of this BFD session to learn the value of the discriminator of the far end of the BFD session. If this option is set to 1, the remote_disc option will be ignored.This option is valid only when -mode is create and -handle is provided or -mode is modify and -session_handle is provided.
			 	-handle
			 		This is the router handle or the router interface handle that needs to be provided when creating a BFD session. This is mandatory when -mode is create.
			 	-ip_version
			 		This is the ip type of the BFD session. This option is valid only when -mode create and -handle is provided or -mode is modify and -session_handle is provided.
			 		Valid choices are:
			    		4 - IPv4 version
			    		6 - IPv6 version
			 	-local_disc
			 		A unique, nonzero discriminator value generated by the interface, used to de-multiplex multiple BFD sessions between the same pair of systems.This option is valid only when -mode create and -handle is provided or -mode is modify and -session_handle is provided.
			 	-local_disc_step
			 		The local discriminator step. Used when creating multiple BFD sessions.This option is valid only when -mode create.
			 	-local_ip_addr
			 		Sets the source IP address for this BFD session. Only enabled if enable_auto_choose_source is 0.This option is valid only when -mode create and -handle is provided or -mode is modify and -session_handle is provided.
			 	-local_ip_addr_step
			 		The source IP address step for the BFD session. Used when creating multiple BFD sessions.This option is valid only when -mode create.(DEFAULT = 0.0.0.1 | 0::1)
			 	-mode
			 		The action that will be taken for a specified handle or session_handle. Parameter -handle is mandatory for -mode create and parameter -session_handle is mandatory for -mode modify/enable/disable/delete.
			 		Valid choices are:
			    		create - Creates BFD session(s). Parameter -handle needs to be provided. If -handle is a router handle, then the session will be configured on each router interface. If -handle is a router interface handle, then the session will be configured for that specific router interface. The router handle and the router interface handle are obtained from the returned keys of a previous call to emulation_bfd_config.
			    		modify/enable/disable/delete - Performs the specified operation for a BFD session identified by -session_handle parameter.
			 	-remote_disc
			 		The discriminator received from the corresponding remote system. This field reflects back the received value of local_disc, or is zero if that value is unknown.This option is valid only when -mode create and -handle is provided or -mode is modify and -session_handle is provided.
			 	-remote_disc_step
			 		The step for the remote discriminator, when creating multiple sessions.This option is valid only when -mode create and -handle is provided.
			 	-remote_ip_addr
			 		The IP address of the remote router in the BFD session.This option is valid only when -mode create and -handle is provided or -mode is modify and -session_handle is provided. Required for -mode create.
			 	-remote_ip_addr_step
			 		The IP address step of the remote router in the BFD session, when creating multiple BFD sessions.This option is valid only when -mode create and -handle is provided.(DEFAULT = 0.0.0.1 | 0::1)
			 	-session_handle
			 		This is the BFD session handle that needs to be provided when modifying/enabling/disabling/deleting a BFD session. A list of session handles can be provided. This is mandatory when -mode is modify/enable/disable/delete.
			 	-session_type
			 		The type of BFD session. This option is valid only when -mode create and -handle is provided or -mode is modify and -session_handle is provided.
			 		Valid choices are:
			    		single_hop - the BFD session is between adjacent BFD routers.
			    		multi_hop - the BFD session traverses more than one router.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status           value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log              value:On status of failure, gives detailed information.
		On mode create, list of session handles
			 key:session_handles  value:On mode create, list of session handles
		
		Examples:
		See files starting with BFD_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_bfd_session_config", kwargs)

	def emulation_bgp_config(self, **kwargs):
		""" This procedure configures BGP neighbors, internal and/or external. It is used to create, enable, modify, and to delete an emulated Border Gateway Protocol.User can configure multiple BGP peers per interface by calling this procedure multiple times.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_bgp_config
			 	-mode                                           CHOICES delete
			                                                 CHOICES disable
			                                                 CHOICES enable
			                                                 CHOICES create
			                                                 CHOICES modify
			                                                 CHOICES reset]
			x	[-active                                        CHOICES 0 1
			x                                                DEFAULT 1]
			x	[-md5_enable                                    CHOICES 0 1]
			x	[-md5_key                                       ANY]
			 	[-port_handle                                   REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle                                        ANY]
			x	[-return_detailed_handles                       CHOICES 0 1
			x                                                DEFAULT 0]
			 	[-ip_version                                    CHOICES 4 6
			                                                 DEFAULT 4]
			 	[-local_ip_addr                                 IPV4]
			 	[-gateway_ip_addr                               IP]
			 	[-remote_ip_addr                                IPV4]
			 	[-local_ipv6_addr                               IPV6]
			 	[-remote_ipv6_addr                              IPV6]
			 	[-local_addr_step                               IP]
			 	[-remote_addr_step                              IP]
			 	[-next_hop_enable                               CHOICES 0 1
			                                                 DEFAULT 1]
			 	[-next_hop_ip                                   IP]
			x	[-enable_4_byte_as                              CHOICES 0 1
			x                                                DEFAULT 0]
			 	[-local_as                                      RANGE 0-4294967295]
			x	[-local_as4                                     RANGE 0-4294967295]
			 	[-local_as_mode                                 CHOICES fixed increment
			                                                 DEFAULT fixed]
			 	[-remote_as                                     ANY]
			 	[-local_as_step                                 RANGE 0-4294967295
			                                                 DEFAULT 1]
			 	[-update_interval                               RANGE 0-65535]
			 	[-count                                         NUMERIC
			                                                 DEFAULT 1]
			 	[-local_router_id                               IPV4]
			x	[-local_router_id_step                          IPV4
			x                                                DEFAULT 0.0.0.1]
			x	[-vlan                                          CHOICES 0 1
			x                                                DEFAULT 0]
			 	[-vlan_id                                       RANGE 0-4095]
			 	[-vlan_id_mode                                  CHOICES fixed increment
			                                                 DEFAULT increment]
			 	[-vlan_id_step                                  RANGE 0-4096
			                                                 DEFAULT 1]
			x	[-vlan_user_priority                            RANGE 0-7]
			x	[-vpi                                           ANY]
			x	[-vci                                           ANY]
			x	[-vpi_step                                      ANY]
			x	[-vci_step                                      ANY]
			x	[-atm_encapsulation                             ANY]
			x	[-interface_handle                              ANY]
			 	[-retry_time                                    ANY]
			 	[-hold_time                                     NUMERIC]
			 	[-neighbor_type                                 CHOICES internal external]
			 	[-graceful_restart_enable                       CHOICES 0 1
			                                                 DEFAULT 0]
			 	[-restart_time                                  RANGE 0-10000000]
			 	[-stale_time                                    RANGE 0-10000000]
			 	[-tcp_window_size                               RANGE 0-10000000]
			 	[-retries                                       ANY]
			 	[-local_router_id_enable                        CHOICES 0 1
			                                                 DEFAULT 0]
			 	[-netmask                                       RANGE 1-128]
			 	[-mac_address_start                             MAC]
			x	[-mac_address_step                              MAC
			x                                                DEFAULT 0000.0000.0001]
			x	[-ipv4_mdt_nlri                                 FLAG]
			x	[-ipv4_capability_mdt_nlri                      FLAG]
			 	[-ipv4_unicast_nlri                             FLAG]
			 	[-ipv4_capability_unicast_nlri                  FLAG]
			 	[-ipv4_filter_unicast_nlri                      FLAG]
			 	[-ipv4_multicast_nlri                           FLAG]
			 	[-ipv4_capability_multicast_nlri                FLAG]
			 	[-ipv4_filter_multicast_nlri                    FLAG]
			 	[-ipv4_mpls_nlri                                FLAG]
			 	[-ipv4_capability_mpls_nlri                     FLAG]
			 	[-ipv4_filter_mpls_nlri                         FLAG]
			 	[-ipv4_mpls_vpn_nlri                            FLAG]
			 	[-ipv4_capability_mpls_vpn_nlri                 FLAG]
			 	[-ipv4_filter_mpls_vpn_nlri                     FLAG]
			 	[-ipv6_unicast_nlri                             FLAG]
			 	[-ipv6_capability_unicast_nlri                  FLAG]
			 	[-ipv6_filter_unicast_nlri                      FLAG]
			 	[-ipv6_multicast_nlri                           FLAG]
			 	[-ipv6_capability_multicast_nlri                FLAG]
			 	[-ipv6_filter_multicast_nlri                    FLAG]
			 	[-ipv6_mpls_nlri                                FLAG]
			 	[-ipv6_capability_mpls_nlri                     FLAG]
			 	[-ipv6_filter_mpls_nlri                         FLAG]
			 	[-ipv6_mpls_vpn_nlri                            FLAG]
			 	[-ipv6_capability_mpls_vpn_nlri                 FLAG]
			 	[-ipv6_filter_mpls_vpn_nlri                     FLAG]
			x	[-capability_route_refresh                      CHOICES 0 1]
			x	[-capability_route_constraint                   CHOICES 0 1]
			x	[-local_loopback_ip_addr                        IP]
			x	[-local_loopback_ip_prefix_length               NUMERIC]
			x	[-local_loopback_ip_addr_step                   IP]
			x	[-remote_loopback_ip_addr                       IP]
			x	[-remote_loopback_ip_addr_step                  IP]
			x	[-ttl_value                                     NUMERIC]
			x	[-updates_per_iteration                         RANGE 0-10000000]
			x	[-bfd_registration                              CHOICES 0 1
			x                                                DEFAULT 0]
			x	[-bfd_registration_mode                         CHOICES single_hop multi_hop
			x                                                DEFAULT multi_hop]
			x	[-override_existence_check                      ANY]
			x	[-override_tracking                             ANY]
			x	[-no_write                                      ANY]
			x	[-vpls                                          CHOICES 0 1 disabled vpn no_vpn
			x                                                DEFAULT 0]
			 	[-vpls_nlri                                     FLAG]
			 	[-vpls_capability_nlri                          FLAG]
			 	[-vpls_filter_nlri                              FLAG]
			n	[-advertise_host_route                          ANY]
			n	[-modify_outgoing_as_path                       ANY]
			n	[-remote_confederation_member                   ANY]
			n	[-reset                                         ANY]
			n	[-route_refresh                                 ANY]
			n	[-routes_per_msg                                ANY]
			n	[-suppress_notify                               ANY]
			n	[-timeout                                       ANY]
			n	[-update_msg_size                               ANY]
			n	[-vlan_cfi                                      ANY]
			x	[-act_as_restarted                              CHOICES 0 1
			x                                                DEFAULT 0]
			x	[-discard_ixia_generated_routes                 CHOICES 0 1
			x                                                DEFAULT 0]
			x	[-local_router_id_type                          CHOICES same new
			x                                                DEFAULT new]
			x	[-send_ixia_signature_with_routes               CHOICES 0 1
			x                                                DEFAULT 0]
			x	[-enable_flap                                   CHOICES 0 1
			x                                                DEFAULT 0]
			x	[-flap_up_time                                  ANY]
			x	[-flap_down_time                                ANY]
			x	[-ipv4_multicast_vpn_nlri                       FLAG]
			x	[-ipv4_capability_multicast_vpn_nlri            FLAG]
			x	[-ipv4_filter_multicast_vpn_nlri                FLAG]
			x	[-ipv6_multicast_vpn_nlri                       FLAG]
			x	[-ipv6_capability_multicast_vpn_nlri            FLAG]
			x	[-ipv6_filter_multicast_vpn_nlri                FLAG]
			x	[-filter_ipv4_multicast_bgp_mpls_vpn            FLAG]
			x	[-filter_ipv6_multicast_bgp_mpls_vpn            FLAG]
			x	[-ipv4_multicast_bgp_mpls_vpn                   FLAG]
			x	[-ipv6_multicast_bgp_mpls_vpn                   FLAG]
			x	[-advertise_end_of_rib                          CHOICES 0 1
			x                                                DEFAULT 0]
			x	[-configure_keepalive_timer                     CHOICES 0 1
			x                                                DEFAULT 0]
			 	[-keepalive_timer                               RANGE 0-65535
			                                                 DEFAULT 30]
			 	[-staggered_start_enable                        FLAG]
			 	[-staggered_start_time                          RANGE 0-10000000]
			x	[-start_rate_enable                             CHOICES 0 1]
			x	[-start_rate_interval                           NUMERIC]
			x	[-start_rate                                    NUMERIC]
			x	[-start_rate_scale_mode                         CHOICES deviceGroup port]
			x	[-stop_rate_enable                              CHOICES 0 1]
			x	[-stop_rate_interval                            ANY]
			x	[-stop_rate                                     ANY]
			x	[-stop_rate_scale_mode                          CHOICES deviceGroup port]
			 	[-active_connect_enable                         FLAG]
			x	[-disable_received_update_validation            CHOICES 0 1]
			x	[-enable_ad_vpls_prefix_length                  CHOICES 0 1]
			x	[-ibgp_tester_as_four_bytes                     NUMERIC]
			x	[-ibgp_tester_as_two_bytes                      NUMERIC]
			x	[-initiate_ebgp_active_connection               CHOICES 0 1]
			x	[-initiate_ibgp_active_connection               CHOICES 0 1]
			x	[-mldp_p2mp_fec_type                            HEX]
			x	[-request_vpn_label_exchange_over_lsp           CHOICES 0 1]
			x	[-trigger_vpls_pw_initiation                    CHOICES 0 1]
			x	[-as_path_set_mode                              CHOICES include_as_seq
			x                                                CHOICES include_as_seq_conf
			x                                                CHOICES include_as_set
			x                                                CHOICES include_as_set_conf
			x                                                CHOICES no_include
			x                                                CHOICES prepend_as
			x                                                DEFAULT no_include]
			x	[-router_id                                     IPV4]
			x	[-router_id_step                                IPV4]
			x	[-filter_link_state                             FLAG]
			x	[-capability_linkstate_nonvpn                   CHOICES 0 1]
			x	[-bgp_ls_id                                     RANGE 0-65256525
			x                                                DEFAULT 0]
			x	[-instance_id                                   NUMERIC
			x                                                DEFAULT 0]
			x	[-number_of_communities                         RANGE 0-32
			x                                                DEFAULT 1]
			x	[-enable_community                              CHOICES 0 1]
			x	[-community_type                                CHOICES no_export
			x                                                CHOICES no_advertised
			x                                                CHOICES noexport_subconfed
			x                                                CHOICES manual
			x                                                DEFAULT no_export]
			x	[-community_as_number                           RANGE 0-65535
			x                                                DEFAULT 0]
			x	[-community_last_two_octets                     RANGE 0-65535
			x                                                DEFAULT 0]
			x	[-number_of_ext_communities                     RANGE 0-32
			x                                                DEFAULT 1]
			x	[-enable_ext_community                          CHOICES 0 1]
			x	[-ext_communities_type                          CHOICES admin_as_two_octet
			x                                                CHOICES admin_ip
			x                                                CHOICES admin_as_four_octet
			x                                                CHOICES opaque
			x                                                CHOICES evpn]
			x	[-ext_communities_subtype                       CHOICES route_target
			x                                                CHOICES origin
			x                                                CHOICES extended_bandwidth
			x                                                CHOICES encapsulation
			x                                                CHOICES mac_address]
			x	[-ext_community_as_number                       RANGE 0-65535
			x                                                DEFAULT 1]
			x	[-ext_community_target_assigned_number_4_octets NUMERIC
			x                                                DEFAULT 1]
			x	[-ext_community_as_4_bytes                      NUMERIC
			x                                                DEFAULT 1]
			x	[-ext_community_target_assigned_number_2_octets NUMERIC
			x                                                DEFAULT 1]
			x	[-ext_community_ip                              IP]
			x	[-ext_community_opaque_data                     HEX]
			x	[-enable_override_peer_as_set_mode              CHOICES 0 1]
			x	[-bgp_ls_as_set_mode                            CHOICES include_as_seq
			x                                                CHOICES include_as_seq_conf
			x                                                CHOICES include_as_set
			x                                                CHOICES include_as_set_conf
			x                                                CHOICES no_include
			x                                                CHOICES prepend_as
			x                                                DEFAULT no_include]
			x	[-number_of_as_path_segments                    RANGE 0-32
			x                                                DEFAULT 1]
			x	[-enable_as_path_segments                       CHOICES 0 1]
			x	[-enable_as_path_segment                        CHOICES 0 1]
			x	[-number_of_as_number_in_segment                RANGE 0-50
			x                                                DEFAULT 1]
			x	[-as_path_segment_type                          CHOICES as_set
			x                                                CHOICES as_seq
			x                                                CHOICES as_set_confederation
			x                                                CHOICES as_seq_confederation
			x                                                DEFAULT as_set]
			x	[-as_path_segment_enable_as_number              CHOICES 0 1]
			x	[-as_path_segment_as_number                     NUMERIC
			x                                                DEFAULT 1]
			x	[-number_of_clusters                            RANGE 0-32
			x                                                DEFAULT 1]
			x	[-enable_cluster                                CHOICES 0 1]
			x	[-cluster_id                                    IP]
			x	[-active_ethernet_segment                       CHOICES 0 1
			x                                                DEFAULT 1]
			x	[-esi_type                                      CHOICES type0
			x                                                CHOICES type1
			x                                                CHOICES type2
			x                                                CHOICES type3
			x                                                CHOICES type4
			x                                                CHOICES type5]
			x	[-esi_value                                     ANY]
			x	[-b_mac_prefix                                  MAC]
			x	[-b_mac_prefix_length                           NUMERIC]
			x	[-use_same_sequence_number                      CHOICES 0 1]
			x	[-include_mac_mobility_extended_community       CHOICES 0 1]
			x	[-enable_sticky_static_flag                     CHOICES 0 1]
			x	[-support_multihomed_es_auto_discovery          CHOICES 0 1]
			x	[-auto_configure_es_import                      CHOICES 0 1]
			x	[-es_import                                     MAC]
			x	[-df_election_timer                             NUMERIC]
			x	[-support_fast_convergence                      CHOICES 0 1]
			x	[-enable_single_active                          CHOICES 0 1]
			x	[-esi_label                                     NUMERIC]
			x	[-advertise_inclusive_multicast_route           CHOICES 0 1]
			x	[-evis_count                                    NUMERIC]
			x	[-enable_next_hop                               CHOICES 0 1]
			x	[-set_next_hop                                  CHOICES manually sameaslocalip]
			x	[-set_next_hop_ip_type                          CHOICES ipv4 ipv6]
			x	[-ipv4_next_hop                                 IPV4]
			x	[-ipv6_next_hop                                 IPV6]
			x	[-enable_origin                                 CHOICES 0 1]
			x	[-origin                                        CHOICES igp egp incomplete]
			x	[-enable_local_preference                       CHOICES 0 1]
			x	[-local_preference                              NUMERIC]
			x	[-enable_multi_exit_discriminator               CHOICES 0 1]
			x	[-multi_exit_discriminator                      NUMERIC]
			x	[-enable_atomic_aggregate                       CHOICES 0 1]
			x	[-enable_aggregator_id                          CHOICES 0 1]
			x	[-aggregator_id                                 IPV4]
			x	[-aggregator_as                                 NUMERIC]
			x	[-enable_originator_id                          CHOICES 0 1]
			x	[-originator_id                                 IPV4]
			x	[-no_of_clusters                                NUMERIC]
			x	[-use_control_word                              CHOICES 0 1]
			x	[-ethernet_segment_name                         ALPHA]
			x	[-ethernet_segments_count                       NUMERIC]
			x	[-filter_evpn                                   FLAG]
			x	[-evpn                                          FLAG]
			x	[-operational_model                             CHOICES symmetric asymmetric]
			x	[-routers_mac_or_irb_mac_address                ANY]
			x	[-ip_type                                       CHOICES ipv4 ipv6]
			x	[-ip_address                                    IP]
			x	[-ipv6_address                                  IP]
			x	[-enable_b_mac_mapped_ip                        CHOICES 0 1
			x                                                DEFAULT 1]
			x	[-no_of_b_mac_mapped_ips                        NUMERIC]
			x	[-capability_ipv4_unicast_add_path              CHOICES 0 1]
			x	[-capability_ipv6_unicast_add_path              CHOICES 0 1]
			x	[-ipv4_mpls_add_path_mode                       CHOICES receiveonly sendonly both]
			x	[-ipv6_mpls_add_path_mode                       CHOICES receiveonly sendonly both]
			x	[-ipv4_unicast_add_path_mode                    CHOICES receiveonly sendonly both]
			x	[-ipv6_unicast_add_path_mode                    CHOICES receiveonly sendonly both]
			x	[-ipv4_mpls_capability                          CHOICES 0 1]
			x	[-ipv6_mpls_capability                          CHOICES 0 1]
			x	[-capability_ipv4_mpls_add_path                 CHOICES 0 1]
			x	[-capability_ipv6_mpls_add_path                 CHOICES 0 1]
			x	[-custom_sid_type                               NUMERIC]
			x	[-srgb_count                                    RANGE 1-5
			x                                                DEFAULT 1]
			x	[-start_sid                                     RANGE 1-1048575
			x                                                DEFAULT 16000]
			x	[-sid_count                                     RANGE 1-1048575
			x                                                DEFAULT 8000]
			x	[-ipv4_multiple_mpls_labels_capability          CHOICES 0 1]
			x	[-ipv6_multiple_mpls_labels_capability          CHOICES 0 1]
			x	[-mpls_labels_count_for_ipv4_mpls_route         RANGE 1-255
			x                                                DEFAULT 1]
			x	[-mpls_labels_count_for_ipv6_mpls_route         RANGE 1-255
			x                                                DEFAULT 1]
			x	[-noOfUserDefinedAfiSafi                        RANGE 0-1000
			x                                                DEFAULT 0]
			x	[-afiSafi_active                                CHOICES 0 1
			x                                                DEFAULT 1]
			x	[-afiValue                                      NUMERIC]
			x	[-safiValue                                     NUMERIC]
			x	[-lengthOfData                                  NUMERIC]
			x	[-dataValue                                     HEX]
			x	[-ipv4_unicast_flowSpec_nlri                    FLAG]
			x	[-capability_ipv4_unicast_flowSpec              FLAG]
			x	[-filter_ipv4_unicast_flowSpec                  FLAG]
			x	[-ipv6_unicast_flowSpec_nlri                    FLAG]
			x	[-capability_ipv6_unicast_flowSpec              FLAG]
			x	[-filter_ipv6_unicast_flowSpec                  FLAG]
			x	[-always_include_tunnel_enc_ext_community       ANY]
			x	[-ip_vrf_to_ip_vrf_type                         CHOICES interfacefullWithCorefacingIRB
			x                                                CHOICES interfacefullWithUnnumberedCorefacingIRB
			x                                                CHOICES interfaceLess]
			x	[-irb_interface_label                           ANY]
			x	[-irb_ipv4_address                              ANY]
			x	[-irb_ipv6_address                              ANY]
			x	[-ipv4_srte_policy_nlri                         FLAG]
			x	[-capability_ipv4_srte_policy                   FLAG]
			x	[-filter_ipv4_srte_policy                       FLAG]
			x	[-ipv6_srte_policy_nlri                         FLAG]
			x	[-capability_ipv6_srte_policy                   FLAG]
			x	[-filter_ipv6_srte_policy                       FLAG]
			x	[-srte_policy_safi                              NUMERIC]
			x	[-srte_policy_attr_type                         NUMERIC]
			x	[-srte_policy_type                              NUMERIC]
			x	[-srte_remote_endpoint_type                     NUMERIC]
			x	[-srte_color_type                               NUMERIC]
			x	[-srte_preference_type                          NUMERIC]
			x	[-srte_binding_type                             NUMERIC]
			x	[-srte_segment_list_type                        NUMERIC]
			x	[-srte_weight_type                              NUMERIC]
			x	[-srte_mplsSID_type                             NUMERIC]
			x	[-srte_ipv6SID_type                             NUMERIC]
			x	[-srte_ipv4_node_address_type                   NUMERIC]
			x	[-srte_ipv6_node_address_type                   NUMERIC]
			x	[-srte_ipv4_node_address_index_type             NUMERIC]
			x	[-srte_ipv4_local_remote_address                NUMERIC]
			x	[-srte_ipv6_node_address_index_type             NUMERIC]
			x	[-srte_ipv6_local_remote_address                NUMERIC]
			x	[-srte_include_length                           CHOICES 0 1]
			x	[-srte_length_unit                              CHOICES bits bytes
			x                                                DEFAULT bits]
		
		Arguments:
			 	-mode
			 		This option defines the action to be taken on the BGP server.
			 		Valid choices are:
			    		delete - delete the BGP4 configuration, requires the use of -handle.
			    		disable - disable the BGP4 configuration, requires the use of -handle.
			    		enable - enable and/or create the BGP4 configuration. If -handle is
specified, then it will be enabled, otherwise created.
			    		create - create the BGP configuration
			    		modify - modify the BGP4 configuration, requires the use of -handle.
			    		reset - deletes all BGP4 configurations from the -port_handle and
then creates the provided BGP4 configuration.
			x	-active
			x		Activates the item
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-md5_enable
			x		If set to 1, enables MD5 authentication for emulated
			x		BGP node.
			x		Valid choices are:
			x   		0 -
			x   		1 -
			x	-md5_key
			x		The key used for md5 authentication.
			 	-port_handle
			 		The port on which the BGP neighbor is to be created.
			 	-handle
			 		BGP handle used for -mode modify/disable/delete.
			 		When -handle is provided with the /globals value the arguments that configure global protocol
			 		setting accept both multivalue handles and simple values.
			 		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
			 		that configure global settings will only accept simple values. In this situation, these arguments will
			 		configure only the settings of the parent device group or the ports associated with the parent topology.
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-ip_version
			 		This option defines the IP version of the BGP4
			 		neighbor to be configured on the Ixia interface.
			 		Valid choices are:
			    		4 - IPv4
			    		6 - IPv6
			 	-local_ip_addr
			 		The IPv4 address of the Ixia simulated BGP node to be emulated.
			 	-gateway_ip_addr
			 		The gateway IPV4 or IPV6 address of the BGP4 neighbor interface. If this
			 		parameter is not provided it will be initialized to the remote_ip_addr value.
			 	-remote_ip_addr
			 		The IPv4 address of the DUTs interface connected to the emulated BGP
			 		port.
			 	-local_ipv6_addr
			 		The IPv6 address of the BGP node to be emulated by the test port.
			 	-remote_ipv6_addr
			 		The IPv6 address of the DUT interface connected to emulated BGP node.
			 		This parameter is mandatory when -mode is create, -ip_version is 6 and
			 		parameter -neighbor_type is external, or -neighbor_type is internal
			 		and ipv4_mpls_nlri, ipv6_mpls_nlri, ipv4_mpls_vpn_nlri, and
			 		ipv6_mpls_vpn_nlri are not enabled.
			 	-local_addr_step
			 		Defines the mask and increment step for the next -local_ip_addr or
			 		"-local_ipv6_addr".
			 	-remote_addr_step
			 		Defines the mask and increment step for the next -remote_ip_addr or
			 		"-remote_ipv6_addr".
			 	-next_hop_enable
			 		This option is used for IPv4 traffic, and enables the
			 		use of the BGP NEXT_HOP attributes.When enabled, the IP next hop
			 		must be configured (using the -next_hop_ip option).
			 		Valid choices are:
			    		0 -
			    		1 -
			 	-next_hop_ip
			 		Defines the IP of the next hop.This option is used if the
			 		flag -next_hop_enable is set.
			x	-enable_4_byte_as
			x		Allow 4 byte values for -local_as.
			 	-local_as
			 		The AS number of the BGP node to be emulated by the test port.
			x	-local_as4
			x		The 4 bytes AS number of the BGP node to be emulated by the test port.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-local_as_mode
			 		For External BGP type only. This option controls the AS number
			 		(local_as) assigned to additional routers.
			 		Valid choices are:
			    		fixed - (default) the local_as remains fixed
			    		increment - increments the local_as
			 	-remote_as
			 		The remote AS.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-local_as_step
			 		If you configure more then 1 eBGP neighbor on the Ixia interface,
			 		and if you select the option local_as_mode to increment, the option
			 		local_as_step defines the step by which the AS number is incremented.
			 	-update_interval
			 		The time intervals at which UPDATE messages are sent to the DUT,
			 		expressed in the number of milliseconds between UPDATE messages.
			 	-count
			 		Number of BGP nodes to create.
			 	-local_router_id
			 		BGP4 router ID of the emulated node, must be in IPv4 format.
			x	-local_router_id_step
			x		BGP4 router ID step of the emulated node, must be in IPv4 format.
			x	-vlan
			x		Enables vlan on the directly connected BGP router interface.
			x		Valid options are: 0 - disable, 1 - enable.
			x		This option is valid only when -mode is create or -mode is modify
			x		and -handle is a BGP router handle.
			x		This option is available only when IxNetwork tcl API is used.
			 	-vlan_id
			 		VLAN ID for the emulated router node.
			 	-vlan_id_mode
			 		For multiple neighbor configuration, configurest the VLAN ID mode.
			 		Valid choices are:
			    		fixed -
			    		increment -
			 	-vlan_id_step
			 		Defines the step for every VLAN When -vlan_id_mode is set to
			 		increment.
			 		When vlan_id_step causes the vlan_id value to exceed it's maximum value the
			 		increment will be done modulo <number of possible vlan ids>.
			 		Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0
			 		vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			x	-vlan_user_priority
			x		The VLAN user priority assigned to emulated router node.
			x	-vpi
			x		VPI for emulated router node. RANGE 0-255
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vci
			x		VCI for emulated router node. RANGE 0-65535
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vpi_step
			x		The step value used for incrementing the -vpi option. RANGE 0-255When vpi_step causes the vpi value to exceed it's maximum value the increment will be done modulo <number of possible vpi ids>.Examples: vpi = 254; vpi_step = 2-> new vpi value = 0vpi = 255; vpi_step = 11 -> new vpi value = 10
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vci_step
			x		The step value used for incrementing the -vci option. RANGE 0-65535 When vci_step causes the vci value to exceed it's maximum value the increment will be done modulo <number of possible vci ids>.Examples: vci = 65534; vci_step = 2-> new vci value = 0vci = 65535; vci_step = 11 -> new vci value = 10
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-atm_encapsulation
			x		The encapsulation of the ATM protocol interface associated with the emulated router.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-interface_handle
			x		This parameter is valid only for IxTclNetwork API and represents a
			x		list of interfaces previously created using interface_config or
			x		another emulation_<protocol>_config command that returns the interface
			x		handles (for example: BFD).
			x		 Starting with IxNetwork 5.60 this parameter accepts handles returned by
			x		emulation_dhcp_group_config procedure in the following format:
			x		<DHCP Group Handle>|<interface index X>,<interface index Y>-<interface index Z>, ...
			x		The DHCP ranges are separated from the Interface Index identifiers with the (|) character.
			x		The Interface Index identifiers are separated with comas (,).
			x		A range of Interface Index identifiers can be defined using the dash (-) character. 
			x		 Ranges along with the Interface Index identifiers are grouped together in TCL Lists. The
			x		lists can contain mixed items, protocol interface handles returned by interface_config
			x		and handles returned by emulation_dhcp_group_config along with the interface index. 
			x		 Example:
			x		count 10 (10 BGP neighbors). 3 DHCP range handles returned by ::ixia::emulation_dhcp_group_config.
			x		Each DHCP range has 20 sessions (interfaces). If we pass a -interface_handle
			x		in the following format: [list $dhcp_r1|1,5 $dhcp_r2|1-3 $dhcp_r3|1,3,5-9,13]
			x		The interfaces will be distributed to the routers in the following manner: 
			x		
			x		BGP Neighbor 1: $dhcp_r1 -> interface 1 
			x		-  BGP Neighbor 2: $dhcp_r1 -> interface 5 
			x		-  BGP Neighbor 3: $dhcp_r2 -> interface 1 
			x		-  BGP Neighbor 4: $dhcp_r2 -> interface 2 
			x		-  BGP Neighbor 5: $dhcp_r2 -> interface 3 
			x		-  BGP Neighbor 6: $dhcp_r3 -> interface 1 
			x		-  BGP Neighbor 7: $dhcp_r3 -> interface 3 
			x		-  BGP Neighbor 8: $dhcp_r3 -> interface 5 
			x		-  BGP Neighbor 9: $dhcp_r3 -> interface 6 
			x		-  BGP Neighbor 10: $dhcp_r3 -> interface 7 
			x		-  BGP Neighbor 11: $dhcp_r3 -> interface 8 
			x		-  BGP Neighbor 12: $dhcp_r3 -> interface 9 
			x		-  BGP Neighbor 13 $dhcp_r3 -> interface 13 
			x		
			x		 Starting with IxNetwork 6.30SP1 this parameter accepts handles returned by
			x		interface_config procedure with -l23_config_type static_type setting in the following format:
			x		<IP Range Handle>|<interface index X>,<interface index Y>-<interface index Z>, ...
			x		The IP ranges are separated from the Interface Index identifiers with the (|) character.
			x		The Interface Index identifiers are separated with comas (,).
			x		A range of Interface Index identifiers can be defined using the dash (-) character. 
			x		 Ranges along with the Interface Index identifiers are grouped together in TCL Lists. The
			x		lists can contain mixed items, protocol interface handles returned by interface_config
			x		with -l23_config_type protocol_interface and with -l23_config_type static_type. 
			x		 Example:
			x		count 10 (10 BGP neighbors). 3 IP range handles returned by ::ixia::interface_config.
			x		Each IP range has 20 sessions (interfaces). If we pass a -interface_handle
			x		in the following format: [list $ip_r1|1,5 $ip_r2|1-3 $ip_r3|1,3,5-9,13]
			x		The interfaces will be distributed to the routers in the following manner: 
			x		
			x		-  BGP Neighbor 1: $ip_r1 -> interface 1 
			x		-  BGP Neighbor 2: $ip_r1 -> interface 5 
			x		-  BGP Neighbor 3: $ip_r2 -> interface 1 
			x		-  BGP Neighbor 4: $ip_r2 -> interface 2 
			x		-  BGP Neighbor 5: $ip_r2 -> interface 3 
			x		-  BGP Neighbor 6: $ip_r3 -> interface 1 
			x		-  BGP Neighbor 7: $ip_r3 -> interface 3 
			x		-  BGP Neighbor 8: $ip_r3 -> interface 5 
			x		-  BGP Neighbor 9: $ip_r3 -> interface 6 
			x		-  BGP Neighbor 10: $ip_r3 -> interface 7 
			x		-  BGP Neighbor 11: $ip_r3 -> interface 8 
			x		-  BGP Neighbor 12: $ip_r3 -> interface 9 
			x		-  BGP Neighbor 13 $ip_r3 -> interface 13 
			x		
			x		 Valid for mode create for IxTclNetwork only. 
			 	-retry_time
			 		For External BGP neighbor.When retries are necessary, the delay in seconds between retries.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-hold_time
			 		Configures the hold time for BGP sessions for this Neighbor.
			 		Keepalives are sent out every one-third of this interval.If the
			 		default value is 90, KeepAlive messages are sent every 30 seconds.
			 	-neighbor_type
			 		Sets the BGP neighbor type.
			 		Valid choices are:
			    		internal - iBGP
			    		external - eBGP
			 	-graceful_restart_enable
			 		Will enable graceful restart (HA) on the BGP4 neighbor.
			 	-restart_time
			 		If -graceful_restart_enable is set, sets the amount of time following
			 		a restart operation allowed to re-establish a BGP session, in seconds.
			 	-stale_time
			 		If -graceful_restart_enable is set, sets the amount of time
			 		after which an End-Of-RIB marker is sent in an Update
			 		message to the peer to allow time for routing convergence via IGP
			 		and BGP selection, in seconds.Stale routing information for that
			 		address family is then deleted by the receiving peer.
			 	-tcp_window_size
			 		For External BGP neighbor only.The TCP window used for
			 		communications from the neighbor.
			 	-retries
			 		For External BGP neighbor.The number of times to attempt an OPEN connection with the DUT routers before giving up.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-local_router_id_enable
			 		Enables the BGP4 local router id option.
			 	-netmask
			 		Netmask represents ipv4_prefix_length / ipv6_prefix_length for Protocol Interface.
			 		It is used in case Protocols Interface and BGP is configured from same BGP command without configure IP addresses in interface_config.
			 	-mac_address_start
			 		Initial MAC address of the interfaces created for the BGP4 neighbor.
			x	-mac_address_step
			x		The incrementing step for thr MAC address of the dirrectly connected
			x		interfaces created for the BGP4 neighbor.
			x		This option is valid only when IxTclNetwork API is used.
			x	-ipv4_mdt_nlri
			x		If checked, this BGP/BGP+ router/peer supports IPv4 MDT address family messages.
			x	-ipv4_capability_mdt_nlri
			x		If checked, this BGP/BGP+ router/peer supports IPv4 MDT address family messages.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-ipv4_unicast_nlri
			 		If used, support for IPv4 Unicast is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 	-ipv4_capability_unicast_nlri
			 		If used, support for IPv4 Unicast is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv4_filter_unicast_nlri
			 		If used, support for IPv4 Unicast is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv4_multicast_nlri
			 		If used, support for IPv4 Multicast is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 	-ipv4_capability_multicast_nlri
			 		If used, support for IPv4 Multicast is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv4_filter_multicast_nlri
			 		If used, support for IPv4 Multicast is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv4_mpls_nlri
			 		If used, support for IPv4 MPLS is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 	-ipv4_capability_mpls_nlri
			 		If used, support for IPv4 MPLS is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv4_filter_mpls_nlri
			 		If used, support for IPv4 MPLS is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv4_mpls_vpn_nlri
			 		If used, support for IPv4 MPLS VPN is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 	-ipv4_capability_mpls_vpn_nlri
			 		If used, support for IPv4 MPLS VPN is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv4_filter_mpls_vpn_nlri
			 		If used, support for IPv4 MPLS VPN is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv6_unicast_nlri
			 		If used, support for IPv6 Unicast is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 	-ipv6_capability_unicast_nlri
			 		If used, support for IPv6 Unicast is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv6_filter_unicast_nlri
			 		If used, support for IPv6 Unicast is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv6_multicast_nlri
			 		If used, support for IPv6 Multicast is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 	-ipv6_capability_multicast_nlri
			 		If used, support for IPv6 Multicast is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv6_filter_multicast_nlri
			 		If used, support for IPv6 Multicast is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv6_mpls_nlri
			 		If used, support for IPv6 MPLS is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 	-ipv6_capability_mpls_nlri
			 		If used, support for IPv6 MPLS is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv6_filter_mpls_nlri
			 		If used, support for IPv6 MPLS is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv6_mpls_vpn_nlri
			 		If used, support for IPv6 MPLS VPN is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 	-ipv6_capability_mpls_vpn_nlri
			 		If used, support for IPv6 MPLS VPN is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ipv6_filter_mpls_vpn_nlri
			 		If used, support for IPv6 MPLS VPN is advertised in the Capabilities
			 		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			 		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-capability_route_refresh
			x		Route Refresh
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-capability_route_constraint
			x		Route Constraint
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-local_loopback_ip_addr
			x		Required when the -ipv4_mpls_vpn_nlri option is used.
			x	-local_loopback_ip_prefix_length
			x		Prefix length for local_loopback_ip_addr.
			x	-local_loopback_ip_addr_step
			x		Required when the -ipv4_mpls_vpn_nlri option is used.
			x	-remote_loopback_ip_addr
			x		Required when the -ipv4_mpls_vpn_nlri option is used.
			x		This parameter is mandatory when -mode is create, and
			x		parameter -neighbor_type is internal and
			x		and ipv4_mpls_nlri, ipv6_mpls_nlri, ipv4_mpls_vpn_nlri, and
			x		ipv6_mpls_vpn_nlri are enabled.
			x	-remote_loopback_ip_addr_step
			x		Required when the -ipv4_mpls_vpn_nlri option is used.
			x	-ttl_value
			x		This attribute represents the limited number of iterations that a unit of data can experience
			x		before the data is discarded.
			x	-updates_per_iteration
			x		When the protocol server operates on older ports that do not possess
			x		a local processor, this tuning parameter controls how many UPDATE
			x		messages are sent at a time. When many routers are being simulated on
			x		such a port, changing this value may help to increase or decrease
			x		performance.
			x	-bfd_registration
			x		Enable or disable BFD registration.
			x	-bfd_registration_mode
			x		Set BFD registration mode to single hop or multi hop.
			x		Valid choices are:
			x   		single_hop -
			x   		multi_hop -
			x	-override_existence_check
			x		If this option is enabled, the interface existence check is skipped but the list of interfaces is still created and maintained in order to keep track of existing interfaces if required. Using this option will speed up the interfaces' creation.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-override_tracking
			x		If this option is enabled, the list of interfaces won't be created and maintained anymore, thus, speeding up the interfaces' creation even more. Also, it will enable -override_existence_check in case it wasn't already enabled because checking for interface existence becomes impossible if the the list of interfaces doesn't exist anymore.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-no_write
			x		If this option is present, the configuration is not written to the hardware. This option can be used to queue up multiple configurations before writing to the hardware.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vpls
			x		(deprecated)
			x		This BGP/BGP+ router/peer supports BGP/BGP+ VPLS per the Kompella draft.
			x		This will enable the L2 Sites. If present, means VPLS capabilities are enabled.
			x		Valid choices are:
			x   		0 - disabled
			x   		1 - enabled
			x   		vpn -
			x   		no_vpn -
			 	-vpls_nlri
			 		This BGP/BGP+ router/peer supports BGP/BGP+ VPLS per the Kompella draft.
			 		This will enable the L2 Sites. If present, means VPLS capabilities are enabled.
			 	-vpls_capability_nlri
			 		This BGP/BGP+ router/peer supports BGP/BGP+ VPLS per the Kompella draft.
			 		This will enable the L2 Sites. If present, means VPLS capabilities are enabled.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vpls_filter_nlri
			 		This BGP/BGP+ router/peer supports BGP/BGP+ VPLS per the Kompella draft.
			 		This will enable the L2 Sites. If present, means VPLS capabilities are enabled.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			n	-advertise_host_route
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-modify_outgoing_as_path
			n		Moved to emulation_bgp_route_config under AS Path configuration.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-remote_confederation_member
			n		Moved to emulation_bgp_route_config under AS Path configuration.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-reset
			n		Clears any BGP4 configuration on the targeted port before configuring further.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-route_refresh
			n		Details needed.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-routes_per_msg
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-suppress_notify
			n		If set to 1, suppresses, the notification message sent to the peer. if set to 0, does not suppress the notification message sent to the peer.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-timeout
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-update_msg_size
			n		Maximum size (bytes) of the UPDATE message transmitted by emulated router node.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-vlan_cfi
			x	-act_as_restarted
			x   		Act as restarted
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-discard_ixia_generated_routes
			x   		Discard Ixia Generated Routes
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-local_router_id_type
			x   		BGP ID Same as Router ID
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		same -
			x       		new -
			x	-send_ixia_signature_with_routes
			x   		Send Ixia Signature With Routes
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_flap
			x   		Flap
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-flap_up_time
			x   		Uptime in Seconds
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-flap_down_time
			x   		Downtime in Seconds
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_multicast_vpn_nlri
			x   		IPv4 Multicast VPN
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_capability_multicast_vpn_nlri
			x   		IPv4 Multicast VPN
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_filter_multicast_vpn_nlri
			x   		IPv4 Multicast VPN
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_multicast_vpn_nlri
			x   		IPv6 Multicast VPN
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_capability_multicast_vpn_nlri
			x   		IPv6 Multicast VPN
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_filter_multicast_vpn_nlri
			x   		IPv6 Multicast VPN
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-filter_ipv4_multicast_bgp_mpls_vpn
			x   		Filter IPv4 Multicast BGP/MPLS VPN
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-filter_ipv6_multicast_bgp_mpls_vpn
			x   		Filter IPv4 Multicast BGP/MPLS VPN
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_multicast_bgp_mpls_vpn
			x   		IPv4 Multicast BGP/MPLS VPN
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_multicast_bgp_mpls_vpn
			x   		IPv6 Multicast BGP/MPLS VPN
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-advertise_end_of_rib
			x   		Advertise End-Of-RIB
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-configure_keepalive_timer
			x   		Configure Keepalive Timer
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-keepalive_timer
			    		Keepalive Timer
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-staggered_start_enable
			    		Enables staggered start of neighbors.
			 	-staggered_start_time
			    		When the -staggered_start_enable flag is used, this is the duration of
			    		the start process in seconds.
			x	-start_rate_enable
			x   		Enable bgp globals start rate
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-start_rate_interval
			x   		Time interval used to calculate the rate for triggering an action (rate = count/interval)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-start_rate
			x   		Number of times an action is triggered per time interval
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-start_rate_scale_mode
			x   		Indicates whether the control is specified per port or per device group
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		deviceGroup - The values regarding start rate are mapped per device group
			x       		port - The values regarding start rate are mapped per port
			x	-stop_rate_enable
			x   		Enable bgp globals stop rate
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-stop_rate_interval
			x   		Time interval used to calculate the rate for triggering an action (rate = count/interval)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-stop_rate
			x   		Number of times an action is triggered per time interval
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-stop_rate_scale_mode
			x   		Indicates whether the control is specified per port or per device group
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		deviceGroup - The values regarding stop rate are mapped per device group
			x       		port - The values regarding stop rate are mapped per port
			 	-active_connect_enable
			    		For External BGP neighbor.If set, a HELLO message is actively sent
			    		when BGP testing starts.Otherwise, the port waits for the DUT to
			    		send its HELLO message.
			x	-disable_received_update_validation
			x   		Disable Received Update Validation (Enabled for High Performance)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_ad_vpls_prefix_length
			x   		Enable AD VPLS Prefix Length in Bits
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ibgp_tester_as_four_bytes
			x   		Tester 4 Byte AS# for iBGP
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ibgp_tester_as_two_bytes
			x   		Tester AS# for iBGP
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-initiate_ebgp_active_connection
			x   		Initiate eBGP Active Connection
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-initiate_ibgp_active_connection
			x   		Initiate iBGP Active Connection
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-mldp_p2mp_fec_type
			x   		MLDP P2MP FEC Type (Hex)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-request_vpn_label_exchange_over_lsp
			x   		Request VPN Label Exchange over LSP
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-trigger_vpls_pw_initiation
			x   		Trigger VPLS PW Initiation
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-as_path_set_mode
			x   		For External routing only.
			x   		Optional setup for the AS-Path.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		include_as_seq - Include Local AS as AS-SEQ
			x       		include_as_seq_conf - Include Local AS as AS-SEQ-Confederation
			x       		include_as_set - Include Local AS as AS-SET
			x       		include_as_set_conf - Include Local AS as AS-SET-Confederation
			x       		no_include - Don't include Local AS
			x       		prepend_as - Prepend Local AS to first segment
			x	-router_id
			x   		The ID of the router to be emulated.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-router_id_step
			x   		The value use to increment the router_id when count > 1.
			x   		(DEFAULT = 0.0.0.1)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-filter_link_state
			x   		If used, support for Link State is advertised in the Capabilities
			x   		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			x   		message and in addition, for IxTclNetwork, also sets the filters for the respective learned Link State
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-capability_linkstate_nonvpn
			x   		If used, support for Link State is advertised in the Capabilities
			x   		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			x   		message and in addition, for IxTclNetwork, also sets the filters for the respective learned Link State
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-bgp_ls_id
			x   		BGP-LS ID
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-instance_id
			x   		BGP-LS Instance ID
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-number_of_communities
			x   		Number of Communities
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_community
			x   		Enable Community
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-community_type
			x   		BGP L3 Site Target Types
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		no_export - Community type "No Export"
			x       		no_advertised - Community type "No Advertised"
			x       		noexport_subconfed - Community type "Noexport Subconfed"
			x       		manual - Community type "Manual"
			x	-community_as_number
			x   		AS #
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-community_last_two_octets
			x   		Last Two Octets
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-number_of_ext_communities
			x   		Number of Extended Communities
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_ext_community
			x   		Enable Ext Community
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_communities_type
			x   		Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		admin_as_two_octet - Extended Community type - Admin AS number 2 octet
			x       		admin_ip - Extended Community type - Admin IP address
			x       		admin_as_four_octet - Extended Community type - Admin AS number 4 octet
			x       		opaque - Extended Community type - Opaque data
			x       		evpn - Extended Community type - EVPN
			x	-ext_communities_subtype
			x   		SubType
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		route_target - Extended Community sub type - Route target
			x       		origin - Extended Community sub type - Origin
			x       		extended_bandwidth - Extended Community sub type - Extended bandwidth
			x       		encapsulation - Extended Community sub type - encapsulation
			x       		mac_address - Extended Community sub type - MacAddress
			x	-ext_community_as_number
			x   		BGP LS Ext Community AS #
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_community_target_assigned_number_4_octets
			x   		BGP LS Ext Target Assigned Number 4
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_community_as_4_bytes
			x   		BGP LS Ext Community AS 4 #
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_community_target_assigned_number_2_octets
			x   		BGP LS Ext Target Assigned Number 2
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_community_ip
			x   		BGP LS Ext IP
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_community_opaque_data
			x   		Opaque Data (Hex)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_override_peer_as_set_mode
			x   		enable_override_peer_as_set_mode
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-bgp_ls_as_set_mode
			x   		For External routing only.
			x   		Optional setup for the AS-Path.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		include_as_seq - BGP-LS As Set Mode - Include Local AS as AS-SEQ
			x       		include_as_seq_conf - BGP-LS As Set Mode - Include Local AS as AS-SEQ-Confederation
			x       		include_as_set - BGP-LS As Set Mode - Include Local AS as AS-SET
			x       		include_as_set_conf - BGP-LS As Set Mode - Include Local AS as AS-SET-Confederation
			x       		no_include - BGP-LS As Set Mode - Don't include Local AS
			x       		prepend_as - BGP-LS As Set Mode - Prepend Local AS to first segment
			x	-number_of_as_path_segments
			x   		Number of AS Path Segments
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_as_path_segments
			x   		Enable AS Path Segments
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_as_path_segment
			x   		Enable AS Path Segment
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-number_of_as_number_in_segment
			x   		Number of AS Path Segments
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-as_path_segment_type
			x   		as_path_segment_type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		as_set - AS Path Segment Type - Include Local AS as AS-SEQ
			x       		as_seq - AS Path Segment Type - Include Local AS as AS-SEQ-Confederation
			x       		as_set_confederation - AS Path Segment Type - Include Local AS as AS-SET
			x       		as_seq_confederation - AS Path Segment Type - Include Local AS as AS-SET-Confederation
			x	-as_path_segment_enable_as_number
			x   		enable as number
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-as_path_segment_as_number
			x   		AS Path Segment AS Number
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-number_of_clusters
			x   		Number of Communities
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_cluster
			x   		Enable cluster
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-cluster_id
			x   		BGP LS Cluster ID
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-active_ethernet_segment
			x   		Activates the ethernet segment
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-esi_type
			x   		ESI Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		type0 -
			x       		type1 -
			x       		type2 -
			x       		type3 -
			x       		type4 -
			x       		type5 -
			x	-esi_value
			x   		ESI Value
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-b_mac_prefix
			x   		B-MAC Prefix
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-b_mac_prefix_length
			x   		B-MAC Prefix Length
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-use_same_sequence_number
			x   		Use B-MAC Same Sequence Number
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-include_mac_mobility_extended_community
			x   		Include MAC Mobility Extended Community
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_sticky_static_flag
			x   		Enable B-MAC Sticky/Static Flag
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-support_multihomed_es_auto_discovery
			x   		Support Multi-homed ES Auto Discovery
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-auto_configure_es_import
			x   		Auto Configure ES-Import
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-es_import
			x   		ES Import
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-df_election_timer
			x   		DF Election Timer(s)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-support_fast_convergence
			x   		Support Fast Convergence
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_single_active
			x   		Enable Single-Active
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-esi_label
			x   		ESI Label
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-advertise_inclusive_multicast_route
			x   		Support Inclusive Multicast Ethernet Tag Route (RT Type 3)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-evis_count
			x   		Number of EVIs
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_next_hop
			x   		Enable Next Hop
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-set_next_hop
			x   		Set Next Hop
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		manually -
			x       		sameaslocalip -
			x	-set_next_hop_ip_type
			x   		Set Next Hop IP Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		ipv4 -
			x       		ipv6 -
			x	-ipv4_next_hop
			x   		IPv4 Next Hop
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_next_hop
			x   		IPv6 Next Hop
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_origin
			x   		Enable Origin
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-origin
			x   		Origin
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		igp -
			x       		egp -
			x       		incomplete -
			x	-enable_local_preference
			x   		Enable Local Preference
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-local_preference
			x   		Local Preference
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_multi_exit_discriminator
			x   		Enable Multi Exit
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-multi_exit_discriminator
			x   		Multi Exit
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_atomic_aggregate
			x   		Enable Atomic Aggregate
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_aggregator_id
			x   		Enable Aggregator ID
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-aggregator_id
			x   		Aggregator ID
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-aggregator_as
			x   		Aggregator AS
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_originator_id
			x   		Enable Originator ID
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-originator_id
			x   		Originator ID
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-no_of_clusters
			x   		Number of Clusters
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-use_control_word
			x   		Use Control Word
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ethernet_segment_name
			x   		Name of NGPF element, guaranteed to be unique in Scenario
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ethernet_segments_count
			x   		Number of Ethernet Segments
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-filter_evpn
			x   		Check box for EVPN filter
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-evpn
			x   		Check box for EVPN
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-operational_model
			x   		Operational Model
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		symmetric -
			x       		asymmetric -
			x	-routers_mac_or_irb_mac_address
			x   		Router's MAC/IRB MAC Address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ip_type
			x   		IP Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		ipv4 -
			x       		ipv6 -
			x	-ip_address
			x   		IPv4 Address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_address
			x   		IPv6 Address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_b_mac_mapped_ip
			x   		Activates the ethernet segment
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-no_of_b_mac_mapped_ips
			x   		Number of B-MAC Mapped IPs
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-capability_ipv4_unicast_add_path
			x   		Capability Ipv4 Unicast AddPath
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-capability_ipv6_unicast_add_path
			x   		Capability Ipv6 Unicast AddPath
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_mpls_add_path_mode
			x   		IPv4 MPLS Add Path Mode
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		receiveonly -
			x       		sendonly -
			x       		both -
			x	-ipv6_mpls_add_path_mode
			x   		IPv6 MPLS Add Path Mode
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		receiveonly -
			x       		sendonly -
			x       		both -
			x	-ipv4_unicast_add_path_mode
			x   		IPv4 Unicast Add Path Mode
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		receiveonly -
			x       		sendonly -
			x       		both -
			x	-ipv6_unicast_add_path_mode
			x   		IPv6 Unicast Add Path Mode
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		receiveonly -
			x       		sendonly -
			x       		both -
			x	-ipv4_mpls_capability
			x   		Ipv4 Mpls Capability
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_mpls_capability
			x   		Ipv6 Mpls Capability
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-capability_ipv4_mpls_add_path
			x   		Capability Ipv4 Mpls AddPath
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-capability_ipv6_mpls_add_path
			x   		Capability Ipv6 Mpls AddPath
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-custom_sid_type
			x   		Custom SID Type for BGP 3107
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srgb_count
			x   		SRGB Count for BGP 3107
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-start_sid
			x   		Start SID for BGP 3107
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-sid_count
			x   		SID Count for BGP 3107
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_multiple_mpls_labels_capability
			x   		IPv4 Multiple MPLS Labels Capability
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_multiple_mpls_labels_capability
			x   		IPv6 Multiple MPLS Labels Capability
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-mpls_labels_count_for_ipv4_mpls_route
			x   		MPLS Labels Count For IPv4 MPLS Route
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-mpls_labels_count_for_ipv6_mpls_route
			x   		MPLS Labels Count For IPv6 MPLS Route
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-noOfUserDefinedAfiSafi
			x   		Number of User Defined Custom AFI-SAFI
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-afiSafi_active
			x   		Select the Active check box to activate the Custom AFI SAFI.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-afiValue
			x   		AFI Value for Custom AFI SAFI.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-safiValue
			x   		SAFI Value for Custom AFI SAFI.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lengthOfData
			x   		Length in bytes for Custom AFI SAFI.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dataValue
			x   		Data Value for Custom AFI SAFI.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_unicast_flowSpec_nlri
			x   		If used, support for IPv4 Unicast FlowSpec is advertised in the Capabilities
			x   		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			x   		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-capability_ipv4_unicast_flowSpec
			x   		IPv4 Unicast Flow Spec
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-filter_ipv4_unicast_flowSpec
			x   		Filter IPv4 Unicast Flow Spec
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_unicast_flowSpec_nlri
			x   		If used, support for IPv6 Unicast FlowSpec is advertised in the Capabilities
			x   		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			x   		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-capability_ipv6_unicast_flowSpec
			x   		IPv6 Unicast Flow Spec
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-filter_ipv6_unicast_flowSpec
			x   		Filter IPv6 Unicast Flow Spec
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-always_include_tunnel_enc_ext_community
			x   		Always Include Tunnel Encapsulation Extended Community
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ip_vrf_to_ip_vrf_type
			x   		IP-VRF-to-IP-VRF Model Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		interfacefullWithCorefacingIRB -
			x       		interfacefullWithUnnumberedCorefacingIRB -
			x       		interfaceLess -
			x	-irb_interface_label
			x   		Label to be used for Route Type 2 carrying IRB MAC and/or IRB IP in Route Type 2
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-irb_ipv4_address
			x   		IRB IPv4 Address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-irb_ipv6_address
			x   		IRB IPv6 Address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_srte_policy_nlri
			x   		If used, support for IPv4 SRTE Policies is advertised in the Capabilities
			x   		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			x   		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-capability_ipv4_srte_policy
			x   		IPv4 SRTE Policies
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-filter_ipv4_srte_policy
			x   		Filter IPv4 SRTE Policies
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_srte_policy_nlri
			x   		If used, support for IPv6 SRTE Policies is advertised in the Capabilities
			x   		Optional Parameter / Multiprotocol Extensions parameter in the OPEN
			x   		message and in addition, for IxTclNetwork, also sets the filters for the respective learned routes.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-capability_ipv6_srte_policy
			x   		IPv6 SRTE Policies Capabilities
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-filter_ipv6_srte_policy
			x   		Filter IPv6 SRTE Policies
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_policy_safi
			x   		SR TE Policy SAFI
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_policy_attr_type
			x   		SR TE Policy Tunnel Encaps Attribute Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_policy_type
			x   		SR TE Policy Tunnel Type for SR Policy
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_remote_endpoint_type
			x   		SR TE Policy Remote Endpoint Sub-TLV Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_color_type
			x   		SR TE Policy Color Sub-TLV Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_preference_type
			x   		SR TE Policy Preference Sub-TLV Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_binding_type
			x   		SR TE Policy Binding Sub-TLV Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_segment_list_type
			x   		SR TE Policy Segment List Sub-TLV Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_weight_type
			x   		SR TE Policy Weight Sub-TLV Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_mplsSID_type
			x   		SR TE Policy MPLS SID Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_ipv6SID_type
			x   		SR TE Policy IPv6 SID Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_ipv4_node_address_type
			x   		SR TE Policy IPv4 Node Address Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_ipv6_node_address_type
			x   		SR TE Policy IPv6 Node Address Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_ipv4_node_address_index_type
			x   		SR TE Policy IPv4 Node Address and Index Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_ipv4_local_remote_address
			x   		SR TE Policy IPv4 Local and remote address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_ipv6_node_address_index_type
			x   		SR TE Policy IPv6 Node Address and Index Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_ipv6_local_remote_address
			x   		SR TE Policy IPv6 Local and remote address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_include_length
			x   		Include length Field in SR TE Policy NLRI
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srte_length_unit
			x   		Length unit in SR TE Policy NLRI
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		bits -
			x       		bytes -
		
		Return Values:
		A list containing the lscommunities  rtr protocol stack handles that were added by the command (if any).
			xkey:lscommunities_handle_rtr     value:A list containing the lscommunities  rtr protocol stack handles that were added by the command (if any).
		A list containing the lsaspath  rtr protocol stack handles that were added by the command (if any).
			xkey:lsaspath_handle_rtr          value:A list containing the lsaspath  rtr protocol stack handles that were added by the command (if any).
		A list containing the bgp ethernet segment protocol stack handles that were added by the command (if any).
			xkey:bgp_ethernet_segment_handle  value:A list containing the bgp ethernet segment protocol stack handles that were added by the command (if any).
		A list containing the bgp b mac mapped ip protocol stack handles that were added by the command (if any).
			xkey:bgp_b_mac_mapped_ip_handle   value:A list containing the bgp b mac mapped ip protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:lscommunities_handles_rtr    value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:lsaspath_handles_rtr         value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		$::SUCCESS | $::FAILURE
			 key:status                       value:$::SUCCESS | $::FAILURE
		When status is $::FAILURE, contains more information
			 key:log                          value:When status is $::FAILURE, contains more information
		Handle of bgpipv4peer or bgpipv6peer configured
			 key:bgp_handle                   value:Handle of bgpipv4peer or bgpipv6peer configured
		Item Handle of any bgpipv4peer or bgpipv6peer configured Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:handles                      value:Item Handle of any bgpipv4peer or bgpipv6peer configured Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		list of BGP node names/ids/handles
			 key:handles                      value:list of BGP node names/ids/handles
		
		Examples:
		See files starting with BGP4_ in the Samples subdirectory.  Also see some of the L3VPN, MPLS, and MVPN sample files for further examples of BGP usage.
		See the BGP examples in Appendix A, "Example APIs," for specific example usage.
		
		Sample Input:
		
		Sample Output:
		{status $::SUCCESS} {bgp_handle /topology:1/deviceGroup:1/ethernet:1/ipv4:1/bgpIpv4Peer:1} {handle {/topology:1/deviceGroup:1/ethernet:1/ipv4:1/bgpIpv4Peer:1/item:1}}
		
		Notes:
		Coded versus functional specification.
		When -handle is provided with the /globals value the arguments that configure global protocol
		setting accept both multivalue handles and simple values.
		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
		that configure global settings will only accept simple values. In this situation, these arguments will
		configure only the settings of the parent device group or the ports associated with the parent topology.
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handles, lscommunities_handles_rtr, lsaspath_handles_rtr
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_bgp_config", kwargs)

	def emulation_bgp_control(self, **kwargs):
		""" This procedure starts, stops and restarts a BGP protocol for the specified port.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_bgp_control
			 	-mode                   CHOICES restart
			                         CHOICES abort
			                         CHOICES restart_down
			                         CHOICES start
			                         CHOICES stop
			                         CHOICES statistic
			                         CHOICES break_tcp_session
			                         CHOICES resume_tcp_session
			                         CHOICES resume_keep_alive
			                         CHOICES stop_keep_alive
			                         CHOICES advertise_aliasing
			                         CHOICES withdraw_aliasing
			                         CHOICES flush_remote_cmac_forwarding_table
			                         CHOICES readvertise_cmac
			                         CHOICES readvertise_routes
			                         CHOICES age_out_routes
			                         CHOICES switch_to_spmsi
			 	[-handle                ANY]
			x	[-notification_code     NUMERIC
			x                        DEFAULT 0]
			x	[-notification_sub_code NUMERIC
			x                        DEFAULT 0]
			 	[-port_handle           ANY]
			x	[-age_out_percent       NUMERIC]
			 	[-link_flap_down_time   ANY]
		
		Arguments:
			 	-mode
			 		What is being done to the protocol..
			 		Valid choices are:
			    		restart - restart the protocol
			    		abort - aborts the protcol
			    		restart_down - restart the down sessions
			    		start - start the protocol
			    		stop - stop the protocol
			    		statistic - enables the retrieval of statistics for a future call of ::ixia::emulation_bgp_info
with parameter -mode set to stats(valid only for IxProtocol)
			    		break_tcp_session - breaks the tcp session using tcp_session_notification_code and tcp_session_notification_sub_code values
			    		resume_tcp_session - resumes the tcp session using tcp_session_notification_code and tcp_session_notification_sub_code values
			    		resume_keep_alive - resumes the keep alive
			    		stop_keep_alive - stops the keep alive
			    		advertise_aliasing - Advertise Aliasing
			    		withdraw_aliasing - Withdraw Aliasing
			    		flush_remote_cmac_forwarding_table - Flush Remote CMAC Forwarding Table
			    		readvertise_cmac - Readvertise CMAC
			    		readvertise_routes - Readvertise Routes
			    		age_out_routes - Age Out Routes
			    		switch_to_spmsi - Switch to S-PMSI
			 	-handle
			 		The BGP session handle.
			x	-notification_code
			x		The notification code for break_tcp_session and resume_tcp_session.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-notification_sub_code
			x		The notification sub code for break_tcp_session and resume_tcp_session.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-port_handle
			 		The port on which the BGP neighbor is to be created.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-age_out_percent
			x		The percentage of addresses that will be aged out. This argument is ignored when mode is not age_out_routes and *must* be specified in such circumstances.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-link_flap_down_time
			 		When mode is link_flap, the amount of time in seconds that the link is disconnected.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log     value:On status of failure, gives detailed information.
		
		Examples:
		See files starting with BGP4_ in the Samples subdirectory.  Also see some of the L3VPN, MPLS, and MVPN sample files for further examples of BGP usage.
		See the BGP examples in Appendix A, "Example APIs," for specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_bgp_control", kwargs)

	def emulation_bgp_flow_spec_config(self, **kwargs):
		""" This procedure allows user to configure BGP Flow Spec capabilites of BGP Peer. BGP Flow Spec enables user rapidly deploy and propagate filtering and policing functionality among a large number of BGP peer.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_bgp_flow_spec_config
			 	-mode                                           CHOICES create modify enable]
			 	-fs_mode                                        CHOICES fsv4 fsv6]
			 	[-handle                                        ANY]
			x	[-no_of_flowSpecRangeV4                         NUMERIC]
			x	[-no_of_flowSpecRangeV6                         NUMERIC]
			x	[-active                                        CHOICES 0 1
			x                                                DEFAULT 1]
			x	[-flowSpecName                                  ANY]
			x	[-fsv4_enableDestPrefix                         CHOICES 0 1]
			x	[-fsv6_enableDestPrefix                         CHOICES 0 1]
			x	[-fsv4_destPrefix                               IPV4]
			x	[-fsv6_destPrefix                               IPV6]
			x	[-fsv4_destPrefixLength                         NUMERIC]
			x	[-fsv6_destPrefixLength                         NUMERIC]
			x	[-fsv6_destPrefixOffset                         NUMERIC]
			x	[-fsv4_enableSrcPrefix                          CHOICES 0 1]
			x	[-fsv6_enableSrcPrefix                          CHOICES 0 1]
			x	[-fsv4_srcPrefix                                IPV4]
			x	[-fsv6_srcPrefix                                IPV6]
			x	[-fsv4_srcPrefixLength                          NUMERIC]
			x	[-fsv6_srcPrefixLength                          NUMERIC]
			x	[-fsv6_srcPrefixOffset                          NUMERIC]
			x	[-fsv4_ipProto                                  ANY]
			x	[-fsv6_nextHeader                               RANGE 0-65535
			x                                                DEFAULT 1]
			x	[-portMatch                                     ANY]
			x	[-destPortMatch                                 ANY]
			x	[-srcPortMatch                                  ANY]
			x	[-icmpTypeMatch                                 ANY]
			x	[-icmpCodeMatch                                 ANY]
			x	[-tcpFlagsMatch                                 ANY]
			x	[-ipPacketMatch                                 ANY]
			x	[-dscpMatch                                     ANY]
			x	[-fsv4_fragmentMatch                            ANY]
			x	[-fsv6_fragmentMatch                            ANY]
			x	[-fsv6_flowLabel                                ANY]
			x	[-enable_traffic_rate                           CHOICES 0 1]
			x	[-trafficRate                                   NUMERIC]
			x	[-enable_trafficAction                          CHOICES 0 1]
			x	[-terminalAction                                CHOICES 0 1]
			x	[-trafficActionSample                           CHOICES 0 1]
			x	[-enable_redirect                               CHOICES 0 1]
			x	[-redirect_ext_communities_type                 CHOICES rdAS2byte
			x                                                CHOICES rdIPv4
			x                                                CHOICES rdAS4byte
			x                                                CHOICES rdnextHop]
			x	[-as_2_bytes                                    RANGE 0-65535
			x                                                DEFAULT 1]
			x	[-as_4_bytes                                    NUMERIC
			x                                                DEFAULT 1]
			x	[-fsv4_ipv4                                     IPV4]
			x	[-fsv6_ipv6                                     IPV6]
			x	[-assigned_number_2_octets                      NUMERIC
			x                                                DEFAULT 1]
			x	[-assigned_number_4_octets                      NUMERIC
			x                                                DEFAULT 1]
			x	[-Cbit                                          CHOICES 0 1]
			x	[-nextHop                                       IPV4]
			x	[-enable_trafficMarking                         CHOICES 0 1]
			x	[-dscp                                          NUMERIC]
			x	[-fsv6_enable_redirectIPv6                      CHOICES 0 1]
			x	[-fsv6_redirectIPv6                             IPV6]
			x	[-enable_next_hop                               CHOICES 0 1]
			x	[-set_next_hop                                  CHOICES manually sameaslocalip]
			x	[-set_next_hop_ip_type                          CHOICES ipv4 ipv6]
			x	[-ipv4_next_hop                                 IPV4]
			x	[-ipv6_next_hop                                 IPV6]
			x	[-enable_origin                                 CHOICES 0 1]
			x	[-origin                                        CHOICES igp egp incomplete]
			x	[-enable_local_preference                       CHOICES 0 1]
			x	[-local_preference                              NUMERIC]
			x	[-enable_multi_exit_discriminator               CHOICES 0 1]
			x	[-multi_exit_discriminator                      NUMERIC]
			x	[-enable_atomic_aggregate                       CHOICES 0 1]
			x	[-enable_aggregator_id                          CHOICES 0 1]
			x	[-aggregator_id                                 IPV4]
			x	[-aggregator_as                                 NUMERIC]
			x	[-enable_originator_id                          CHOICES 0 1]
			x	[-originator_id                                 IPV4]
			x	[-enable_community                              CHOICES 0 1]
			x	[-number_of_communities                         RANGE 0-32
			x                                                DEFAULT 1]
			x	[-community_type                                CHOICES no_export
			x                                                CHOICES no_advertised
			x                                                CHOICES noexport_subconfed
			x                                                CHOICES manual
			x                                                CHOICES llgr_stale
			x                                                CHOICES no_llgr
			x                                                DEFAULT no_export]
			x	[-community_as_number                           RANGE 0-65535
			x                                                DEFAULT 0]
			x	[-community_last_two_octets                     RANGE 0-65535
			x                                                DEFAULT 0]
			 	[-enable_large_communitiy                       CHOICES 0 1]
			x	[-num_of_large_communities                      NUMERIC]
			x	[-large_community                               ANY]
			x	[-enable_ext_community                          CHOICES 0 1]
			x	[-number_of_ext_communities                     RANGE 0-32
			x                                                DEFAULT 1]
			x	[-ext_communities_type                          CHOICES admin_as_two_octet
			x                                                CHOICES admin_ip
			x                                                CHOICES admin_as_four_octet
			x                                                CHOICES opaque
			x                                                CHOICES evpn
			x                                                CHOICES admin_as_two_octet_link_bw
			x                                                DEFAULT admin_as_two_octet]
			x	[-ext_communities_subtype                       CHOICES route_target
			x                                                CHOICES origin
			x                                                CHOICES extended_bandwidth
			x                                                CHOICES color
			x                                                CHOICES encapsulation
			x                                                CHOICES mac_address
			x                                                DEFAULT route_target]
			x	[-ext_community_as_number                       RANGE 0-65535
			x                                                DEFAULT 1]
			x	[-ext_community_target_assigned_number_4_octets NUMERIC
			x                                                DEFAULT 1]
			x	[-ext_community_ip                              IP]
			x	[-ext_community_as_4_bytes                      NUMERIC
			x                                                DEFAULT 1]
			x	[-ext_community_target_assigned_number_2_octets NUMERIC
			x                                                DEFAULT 1]
			x	[-ext_community_opaque_data                     HEX]
			x	[-ext_community_colorCObits                     CHOICES 00 01 10 11
			x                                                DEFAULT 00]
			x	[-ext_community_colorReservedBits               NUMERIC]
			x	[-ext_community_colorValue                      NUMERIC]
			x	[-ext_community_linkBandwidth                   NUMERIC]
			x	[-enable_override_peer_as_set_mode              CHOICES 0 1]
			x	[-as_path_set_mode                              CHOICES include_as_seq
			x                                                CHOICES include_as_seq_conf
			x                                                CHOICES include_as_set
			x                                                CHOICES include_as_set_conf
			x                                                CHOICES no_include
			x                                                CHOICES prepend_as
			x                                                DEFAULT no_include]
			x	[-enable_as_path_segments                       CHOICES 0 1]
			x	[-no_of_as_path_segments                        RANGE 0-32
			x                                                DEFAULT 1]
			x	[-enable_as_path_segment                        CHOICES 0 1]
			x	[-as_path_segment_type                          CHOICES as_set
			x                                                CHOICES as_seq
			x                                                CHOICES as_set_confederation
			x                                                CHOICES as_seq_confederation
			x                                                DEFAULT as_set]
			x	[-number_of_as_number_in_segment                RANGE 0-50
			x                                                DEFAULT 1]
			x	[-as_path_segment_enable_as_number              CHOICES 0 1]
			x	[-as_path_segment_as_number                     NUMERIC
			x                                                DEFAULT 1]
			x	[-enable_cluster                                CHOICES 0 1]
			x	[-no_of_clusters                                RANGE 0-32
			x                                                DEFAULT 1]
			x	[-cluster_id                                    IP]
		
		Arguments:
			 	-mode
			 		This option defines the action to be taken on the BGP server.
			 		Valid choices are:
			    		create - create the BGP FlowSpec configuration
			    		modify - modify the BGP FlowSpec configuration, requires the use of -handle.
			    		enable - Helps to modify the BGP FlowSpec configuration, requires the use of -handle.
			 	-fs_mode
			 		This option defines the type of Flowspec.
			 		Valid choices are:
			    		fsv4 - IPv4 FlowSpec configuration
			    		fsv6 - IPv6FlowSpec configuration
			 	-handle
			 		bgp_flowSpecV4_handle: -handle is returned by procedure emulation_bgp_flow_spec_config when a IPv4 Flow Spec is created or modified
			 		bgp_flowSpecV6_handle: -handle is returned by procedure emulation_bgp_flow_spec_config when a IPv6 Flow Spec is created or modified
			x	-no_of_flowSpecRangeV4
			x		Number of IPV4 Flow Spec Ranges
			x	-no_of_flowSpecRangeV6
			x		Number of IPV6 Flow Spec Ranges
			x	-active
			x		Select the Active check box to activate the Flow Spec. This means that the Flow Spec can be started or stopped and is usable in the state machine.
			x		If this check box is not selected, the element is not able to respond to any action including Start and Stop.
			x	-flowSpecName
			x		BGP Flow Spec Name
			x	-fsv4_enableDestPrefix
			x		Enables Destination Prefix and Prefix Length for Flow Spec
			x	-fsv6_enableDestPrefix
			x		Enables Destination Prefix and Prefix Length for Flow Spec
			x	-fsv4_destPrefix
			x		Destination Prefix for IPv4 Flow Spec
			x	-fsv6_destPrefix
			x		Destination Prefix for IPv6 Flow Spec
			x	-fsv4_destPrefixLength
			x		Destination Prefix Length for IPv4 Flow Spec
			x	-fsv6_destPrefixLength
			x		Destination Prefix Length for IPv6 Flow Spec
			x	-fsv6_destPrefixOffset
			x		Destination Prefix Offset for IPv6 Flow Spec
			x	-fsv4_enableSrcPrefix
			x		Enables Source Prefix and Prefix Length for IPv4 Flow Spec
			x	-fsv6_enableSrcPrefix
			x		Enables Source Prefix and Prefix Length for IPv6 Flow Spec
			x	-fsv4_srcPrefix
			x		Source Prefix for IPv4 Flow Spec
			x	-fsv6_srcPrefix
			x		Source Prefix for IPv6 Flow Spec
			x	-fsv4_srcPrefixLength
			x		Source Prefix Length for IPv4 Flow Spec
			x	-fsv6_srcPrefixLength
			x		Source Prefix Length for IPv6 Flow Spec
			x	-fsv6_srcPrefixOffset
			x		Source Prefix Offset for IPv6 Flow Spec
			x	-fsv4_ipProto
			x		IPv4 Flow Spec Proto Match. Minimum Value: 0 Maximum Value: 65535
			x	-fsv6_nextHeader
			x		IPv6 Flow Spec Next Header
			x	-portMatch
			x		Flow Spec Port match. Minimum Value: 0 Maximum Value: 65535
			x	-destPortMatch
			x		Flow Spec Destination Port Match. Minimum Value: 0 Maximum Value: 65535
			x	-srcPortMatch
			x		Flow Spec Source Port Match. Minimum Value: 0 Maximum Value: 65535
			x	-icmpTypeMatch
			x		Flow Spec ICMP Type Match. Minimum Value: 0 Maximum Value: 255
			x	-icmpCodeMatch
			x		Flow Spec ICMP Code Match. Minimum Value: 0 Maximum Value: 255
			x	-tcpFlagsMatch
			x		Flow Spec TCP Flags Match. Minimum Value: 0 Maximum Value: 0xFFF
			x	-ipPacketMatch
			x		Flow Spec IP Packet Match. Minimum Value: 0 Maximum Value: 65535
			x	-dscpMatch
			x		Flow Spec DSCP Match. Minimum Value: 0 Maximum Value: 63
			x	-fsv4_fragmentMatch
			x		IPv4 Flow Spec Fragment Match. Minimum Value: 0 Maximum Value: 0xFF
			x	-fsv6_fragmentMatch
			x		IPv6 Flow Spec Fragment Match. Minimum Value: 0 Maximum Value: 0xFF
			x	-fsv6_flowLabel
			x		IPv6 Flow Spec Flow Label
			x	-enable_traffic_rate
			x		Enable Traffic Rate for Flow Spec
			x	-trafficRate
			x		Traffic Rate for Flow Spec
			x	-enable_trafficAction
			x		Enable Traffic Action for Flow Spec
			x	-terminalAction
			x		Enable Terminal Action for Flow Spec. Set Terminal(T) flag for Traffic action
			x	-trafficActionSample
			x		Traffic Action Sample for Flow Spec. Set Sample(S) flag for Traffic action
			x	-enable_redirect
			x		Enable Redirect for Flow Spec
			x	-redirect_ext_communities_type
			x		Relates to the high-order Extended Community Type field for Flow Spec Actions
			x		Valid choices are:
			x   		rdAS2byte - Extended Community Type - Redirect AS-2 byte
			x   		rdIPv4 - Extended Community Type - Redirect IPv4
			x   		rdAS4byte - Extended Community Type - Redirect AS-4 byte
			x   		rdnextHop - Extended Community Type - Redirect to IP Next Hop
			x	-as_2_bytes
			x		2-byte Autonomous System (AS) number for Flow Spec
			x	-as_4_bytes
			x		4-byte Autonomous System (AS) number for Flow Spec
			x	-fsv4_ipv4
			x		IP Address for IPv4 Flow Spec
			x	-fsv6_ipv6
			x		IP Address for IPv6 Flow Spec
			x	-assigned_number_2_octets
			x		2 Octet assigned Number for Flow Spec
			x	-assigned_number_4_octets
			x		4 Octet assigned Number for Flow Spec
			x	-Cbit
			x		C Bit for Flow Spec. It is the highest order bit in the VC Type field. If the bit is set, it indicates the presence of a control word on this VC.
			x	-nextHop
			x		Next Hop for Flow Spec
			x	-enable_trafficMarking
			x		Enable Traffic Marking for Flow Spec
			x	-dscp
			x		DSCP for IPv4 Flow Spec
			x	-fsv6_enable_redirectIPv6
			x		Enable Redirect IPv6 for IPv6 Flow Spec
			x	-fsv6_redirectIPv6
			x		Redirected IPv6 Address for IPv6 Flow Spec
			x	-enable_next_hop
			x		Enable Next Hop for Flow Spec
			x	-set_next_hop
			x		Set IP Address of Next Hop for Flow Spec
			x		Valid choices are:
			x   		manually - Sets Next Hop to Manually
			x   		sameaslocalip - Set Next Hop to Same as local IP
			x	-set_next_hop_ip_type
			x		Set Next Hop IP Type for Flow Spec
			x		Valid choices are:
			x   		ipv4 - Sets Next Hop Ip type to IPv4
			x   		ipv6 - Sets Next Hop Ip type to IPv6
			x	-ipv4_next_hop
			x		IPv4 Next Hop IP Address for Flow Spec
			x	-ipv6_next_hop
			x		IPv6 Next Hop IP Address for Flow Spec
			x	-enable_origin
			x		Enable Origin for Flow Spec
			x	-origin
			x		Origin for Flow Spec
			x		Valid choices are:
			x   		igp - Sets Origin to IGP
			x   		egp - Sets Origin to EGP
			x   		incomplete - Sets Origin to Incomplete
			x	-enable_local_preference
			x		Enable Local Preference for Flow Spec
			x	-local_preference
			x		Local Preference for Flow Spec
			x	-enable_multi_exit_discriminator
			x		Enable Multi Exit Discriminator for Flow Spec
			x	-multi_exit_discriminator
			x		Multi Exit Discriminator for Flow Spec
			x	-enable_atomic_aggregate
			x		Enable Atomic Aggregate for Flow Spec
			x	-enable_aggregator_id
			x		Enable Aggregator ID for Flow Spec
			x	-aggregator_id
			x		Aggregator ID for Flow Spec
			x	-aggregator_as
			x		Sets the AS asssociated with the Aggregator router id for Flow Spec
			x	-enable_originator_id
			x		Enable Originator ID for Flow Spec
			x	-originator_id
			x		Originator ID for the router that originated the rule for Flow Spec
			x	-enable_community
			x		Enable Community for BGP Flow Spec
			x	-number_of_communities
			x		Number of Communities for Flow Spec
			x	-community_type
			x		BGP Flow Spec Community Types
			x		Valid choices are:
			x   		no_export - Community type "No Export"
			x   		no_advertised - Community type "No Advertised"
			x   		noexport_subconfed - Community type "Noexport Subconfed"
			x   		manual - Community type "Manual"
			x   		llgr_stale - Community type "LLGR_STALE"
			x   		no_llgr - Community type "NO LLGR"
			x	-community_as_number
			x		BGP Flow Spec AS Number
			x	-community_last_two_octets
			x		BGP FlowSpec Last Two Octets
			 	-enable_large_communitiy
			 		Enables or disables Large communities.
			x	-num_of_large_communities
			x		Internal mapping to implicit list length param
			x	-large_community
			x		Large Community in cannonical format as defined in RFC8092 which is:
			x		GlobalAdmin:LocalDataPart1:LocalDataPart2
			x		where each value must have range 1-4294967295.
			x		e.g. 65535:100:10 or 4294967295:1:65535
			x	-enable_ext_community
			x		Enable Ext Community for Flow Spec
			x	-number_of_ext_communities
			x		Number of Extended Communities for Flow Spec
			x	-ext_communities_type
			x		BGP Flow Spec Extended Communities Type
			x		Valid choices are:
			x   		admin_as_two_octet - Extended Community type - Administrator AS2 octet
			x   		admin_ip - Extended Community type - Administrator IP
			x   		admin_as_four_octet - Extended Community type - Administrator AS4 octet
			x   		opaque - Extended Community type - Opaque data
			x   		evpn - Extended Community type - EVPN
			x   		admin_as_two_octet_link_bw - Extended Community type - Administrator AS2 Octet Link Bandwidth
			x	-ext_communities_subtype
			x		BGP Flow Spec Extended Communities SubType
			x		Valid choices are:
			x   		route_target - Extended Community sub type - Route target
			x   		origin - Extended Community sub type - Origin
			x   		extended_bandwidth - Extended Community sub type - Extended bandwidth
			x   		color - Extended Community sub type - Color
			x   		encapsulation - Extended Community sub type - encapsulation
			x   		mac_address - Extended Community sub type - MacAddress
			x	-ext_community_as_number
			x		BGP Flow Spec Extended Communities AS2 Number
			x	-ext_community_target_assigned_number_4_octets
			x		BGP Flow Spec Extended Communities Target Assigned Number 4
			x	-ext_community_ip
			x		BGP Flow Spec Extended Communites IP
			x	-ext_community_as_4_bytes
			x		BGP Flow Spec Extended Community AS 4 Number
			x	-ext_community_target_assigned_number_2_octets
			x		BGP Flow Spec Extended Target Assigned Number 2
			x	-ext_community_opaque_data
			x		BGP Flow Spec Extended Communities Opaque Data (Hex)
			x	-ext_community_colorCObits
			x		BGP Flow Spec Extended Communities Color CO Bits
			x		Valid choices are:
			x   		00 - Extended Community Color CO Bits - 00
			x   		01 - Extended Community Color CO Bits - 01
			x   		10 - Extended Community Color CO Bits - 10
			x   		11 - Extended Community Color CO Bits - 11
			x	-ext_community_colorReservedBits
			x		BGP Flow Spec Extended Communities Color Reserved Bits
			x	-ext_community_colorValue
			x		BGP Flow Spec Extended Communities Color Value
			x	-ext_community_linkBandwidth
			x		BGP Flow Spec Extended Communities Link Bandwidth
			x	-enable_override_peer_as_set_mode
			x		Enable override Reer as set mode for Flow Spec
			x	-as_path_set_mode
			x		Set mode for AS value for Flow Spec
			x		Valid choices are:
			x   		include_as_seq - Include Local AS as AS-SEQ
			x   		include_as_seq_conf - Include Local AS as AS-SEQ-Confederation
			x   		include_as_set - Include Local AS as AS-SET
			x   		include_as_set_conf - Include Local AS as AS-SET-Confederation
			x   		no_include - Don't include Local AS
			x   		prepend_as - Prepend Local AS to first segment
			x	-enable_as_path_segments
			x		Enable AS Path Segments for Flow Spec
			x	-no_of_as_path_segments
			x		Number of AS Path Segments for Flow Spec
			x	-enable_as_path_segment
			x		Enable AS Path Segment for BGP Flow Spec
			x	-as_path_segment_type
			x		AS Path Segment Type for BGP Flow Spec
			x		Valid choices are:
			x   		as_set - AS Path Segment Type - Include Local AS as AS-SEQ
			x   		as_seq - AS Path Segment Type - Include Local AS as AS-SEQ-Confederation
			x   		as_set_confederation - AS Path Segment Type - Include Local AS as AS-SET
			x   		as_seq_confederation - AS Path Segment Type - Include Local AS as AS-SET-Confederation
			x	-number_of_as_number_in_segment
			x		Number of AS Path Segments for BGP Flow Spec
			x	-as_path_segment_enable_as_number
			x		Enable AS number for BGP Flow Spec
			x	-as_path_segment_as_number
			x		AS Path Segments AS Number for BGP Flow Spec
			x	-enable_cluster
			x		Enable cluster for Flow Spec
			x	-no_of_clusters
			x		Number of Clusters for Flow Spec
			x	-cluster_id
			x		BGP LS Cluster ID for BGP Flow Specs
		
		Return Values:
		A list containing the bgp flowSpecV6 protocol stack handles that were added by the command (if any).
			xkey:bgp_flowSpecV6_handle  value:A list containing the bgp flowSpecV6 protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE
			 key:status                 value:$::SUCCESS | $::FAILURE
		When status is $::FAILURE, contains more information
			 key:log                    value:When status is $::FAILURE, contains more information
		Handle of bgpipv4flowspec configured
			 key:bgp_flowSpecV4_handle  value:Handle of bgpipv4flowspec configured
		Item Handle of any bgpFlowSpecRangesListV4 or bgpFlowSpecRangesListV6 configured
			 key:handles                value:Item Handle of any bgpFlowSpecRangesListV4 or bgpFlowSpecRangesListV6 configured
		
		Examples:
		See files starting with BGP_ in the Samples subdirectory.  Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the BGP usage.
		See the BGP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		{status $::SUCCESS}
		{bgp_flowSpecV4_handle {/topology:1/deviceGroup:1/ethernet:1/ipv4:1/bgpIpv4Peer:1/bgpFlowSpecRangesListV4:1/} {/topology:1/deviceGroup:1/ethernet:1/ipv6:1/bgpIpv6Peer:1/bgpFlowSpecRangesListV4:1/}}
		{bgp_flowSpecV6_handle {/topology:1/deviceGroup:1/ethernet:1/ipv4:1/bgpIpv4Peer:1/bgpFlowSpecRangesListV6:1/} {/topology:1/deviceGroup:1/ethernet:1/ipv6:1/bgpIpv6Peer:1/bgpFlowSpecRangesListV6:1/}}
		
		Notes:
		Coded versus functional specification.
		When a -handle is provided with a BGP/BGP+ protocol stack handle or a protocol session handle, the api will create IPv4/IPv6 Flow Spec
		When a -handle is provided with a BGP Flow Spec Handle, the api will modify the created IPv4/IPv6 Flow Spec
		
		See Also:
		
		"""
		return self._run_keyword("emulation_bgp_flow_spec_config", kwargs)

	def emulation_bgp_info(self, **kwargs):
		""" This procedure retrieves information on Ixia BGP Router  statistics , learned routing information from BGP Router.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_bgp_info
			 	-mode    CHOICES stats
			          CHOICES clear_stats
			          CHOICES settings
			          CHOICES session
			          CHOICES neighbors
			          CHOICES labels
			          CHOICES learned_info
			          CHOICES clear_learned_info
			          CHOICES stats_per_device_group
			 	-handle  ANY]
		
		Arguments:
			 	-mode
			 		Specifies action to be taken on the BGP or BGP+ Peer handle
			 		Valid choices are:
			    		stats - returns Tx and Rx statistics of different BGP messages.
			    		stats_per_device_group - returns Tx and Rx statistics of different BGP messages per device group.
			    		clear_stats - clears Tx and Rx statistics of different BGP messages.
			    		settings - returns tester IP address and AS number.
			    		neighbors - returns SUT IP address.
			    		session - retrieves non-aggregated stats per handle.
			    		labels - returns MPLS label information like label, network,
next_hop, prefix_len, distinguisher (only for MPLS VPN),
version(ipV4|ipV6), type (mpls|mplsVpn)
			    		learned_info - retrieve learned information by the BGP protocol
			    		clear_learned_info - clears the learned information by the BGP protocol
			 	-handle
			 		The BGP session handle or L3 Site handle or L2 Site handle.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                 value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                                    value:On status of failure, gives detailed information.
		These stats are per BGP neighbor. For obtaining these statistics, you need to call emulation_bgp_control -mode statistic first.
			 key:Statistics retrieved for -mode stats, IxTclProtocols.  value:These stats are per BGP neighbor. For obtaining these statistics, you need to call emulation_bgp_control -mode statistic first.
		a.b.c.d
			 key:ip_address                                             value:a.b.c.d
		number of keepalive messages sent
			 key:keepalive_tx                                           value:number of keepalive messages sent
		number of keepalive messages received
			 key:keepalive_rx                                           value:number of keepalive messages received
		number of notify messages sent
			 key:notify_tx                                              value:number of notify messages sent
		number of notify messages received
			 key:notify_rx                                              value:number of notify messages received
		number of routes in session
			 key:num_node_routes                                        value:number of routes in session
		number of open messages sent
			 key:open_tx                                                value:number of open messages sent
		number of open messages received
			 key:open_rx                                                value:number of open messages received
		BGP peer IP address (a.b.c.e)
			 key:peers                                                  value:BGP peer IP address (a.b.c.e)
		BGP session type
			 key:routing_protocol                                       value:BGP session type
		number of updates sent
			 key:update_tx                                              value:number of updates sent
		number of updates received
			 key:update_rx                                              value:number of updates received
		number of advertised routes sent
			 key:routes_advertised_tx                                   value:number of advertised routes sent
		number of advertised routes received
			 key:routes_advertised_rx                                   value:number of advertised routes received
		These stats are aggregated per port. As a handle you can specify a BGP session handle or L3 Site handle, but the stats will be retrieved per port.
			 key:Statistics retrieved for -mode stats, IxTclNetwork.    value:These stats are aggregated per port. As a handle you can specify a BGP session handle or L3 Site handle, but the stats will be retrieved per port.
		The port name.
			 key:port_name                                              value:The port name.
		The number of BGP neighbors configured.
			 key:sessions_configured                                    value:The number of BGP neighbors configured.
		The number of BGP sessions established.
			 key:sessions_established                                   value:The number of BGP sessions established.
		The total number of all types of BGP messages sent.
			 key:messages_tx                                            value:The total number of all types of BGP messages sent.
		The total number of all types of BGP messages received.
			 key:messages_rx                                            value:The total number of all types of BGP messages received.
		The total number of BGP route updates sent.
			 key:update_tx                                              value:The total number of BGP route updates sent.
		The total number of BGP route updates received.
			 key:update_rx                                              value:The total number of BGP route updates received.
		The number of routes advertised.
			 key:routes_advertised                                      value:The number of routes advertised.
		The number of routes withdrawn.
			 key:routes_withdrawn                                       value:The number of routes withdrawn.
		The number of routes received.
			 key:routes_rx                                              value:The number of routes received.
		The number of update messages received which have a non-empty Withdrawn Routes field.
			 key:route_withdraws_rx                                     value:The number of update messages received which have a non-empty Withdrawn Routes field.
		The number of open messages sent.
			 key:open_tx                                                value:The number of open messages sent.
		The number of open messages received.
			 key:open_rx                                                value:The number of open messages received.
		The total number of keepalive messages sent. They cannot be sent more often than 1 per second,but must be sent often enough to keep the hold timer from expiring.
			 key:keepalive_tx                                           value:The total number of keepalive messages sent. They cannot be sent more often than 1 per second,but must be sent often enough to keep the hold timer from expiring.
		The total number of keepalive messages received.
			 key:keepalive_rx                                           value:The total number of keepalive messages received.
		The total number of notification messages sent.
			 key:notify_tx                                              value:The total number of notification messages sent.
		The number of notification messages received.
			 key:notify_rx                                              value:The number of notification messages received.
		The number of BGP Start Events which have occurred.
			 key:starts_occurred                                        value:The number of BGP Start Events which have occurred.
		The number of times that graceful restarts were attempted.
			 key:graceful_restart_attempted                             value:The number of times that graceful restarts were attempted.
		The number of times that graceful restarts were attempted but failed.
			 key:graceful_restart_failed                                value:The number of times that graceful restarts were attempted but failed.
		The number of BGP routes received during the process of graceful restart.
			 key:routes_rx_graceful_restart                             value:The number of BGP routes received during the process of graceful restart.
		The number of BGP neighbors that are in State Machine State Idle.
			 key:idle_state                                             value:The number of BGP neighbors that are in State Machine State Idle.
		The number of BGP neighbors that are in State Machine State Connect.
			 key:connect_state                                          value:The number of BGP neighbors that are in State Machine State Connect.
		The number of BGP neighbors that are in State Machine State Active.
			 key:active_state                                           value:The number of BGP neighbors that are in State Machine State Active.
		The number of BGP neighbors that are in State Machine State OpenTx.
			 key:opentx_state                                           value:The number of BGP neighbors that are in State Machine State OpenTx.
		The number of BGP neighbors that are in State Machine State OpenConfirm.
			 key:openconfirm_state                                      value:The number of BGP neighbors that are in State Machine State OpenConfirm.
		The number of BGP neighbors that are in State Machine State Established.
			 key:established_state                                      value:The number of BGP neighbors that are in State Machine State Established.
		ls_node_advertised_tx
			 key:ls_node_advertised_tx                                  value:ls_node_advertised_tx
		ls_node_advertised_rx
			 key:ls_node_advertised_rx                                  value:ls_node_advertised_rx
		ls_node_withdrawn_tx
			 key:ls_node_withdrawn_tx                                   value:ls_node_withdrawn_tx
		ls_node_withdrawn_rx
			 key:ls_node_withdrawn_rx                                   value:ls_node_withdrawn_rx
		ls_link_advertised_tx
			 key:ls_link_advertised_tx                                  value:ls_link_advertised_tx
		ls_link_advertised_rx
			 key:ls_link_advertised_rx                                  value:ls_link_advertised_rx
		ls_link_withdrawn_tx
			 key:ls_link_withdrawn_tx                                   value:ls_link_withdrawn_tx
		ls_link_withdrawn_rx
			 key:ls_link_withdrawn_rx                                   value:ls_link_withdrawn_rx
		ls_ipv4_prefix_advertised_tx
			 key:ls_ipv4_prefix_advertised_tx                           value:ls_ipv4_prefix_advertised_tx
		ls_ipv4_prefix_advertised_rx
			 key:ls_ipv4_prefix_advertised_rx                           value:ls_ipv4_prefix_advertised_rx
		ls_ipv4_prefix_withdrawn_rx
			 key:ls_ipv4_prefix_withdrawn_rx                            value:ls_ipv4_prefix_withdrawn_rx
		ls_ipv4_prefix_withdrawn_tx
			 key:ls_ipv4_prefix_withdrawn_tx                            value:ls_ipv4_prefix_withdrawn_tx
		ls_ipv6_prefix_advertised_tx
			 key:ls_ipv6_prefix_advertised_tx                           value:ls_ipv6_prefix_advertised_tx
		ls_ipv6_prefix_advertised_rx
			 key:ls_ipv6_prefix_advertised_rx                           value:ls_ipv6_prefix_advertised_rx
		ls_ipv6_prefix_withdrawn_rx
			 key:ls_ipv6_prefix_withdrawn_rx                            value:ls_ipv6_prefix_withdrawn_rx
		ls_ipv6_prefix_withdrawn_tx
			 key:ls_ipv6_prefix_withdrawn_tx                            value:ls_ipv6_prefix_withdrawn_tx
		error_link_state_nlri_rx
			 key:error_link_state_nlri_rx                               value:error_link_state_nlri_rx
			 key:Statistics retrieved for -mode neighbors:              value:
		List of BGP peers (a.b.c.e)
			 key:peers                                                  value:List of BGP peers (a.b.c.e)
			 key:Statistics retrieved for -mode settings:               value:
		a.b.c.d
			 key:ip_address                                             value:a.b.c.d
		integer
			 key:asn                                                    value:integer
			 key:Statistics retrieved for -mode labels:                 value:
		only for MPLS VPN
			 key:<number>.distinguisher                                 value:only for MPLS VPN
		integer
			 key:<number>.label                                         value:integer
		ip address (v4 or v6)
			 key:<number>.neighbor                                      value:ip address (v4 or v6)
		ip address (v4 or v6)
			 key:<number>.network                                       value:ip address (v4 or v6)
		ip address (v4 or v6)
			 key:<number>.next_hop                                      value:ip address (v4 or v6)
		integer
			 key:<number>.prefix_len                                    value:integer
		mpls|mplsVpn
			 key:<number>.type                                          value:mpls|mplsVpn
		ipV4|ipV6
			 key:<number>.version                                       value:ipV4|ipV6
		integer
			 key:<number>.site_id                                       value:integer
		boolean
			 key:<number>.control_word                                  value:boolean
		integer
			 key:<number>.block_offset                                  value:integer
		value:integer
			 key:<number>.label_                                        value:value:integer
		The number of BGP sessions established.
			 key:sessions_established                                   value: The number of BGP sessions established.
		The total number of all types of BGP messages sent.
			 key:messages_tx                                            value: The total number of all types of BGP messages sent.
		The total number of all types of BGP messages received.
			 key:messages_rx                                            value: The total number of all types of BGP messages received.
		The total number of BGP route updates sent.
			 key:update_tx                                              value: The total number of BGP route updates sent.
		The total number of BGP route updates received.
			 key:update_rx                                              value: The total number of BGP route updates received.
		The number of routes advertised.
			 key:routes_advertised                                      value: The number of routes advertised.
		The number of routes withdrawn.
			 key:routes_withdrawn                                       value: The number of routes withdrawn.
		The number of routes received.
			 key:routes_rx                                              value: The number of routes received.
		The number of update messages received which have a non-empty Withdrawn Routes field.
			 key:route_withdraws_rx                                     value: The number of update messages received which have a non-empty Withdrawn Routes field.
		The number of open messages sent.
			 key:open_tx                                                value: The number of open messages sent.
		The number of open messages received.
			 key:open_rx                                                value: The number of open messages received.
		The total number of keepalive messages sent. They cannot be sent more often than 1 per second,but must be sent often enough to keep the hold timer from expiring.
			 key:keepalive_tx                                           value: The total number of keepalive messages sent. They cannot be sent more often than 1 per second,but must be sent often enough to keep the hold timer from expiring.
		The total number of keepalive messages received.
			 key:keepalive_rx                                           value: The total number of keepalive messages received.
		The total number of notification messages sent.
			 key:notify_tx                                              value: The total number of notification messages sent.
		The number of notification messages received.
			 key:notify_rx                                              value: The number of notification messages received.
		The number of BGP Start Events which have occurred.
			 key:starts_occurred                                        value: The number of BGP Start Events which have occurred.
		The number of times that graceful restarts were attempted.
			 key:graceful_restart_attempted                             value: The number of times that graceful restarts were attempted.
		The number of times that graceful restarts were attempted but failed.
			 key:graceful_restart_failed                                value: The number of times that graceful restarts were attempted but failed.
		The number of BGP routes received during the process of graceful restart.
			 key:routes_rx_graceful_restart                             value: The number of BGP routes received during the process of graceful restart.
		The number of BGP neighbors that are in State Machine State Idle.
			 key:idle_state                                             value: The number of BGP neighbors that are in State Machine State Idle.
		The number of BGP neighbors that are in State Machine State Connect.
			 key:connect_state                                          value: The number of BGP neighbors that are in State Machine State Connect.
		The number of BGP neighbors that are in State Machine State Active.
			 key:active_state                                           value: The number of BGP neighbors that are in State Machine State Active.
		The number of BGP neighbors that are in State Machine State OpenTx.
			 key:opentx_state                                           value: The number of BGP neighbors that are in State Machine State OpenTx.
		The number of BGP neighbors that are in State Machine State OpenConfirm.
			 key:openconfirm_state                                      value: The number of BGP neighbors that are in State Machine State OpenConfirm.
		The number of BGP neighbors that are in State Machine State Established.
			 key:established_state                                      value: The number of BGP neighbors that are in State Machine State Established.
		integer
			 key:<number>.label_value                                   value:integer
		
		Examples:
		See files starting with BGP4_ in the Samples subdirectory.  Also see some of the L3VPN, MPLS, and MVPN sample files for further examples of BGP usage.
		See the BGP examples in Appendix A, "Example APIs," for specific example usage.
		
		Sample Input:
		.
		
		Sample Output:
		.
		
		Notes:
		Coded versus functional specification.
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_bgp_info", kwargs)

	def emulation_bgp_mvpn_config(self, **kwargs):
		""" This procedure configures BGP mVRF neighbors, internal and/or external.     You can configure multiple BGP mVRF peers per interface by calling this     procedure multiple times.This command is also used to configure MVPN Sender     and MVPN Receiver Site. This command will be used to configure MVPN.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_bgp_mvpn_config
			 	-handle                                          ANY]
			 	-mode                                            CHOICES disable enable create modify]
			x	[-protocol_name                                  ALPHA]
			x	[-spmsi_name                                     ALPHA]
			x	[-active                                         CHOICES 0 1
			x                                                 DEFAULT 1]
			 	[-num_sites                                      NUMERIC]
			 	[-target                                         ANY]
			 	[-target_assign                                  NUMERIC]
			 	[-target_type                                    CHOICES as ip as4]
			x	[-import_rt_as_export_rt                         CHOICES 0 1]
			x	[-target_count                                   NUMERIC]
			x	[-import_target_count                            NUMERIC]
			 	[-import_target                                  ANY]
			 	[-import_target_assign                           NUMERIC]
			 	[-import_target_type                             CHOICES as ip as4]
			x	[-include_pmsi_tunnel_attribute                  CHOICES 0 1]
			x	[-rsvp_p2mp_id                                   IPV4]
			x	[-rsvp_p2mp_id_as_number                         NUMERIC]
			x	[-rsvp_tunnel_id                                 NUMERIC]
			x	[-root_address                                   IPV4]
			x	[-multicast_distinguisher_as4_number             NUMERIC]
			x	[-multicast_distinguisher_as_number              NUMERIC]
			x	[-multicast_distinguisher_assigned_number        NUMERIC]
			x	[-multicast_distinguisher_ip_address             IPV4]
			x	[-multicast_distinguisher_type                   CHOICES as ip as4]
			x	[-enable_trm                                     CHOICES 0 1]
			x	[-advertise_impsi_routes                         CHOICES 0 1]
			x	[-mvrf_multicast_tunnel_type                     CHOICES tunneltypersvpp2mp
			x                                                 CHOICES tunneltypemldpp2mp
			x                                                 CHOICES tunneltypeingressreplication
			x                                                 CHOICES tunneltypebier
			x                                                 CHOICES tunneltypepimsm
			x                                                 CHOICES tunneltypepimssm]
			x	[-group_address                                  ANY]
			x	[-sender_address_p_root_node_address             ANY]
			x	[-umh_export_target_count                        NUMERIC]
			x	[-umh_import_target_count                        NUMERIC]
			x	[-same_as_export_rt                              CHOICES 0 1]
			x	[-same_as_import_rt                              CHOICES 0 1]
			 	[-umh_import_target_type                         CHOICES as ip as4]
			 	[-umh_import_target                              ANY]
			 	[-umh_import_target_assign                       NUMERIC]
			 	[-umh_target_type                                CHOICES as ip as4]
			 	[-umh_target_assign                              NUMERIC]
			 	[-umh_target                                     ANY]
			x	[-import_target_inner_step                       NUMERIC]
			x	[-target_inner_step                              NUMERIC]
			x	[-umh_import_target_inner_step                   NUMERIC]
			x	[-import_target_assign_inner_step                NUMERIC]
			x	[-target_assign_inner_step                       NUMERIC]
			x	[-umh_import_target_assign_inner_step            NUMERIC]
			x	[-umh_target_assign_inner_step                   NUMERIC]
			x	[-umh_target_inner_step                          NUMERIC]
			x	[-group_address_count                            NUMERIC]
			x	[-send_trigger_source_active_adroute             CHOICES 0 1]
			x	[-source_address_count                           NUMERIC]
			x	[-source_group_mapping                           CHOICES fullymeshed onetoone]
			x	[-start_group_address_ipv4                       IPV4]
			x	[-start_source_address_ipv4                      IPV4]
			x	[-start_source_or_crp_address_ipv4               IPV4]
			x	[-start_source_or_crp_address_ipv6               IPV6]
			x	[-start_group_address_ipv6                       IPV6]
			x	[-start_source_address_ipv6                      IPV6]
			x	[-c_multicast_route_type                         CHOICES sourcetreejoin sharedtreejoin]
			x	[-downstream_label                               NUMERIC]
			x	[-send_triggered_multicast_route                 CHOICES 0 1]
			x	[-upstream_or_downstream_assigned_label          NUMERIC]
			x	[-up_or_down_stream_assigned_label               NUMERIC]
			x	[-use_up_or_down_stream_assigned_label           CHOICES 0 1]
			x	[-spmsi_root_address                             IPV4]
			x	[-spmsi_rsvp_p2mp_id                             IPV4]
			x	[-spmsi_rsvp_p2mp_id_as_number                   NUMERIC]
			x	[-spmsi_rsvp_p2mp_id_inner_step                  NUMERIC]
			x	[-spmsi_rsvp_tunnel_id                           NUMERIC]
			x	[-spmsi_rsvp_tunnel_id_step                      NUMERIC]
			x	[-spmsi_tunnel_count                             NUMERIC]
			x	[-upstream_or_downstream_assigned_label_step     NUMERIC]
			x	[-use_upstream_or_downstream_assigned_label_step CHOICES 0 1]
			x	[-include_ipv6_explicit_null_label               CHOICES 0 1]
		
		Arguments:
			 	-handle
			 		Valid values are:
			 		BGP mVRF:
			 		For create and modify -mode, handle should be its parent BGP Peer node handle.
			 		For delete -mode, -handle should be its own handle i.e BGP mVRF node handle.
			 		MVPN Sender Site:
			 		For create -mode, handle should be the parent prefix pool node Handle.
			 		For modify and delete -mode, handle should be its own handle i.e MVPN Sender Site node handle.
			 		MVPN Receiver Site:
			 		For create -mode, handle should be the parent prefix pool node handle.
			 		For modify and delete -mode, handle should be its own handle i.e MVPN Receiver Site node handle.
			 	-mode
			 		This option defines the action to be taken on the BGP server.
			 		Valid choices are:
			    		disable - disable the BGP mVRF configuration, requires the use of -handle.
			    		enable - enable and/or create the BGP mVRF configuration. If -handle is
specified, then it will be enabled, otherwise created.
			    		create - create the BGP mVRF configuration
			    		modify - modify the BGP mVRFconfiguration, requires the use of -handle.
			x	-protocol_name
			x		This is the name of the protocol stack as it appears in the GUI.
			x	-spmsi_name
			x		This is the name of the protocol stack as it appears in the GUI.
			x	-active
			x		Activates the item(like BGP mVRF, MVPN Sendert Sites or MVPN Receiver Sites)
			 	-num_sites
			 		Number of BGP mVRF to be created.
			 	-target
			 		AS number or IP address list based on the -target_type list.
			 	-target_assign
			 		The assigned number subfield of the value field of the target.It is
			 		a number from a numbering space which is maintained by the enterprise
			 		administers for a given IP address or ASN space.It is the local
			 		part of the target.
			 	-target_type
			 		List of the target type.
			 		Valid choices are:
			    		as - AS target type
			    		ip - IP target type
			    		as4 - AS4 target type
			x	-import_rt_as_export_rt
			x		Import RT List Same As Export RT List
			x	-target_count
			x		Number of AS number or IP address list based on the -target_type list.
			x	-import_target_count
			x		Number of RTs in Import Route Target List
			 	-import_target
			 		AS number or IP address list based on the -import_target_type list.
			 	-import_target_assign
			 		The assigned number subfield of the value field of the import target.
			 		It is a number from a numbering space which is maintained by the
			 		enterprise administers for a given IP address or ASN space.It is the
			 		local part of the import target.
			 	-import_target_type
			 		List of the import target type.
			 		Valid choices are:
			    		as - Import target type is AS
			    		ip - Import target type is IP
			    		as4 - Import target type is AS4
			x	-include_pmsi_tunnel_attribute
			x		Enable or Disable Include PMSI Tunnel Attribute.If selected, this causes the PE to include PMSI Tunnel Attribute in the Inclusive Multicast Ethernet Tag Routes containing tunnel information for ingress replication or P2MP.
			x	-rsvp_p2mp_id
			x		The P2MP Identifier represented in IP address format.
			x	-rsvp_p2mp_id_as_number
			x		The P2MP Identifier represented in integer format.
			x	-rsvp_tunnel_id
			x		This allows to select the P2MP LSP that can be used for this particular ES. An LSP is uniquely identified by P2MP-Id, Tunnel Id, and Extended Tunnel ID (Tunnel Head Address).
			x	-root_address
			x		The root address of the multicast LSP.
			x	-multicast_distinguisher_as4_number
			x		The 4-octet user-defined number that is used with the Multicast (Route) Distinguisher IP address or AS number to uniquely identify the MVRFs for this MVPN.
			x	-multicast_distinguisher_as_number
			x		If the Admin part Type is set to AS, this is the 2-byte AS number in the Administrator subfield of the Value field of the RD. If the Admin part Type was set to AS 4 Byte, this is the 4-byte AS number in the Administrator subfield of the Value field of the RD.
			x	-multicast_distinguisher_assigned_number
			x		If the Multicast (Route) Distinguisher Type is set to "AS", a 2-octet autonomous system number (for the local AS) can be configured in this field. If set to "AS 4 Byte", a 4-octet autonomous system number can be configured in this field.
			x	-multicast_distinguisher_ip_address
			x		If the Admin part Type is set to I, this is the 4-byte IP address in the Administrator sub-field of the Value field of the VPN RD.
			x	-multicast_distinguisher_type
			x		Choose the type of Route Distinguisher (RD). Options include the following:
			x		IP-The Administrator subfield is 4 bytes in length, and contains an IP address. (This is a Type 1 RD.)
			x		AS-The Administrator subfield is 2 bytes in length, and contains an Autonomous System number (ASN). (This is a Type 0 RD.)
			x		AS 4 Byte-The Administrator subfield is 4 bytes in length, and contains an Autonomous System number (ASN). (This is a Type 2 RD).
			x		Valid choices are:
			x   		as - AS
			x   		ip - IP
			x   		as4 - AS 4 Byte
			x	-enable_trm
			x		Enables Tenant Routed Multicast support in EVPN.
			x		Upon Enabling,
			x		- "Advertise I-PMSI Routes" will be disabled (by default).
			x		- "Multicast Tunnel Type" will be "PIM-SSM" (by default).
			x		- "VRF Route Import Extended Community" is sent with EVPN Route Type 2 &amp;amp; 5 (always).
			x	-advertise_impsi_routes
			x		Enables I-PMSI Route Advertisement for MVPN (if True).
			x		Disables I-PMSI Route Advertisement for MVPN (if False).
			x		- Set to False when "Enable TRM" is Enabled (by deafult).
			x	-mvrf_multicast_tunnel_type
			x		The type of multicast tunnel to be configured. Options include the following:
			x		RSVP-TE P2MP: This helps to set up RSVP tunnels as P-Tunnel protocol following new draft.
			x		MLDP P2MP: This is described by a root address with combination of opaque value.
			x		Ingress Replication:This helps to setup ingress replication Tunnels as P-Tunnel Protocol for S-PMSI instances using RSVP P2P/LDP.
			x		BIER: When a multicast data packet enters the domain, the ingress router determines the set of egress routers to which the packets are sent. The ingress router then encapsulates the packet in a BIER header. The BIER header contains a bit string in which each bit represents exactly one egress router in the domain. To forward the packet to a given set of egress routers, the bits corresponding to those routers are set in the BIER header.
			x		Valid choices are:
			x   		tunneltypersvpp2mp - RSVP-TE P2MP
			x   		tunneltypemldpp2mp - MLDP P2MP
			x   		tunneltypeingressreplication - Ingress Replication
			x   		tunneltypebier - BIER
			x   		tunneltypepimsm - PIM-SM
			x   		tunneltypepimssm - PIM-SSM
			x	-group_address
			x		Group Address
			x	-sender_address_p_root_node_address
			x		Sender Address/P-Root Node Address
			x	-umh_export_target_count
			x		Number of RTs in Export Route Target List(multiplier).
			x	-umh_import_target_count
			x		Number of RTs in Import Route Target List(multiplier).
			x	-same_as_export_rt
			x		If selected, UMH Export RT List will be same as Export RT List.
			x	-same_as_import_rt
			x		If selected, UMH Import RT List will be same as Import RT List.
			 	-umh_import_target_type
			 		List of the import target type.
			 		Valid choices are:
			    		as - Import target type is AS
			    		ip - Import target type is IP
			    		as4 - Import target type is AS4
			 	-umh_import_target
			 		AS number or IP address list based on the -import_target_type list.
			 	-umh_import_target_assign
			 		The assigned number subfield of the value field of the import target.
			 		It is a number from a numbering space which is maintained by the
			 		enterprise administers for a given IP address or ASN space.It is the
			 		local part of the import target.
			 	-umh_target_type
			 		List of the target type.
			 		Valid choices are:
			    		as - AS target type
			    		ip - IP target type
			    		as4 - AS4 target type
			 	-umh_target_assign
			 		The assigned number subfield of the value field of the target.It is
			 		a number from a numbering space which is maintained by the enterprise
			 		administers for a given IP address or ASN space.It is the local
			 		part of the target.
			 	-umh_target
			 		AS number or IP address list based on the -target_type list.
			x	-import_target_inner_step
			x		Increment value to step the base import target field when -target_count is greater than 1.
			x	-target_inner_step
			x		Increment value to step the base import target field when -target_count is greater than 1.
			x	-umh_import_target_inner_step
			x		Increment value to step the base import target field when -target_count is greater than 1.
			x	-import_target_assign_inner_step
			x		Increment value to step the base import target assigned number field when -target_count is greater than 1.
			x	-target_assign_inner_step
			x		Increment value to step the base import target assigned number field when -target_count is greater than 1.
			x	-umh_import_target_assign_inner_step
			x		Increment value to step the base import target assigned number field when -target_count is greater than 1.
			x	-umh_target_assign_inner_step
			x		Increment value to step the base target assigned number fieldwhen -target_count is greater than 1.
			x	-umh_target_inner_step
			x		Increment value to step the base target field when -target_count is greater than 1.
			x	-group_address_count
			x		The number of group addresses to be included in the Join message/ C-Multicast route.
			x	-send_trigger_source_active_adroute
			x		If selected, allows to send the Source Active A-D Route after receiving Source Tree Join C-Multicast route.
			x	-source_address_count
			x		The number of multicast source addresses to be included. The maximum number of valid possible addresses depends on the values for the Source Address and the Source Mask Width.
			x		The value changes to 1 and is not available for change when the C-Multicast Route Type is Shared Tree Join/meshing is One to one.
			x	-source_group_mapping
			x		Indicates the source group mapping. Options include the following:
			x		Fully-Meshed, One-To-One.
			x		Valid choices are:
			x   		fullymeshed - Fully-Meshed
			x   		onetoone - One-To-One
			x	-start_group_address_ipv4
			x		The first IPv4 Multicast group address in the range of group addresses included in this Join message/ C-Multicast route.
			x	-start_source_address_ipv4
			x		The Start Source Address is the first IPv4 source addresses that like to send multicast traffic towards interested receivers.
			x		(IPv4 Multicast addresses are not valid for sources)
			x	-start_source_or_crp_address_ipv4
			x		The Start Source Address is the first IPv4 source address to be included in this Join message when C-Multicast Route Type is Source Tree Join.
			x		(IPv4 Multicast addresses are not valid for sources)
			x		The C-RP Address is the IPv4 address of C-RP when C-Multicast Route Type is Shared Tree Join.
			x	-start_source_or_crp_address_ipv6
			x		The Start Source Address is the first IPv6 source address to be included in this Join message when C-Multicast Route Type is Source Tree Join.
			x		The C-RP Address is the IPv6 address of C-RP when C-Multicast Route Type is Shared Tree Join.
			x	-start_group_address_ipv6
			x		The first IPv6 Multicast group address in the range of group addresses included in this Join message/ C-Multicast route.
			x	-start_source_address_ipv6
			x		The Start Source Address is the first IPv6 source addresses that like to send multicast traffic towards interested receivers.
			x	-c_multicast_route_type
			x		Choose one of the C-Multicast Route Types. Options include the following:
			x		Source Tree Join, Shared Tree Join.
			x		Valid choices are:
			x   		sourcetreejoin - Source Tree Join
			x   		sharedtreejoin - Shared Tree Join
			x	-downstream_label
			x		Downstream Assigned Label in Leaf A-D route when tunnel type is Ingress Replication
			x	-send_triggered_multicast_route
			x		This helps to send Source Tree Join C-Multicast route after receiving Source Active A-D route. This is also required by Shared Tree Join C-Multicast route to send Source Tree Join after receiving Source Active A-D Route.
			x	-upstream_or_downstream_assigned_label
			x		This label is used when Use Upstream/Downstream is selected. The PMSI Tunnel Identifier contains this label value.
			x	-up_or_down_stream_assigned_label
			x		Upstream/Downstream Assigned Label
			x	-use_up_or_down_stream_assigned_label
			x		This field indicates whether the configured upstream label or downstream label(Ingress Replication) need to be used. If not selected, MPLS Assigned Upstream/Downstream Label is unavailable.
			x	-spmsi_root_address
			x		The root address of the multicast tunnel type. This field is available when Multicast Tunnel Type is mLDP P2MP.
			x	-spmsi_rsvp_p2mp_id
			x		The P2MP ID represented in IP address format. This field is available when Multicast Tunnel Type is RSVP-TE P2MP.
			x	-spmsi_rsvp_p2mp_id_as_number
			x		The P2MP ID represented in integer format. This field is available when Multicast Tunnel Type is RSVP-TE P2MP.
			x	-spmsi_rsvp_p2mp_id_inner_step
			x		The increment value in the range of RSVP P2MP IDs for that S-PMSI range. This field is available when Multicast Tunnel Type is RSVP-TE P2MP.
			x	-spmsi_rsvp_tunnel_id
			x		The first Tunnel ID value in the range of Tunnel IDs. This field is available when Multicast Tunnel Type is RSVP-TE P2MP.
			x	-spmsi_rsvp_tunnel_id_step
			x		The increment value in the range of Tunnel IDs for that S-PMSI range. This field is available when Multicast Tunnel Type is RSVP-TE P2MP.
			x	-spmsi_tunnel_count
			x		The total count of the S-PMSI Tunnel Count.
			x	-upstream_or_downstream_assigned_label_step
			x		This helps to assign unique upstream assigned label for each flow. This is applicable only if Use Upstream Assigned Label is selected.
			x	-use_upstream_or_downstream_assigned_label_step
			x		Indicates whether the configured upstream label or downstream label(Ingress Replication) need to be used. Except for BIER as Multicast Tunnel Type, if not selected, MPLS Assigned Upstream/Downstream Label is unavailable.
			x	-include_ipv6_explicit_null_label
			x		If selected, allows to include Explicit NULL label (2) in I-PMSI IPv6 PE-to-CE Traffic.
		
		Return Values:
		A list containing the network group protocol stack handles that were added by the command (if any).
			xkey:network_group_handle       value:A list containing the network group protocol stack handles that were added by the command (if any).
		A list containing the bgp mvrf protocol stack handles that were added by the command (if any).
			xkey:bgp_mvrf                   value:A list containing the bgp mvrf protocol stack handles that were added by the command (if any).
		A list containing the mvpn receiver site v4 protocol stack handles that were added by the command (if any).
			xkey:mvpn_receiver_site_v4      value:A list containing the mvpn receiver site v4 protocol stack handles that were added by the command (if any).
		A list containing the mvpn sender site v4 protocol stack handles that were added by the command (if any).
			xkey:mvpn_sender_site_v4        value:A list containing the mvpn sender site v4 protocol stack handles that were added by the command (if any).
		A list containing the mvpn sender site spmsi v4 protocol stack handles that were added by the command (if any).
			xkey:mvpn_sender_site_spmsi_v4  value:A list containing the mvpn sender site spmsi v4 protocol stack handles that were added by the command (if any).
		A list containing the mvpn receiver site v6 protocol stack handles that were added by the command (if any).
			xkey:mvpn_receiver_site_v6      value:A list containing the mvpn receiver site v6 protocol stack handles that were added by the command (if any).
		A list containing the mvpn sender site v6 protocol stack handles that were added by the command (if any).
			xkey:mvpn_sender_site_v6        value:A list containing the mvpn sender site v6 protocol stack handles that were added by the command (if any).
		A list containing the mvpn sender site spmsi v6 protocol stack handles that were added by the command (if any).
			xkey:mvpn_sender_site_spmsi_v6  value:A list containing the mvpn sender site spmsi v6 protocol stack handles that were added by the command (if any).
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		1) You can configure multiple BGP mVRF on each Ixia interface.
		2) You can configure multiple MVPN(MVN Sender and Receiver Sites).
		
		See Also:
		
		"""
		return self._run_keyword("emulation_bgp_mvpn_config", kwargs)

	def emulation_bgp_route_config(self, **kwargs):
		""" This procedure creates a route range that is associated with a BGP4 neighbor. It also defines the characteristics of the routes that will be advertised at the beginning of the session. It defines a set of routes and associated attributes. The routes can be unicast/multicast, mpls, vpn and vpls.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_bgp_route_config
			 	-handle                                       ANY]
			 	[-route_handle                                ANY]
			 	[-l3_site_handle                              ANY]
			 	-mode                                         CHOICES add
			                                               CHOICES create
			                                               CHOICES modify
			                                               CHOICES remove
			                                               CHOICES delete
			                                               CHOICES enable
			                                               CHOICES disable
			                                               CHOICES import_routes
			                                               CHOICES generate_routes
			                                               CHOICES generate_ipv6_routes
			x	[-protocol_name                               ALPHA]
			x	[-protocol_route_name                         ALPHA]
			x	[-active                                      CHOICES 0 1]
			 	[-ipv4_unicast_nlri                           FLAG]
			 	[-ipv4_multicast_nlri                         FLAG]
			 	[-ipv4_mpls_nlri                              FLAG]
			 	[-ipv4_mpls_vpn_nlri                          FLAG]
			 	[-ipv6_unicast_nlri                           FLAG]
			 	[-ipv6_multicast_nlri                         FLAG]
			 	[-ipv6_mpls_nlri                              FLAG]
			 	[-ipv6_mpls_vpn_nlri                          FLAG]
			 	[-max_route_ranges                            NUMERIC
			                                               DEFAULT 1]
			 	[-ip_version                                  CHOICES 4 6
			                                               DEFAULT 4]
			 	[-prefix                                      IP]
			 	[-route_ip_addr_step                          IP]
			x	[-prefix_step_accross_vrfs                    IP]
			 	[-num_routes                                  NUMERIC]
			 	[-num_sites                                   NUMERIC]
			x	[-prefix_from                                 RANGE 0-128]
			x	[-prefix_to                                   RANGE 0-128]
			 	[-prefix_step                                 NUMERIC]
			 	[-prefix_step_across_vrfs                     IP]
			 	[-netmask                                     IP]
			 	[-ipv6_prefix_length                          RANGE 1-128]
			x	[-enable_generate_unique_routes               FLAG]
			x	[-end_of_rib                                  CHOICES 0 1]
			 	[-packing_from                                RANGE 0-65535]
			 	[-packing_to                                  RANGE 0-65535]
			x	[-enable_traditional_nlri                     CHOICES 0 1
			x                                              DEFAULT 1]
			 	[-next_hop_enable                             FLAG
			                                               DEFAULT 1]
			 	[-next_hop_set_mode                           CHOICES same manual
			                                               DEFAULT same]
			 	[-next_hop_ip_version                         CHOICES 4 6]
			 	[-next_hop                                    IP]
			x	[-next_hop_ipv4                               IP]
			x	[-next_hop_ipv6                               IP]
			 	[-next_hop_mode                               CHOICES fixed
			                                               CHOICES increment
			                                               CHOICES incrementPerPrefix]
			x	[-advertise_nexthop_as_v4                     CHOICES 0 1]
			 	[-origin_route_enable                         FLAG]
			 	[-origin                                      CHOICES igp egp incomplete]
			x	[-enable_local_pref                           CHOICES 0 1]
			 	[-local_pref                                  NUMERIC
			                                               DEFAULT 0]
			x	[-enable_med                                  CHOICES 0 1]
			 	[-multi_exit_disc                             NUMERIC]
			x	[-enable_weight                               CHOICES 0 1]
			x	[-weight                                      NUMERIC]
			 	[-atomic_aggregate                            FLAG]
			 	[-aggregator                                  ANY]
			x	[-enable_aggregator                           CHOICES 0 1]
			x	[-aggregator_id_mode                          CHOICES fixed increment]
			x	[-aggregator_id                               IP]
			x	[-aggregator_as                               NUMERIC]
			 	[-originator_id_enable                        CHOICES 0 1
			                                               DEFAULT 0]
			 	[-originator_id                               IP]
			 	[-use_safi_multicast                          CHOICES 0 1]
			 	[-skip_multicast_routes                       CHOICES 0 1]
			x	[-enable_route_flap                           FLAG]
			x	[-flap_up_time                                RANGE 1-1000000]
			x	[-flap_down_time                              RANGE 1-1000000]
			x	[-enable_partial_route_flap                   FLAG]
			x	[-partial_route_flap_from_route_index         RANGE 0-1000000]
			x	[-partial_route_flap_to_route_index           RANGE 0-1000000]
			x	[-flap_delay                                  NUMERIC]
			 	[-communities_enable                          FLAG]
			x	[-num_communities                             NUMERIC]
			 	[-communities                                 NUMERIC]
			x	[-communities_as_number                       NUMERIC]
			x	[-communities_last_two_octets                 NUMERIC]
			x	[-communities_type                            CHOICES no_export
			x                                              CHOICES no_advertised
			x                                              CHOICES no_export_subconfed
			x                                              CHOICES manual
			x                                              CHOICES llgr_stale
			x                                              CHOICES no_llgr]
			 	[-enable_large_communitiy                     CHOICES 0 1]
			x	[-num_of_large_communities                    NUMERIC]
			x	[-large_community                             ANY]
			x	[-ext_communities_enable                      CHOICES 0 1]
			x	[-num_ext_communities                         NUMERIC]
			 	[-ext_communities                             REGEXP ^(0|2|3|4),\d+,(\d{2}\s){5}\d{2}$]
			x	[-ext_communities_as_two_bytes                NUMERIC]
			x	[-ext_communities_as_four_bytes               NUMERIC]
			x	[-ext_communities_assigned_two_bytes          NUMERIC]
			x	[-ext_communities_assigned_four_bytes         NUMERIC]
			x	[-ext_communities_ip                          IP]
			x	[-ext_communities_opaque_data                 ANY]
			x	[-ext_communities_colorCObits                 CHOICES 00 01 10 11
			x                                              DEFAULT 00]
			x	[-ext_communities_colorReservedBits           NUMERIC]
			x	[-ext_communities_colorValue                  NUMERIC]
			x	[-ext_communities_link_bandwidth              NUMERIC]
			x	[-ext_communities_type                        CHOICES admin_as_two_octet
			x                                              CHOICES admin_ip
			x                                              CHOICES admin_as_four_octet
			x                                              CHOICES opaque
			x                                              CHOICES evpn
			x                                              CHOICES admin_as_two_octet_link_bandwidth]
			x	[-ext_communities_subtype                     CHOICES route_target
			x                                              CHOICES origin
			x                                              CHOICES extended_bandwidth
			x                                              CHOICES mac_address
			x                                              CHOICES color]
			 	[-cluster_list_enable                         FLAG]
			x	[-num_clusters                                NUMERIC]
			 	[-cluster_list                                REGEXP ^([0-9]{1,3}.[0-9]{1,3}.[0-9]{1,3}.[0-9]{1,3}\s*)+|([0-9]+\s*)+$]
			x	[-advertise_as_bgpls_prefix                   CHOICES 0 1]
			x	[-route_origin                                CHOICES static direct]
			x	[-advertise_as_bgp_3107                       CHOICES 0 1]
			x	[-label_id                                    NUMERIC
			x                                              DEFAULT 0]
			 	[-label_value                                 NUMERIC
			                                               DEFAULT 16]
			x	[-label_end                                   NUMERIC]
			 	[-label_step                                  NUMERIC
			                                               DEFAULT 1]
			x	[-advertise_as_bgp_3107_sr                    CHOICES 0 1]
			x	[-segmentId                                   NUMERIC]
			x	[-incrementMode                               CHOICES same increment]
			x	[-specialLabel                                CHOICES none
			x                                              CHOICES includeexplicitipv4null
			x                                              CHOICES includeimplicitnull]
			x	[-enableSRGB                                  CHOICES 0 1]
			x	[-advertise_as_rfc_8277                       CHOICES 0 1]
			x	[-no_of_labels                                RANGE 1-9
			x                                              DEFAULT 1]
			x	[-mpls_label_step                             ANY]
			x	[-mpls_label_start                            ANY]
			x	[-mpls_label_end                              ANY]
			x	[-enable_aigp                                 CHOICES 0 1]
			x	[-no_of_tlvs                                  NUMERIC]
			x	[-aigp_type                                   CHOICES aigptlv]
			x	[-aigp_value                                  ANY]
			x	[-enable_add_path                             CHOICES 0 1]
			x	[-add_path_id                                 NUMERIC]
			x	[-enable_random_as_path                       CHOICES 0 1]
			x	[-max_no_of_as_path_segments                  RANGE 1-20]
			x	[-min_no_of_as_path_segments                  RANGE 1-20]
			x	[-as_segment_distribution                     CHOICES as_set
			x                                              CHOICES as_seq
			x                                              CHOICES as_set_confederation
			x                                              CHOICES as_seq_confederation
			x                                              CHOICES random_segments
			x                                              CHOICES random_between_asset_and_asseq
			x                                              DEFAULT as_set]
			x	[-max_as_numbers_per_segments                 RANGE 1-50]
			x	[-min_as_numbers_per_segments                 RANGE 1-50]
			x	[-range_of_as_number_suffix                   ALPHA]
			x	[-as_path_per_route                           CHOICES same different
			x                                              DEFAULT same]
			x	[-random_as_seed_value                        RANGE 1-4294967295]
			x	[-enable_as_path                              CHOICES 0 1]
			x	[-num_as_path_segments                        NUMERIC
			x                                              DEFAULT 1]
			x	[-as_path_set_mode                            CHOICES include_as_seq
			x                                              CHOICES include_as_seq_conf
			x                                              CHOICES include_as_set
			x                                              CHOICES include_as_set_conf
			x                                              CHOICES no_include
			x                                              CHOICES prepend_as
			x                                              DEFAULT include_as_seq]
			 	[-as_path                                     REGEXP ^(as_set|as_seq|as_confed_set|as_confed_seq):\d(,\d)*$]
			x	[-as_path_segment_type                        CHOICES as_set
			x                                              CHOICES as_seq
			x                                              CHOICES as_confed_set
			x                                              CHOICES as_confed_seq
			x                                              DEFAULT as_set]
			x	[-num_as_numbers_in_segment                   NUMERIC
			x                                              DEFAULT 1]
			x	[-enable_as_path_segment                      CHOICES 0 1]
			x	[-enable_as_path_segment_number               CHOICES 0 1]
			x	[-as_path_segment_numbers                     ANY]
			x	[-vpls                                        FLAG]
			x	[-vpls_nlri                                   FLAG]
			 	[-rd_admin_value                              ANY]
			x	[-rd_admin_value_step                         ANY]
			 	[-rd_admin_step                               NUMERIC]
			 	[-rd_assign_value                             NUMERIC]
			x	[-rd_assign_value_step                        NUMERIC]
			 	[-rd_assign_step                              NUMERIC]
			x	[-control_word_enable                         CHOICES 0 1]
			x	[-seq_delivery_enable                         CHOICES 0 1]
			x	[-mtu                                         RANGE 0-65535
			x                                              DEFAULT 1500]
			x	[-site_id                                     RANGE 0-65535
			x                                              DEFAULT 0]
			x	[-site_id_step                                RANGE 0-65535
			x                                              DEFAULT 0]
			 	[-target                                      ANY]
			x	[-target_inner_step                           ANY]
			x	[-target_step                                 ANY]
			 	[-target_assign                               NUMERIC]
			x	[-target_assign_inner_step                    NUMERIC]
			x	[-target_assign_step                          NUMERIC]
			 	[-rd_type                                     CHOICES 0 1 2
			                                               DEFAULT 0]
			 	[-target_type                                 CHOICES as ip as4]
			x	[-vpn_name                                    ALPHA]
			x	[-advertise_label_block                       CHOICES 0 1]
			x	[-num_labels                                  RANGE 1-65535
			x                                              DEFAULT 1]
			 	[-num_labels_type                             CHOICES list single_value
			                                               DEFAULT single_value]
			x	[-label_block_offset                          RANGE 0-65535
			x                                              DEFAULT 0]
			x	[-label_block_offset_type                     CHOICES list single_value
			x                                              DEFAULT single_value]
			 	[-label_value_type                            CHOICES list single_value
			                                               DEFAULT single_value]
			x	[-l2_start_mac_addr                           MAC]
			x	[-l2_mac_incr                                 CHOICES 0 1
			x                                              DEFAULT 0]
			x	[-l2_mac_count                                NUMERIC
			x                                              DEFAULT 1]
			x	[-l2_enable_vlan                              CHOICES 0 1
			x                                              DEFAULT 0]
			x	[-l2_vlan_priority                            NUMERIC]
			x	[-l2_vlan_tpid                                CHOICES 0x8100
			x                                              CHOICES 0x88a8
			x                                              CHOICES 0x9100
			x                                              CHOICES 0x9200
			x                                              CHOICES 0x9300]
			x	[-l2_vlan_id                                  RANGE 0-65535
			x                                              DEFAULT 1]
			x	[-l2_vlan_id_incr                             NUMERIC]
			x	[-l2_vlan_incr                                CHOICES 0
			x                                              CHOICES 1
			x                                              CHOICES 2
			x                                              CHOICES 3
			x                                              CHOICES no_increment
			x                                              CHOICES parallel_increment
			x                                              CHOICES inner_first
			x                                              CHOICES outer_first
			x                                              DEFAULT 0]
			x	[-import_rt_as_export_rt                      CHOICES 0 1]
			x	[-target_count                                NUMERIC]
			x	[-import_target_count                         NUMERIC]
			x	[-default_mdt_ip                              IP]
			x	[-default_mdt_ip_incr                         IP]
			 	[-import_target                               ANY]
			x	[-import_target_step                          ANY]
			x	[-import_target_inner_step                    ANY]
			 	[-import_target_assign                        NUMERIC]
			 	[-import_target_type                          CHOICES as ip as4]
			x	[-import_target_assign_step                   NUMERIC]
			x	[-import_target_assign_inner_step             NUMERIC]
			x	[-rd_count                                    NUMERIC
			x                                              DEFAULT 1]
			x	[-rd_count_per_vrf                            NUMERIC
			x                                              DEFAULT 1]
			x	[-rd_admin_value_step_across_vrfs             NUMERIC]
			x	[-rd_assign_value_step_across_vrfs            NUMERIC]
			x	[-label_value_end                             NUMERIC]
			 	[-label_incr_mode                             CHOICES fixed rd prefix]
			x	[-ad_vpls_nlri                                FLAG]
			x	[-as_number_vpls_id                           ANY]
			x	[-as_number_vpls_rd                           ANY]
			x	[-as_number_vpls_rt                           ANY]
			x	[-assigned_number_vpls_id                     ANY]
			x	[-assigned_number_vpls_rd                     ANY]
			x	[-assigned_number_vpls_rt                     ANY]
			x	[-import_rd_as_rt                             CHOICES 0 1]
			x	[-import_vpls_id_as_rd                        CHOICES 0 1]
			x	[-ip_address_vpls_id                          ANY]
			x	[-ip_address_vpls_rd                          ANY]
			x	[-ip_address_vpls_rt                          ANY]
			x	[-number_vsi_id                               ANY]
			x	[-type_vpls_id                                CHOICES as ip]
			x	[-type_vpls_rd                                CHOICES as ip]
			x	[-type_vpls_rt                                CHOICES as ip]
			x	[-type_vsi_id                                 CHOICES concat_pe_addr concat_num]
			x	[-override_peer_as_set_mode                   CHOICES 0 1]
			x	[-no_write                                    FLAG]
			x	[-best_routes                                 CHOICES 0 1
			x                                              DEFAULT 0]
			x	[-route_distribution_type                     CHOICES round_robin replicate
			x                                              DEFAULT round_robin]
			x	[-next_hop_modification_type                  CHOICES overwrite_testers_address
			x                                              CHOICES preserve_from_file
			x                                              DEFAULT overwrite_testers_address]
			x	[-file_type                                   CHOICES csv cisco juniper
			x                                              DEFAULT csv]
			x	[-route_file                                  ANY]
			x	[-route_limit                                 RANGE 1-2000000
			x                                              DEFAULT 800000]
			x	[-primary_routes_per_device                   RANGE 1-1000000
			x                                              DEFAULT 1000]
			x	[-primary_routes_per_range                    RANGE 1-1000000
			x                                              DEFAULT 1]
			x	[-duplicate_routes_per_device_percent         RANGE 0-100
			x                                              DEFAULT 0]
			x	[-network_address_start                       IP
			x                                              DEFAULT 1.0.0.0]
			x	[-network_address_step                        ANY
			x                                              DEFAULT 2]
			x	[-prefix_length_distribution_type             CHOICES fixed
			x                                              CHOICES random
			x                                              CHOICES even
			x                                              CHOICES exponential
			x                                              CHOICES internet_mix
			x                                              CHOICES custom_profile
			x                                              DEFAULT even]
			x	[-prefix_length_distribution_scope            CHOICES per_device
			x                                              CHOICES per_port
			x                                              CHOICES per_topology
			x                                              DEFAULT per_port]
			x	[-custom_distribution_file                    ANY]
			x	[-prefix_length_start                         RANGE 1-32
			x                                              DEFAULT 8]
			x	[-prefix_length_end                           RANGE 1-32
			x                                              DEFAULT 30]
			x	[-primary_routes_as_path_suffix               ALPHA
			x                                              DEFAULT 100,200,300]
			x	[-duplicate_routes_as_path_suffix             ALPHA
			x                                              DEFAULT 500,600]
			x	[-skip_mcast                                  CHOICES 0 1
			x                                              DEFAULT 0]
			x	[-skip_loopback                               CHOICES 0 1
			x                                              DEFAULT 0]
			x	[-address_range_to_skip                       ALPHA]
			x	[-primary_ipv6_routes_per_range               RANGE 1-1000000
			x                                              DEFAULT 1]
			x	[-primary_ipv6_routes_per_device              RANGE 1-1000000
			x                                              DEFAULT 1000]
			x	[-duplicate_ipv6_routes_per_device_percent    RANGE 0-100
			x                                              DEFAULT 0]
			x	[-ipv6_network_address_start                  IP
			x                                              DEFAULT 1000:0:1:1:0:0:0:0]
			x	[-ipv6_network_address_step                   ANY
			x                                              DEFAULT 2]
			x	[-ipv6_prefix_length_distribution_type        CHOICES fixed
			x                                              CHOICES random
			x                                              CHOICES even
			x                                              CHOICES exponential
			x                                              CHOICES internet_mix
			x                                              CHOICES custom_profile
			x                                              DEFAULT even]
			x	[-ipv6_prefix_length_distribution_scope       CHOICES per_device
			x                                              CHOICES per_port
			x                                              CHOICES per_topology
			x                                              DEFAULT per_port]
			x	[-ipv6_custom_distribution_file               ANY]
			x	[-ipv6_prefix_length_start                    RANGE 1-128
			x                                              DEFAULT 64]
			x	[-ipv6_prefix_length_end                      RANGE 1-128
			x                                              DEFAULT 64]
			x	[-primary_ipv6_routes_as_path_suffix          ALPHA
			x                                              DEFAULT 100,200,300]
			x	[-duplicate_ipv6_routes_as_path_suffix        ALPHA
			x                                              DEFAULT 500,600]
			x	[-ipv6_skip_mcast                             CHOICES 0 1
			x                                              DEFAULT 0]
			x	[-ipv6_skip_loopback                          CHOICES 0 1
			x                                              DEFAULT 0]
			x	[-ipv6_address_range_to_skip                  ALPHA]
			x	[-num_broadcast_domain                        NUMERIC]
			x	[-auto_configure_rd_ip_address                CHOICES 0 1]
			x	[-rd_ip_address                               ANY]
			x	[-rd_evi                                      ANY]
			x	[-enable_l3vni_target_list                    CHOICES 0 1]
			x	[-advertise_l3vni_separately                  CHOICES 0 1]
			x	[-b_mac_first_label                           ANY]
			x	[-enable_b_mac_second_label                   CHOICES 0 1]
			x	[-b_mac_second_label                          ANY]
			x	[-ad_route_label                              ANY]
			x	[-multicast_tunnel_type                       CHOICES tunneltypeingressreplication
			x                                              CHOICES tunneltypersvpp2mp
			x                                              CHOICES tunneltypemldpp2mp]
			x	[-use_upstream_downstream_assigned_mpls_label CHOICES 0 1]
			x	[-include_pmsi_tunnel_attribute               CHOICES 0 1]
			x	[-auto_configure_pmsi_tunnel_id               CHOICES 0 1]
			x	[-pmsi_tunnel_id_v4                           IPV4]
			x	[-pmsi_tunnel_id_v6                           IPV6]
			x	[-upstream_downstream_assigned_mpls_label     ANY]
			x	[-use_ipv4_mapped_ipv6_address                CHOICES 0 1]
			x	[-l3_target_count                             NUMERIC]
			x	[-l3_import_target_count                      NUMERIC]
			x	[-l3_import_rt_same_as_l3_export_rt           CHOICES 0 1]
			 	[-l3_target_type                              CHOICES as ip as4]
			 	[-l3_target                                   ANY]
			x	[-l3_target_inner_step                        ANY]
			x	[-l3_target_step                              ANY]
			x	[-l3_target_as4_number                        NUMERIC]
			x	[-l3_target_ip_address                        IP]
			 	[-l3_target_assign                            NUMERIC]
			x	[-l3_target_assign_inner_step                 NUMERIC]
			x	[-l3_target_assign_step                       NUMERIC]
			 	[-l3_import_target_type                       CHOICES as ip as4]
			 	[-l3_import_target                            ANY]
			n	[-l3_import_target_step                       ANY]
			x	[-l3_import_target_inner_step                 ANY]
			x	[-l3_import_target_as4_number                 NUMERIC]
			x	[-l3_import_target_ip_address                 IP]
			 	[-l3_import_target_assign                     NUMERIC]
			n	[-l3_import_target_assign_step                ANY]
			x	[-l3_import_target_assign_inner_step          NUMERIC]
			x	[-enable_next_hop                             CHOICES 0 1]
			x	[-set_next_hop                                CHOICES manually sameaslocalip]
			x	[-set_next_hop_ip_type                        CHOICES ipv4 ipv6]
			x	[-ipv4_next_hop                               ANY]
			x	[-ipv6_next_hop                               ANY]
			x	[-enable_origin                               CHOICES 0 1]
			x	[-enable_local_preference                     CHOICES 0 1]
			x	[-local_preference                            ANY]
			x	[-enable_multi_exit_discriminator             CHOICES 0 1]
			x	[-multi_exit_discriminator                    ANY]
			x	[-enable_atomic_aggregate                     CHOICES 0 1]
			x	[-enable_aggregator_id                        CHOICES 0 1]
			x	[-enable_originator_id                        CHOICES 0 1]
			x	[-evpn                                        FLAG]
			x	[-pbb_evpn                                    FLAG]
			x	[-evpn_vxlan                                  FLAG]
			x	[-evpn_vpws                                   FLAG]
			x	[-vxlan_vpws                                  FLAG]
			x	[-ethernet_tag_id                             NUMERIC]
			x	[-enable_vlan_aware_service                   CHOICES 0 1]
			x	[-useb_vlan                                   CHOICES 0 1]
			x	[-b_vlan_id                                   NUMERIC]
			x	[-b_vlan_priority                             NUMERIC]
			x	[-b_vlan_tpid                                 CHOICES bvlantpid8100
			x                                              CHOICES bvlantpid88a8
			x                                              CHOICES bvlantpid9100
			x                                              CHOICES bvlantpid9200
			x                                              CHOICES bvlantpid9300]
			x	[-broadcast_domain_ad_route_label             NUMERIC]
			x	[-no_of_mac_pools                             NUMERIC]
			x	[-enable_broadcast_domain                     CHOICES 0 1]
			x	[-use_same_sequence_number                    CHOICES 0 1]
			x	[-enable_user_defined_sequence_number         ANY]
			x	[-sequence_number                             ANY]
			x	[-advertise_ipv4_address                      CHOICES 0 1]
			x	[-ipv4_address_prefix_length                  NUMERIC]
			x	[-advertise_ipv6_address                      CHOICES 0 1]
			x	[-ipv6_address_prefix_length                  NUMERIC]
			x	[-active_ts                                   CHOICES 0 1]
			x	[-enable_sticky_static_flag                   CHOICES 0 1]
			x	[-include_default_gateway_extended_community  CHOICES 0 1]
			x	[-first_label_start                           ANY]
			x	[-enable_second_label                         CHOICES 0 1]
			x	[-second_label_start                          ANY]
			x	[-label_mode                                  CHOICES fixed increment]
			x	[-label_start                                 NUMERIC]
			x	[-cmac                                        FLAG]
			x	[-evpn_ipv4_prefix_range                      FLAG]
			x	[-evpn_ipv6_prefix_range                      FLAG]
			x	[-export_rt_as_number                         NUMERIC]
			x	[-export_rt_as4_number                        NUMERIC]
			x	[-export_rt_ip_address                        IP]
			x	[-export_rt_assigned_number                   NUMERIC]
			x	[-export_rt_type                              CHOICES as ip as4]
			x	[-import_rt_as_number                         NUMERIC]
			x	[-import_rt_as4_number                        NUMERIC]
			x	[-import_rt_ip_address                        IP]
			x	[-import_rt_assigned_number                   NUMERIC]
			x	[-import_rt_type                              CHOICES as ip as4]
			x	[-multicast_tunnel_type_vxlan                 CHOICES tunneltypeingressreplication
			x                                              CHOICES pimsm
			x                                              CHOICES pimssm]
			x	[-group_address                               ANY]
			x	[-sender_address_p_root_node_address          ANY]
			x	[-group_address_v6                            ANY]
			x	[-sender_address_p_root_node_address_v6       ANY]
			x	[-rsvp_p2mp_id                                ANY]
			x	[-rsvp_p2mp_id_as_number                      ANY]
			x	[-rsvp_tunnel_id                              ANY]
			x	[-remote_service_id                           ANY]
			x	[-vid_normalization                           CHOICES vpws singlevid doublevid]
			x	[-include_vpws_l2_attr_ext_comm               ANY]
			x	[-primary_p_e                                 ANY]
			x	[-backup_flag                                 ANY]
			x	[-require_c_w                                 ANY]
			x	[-l2_mtu                                      ANY]
			x	[-fxc_type                                    CHOICES vpws vlanaware vlanunaware]
			x	[-root_address                                ANY]
			x	[-name                                        ANY]
			x	[-type                                        ANY]
			x	[-tlv_length                                  ANY]
			x	[-value                                       ANY]
			x	[-enable_ipv4_receiver                        CHOICES 0 1]
			x	[-enable_ipv4_sender                          CHOICES 0 1]
			x	[-enable_ipv6_receiver                        CHOICES 0 1]
			x	[-enable_ipv6_sender                          CHOICES 0 1]
		
		Arguments:
			 	-handle
			 		Valid values are:
			 		BGP router handle - handle is returned by procedure emulation_bgp_config.
			 		A new route will be added when -mode is add.
			 		BGP route handle - Valid only for IxNetwork Tcl API (new api). Handle is returned
			 		by procedure emulation_bgp_route_config with 'bgp_routes' key.
			 		Valid only for mode remove. The object will be removed.
			 		BGP L2Site handle - Valid only for IxNetwork Tcl API (new api). Handle is returned
			 		by procedure emulation_bgp_route_config with 'bgp_routes' key. When mode is
			 		remove the L2Site will be removed. When mode is add a new label block will be
			 		added to the provided L2Site.
			 		BGP L3Site handle - Valid only for IxNetwork Tcl API (new api). Handle is returned
			 		by procedure emulation_bgp_route_config with 'bgp_routes' key. When mode is
			 		remove the L3Site will be removed. When mode is add a new vpn route range will be
			 		added to the provided L3Site.
			 	-route_handle
			 		The handle of the BGP route where to take action.
			 	-l3_site_handle
			 		The handle of the L3 VPN Site where to take action.
			 	-mode
			 		Specifies either addition or removal of routes from emulated nodes
			 		BGP table.
			 		Valid choices are:
			    		add - Add a new unicast, vpn or ip BGP route. Can also add L3 Sites, L2 Sites, L2 Site LabelBlocks, AD VPLS. (legacy alias)
			    		create - Add a new unicast, vpn or ip BGP route. Can also add L3 Sites, L2 Sites, L2 Site LabelBlocks, AD VPLS.
			    		enable - Enables the given BGP route handle.
			    		disable - Disables the given BGP route handle.
			    		modify - Modify the given BGP route handle.
			    		remove - Remove the given BGP route handle. (legacy alias)
			    		delete - Remove the given BGP route handle.
			    		import_routes - Import BGP routes from a given file and also take in account some other arguments needed for successful route import
			    		generate_routes - This mode will execute statistical route distribution on BGP. The api will also support the attributes needed for successful route distribution.
			    		generate_ipv6_routes - This mode will execute statistical IPv6 route distribution on BGP. The api will also support the attributes needed for successful ipv6 route distribution.
			x	-protocol_name
			x		This is the name of the protocol stack as it appears in the GUI.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-protocol_route_name
			x		This is the name of the protocol stack as it appears in the GUI.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-active
			x		Activates the item
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-ipv4_unicast_nlri
			 		Enables the emulation of routes for IPv4 unicast.
			 		This option is mandatory if user wants to give a network_group_handle to bgp_route_config without creating a new network group.
			 		Learned routes filter is enabled at neighbor level for IxTclProcol, for IxTclNetwork the filters are set in emulation_bgp_config.
			 		The priority of the flags is the following VPN (L3 Sites), AD VPLS (L2 VPN), VPLS (L2 Sites), MPLS, Unicast/Multicast.
			 		Only one of the three route categories can be emulated in a single emulation_bgp_route_config call, the selection is made based on priority.
			 	-ipv4_multicast_nlri
			 		Enables the emulation of routes for IPv4 multicast.
			 		Learned routes filter is enabled at neighbor level for IxTclProcol, for IxTclNetwork the filters are set in emulation_bgp_config.
			 		The priority of the flags is the following VPN (L3 Sites), AD VPLS (L2 VPN), VPLS (L2 Sites), MPLS, Unicast/Multicast.
			 		Only one of the three route categories can be emulated in a single emulation_bgp_route_config call, the selection is made based on priority.
			 	-ipv4_mpls_nlri
			 		Enables the emulation of routes for IPv4 MPLS.
			 		Learned routes filter is enabled at neighbor level for IxTclProcol, for IxTclNetwork the filters are set in emulation_bgp_config.
			 		The priority of the flags is the following VPN (L3 Sites), AD VPLS (L2 VPN), VPLS (L2 Sites), MPLS, Unicast/Multicast.
			 		Only one of the three route categories can be emulated in a single emulation_bgp_route_config call, the selection is made based on priority.
			 	-ipv4_mpls_vpn_nlri
			 		Enables the emulation of routes for IPv4 MPLS VPNs.
			 		Learned routes filter is enabled at neighbor level for IxTclProcol, for IxTclNetwork the filters are set in emulation_bgp_config.
			 		The priority of the flags is the following VPN (L3 Sites), AD VPLS (L2 VPN), VPLS (L2 Sites), MPLS, Unicast/Multicast.
			 		Only one of the three route categories can be emulated in a single emulation_bgp_route_config call, the selection is made based on priority.
			 		Requires parameter num_sites to be present in order to create VPN route ranges.
			 	-ipv6_unicast_nlri
			 		Enables the emulation of routes for IPv6 unicast.
			 		Learned routes filter is enabled at neighbor level for IxTclProcol, for IxTclNetwork the filters are set in emulation_bgp_config.
			 		The priority of the flags is the following VPN (L3 Sites), AD VPLS (L2 VPN), VPLS (L2 Sites), MPLS, Unicast/Multicast.
			 		Only one of the three route categories can be emulated in a single emulation_bgp_route_config call, the selection is made based on priority.
			 	-ipv6_multicast_nlri
			 		Enables the emulation of routes for IPv6 multicast.
			 		Learned routes filter is enabled at neighbor level for IxTclProcol, for IxTclNetwork the filters are set in emulation_bgp_config.
			 		The priority of the flags is the following VPN (L3 Sites), AD VPLS (L2 VPN), VPLS (L2 Sites), MPLS, Unicast/Multicast.
			 		Only one of the three route categories can be emulated in a single emulation_bgp_route_config call, the selection is made based on priority.
			 	-ipv6_mpls_nlri
			 		Enables the emulation of routes for IPv6 MPLS.
			 		Learned routes filter is enabled at neighbor level for IxTclProcol, for IxTclNetwork the filters are set in emulation_bgp_config.
			 		The priority of the flags is the following VPN (L3 Sites), AD VPLS (L2 VPN), VPLS (L2 Sites), MPLS, Unicast/Multicast.
			 		Only one of the three route categories can be emulated in a single emulation_bgp_route_config call, the selection is made based on priority.
			 	-ipv6_mpls_vpn_nlri
			 		Enables the emulation of routes for IPv6 MPLS VPNs.
			 		Learned routes filter is enabled at neighbor level for IxTclProcol, for IxTclNetwork the filters are set in emulation_bgp_config.
			 		The priority of the flags is the following VPN (L3 Sites), AD VPLS (L2 VPN), VPLS (L2 Sites), MPLS, Unicast/Multicast.
			 		Only one of the three route categories can be emulated in a single emulation_bgp_route_config call, the selection is made based on priority.
			 		Requires parameter num_sites to be present in order to create VPN route ranges.
			 	-max_route_ranges
			 		The number of route ranges, mpls route ranges, vpn routes to create
			 		under the BGP neighbor or the number of label blocks to create under the BGP neighbor when VPLS is enabled.
			 	-ip_version
			 		The IP version of the BGP route to be created.
			 		Valid choices are:
			    		4 - Bgp version 4
			    		6 - Bgp version 6
			 	-prefix
			 		Route prefix to be advertised / removed by emulated BGP node.
			 	-route_ip_addr_step
			 		IP address increment step between the multiple route ranges created
			 		under the BGP neighbor, based on -max_route_ranges.
			x	-prefix_step_accross_vrfs
			x		If -target_count is greater than one, the step interval for the next
			x		incremented prefix.
			 	-num_routes
			 		Number of routes to advertise, using the prefix as the starting prefix
			 		and incrementing based upon the -prefix_step and the -netmask
			 		arguments.
			 	-num_sites
			 		Number of L2/L3 VPN sites (PEs) to be created on a BGP neighbor.
			x	-prefix_from
			x		The first prefix length to generate based on the -prefix.
			x	-prefix_to
			x		The last prefix length to generate based on the -prefix.
			 	-prefix_step
			 		If -num_routes is greater than one, the step interval for the next
			 		incremented prefix.
			 	-prefix_step_across_vrfs
			 		The step interval for the next increment prefix when crossing vrfs.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-netmask
			 		Netmask of the advertised routes.
			 	-ipv6_prefix_length
			 		IPv6 mask for the IPv6 routes advertised.
			x	-enable_generate_unique_routes
			x		FLAG - When set to 1, each router generates a different IP address
			x		range.When set to 0, each router advertises the route range as is.
			x		When enabled, the first router advertises numRoutes routes starting
			x		at networkAddress, the next router advertises numRoutes routes
			x		starting at (networkAddress + numRoutes), and so on.
			x	-end_of_rib
			x		Configures BGP End of RIB marker
			 	-packing_from
			 		The minimum number of routes to pack into an UPDATE message.Random
			 		numbers are chosen from the range -packing_from to -packing_to.
			 	-packing_to
			 		The maximum number of routes to pack into an UPDATE message.Random
			 		numbers are chosen from the range -packing_from to -packing_to.
			x	-enable_traditional_nlri
			x		If checked, use the traditional NLRI in the UPDATE message, instead
			x		of using the MP_REACH_NLRI Multi-protocol extension to advertise
			x		the routes. (Not applicable for MPLS and MPLS VPN Route Ranges.)
			 	-next_hop_enable
			 		A flag to enable the generation of a NEXT HOP attribute. Can be used
			 		as a flag of a choice of 0 or 1.
			 	-next_hop_set_mode
			 		Indicates how to set the next hop IP address.
			 		Valid choices are:
			    		same - Will set the value as the local IP address
			    		manual - The value is read from -next_hop_ip_address
			 	-next_hop_ip_version
			 		The type of IP address in nextHopIpAddress.
			 		Valid choices are:
			    		4 - Ipv4 next hop address
			    		6 - Ipv6 next hop address
			 	-next_hop
			 		Specifies a mandatory path attribute that defines the IP address of
			 		the border router that should be used as the next hop to the
			 		destinations listed in the Network Layer Reachability field of the
			 		UPDATE message.
			x	-next_hop_ipv4
			x		Specifies a mandatory path attribute that defines the IP address of
			x		the border router that should be used as the next hop to the
			x		destinations listed in the Network Layer Reachability field of the
			x		UPDATE message.
			x		Has priority over the legacy -next_hop parameter.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-next_hop_ipv6
			x		Specifies a mandatory path attribute that defines the IP address of
			x		the border router that should be used as the next hop to the
			x		destinations listed in the Network Layer Reachability field of the
			x		UPDATE message.
			x		Has priority over the legacy -next_hop parameter.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-next_hop_mode
			 		Indicates that the nextHopIpAddress may be incremented for each
			 		neighbor session generated for the range of neighbor addresses.
			 		Valid choices are:
			    		fixed - Fixed next hop mode
			    		increment - Increment next hop mode
			x	-advertise_nexthop_as_v4
			x		Advertise Nexthop as V4
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-origin_route_enable
			 		A flag to define whether to enable the origin route or not.
			 	-origin
			 		Selects the value for the ORIGIN path attribute.Note that specifying
			 		a path attribute forces the advertised route to be a node route as
			 		opposed to a global route.
			 		Valid choices are:
			    		igp - Internal
			    		egp - External
			    		incomplete - Incomplete
			x	-enable_local_pref
			x		This attribute inserts a local_pref attribute with the indicated value. (internal bgp only)
			 	-local_pref
			 		Specifies the LOCAL_PREF path attribute, which is a discretionary
			 		attribute used by a BGP speaker to inform other BGP speakers in its
			 		own AS of the originating speakers degree of preference for an
			 		advertised route.
			x	-enable_med
			x		Enable Multi Exit
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-multi_exit_disc
			 		Specifies the multi-exit discriminator, which is an optional
			 		non-transitive path attribute.The value of this attribute may be
			 		used by a BGP speakers decision process to discriminate among multiple
			 		exit points to a neighboring AS.
			x	-enable_weight
			x		Enable Weight
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-weight
			x		Weight
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-atomic_aggregate
			 		Specifies the ATOMIC_AGGREGATE path attribute, which is a discretionary
			 		attribute.If set to 1, informs other BGP speakers that the local
			 		system selected a less specific route without selecting a more specific
			 		route included in it.
			 	-aggregator
			 		For the AGGREGATOR path attribute, specifies the last AS number that
			 		formed the aggregate route, and the IP address of the BGP speaker
			 		that formed the aggregate route.Format: <asn>:<a.b.c.d>.
			x	-enable_aggregator
			x		Enable Aggregator ID
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-aggregator_id_mode
			x		Aggregator ID Mode
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		fixed - Fixed mode
			x   		increment - Increment aggregator ID
			x	-aggregator_id
			x		For the AGGREGATOR path attribute, specifies the IP address of the BGP speaker
			x		that formed the aggregate route.
			x		Has priority over the legacy -aggregator parameter.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-aggregator_as
			x		For the AGGREGATOR path attribute, specifies the last AS number that
			x		formed the aggregate route.
			x		Has priority over the legacy -aggregator parameter.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-originator_id_enable
			 		Enables or disables originator ID on BGP route range.
			 	-originator_id
			 		Specifies the ORIGINATOR_ID path attribute, which is an optional,
			 		non-transitive BGP attribute.It is created by a Route Reflector and
			 		carries the ROUTER_ID of the originator of the route in the local AS.
			 	-use_safi_multicast
			 		Send Routes with SAFI as Multicast (2)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-skip_multicast_routes
			 		Skip the Multicast routes for this route range
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-enable_route_flap
			x		FLAG - Enables the flapping functions described by
			x		route_flap_up_time, route_flap_down_time, routesToFlapFrom, and
			x		routesToFlapTo.
			x	-flap_up_time
			x		During flapping operation, the time between flap cycles, expressed
			x		in seconds. During this period, the route range will be up.
			x	-flap_down_time
			x		During flapping operation, the period expressed in seconds during
			x		which the route is withdrawn from its neighbors.
			x	-enable_partial_route_flap
			x		FLAG - Enable partial flapping functions.
			x	-partial_route_flap_from_route_index
			x		When partial route flapping is enabled, gives the index of the
			x		route from which to start.
			x	-partial_route_flap_to_route_index
			x		When partial route flapping is enabled, gives the index of the
			x		route which to end the flap.
			x	-flap_delay
			x		Flapping delay
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-communities_enable
			 		Enables or disables communities.
			x	-num_communities
			x		Internal mapping to implicit list length param
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-communities
			 		Specifies the COMMUNITIES path attribute, which is an optional
			 		transitive attribute of variable length.All routes with this
			 		attribute belong to the communities listed in the attribute.
			 		This is a list of numbers.
			x	-communities_as_number
			x		Communities AS #
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-communities_last_two_octets
			x		Last Two Octets
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-communities_type
			x		Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		noexport - No export
			x   		noadvertised - No advertised
			x   		noexport_subconfed - No export subconfed
			x   		manual - Manual AS number
			x   		llgr_stale - LLGR STALE
			x   		no_llgr - NO LLGR
			 	-enable_large_communitiy
			 		Enables or disables Large communities.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-num_of_large_communities
			x		Internal mapping to implicit list length param
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-large_community
			x		Large Community in cannonical format as defined in RFC8092 which is:
			x		GlobalAdmin:LocalDataPart1:LocalDataPart2
			x		where each value must have range 1-4294967295.
			x		e.g. 65535:100:10 or 4294967295:1:65535
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_communities_enable
			x		Enable Extended Community
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-num_ext_communities
			x		Internal mapping to implicit list length param
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-ext_communities
			 		Specifies the EXTENDED COMMUNITIES path attribute, which is a
			 		transitive optional BGP attribute.All routes with the EXTENDED
			 		COMMUNITIES attribute belong to the communities listed in the
			 		attribute.
			 		 This is a list of numbers separated by comma char "," as follows: 
			 		 The first number is the value of the low-order type byte.
			 		Possible values: 
			 		
			 		-  0 - (default) 
			 		-  2 - Route target community 
			 		-  3 - Route origin community 
			 		-  4 - Link bandwidth community 
			 		
			 		 The second number is the value of the high-order type byte.
			 		Possible values: 
			 		
			 		-  128 - IANA bit:
			 		This bit may be or'd with any other values. 0 indicates
			 		that this is an IANA assignable type using First Come
			 		First Serve policy. 1 indicates that this is an IANA
			 		assignable type using the IETF Consensus policy. 
			 		
			 		
			 		-  64 - Transitive bit:
			 		This bit may be or'd with any other values. 0 indicates
			 		that the community is transitive across ASes and 1
			 		indicates that it is non-transitive. 
			 		
			 		
			 		-  0 - Two-octet AS specific (default):
			 		Value holds a two-octet global ASN followed by a four-bytes
			 		local admin value. 
			 		-  1 - IPv4 address specific:
			 		Value holds a four-octet IP address followed by a two-bytes
			 		local administrator value. 
			 		-  2 - Four-octet AS specific:
			 		Value holds a four-octet global ASN followed by a two-bytes
			 		local admin value. 
			 		-  3 - Generic:
			 		Value holds six-octets. 
			 		-  The third number is the value associated with the extended
			 		community. (default = {00 00 00 00 00 00}) 
			 		
			 		 Example value: {2,128,03 22 00 00 00 00}. 
			x	-ext_communities_as_two_bytes
			x		AS 2-Bytes
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_communities_as_four_bytes
			x		AS 4-Bytes
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_communities_assigned_two_bytes
			x		Assigned Number(2 Octets)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_communities_assigned_four_bytes
			x		Assigned Number(4 Octets)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_communities_ip
			x		IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_communities_opaque_data
			x		Opaque Data
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_communities_colorCObits
			x		Extended Communities Color CO Bits
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		00 - Extended Community Color CO Bits - 00
			x   		01 - Extended Community Color CO Bits - 01
			x   		10 - Extended Community Color CO Bits - 10
			x   		11 - Extended Community Color CO Bits - 11
			x	-ext_communities_colorReservedBits
			x		Extended Communities Color Reserved Bits
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_communities_colorValue
			x		Extended Communities Color Value
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_communities_link_bandwidth
			x		Link Bandwidth
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ext_communities_type
			x		Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		administratoras2octet - Admin AS number 2 octet
			x   		administratorip - Admin IP address
			x   		administratoras4octet - Admin AS number 4 octet
			x   		opaque - Opaque data
			x   		evpn - Extended Community type - EVPN
			x   		administratoras2octetlinkbw - Administrator AS2 Octet Link Bandwidth
			x	-ext_communities_subtype
			x		SubType
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		routetarget - Route target
			x   		origin - Origin
			x   		extendedbandwidth - Extended bandwidth
			x   		encapsulation - Encapsulation
			x   		mac_address - Mac Address
			x   		color - Color
			 	-cluster_list_enable
			 		Enables or disables cluster list on BGP route range.
			x	-num_clusters
			x		Internal mapping to implicit list length param
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-cluster_list
			 		Specifies the CLUSTER_LIST path attribute, which is an optional,
			 		non-transitive BGP attribute.It is a sequence of CLUSTER_ID values
			 		representing the reflection path through which the route has passed.
			x	-advertise_as_bgpls_prefix
			x		Advertise As BGP-LS Prefix
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-route_origin
			x		Selects the value for the Route ORIGIN path attribute.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		static - static
			x   		direct - direct
			x	-advertise_as_bgp_3107
			x		Will cause this route to be sent as BGP 3107 MPLS SAFI route
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-label_id
			x		The identifier for the label space.
			 	-label_value
			 		Starting value for the label of the BGP route. Default is 16.
			x	-label_end
			x		Route Range Label End
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-label_step
			 		Increment value used to step the base label.
			x	-advertise_as_bgp_3107_sr
			x		Will cause this route to be sent as BGP 3107
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-segmentId
			x		Route Range Segment ID for BGP 3107
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-incrementMode
			x		Route Range Segment ID for BGP 3107
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		same -
			x   		increment -
			x	-specialLabel
			x		Route Range Special Label for BGP 3107
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		none -
			x   		includeexplicitipv4null -
			x   		includeimplicitnull -
			x	-enableSRGB
			x		Enable SRGB for BGP 3107
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-advertise_as_rfc_8277
			x		Will cause this route to be sent as RFC 8277 MPLS SAFI route
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-no_of_labels
			x		Number of RFC 8277 Labels
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-mpls_label_step
			x		MPLS Label Step
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-mpls_label_start
			x		MPLS Label Start
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-mpls_label_end
			x		MPLS Label End
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_aigp
			x		Enable AIGP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-no_of_tlvs
			x		Enable AIGP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-aigp_type
			x		AIGP type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		aigptlv -
			x	-aigp_value
			x		AIGP Value
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_add_path
			x		Enable Path ID when ADD Path Capability is enabled in BGP Peer
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-add_path_id
			x		BGP ADD Path Id
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_random_as_path
			x		Enable Random AS Path
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-max_no_of_as_path_segments
			x		Maximum Number Of AS Path Segments Per Route Range
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-min_no_of_as_path_segments
			x		Minimum Number Of AS Path Segments Per Route Range
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-as_segment_distribution
			x		Type of AS Segment generated. If user selects Random, then any of the four types (AS-SET, AS-SEQ, AS-SET-CONFEDERATION, AS-SEQ-CONFEDERATION)
			x		will get randomly generated
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		as_set - AS-SET
			x   		as_seq - AS-SEQ
			x   		as_set_confederation - AS-SET-CONFEDERATION
			x   		as_seq_confederation - AS-SEQ-CONFEDERATION
			x   		random_segments - Random Segments
			x   		random_between_asset_and_asseq - Random between AS-SET and AS-SEQ
			x	-max_as_numbers_per_segments
			x		Maximum Number Of AS Numbers generated per Segment
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-min_as_numbers_per_segments
			x		Minimum Number Of AS Numbers generated per Segments
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-range_of_as_number_suffix
			x		Supported Formats:
			x		value
			x		value1-value2
			x		Values or value ranges separated by comma(,).
			x		e.g. 100,150-200,400,600-800 etc.
			x		Cannot be kept empty.
			x		Should be >= ((Max Number of AS Path Segments) x (Max AS Numbers Per Segment))
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-as_path_per_route
			x		When there are multiple routes in a route range, this option decides whether to use same or different
			x		AS paths randomly generated for all the routes within that route range.
			x		For the Different option, each route will be sent in different update messages.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		same - Same
			x   		different - Different
			x	-random_as_seed_value
			x		Seed value decides the way the AS Values are generated. To generate different AS Paths for different Route ranges,
			x		select unique Seed Values
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_as_path
			x		This parameter indicates that as_path attributes are to be generated.
			x	-num_as_path_segments
			x		Number of AS_Path Segments Per Route Range
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-as_path_set_mode
			x		For External routing only.
			x		Optional setup for the AS-Path.
			x		Valid choices are:
			x   		include_as_seq - Include Local AS as AS-SEQ
			x   		include_as_seq_conf - Include Local AS as AS-SEQ-Confederation
			x   		include_as_set - Include Local AS as AS-SET
			x   		include_as_set_conf - Include Local AS as AS-SET-Confederation
			x   		no_include - Don't include Local AS
			x   		prepend_as - Prepend Local AS to first segment
			 	-as_path
			 		Specifies the AS_PATH path attribute, which is a mandatory attribute
			 		composed of a sequence of AS path segments.
			 		Format: <as path type>:<comma separated segment list>
			 		{as_set|as_seq|as_confed_set|as_confed_seq}:<x,x,x,x>.
			 		Example:
			 		as_set:1,2,3,4
			 		as_set - specifies an unordered set of autonomous systems though
			 		which a route in the UPDATE message has traversed.
			 		as_seq - specifies an ordered set of autonomous systems through
			 		which a route in the UPDATE message has traversed.
			 		as_confed_set - specifies an unordered set of autonomous systems in
			 		the local confederation that the UPDATE message has traversed.
			 		as_confed_seq - specifies an ordered set of autonomous systems in
			 		the local confederation that the UPDATE message has traversed.
			 		DEFAULT = as_set:<router_as>, where <router_as> is the AS of the
			 		router which advertises this route.
			x	-as_path_segment_type
			x		Specifies the segment type for the AS_PATH attribute.
			x		This may be a list of values with equal length to the as_path parameter list.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		as_set - AS-SET
			x   		as_seq - AS-SEQ
			x   		as_confed_set - AS-SET-CONFEDERATION
			x   		as_confed_seq - AS-SEQ-CONFEDERATION
			x	-num_as_numbers_in_segment
			x		Numbers of AS numbers in the AS_PATH segment.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_as_path_segment
			x		Enable AS Path Segment
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_as_path_segment_number
			x		Enable AS Number
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-as_path_segment_numbers
			x		A list of lists of AS_PATH segment numbers. The outer list length needs to match as_path_segment_type list length.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-vpls
			x		(deprecated)
			x		This BGP/BGP+ router/peer supports BGP/BGP+ VPLS per the Kompella draft.
			x		This will enable the L2 Sites.
			x		Does not take priority over other flags that enable L3 sites and AD VPLS.
			x		The priority of the flags is the following VPN (L3 Sites), AD VPLS (L2 VPN), VPLS (L2 Sites), MPLS, Unicast/Multicast.
			x	-vpls_nlri
			x		This BGP/BGP+ router/peer supports BGP/BGP+ VPLS per the Kompella draft.
			x		This will enable the L2 Sites.
			x		Does not take priority over other flags that enable L3 sites and AD VPLS.
			x		The priority of the flags is the following VPN (L3 Sites), AD VPLS (L2 VPN), VPLS (L2 Sites), MPLS, Unicast/Multicast.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-rd_admin_value
			 		Starting value of the administrator field of the route distinguisher.
			x	-rd_admin_value_step
			x		Inner increment value to step the base route distinguisher administrator
			x		field.
			 	-rd_admin_step
			 		Increment value to step the base route distinguisher administrator
			 		field.
			 	-rd_assign_value
			 		Starting value of the assigned number field of the route
			 		distinguisher.
			x	-rd_assign_value_step
			x		Inner increment value to step the base route distinguisher assigned number
			x		field if -target_count is greater than 1.
			 	-rd_assign_step
			 		Increment value to step the base route distinguisher assigned number
			 		field.
			x	-control_word_enable
			x		Enable Control Word
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-seq_delivery_enable
			x		Enable Sequenced Delivery
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-mtu
			x		Maximum transmit unit. Has to be in concordance with the DUT settings.
			x	-site_id
			x		The current L2 site identifier.
			x	-site_id_step
			x		Increment for the L2 site identifier.
			 	-target
			 		AS number or IP address list based on the -target_type list.
			x	-target_inner_step
			x		Increment value to step the base target field when -target_count is greater than 1.
			x	-target_step
			x		Increment value to step the base target field.
			 	-target_assign
			 		The assigned number subfield of the value field of the target.It is
			 		a number from a numbering space which is maintained by the enterprise
			 		administers for a given IP address or ASN space.It is the local
			 		part of the target.
			x	-target_assign_inner_step
			x		Increment value to step the base target assigned number fieldwhen -target_count is greater than 1.
			x	-target_assign_step
			x		Increment value to step the base target assigned number field.
			 	-rd_type
			 		Route distinguisher type.
			 		Valid choices are:
			    		0 - 2 byte AS route distinguisher type
			    		1 - IP route distinguisher type
			    		2 - 4 byte AS route distinguisher type
			 	-target_type
			 		List of the target type.
			 		Valid choices are:
			    		as - AS target type
			    		ip - IP target type
			    		as4 - AS4 target type
			x	-vpn_name
			x		VPN Name
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-advertise_label_block
			x		Advertise Label Block
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-num_labels
			x		Specifies the number of labels to be created for the current label block.
			 	-num_labels_type
			 		Type of the -num_labels parameter. Default value is single_value.
			 		Valid choices are:
			    		list - Specifies that the num_labels parameter is a list and shouldnt be multiplied
			    		single_value - Specifies that the num_labels parameter is a single value and should be used a number of times equal to max_route_ranges
			x	-label_block_offset
			x		The offset of the label block.
			x	-label_block_offset_type
			x		Type of the -label_block_offset parameter. Default value is single_value.
			x		Valid choices are:
			x   		list - Specifies that the label_block_offset parameter is a list and shouldnt be multiplied
			x   		single_value - Specifies that the label_block_offset parameter is a single value and should be used a number of times equal to max_route_ranges
			 	-label_value_type
			 		Type of the -label_value parameter. If this parameter is set to list "-label_value_step" is ignored. Default value is single_value.
			 		Valid choices are:
			    		list - Specifies that the label_value parameter is a list and shouldnt be multiplied
			    		single_value - Specifies that the label_value parameter is a single value and should be used a number of times equal to max_route_ranges
			x	-l2_start_mac_addr
			x		Start address for the MAC range.
			x	-l2_mac_incr
			x		Indicates whether the initial mac address gets incremented across the range.
			x	-l2_mac_count
			x		Number of mac addresses for this range.
			x	-l2_enable_vlan
			x		Enable or disable vlan on this mac range.
			x	-l2_vlan_priority
			x		3-bit user priority field in the VLAN tag.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-l2_vlan_tpid
			x		16-bit Tag Protocol Identifier (TPID) or EtherType in the VLAN tag.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		0x8100 - Tunneling vlan protocol id is 0x8100
			x   		0x88a8 - Tunneling vlan protocol id is 0x88a8
			x   		0x9100 - Tunneling vlan protocol id is 0x9100
			x   		0x9200 - Tunneling vlan protocol id is 0x9200
			x   		0x9300 - Tunneling vlan protocol id is 0x9300
			x	-l2_vlan_id
			x		Current vlan id.
			x	-l2_vlan_id_incr
			x		This parameter represents the increment step for vlan id across the ranges.
			x	-l2_vlan_incr
			x		Indicates whether the vlan id gets incremented inside the same range.
			x		Valid choices are:
			x   		0 - No increment
			x   		1 - Parallel increment
			x   		2 - Inner first increment
			x   		3 - Outer first increment
			x   		no_increment - No increment
			x   		parallel_increment - Parallel increment
			x   		inner_first - Inner first increment
			x   		outer_first - Outer first increment
			x	-import_rt_as_export_rt
			x		Import RT List Same As Export RT List
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-target_count
			x		Number of AS number or IP address list based on the -target_type list.
			x	-import_target_count
			x		Number of RTs in Import Route Target List
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-default_mdt_ip
			x		Defines the IP address of the default MDT for mVPN.
			x	-default_mdt_ip_incr
			x		Defines the IP address increment for each default MDT.
			 	-import_target
			 		AS number or IP address list based on the -import_target_type list.
			x	-import_target_step
			x		Increment value to step the base import target field.
			x	-import_target_inner_step
			x		Increment value to step the base import target field when -target_count is greater than 1.
			 	-import_target_assign
			 		The assigned number subfield of the value field of the import target.
			 		It is a number from a numbering space which is maintained by the
			 		enterprise administers for a given IP address or ASN space.It is the
			 		local part of the import target.
			 	-import_target_type
			 		List of the import target type.
			 		Valid choices are:
			    		as - Import target type is AS
			    		ip - Import target type is IP
			    		as4 - Import target type is AS4
			x	-import_target_assign_step
			x		Increment value to step the base import target assigned number field.
			x	-import_target_assign_inner_step
			x		Increment value to step the base import target assigned number field when -target_count is greater than 1.
			x	-rd_count
			x		The number of route distinguisher values in a VRF range.
			x	-rd_count_per_vrf
			x		The number of times that the increment step is used per VRF.
			x	-rd_admin_value_step_across_vrfs
			x		Outer increment value to step the base route distinguisher administrator
			x		field if -target_count is greater than 1.
			x	-rd_assign_value_step_across_vrfs
			x		Outer increment value to step the base route distinguisher assigned number
			x		field if -target_count is greater than 1.
			x	-label_value_end
			x		Ending value for the label of the BGP route. If this parameter is not provided it will be calculated as label_value + num_routes * label_step.
			 	-label_incr_mode
			 		Method in which the MPLS label of an IPv4 MPLS-VPN route will be
			 		incremented.
			 		Valid choices are:
			    		fixed - Fixed MPLS label for all RDs
			    		rd - Increment label per RD. Not used in NGPF
			    		prefix - Increment label per prefix advertised
			x	-ad_vpls_nlri
			x		This BGP/BGP+ router/peer supports BGP/BGP+ AD VPLS.
			x		Does not take priority over other flags that enable L3 sites.
			x		The priority of the flags is the following VPN (L3 Sites), AD VPLS (L2 VPN), VPLS (L2 Sites), MPLS, Unicast/Multicast.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-as_number_vpls_id
			x		VPLS ID AS Number
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-as_number_vpls_rd
			x		Route Distinguisher AS Number
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-as_number_vpls_rt
			x		Route Target AS Number
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-assigned_number_vpls_id
			x		VPLS ID Assigned Number
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-assigned_number_vpls_rd
			x		Route Distinguisher Assigned Number
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-assigned_number_vpls_rt
			x		Route Target Assigned Number
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-import_rd_as_rt
			x		Use RD As RT
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-import_vpls_id_as_rd
			x		Use VPLS ID As Route Distinguisher
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ip_address_vpls_id
			x		VPLS ID IP Address
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ip_address_vpls_rd
			x		Route Distinguisher IP Address
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ip_address_vpls_rt
			x		Route Target IP Address
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-number_vsi_id
			x		VSI ID Number
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-type_vpls_id
			x		VPLS ID Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		as - AS VPLS ID type
			x   		ip - IP VPLS ID type
			x	-type_vpls_rd
			x		RD Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		as - AS route distinguisher type
			x   		ip - IP route distinguisher type
			x	-type_vpls_rt
			x		RT Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		as - AS route target type
			x   		ip - IP route target type
			x	-type_vsi_id
			x		VSI ID
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		concat_pe_addr - Concatenate PE address
			x   		concat_num - Concatenate number
			x	-override_peer_as_set_mode
			x		Override Peer AS# Set Mode
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-no_write
			x		If this option is present, the configuration is not written to the
			x		hardware. This option can be used to queue up multiple configurations
			x		before writing to the hardware.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-best_routes
			x		Import only the best routes (provided route file has this information)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-route_distribution_type
			x		Option to specify distribution type, for distributing imported routes across all BGP Peer.
			x		Options:
			x		round_robin, for allocating routes sequentially, and
			x		replicate, for allocating all routes to each Peer.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		round_robin - for allocating routes sequentially
			x   		replicate - for allocating all routes to each Peer.
			x	-next_hop_modification_type
			x		Option for setting Next Hop modification type.
			x		Options are
			x		overwrite_testers_address for "Overwrite Next Hop with Tester's address"
			x		preserve_from_file for "Preserve Next Hop from file"
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		overwrite_testers_address - Overwrite Next Hop with Tester's address
			x   		preserve_from_file - Preserve Next Hop from file.
			x	-file_type
			x		Import routes file type. Route import may fail in file type is not matching with the file being imported.
			x		Options are:
			x		csv for "Ixia Format / Standard CSV (.csv)"
			x		cisco for "Cisco IOS Format (.txt)"
			x		juniper for "Juniper JUNOS Format (.txt)"
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		csv - Ixia Format / Standard CSV (.csv)
			x   		cisco - Cisco IOS Format (.txt)
			x   		juniper - Juniper JUNOS Format (.txt)
			x	-route_file
			x		Select source file having route information
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-route_limit
			x		Specify maximum routes(per port) that you want to import. Based on Card Memory, the Max Route Limit Per Port are:
			x		----------------------------------------
			x		4GB or more=>2.0 million
			x		2GB=>1.6 million
			x		1GB=>0.8 million
			x		Less than 1GB=>0.5 million
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-primary_routes_per_device
			x		Number of Primary Routes per Device
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-primary_routes_per_range
			x		Number of Primary Routes per Route Range
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-duplicate_routes_per_device_percent
			x		Percentage to Duplicate Primary Routes per Device
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-network_address_start
			x		This attribute will configure the network start address of the Routes to be generated
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-network_address_step
			x		This attribute will configure the network step address of the Routes to be generated
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-prefix_length_distribution_type
			x		Prefix Length Distribution Type
			x		Options are:
			x		fixed
			x		random
			x		even
			x		exponential
			x		internet_mix
			x		custom_profile
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		fixed - Fixed Distribution
			x   		random - Random Distribution
			x   		even - Even Distribution
			x   		exponential - Exponential Distribution
			x   		internet_mix - Internet-mix Distribution
			x   		custom_profile - Custom Distribution, can provide file as an argument
			x	-prefix_length_distribution_scope
			x		Prefix Length Distribution Scope
			x		Options are:
			x		per_device
			x		per_port
			x		per_topology
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		per_device - Per device Distribution
			x   		per_port - Per port Distribution
			x   		per_topology - Per topology Distribution
			x	-custom_distribution_file
			x		Source file having custom distribution information
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-prefix_length_start
			x		Prefix Length Start Value of the Routes to be generated. Applicable only for Fixed, Even and Exponential distribution type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-prefix_length_end
			x		Prefix Length End Value of the Routes to be generated. Applicable only for Even and Exponential distribution type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-primary_routes_as_path_suffix
			x		AS Path Suffix for Primary Routes to be generated
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-duplicate_routes_as_path_suffix
			x		AS Path Suffix for Duplicate Routes to be generated
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-skip_mcast
			x		Do not include Multicast Address in generated Address Range
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-skip_loopback
			x		Do not include Loopback Address in generated Address Range
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-address_range_to_skip
			x		Address Ranges that will be skipped. You can provide multiple ranges seperated by ','. Example: aa:0:1:b::-bb:0:2:c::, aa00::-bb00::1
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-primary_ipv6_routes_per_range
			x		Number of Primary Routes per Route Range
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-primary_ipv6_routes_per_device
			x		Number of Primary Routes per Device
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-duplicate_ipv6_routes_per_device_percent
			x		Percentage to Duplicate Primary Routes per Device
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_network_address_start
			x		This attribute will configure the network start address of the Routes to be generated
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_network_address_step
			x		This attribute will configure the network step address of the Routes to be generated
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_prefix_length_distribution_type
			x		Prefix Length Distribution Type
			x		Options are:
			x		fixed
			x		random
			x		even
			x		exponential
			x		internet_mix
			x		custom_profile
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		fixed - Fixed Distribution
			x   		random - Random Distribution
			x   		even - Even Distribution
			x   		exponential - Exponential Distribution
			x   		internet_mix - Internet-mix Distribution
			x   		custom_profile - Custom Distribution, can provide file as an argument
			x	-ipv6_prefix_length_distribution_scope
			x		Prefix Length Distribution Scope
			x		Options are:
			x		per_device
			x		per_port
			x		per_topology
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		per_device - Per device Distribution
			x   		per_port - Per port Distribution
			x   		per_topology - Per topology Distribution
			x	-ipv6_custom_distribution_file
			x		Source file having custom distribution information
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_prefix_length_start
			x		Prefix Length Start Value of the Routes to be generated. Applicable only for Fixed, Even and Exponential distribution type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_prefix_length_end
			x		Prefix Length End Value of the Routes to be generated. Applicable only for Even and Exponential distribution type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-primary_ipv6_routes_as_path_suffix
			x		AS Path Suffix for Primary Routes to be generated
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-duplicate_ipv6_routes_as_path_suffix
			x		AS Path Suffix for Duplicate Routes to be generated
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_skip_mcast
			x		Do not include Multicast Address in generated Address Range
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_skip_loopback
			x		Do not include Loopback Address in generated Address Range
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_address_range_to_skip
			x		Address Ranges that will be skipped. You can provide multiple ranges seperated by ','. Example: aa:0:1:b::-bb:0:2:c::, aa00::-bb00::1
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-num_broadcast_domain
			x		The number of broadcast domain to be configured under EVI
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-auto_configure_rd_ip_address
			x		Auto-Configure RD IP Addresses
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-rd_ip_address
			x		RD IP Addresses
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-rd_evi
			x		RD EVI
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_l3vni_target_list
			x		Enable L3VNI Target List
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-advertise_l3vni_separately
			x		Advertise L3VNI Separately
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-b_mac_first_label
			x		B MAC First Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_b_mac_second_label
			x		Enable B MAC Second Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-b_mac_second_label
			x		B MAC Second Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ad_route_label
			x		AD Route Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-multicast_tunnel_type
			x		Multicast Tunnel Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		tunneltypeingressreplication -
			x   		tunneltypersvpp2mp -
			x   		tunneltypemldpp2mp -
			x	-use_upstream_downstream_assigned_mpls_label
			x		Use Upstream/Downstream Assigned MPLS Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-include_pmsi_tunnel_attribute
			x		Include PMSI Tunnel Attribute
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-auto_configure_pmsi_tunnel_id
			x		Auto Configure PMSI Tunnel ID
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pmsi_tunnel_id_v4
			x		PMSI Tunnel ID
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pmsi_tunnel_id_v6
			x		PMSI Tunnel ID
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-upstream_downstream_assigned_mpls_label
			x		Upstream/Downstream Assigned MPLS Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-use_ipv4_mapped_ipv6_address
			x		Use IPv4 Mapped IPv6 Address
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-l3_target_count
			x		Number of RTs in L3VNI Export Route Target List(multiplier)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-l3_import_target_count
			x		Number of RTs in L3VNI Import Route Target List(multiplier)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-l3_import_rt_same_as_l3_export_rt
			x		L3VNI Import RT List Same As L3VNI Export RT List
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-l3_target_type
			 		List of the target type.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		as - AS target type
			    		ip - IP target type
			    		as4 - AS4 target type
			 	-l3_target
			 		AS number or IP address list based on the -target_type list.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-l3_target_inner_step
			x		Increment value to step the base target field when -target_count is greater than 1.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-l3_target_step
			x		Increment value to step the base target field.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-l3_target_as4_number
			x		L3VNI Export Route Target AS4 Number
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-l3_target_ip_address
			x		L3VNI Export Route Target IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-l3_target_assign
			 		The assigned number subfield of the value field of the target.It is
			 		a number from a numbering space which is maintained by the enterprise
			 		administers for a given IP address or ASN space.It is the local
			 		part of the target.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-l3_target_assign_inner_step
			x		Increment value to step the base target assigned number fieldwhen -target_count is greater than 1.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-l3_target_assign_step
			x		Increment value to step the base target assigned number field.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-l3_import_target_type
			 		List of the import target type.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		as - Import target type is AS
			    		ip - Import target type is IP
			    		as4 - Import target type is AS4
			 	-l3_import_target
			 		AS number or IP address list based on the -import_target_type list.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			n	-l3_import_target_step
			x	-l3_import_target_inner_step
			x   		Increment value to step the base import target field when -target_count is greater than 1.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-l3_import_target_as4_number
			x   		L3VNI Import Route Target AS4 Number
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-l3_import_target_ip_address
			x   		L3VNI Import Route Target IP
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-l3_import_target_assign
			    		The assigned number subfield of the value field of the import target.
			    		It is a number from a numbering space which is maintained by the
			    		enterprise administers for a given IP address or ASN space.It is the
			    		local part of the import target.
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			n	-l3_import_target_assign_step
			x   	-l3_import_target_assign_inner_step
			x       		Increment value to step the base import target assigned number field when -target_count is greater than 1.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_next_hop
			x       		Enable Next Hop
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-set_next_hop
			x       		Set Next Hop
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		manually -
			x           		sameaslocalip -
			x   	-set_next_hop_ip_type
			x       		Set Next Hop IP Type
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		ipv4 -
			x           		ipv6 -
			x   	-ipv4_next_hop
			x       		IPv4 Next Hop
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-ipv6_next_hop
			x       		IPv6 Next Hop
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_origin
			x       		Enable Origin
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_local_preference
			x       		Enable Local Preference
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-local_preference
			x       		Local Preference
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_multi_exit_discriminator
			x       		Enable Multi Exit
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-multi_exit_discriminator
			x       		Multi Exit
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_atomic_aggregate
			x       		Enable Atomic Aggregate
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_aggregator_id
			x       		Enable Aggregator ID
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_originator_id
			x       		Enable Originator ID
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-evpn
			x       		Enable BGP EVPN
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-pbb_evpn
			x       		Enable BGP PBB-EVPN
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-evpn_vxlan
			x       		Enable BGP EVPN-VXLAN
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-evpn_vpws
			x       		Enable BGP EVPN-VPWS
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-vxlan_vpws
			x       		Enable BGP VXLAN-VPWS
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-ethernet_tag_id
			x       		Ethernet Tag ID
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_vlan_aware_service
			x       		Enable VLAN Aware Service
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-useb_vlan
			x       		Use B-VLAN
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-b_vlan_id
			x       		B VLAN ID
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-b_vlan_priority
			x       		B VLAN Priority
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-b_vlan_tpid
			x       		B VLAN TPID
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		bvlantpid8100 -
			x           		bvlantpid88a8 -
			x           		bvlantpid9100 -
			x           		bvlantpid9200 -
			x           		bvlantpid9300 -
			x   	-broadcast_domain_ad_route_label
			x       		AD Route Label
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-no_of_mac_pools
			x       		Number of Mac Pools
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_broadcast_domain
			x       		Activates the Broadcast Domain item
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-use_same_sequence_number
			x       		Use Same Sequence Number
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_user_defined_sequence_number
			x       		Enable User Defined Sequence Number
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-sequence_number
			x       		Sequence Number
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-advertise_ipv4_address
			x       		Advertise IPv4 Address
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-ipv4_address_prefix_length
			x       		IPv4 Address Prefix Length which is used to determine the intersubnetting between local and remote host
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-advertise_ipv6_address
			x       		Advertise IPv6 Address
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-ipv6_address_prefix_length
			x       		IPv6 Address Prefix Length which is used to determine the intersubnetting between local and remote host
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-active_ts
			x       		Active TS
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_sticky_static_flag
			x       		Enable Sticky/Static Flag
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-include_default_gateway_extended_community
			x       		Include Default Gateway Extended Community
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-first_label_start
			x       		First Label (L2) Start
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_second_label
			x       		Enable Second Label (L3)
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-second_label_start
			x       		Second Label (L3) Start
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-label_mode
			x       		Label Mode
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		fixed -
			x           		increment -
			x   	-label_start
			x       		Label (L2) Start
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-cmac
			x       		Enable CMAC Properties
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-evpn_ipv4_prefix_range
			x       		Enable EVPN IPv4 Prefix Range
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-evpn_ipv6_prefix_range
			x       		Enable EVPN IPv6 Prefix Range
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-export_rt_as_number
			x       		Export Route Target AS Number
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-export_rt_as4_number
			x       		Export Route Target AS4 Number
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-export_rt_ip_address
			x       		IP
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-export_rt_assigned_number
			x       		Export Route Target Assigned Number
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-export_rt_type
			x       		List of the target type.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		as - AS target type
			x           		ip - IP target type
			x           		as4 - AS4 target type
			x   	-import_rt_as_number
			x       		Export Route Target AS Number
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-import_rt_as4_number
			x       		Export Route Target AS4 Number
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-import_rt_ip_address
			x       		IP
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-import_rt_assigned_number
			x       		Export Route Target Assigned Number
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-import_rt_type
			x       		List of the target type.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		as - AS target type
			x           		ip - IP target type
			x           		as4 - AS4 target type
			x   	-multicast_tunnel_type_vxlan
			x       		Multicast Tunnel Type
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		tunneltypeingressreplication -
			x           		pimsm -
			x           		pimssm -
			x   	-group_address
			x       		Group Address
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-sender_address_p_root_node_address
			x       		Sender Address/P-Root Node Address
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-group_address_v6
			x       		Group Address
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-sender_address_p_root_node_address_v6
			x       		Sender Address/P-Root Node Address
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-rsvp_p2mp_id
			x       		RSVP P2MP ID
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-rsvp_p2mp_id_as_number
			x       		RSVP P2MP ID as Number
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-rsvp_tunnel_id
			x       		RSVP Tunnel ID
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-remote_service_id
			x       		Remote Service ID
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-vid_normalization
			x       		VID Normalization
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		vpws -
			x           		singlevid -
			x           		doublevid -
			x   	-include_vpws_l2_attr_ext_comm
			x       		Include VPWS Layer 2 Attributes Extended Community
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-primary_p_e
			x       		Primary PE
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-backup_flag
			x       		Backup Flag
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-require_c_w
			x       		Require CW
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-l2_mtu
			x       		L2 MTU
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-fxc_type
			x       		FXC Type
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		vpws -
			x           		vlanaware -
			x           		vlanunaware -
			x   	-root_address
			x       		Root Address
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-name
			x       		MVPN Opaque TLV 1
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-type
			x       		Type
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-tlv_length
			x       		Length
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-value
			x       		Value
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_ipv4_receiver
			x       		Enable As IPv4 Receiver Site
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_ipv4_sender
			x       		Enable As IPv4 Sender Site
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_ipv6_receiver
			x       		Enable As IPv6 Receiver Site
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_ipv6_sender
			x       		Enable As IPv6 Sender Site
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		   A list containing the network group protocol stack handles that were added by the command (if any).
			x   key:network_group_handle                 value:A list containing the network group protocol stack handles that were added by the command (if any).
		   A list containing the ip routes protocol stack handles that were added by the command (if any).
			x   key:ip_routes                            value:A list containing the ip routes protocol stack handles that were added by the command (if any).
		   A list containing the l3 vpn routes protocol stack handles that were added by the command (if any).
			x   key:l3_vpn_routes                        value:A list containing the l3 vpn routes protocol stack handles that were added by the command (if any).
		   A list containing the ip prefix protocol stack handles that were added by the command (if any).
			x   key:ip_prefix                            value:A list containing the ip prefix protocol stack handles that were added by the command (if any).
		   A list containing the mac pools protocol stack handles that were added by the command (if any).
			x   key:mac_pools                            value:A list containing the mac pools protocol stack handles that were added by the command (if any).
		   A list containing the macpool ip prefix protocol stack handles that were added by the command (if any).
			x   key:macpool_ip_prefix                    value:A list containing the macpool ip prefix protocol stack handles that were added by the command (if any).
		   A list containing the cmac properties protocol stack handles that were added by the command (if any).
			x   key:cmac_properties                      value:A list containing the cmac properties protocol stack handles that were added by the command (if any).
		   A list containing the l2 site protocol stack handles that were added by the command (if any).
			x   key:l2_site                              value:A list containing the l2 site protocol stack handles that were added by the command (if any).
		   A list containing the label blocks protocol stack handles that were added by the command (if any).
			x   key:label_blocks                         value:A list containing the label blocks protocol stack handles that were added by the command (if any).
		   A list containing the bgp vrf protocol stack handles that were added by the command (if any).
			x   key:bgp_vrf                              value:A list containing the bgp vrf protocol stack handles that were added by the command (if any).
		   A list containing the ad l2vpn protocol stack handles that were added by the command (if any).
			x   key:ad_l2vpn                             value:A list containing the ad l2vpn protocol stack handles that were added by the command (if any).
		   A list containing the evpn evi protocol stack handles that were added by the command (if any).
			x   key:evpn_evi                             value:A list containing the evpn evi protocol stack handles that were added by the command (if any).
		   A list containing the broadcast domain protocol stack handles that were added by the command (if any).
			x   key:broadcast_domain_handle              value:A list containing the broadcast domain protocol stack handles that were added by the command (if any).
		   A list containing the broadcast domain vpws protocol stack handles that were added by the command (if any).
			x   key:broadcast_domain_vpws_handle         value:A list containing the broadcast domain vpws protocol stack handles that were added by the command (if any).
		   A list containing the broadcast domain vxlan vpws protocol stack handles that were added by the command (if any).
			x   key:broadcast_domain_vxlan_vpws_handle   value:A list containing the broadcast domain vxlan vpws protocol stack handles that were added by the command (if any).
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:bgp_routes                           value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:bgp_sites                            value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:broadcast_domain_handles             value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:broadcast_domain_vpws_handles        value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:broadcast_domain_vxlan_vpws_handles  value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   $::SUCCESS | $::FAILURE
			    key:status                               value:$::SUCCESS | $::FAILURE
		   When status is failure, contains more information.
			    key:log                                  value:When status is failure, contains more information.
		   The route range handles.
			    key:bgp_routes                           value:The route range handles.
		   A keyed list of sites with route ranges for MPLS VPN.
			    key:bgp_sites                            value:A keyed list of sites with route ranges for MPLS VPN.
		
		Examples:
		   See files starting with BGP4_ in the Samples subdirectory.  Also see some
		   of the L3VPN, MPLS, and MVPN sample files for further examples of BGP usage.
		   See the BGP examples in Appendix A, "Example APIs," for specific example usage.
		   See files starting with BGP4_ in the Samples subdirectory.  Also see some of the L3VPN, MPLS, and MVPN sample files for further examples of BGP usage.
		   See the BGP examples in Appendix A, "Example APIs," for specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		   Coded versus functional specification.
		   1) You can configure multiple BGP route range on each Ixia interface.
		   If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  bgp_routes, bgp_sites, broadcast_domain_handles, broadcast_domain_vpws_handles, broadcast_domain_vxlan_vpws_handles
		   Coded versus functional specification.
		   1) You can configure multiple BGP route range on each Ixia interface.
		   If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  bgp_routes, bgp_sites
		   Coded versus functional specification.1) You can configure multiple BGP route range on each Ixia interface.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_bgp_route_config", kwargs)

	def emulation_bgp_srte_policies_config(self, **kwargs):
		""" This procedure configures BGP IPv4 and IPv6 SRTE Policies
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_bgp_srte_policies_config
			 	-mode                                           CHOICES create enable modify]
			 	[-handle                                        ANY]
			x	[-no_of_srte_policies                           NUMERIC]
			x	[-active                                        CHOICES 0 1
			x                                                DEFAULT 1]
			x	[-policy_type                                   CHOICES ipv4 ipv6]
			x	[-distinguisher                                 NUMERIC]
			x	[-policy_color                                  NUMERIC]
			x	[-end_pointV4                                   IPV4]
			x	[-end_pointV6                                   IPV6]
			x	[-no_of_tunnels                                 RANGE 1-2]
			x	[-enable_next_hop                               CHOICES 0 1]
			x	[-set_next_hop                                  CHOICES manually sameaslocalip]
			x	[-set_next_hop_ip_type                          CHOICES ipv4 ipv6]
			x	[-ipv4_next_hop                                 IPV4]
			x	[-ipv6_next_hop                                 IPV6]
			x	[-enable_origin                                 CHOICES 0 1]
			x	[-origin                                        CHOICES igp egp incomplete]
			x	[-enable_local_preference                       CHOICES 0 1]
			x	[-local_preference                              NUMERIC]
			x	[-enable_multi_exit_discriminator               CHOICES 0 1]
			x	[-multi_exit_discriminator                      NUMERIC]
			x	[-enable_atomic_aggregate                       CHOICES 0 1]
			x	[-enable_aggregator_id                          CHOICES 0 1]
			x	[-aggregator_id                                 IPV4]
			x	[-aggregator_as                                 NUMERIC]
			x	[-enable_originator_id                          CHOICES 0 1]
			x	[-originator_id                                 IPV4]
			x	[-enable_add_path                               CHOICES 0 1]
			x	[-add_path_id                                   NUMERIC]
			x	[-enable_community                              CHOICES 0 1]
			x	[-no_of_communities                             RANGE 0-32
			x                                                DEFAULT 1]
			x	[-community_type                                CHOICES no_export
			x                                                CHOICES no_advertised
			x                                                CHOICES noexport_subconfed
			x                                                CHOICES manual
			x                                                CHOICES llgr_stale
			x                                                CHOICES no_llgr
			x                                                DEFAULT no_export]
			x	[-community_as_number                           RANGE 0-65535
			x                                                DEFAULT 0]
			x	[-community_last_two_octets                     RANGE 0-65535
			x                                                DEFAULT 0]
			x	[-enable_extended_community                     CHOICES 0 1]
			x	[-no_of_extended_community                      RANGE 0-32
			x                                                DEFAULT 1]
			x	[-ext_communities_type                          CHOICES admin_as_two_octet
			x                                                CHOICES admin_ip
			x                                                CHOICES admin_as_four_octet
			x                                                CHOICES opaque
			x                                                CHOICES evpn
			x                                                CHOICES admin_as_two_octet_link_bw
			x                                                DEFAULT admin_as_two_octet]
			x	[-ext_communities_subtype                       CHOICES route_target
			x                                                CHOICES origin
			x                                                CHOICES extended_bandwidth
			x                                                CHOICES color
			x                                                CHOICES encapsulation
			x                                                CHOICES mac_address
			x                                                DEFAULT route_target]
			x	[-ext_community_as_number                       RANGE 0-65535
			x                                                DEFAULT 1]
			x	[-ext_community_target_assigned_number_4_octets NUMERIC
			x                                                DEFAULT 1]
			x	[-ext_community_ip                              IP]
			x	[-ext_community_as_4_bytes                      NUMERIC
			x                                                DEFAULT 1]
			x	[-ext_community_target_assigned_number_2_octets NUMERIC
			x                                                DEFAULT 1]
			x	[-ext_community_opaque_data                     HEX]
			x	[-ext_community_colorCObits                     CHOICES 00 01 10 11
			x                                                DEFAULT 00]
			x	[-ext_community_colorReservedBits               NUMERIC]
			x	[-ext_community_colorValue                      NUMERIC]
			x	[-ext_community_linkBandwidth                   NUMERIC]
			x	[-enable_override_peer_as_set_mode              CHOICES 0 1]
			x	[-as_set_mode                                   CHOICES include_as_seq
			x                                                CHOICES include_as_seq_conf
			x                                                CHOICES include_as_set
			x                                                CHOICES include_as_set_conf
			x                                                CHOICES no_include
			x                                                CHOICES prepend_as
			x                                                DEFAULT no_include]
			x	[-enable_as_path_segments                       CHOICES 0 1]
			x	[-no_of_as_path_segments                        RANGE 0-32
			x                                                DEFAULT 1]
			x	[-enable_as_path_segment                        CHOICES 0 1]
			x	[-as_path_segment_type                          CHOICES as_set
			x                                                CHOICES as_seq
			x                                                CHOICES as_set_confederation
			x                                                CHOICES as_seq_confederation
			x                                                DEFAULT as_set]
			x	[-number_of_as_number_in_segment                RANGE 0-50
			x                                                DEFAULT 1]
			x	[-as_path_segment_enable_as_number              CHOICES 0 1]
			x	[-as_path_segment_as_number                     NUMERIC
			x                                                DEFAULT 1]
			x	[-enable_cluster                                CHOICES 0 1]
			x	[-no_of_clusters                                RANGE 0-32
			x                                                DEFAULT 1]
			x	[-cluster_id                                    IP]
			x	[-active_tunnel_tlv                             CHOICES 0 1
			x                                                DEFAULT 1]
			x	[-no_of_segment_lists                           RANGE 1-10]
			x	[-enable_remote_endpoint_subtlv                 CHOICES 0 1
			x                                                DEFAULT 0]
			x	[-as_number                                     NUMERIC
			x                                                DEFAULT 0]
			x	[-address_family                                CHOICES ipv4 ipv6]
			x	[-ipv4_address                                  IPV4
			x                                                DEFAULT 0.0.0.0]
			x	[-ipv6_address                                  IPV6
			x                                                DEFAULT 0::0]
			x	[-enable_color_subtlv                           CHOICES 0 1
			x                                                DEFAULT 0]
			x	[-color_co_bits                                 CHOICES 00 01 10 11
			x                                                DEFAULT 00]
			x	[-color_reserved_bits                           NUMERIC
			x                                                DEFAULT 0]
			x	[-color_value                                   NUMERIC
			x                                                DEFAULT 0]
			x	[-enable_preference_sub_tlv                     CHOICES 0 1
			x                                                DEFAULT 0]
			x	[-perference                                    NUMERIC
			x                                                DEFAULT 0]
			x	[-enable_binding_subtlv                         CHOICES 0 1
			x                                                DEFAULT 0]
			x	[-binding_SIDType                               CHOICES nobinding sid4 ipv6sid]
			x	[-sid_4octet                                    NUMERIC
			x                                                DEFAULT 0]
			x	[-bsid_as_mpls_label                            CHOICES 0 1
			x                                                DEFAULT 1]
			x	[-tunnel_tlv_ipv6_sid                           IPV6
			x                                                DEFAULT 0::0]
			x	[-active_segment_lists                          CHOICES 0 1
			x                                                DEFAULT 1]
			x	[-enable_weight                                 CHOICES 0 1
			x                                                DEFAULT 0]
			x	[-weight                                        NUMERIC]
			x	[-no_of_segments                                RANGE 1-20]
			x	[-active_segments                               CHOICES 0 1
			x                                                DEFAULT 1]
			x	[-segment_type                                  CHOICES mplssid
			x                                                CHOICES ipv6sid
			x                                                CHOICES ipv4nodeaddress
			x                                                CHOICES ipv6nodeaddress
			x                                                CHOICES ipv4nodeaddressindex
			x                                                CHOICES ipv4localandremoteaddress
			x                                                CHOICES ipv6nodeaddressindex
			x                                                CHOICES ipv6localandremoteaddress]
			x	[-label                                         NUMERIC
			x                                                DEFAULT 16]
			x	[-traffic_class                                 NUMERIC
			x                                                DEFAULT 0]
			x	[-bottom_of_stack                               CHOICES 0 1
			x                                                DEFAULT 0]
			x	[-ttl                                           NUMERIC
			x                                                DEFAULT 255]
			x	[-ipv6_sid                                      IPV6
			x                                                DEFAULT 0::0]
			x	[-ipv4_nodeaddress                              IPV4
			x                                                DEFAULT 0.0.0.0]
			x	[-ipv6_nodeaddress                              IPV6
			x                                                DEFAULT 0::0]
			x	[-interface_index                               NUMERIC
			x                                                DEFAULT 0]
			x	[-ipv4_localaddress                             IPV4
			x                                                DEFAULT 0.0.0.0]
			x	[-ipv4_remoteaddress                            IPV4
			x                                                DEFAULT 0.0.0.0]
			x	[-ipv6_localaddress                             IPV6
			x                                                DEFAULT 0::0]
			x	[-ipv6_remoteaddress                            IPV6
			x                                                DEFAULT 0::0]
			x	[-optional_tlv_type                             CHOICES none mpls ipv6]
			x	[-optional_label                                NUMERIC
			x                                                DEFAULT 16]
			x	[-optional_traffic_class                        NUMERIC
			x                                                DEFAULT 0]
			x	[-optional_time_to_live                         NUMERIC
			x                                                DEFAULT 255]
			x	[-optional_ipv6_sid                             IPV6
			x                                                DEFAULT 0::0]
		
		Arguments:
			 	-mode
			 		This option defines the action to be taken on the BGP server.
			 		Valid choices are:
			    		create - Create the BGP SRTE Policies configuration
			    		enable - Enable the BGP SRTE Policies configuration, requires the use of -handle.
			    		modify - Modify the BGP SRTE Policies configuration, requires the use of -handle.
			 	-handle
			 		bgpSRTEPoliciesListV4: -handle is returned by procedure emulation_bgp_srte_policies_config when a IPv4 SRTE Policy is created or modified
			 		bgpSRTEPoliciesListV6: -handle is returned by procedure emulation_bgp_srte_policies_config when a IPv6 SRTE Policy is created or modified
			x	-no_of_srte_policies
			x		Number of SRTE Policies
			x	-active
			x		Select the Active check box to activate the SRTE Policies. This means that the SRTE Policies can be started or stopped and is usable in the state machine.
			x		If this check box is not selected, the element is not able to respond to any action including Start and Stop.
			x	-policy_type
			x		Set Policy Type for BGP SRTE Policies
			x		Valid choices are:
			x   		ipv4 - IPv4 Policy Type
			x   		ipv6 - IPv6 Policy Type
			x	-distinguisher
			x		Distinguisher for SRTE Policies
			x	-policy_color
			x		Policy Color for SRTE Policies
			x	-end_pointV4
			x		IPv4 End Point for SRTE Policies
			x	-end_pointV6
			x		IPv6 End Point for SRTE Policies
			x	-no_of_tunnels
			x		Number of Tunnel TLVs for SRTE Policies
			x	-enable_next_hop
			x		Enable Next Hop for SRTE Policies
			x	-set_next_hop
			x		Set IP Address of Next Hop for SRTE Policies
			x		Valid choices are:
			x   		manually - IP Address of the next hop will be selected manually
			x   		sameaslocalip - IP Address of the next hop will be same as local IP
			x	-set_next_hop_ip_type
			x		Set Next Hop IP Type for SRTE Policies
			x		Valid choices are:
			x   		ipv4 - Next Hop IP Type- IPv4
			x   		ipv6 - Next Hop IP Type- IPv6
			x	-ipv4_next_hop
			x		IPv4 Next Hop IP Address for SRTE Policies
			x	-ipv6_next_hop
			x		IPv6 Next Hop IP Address for SRTE Policies
			x	-enable_origin
			x		Enable Origin for SRTE Policies
			x	-origin
			x		Origin for SRTE Policies
			x		Valid choices are:
			x   		igp - Origin for SRTE Policies is IGP
			x   		egp - Origin for SRTE Policies is EGP
			x   		incomplete - Origin for SRTE Policies is Incomplete
			x	-enable_local_preference
			x		Enable Local Preference for SRTE Policies
			x	-local_preference
			x		Local Preference for SRTE Policies
			x	-enable_multi_exit_discriminator
			x		Enable Multi Exit Discriminator for SRTE Policies
			x	-multi_exit_discriminator
			x		Multi Exit Discriminator for SRTE Policies
			x	-enable_atomic_aggregate
			x		Enable Atomic Aggregate for SRTE Policies
			x	-enable_aggregator_id
			x		Enable Aggregator ID for SRTE Policies
			x	-aggregator_id
			x		Aggregator ID for SRTE Policies
			x	-aggregator_as
			x		Sets the AS asssociated with the Aggregator router id for SRTE Policies
			x	-enable_originator_id
			x		Enable Originator ID for SRTE Policies
			x	-originator_id
			x		Originator ID for the router that originated the rule for SRTE Policies
			x	-enable_add_path
			x		Enable Add Path for SRTE Policies
			x	-add_path_id
			x		Add Path ID for SRTE Policies
			x	-enable_community
			x		Enable Community for SRTE Policies
			x	-no_of_communities
			x		Number of Communities for SRTE Policies
			x	-community_type
			x		SRTE Policies Community Types
			x		Valid choices are:
			x   		no_export - Community type "No Export"
			x   		no_advertised - Community type "No Advertised"
			x   		noexport_subconfed - Community type "Noexport Subconfed"
			x   		manual - Community type "Manual"
			x   		llgr_stale - Community type "LLGR_STALE"
			x   		no_llgr - Community type "NO LLGR"
			x	-community_as_number
			x		SRTE Policies Communities AS Number
			x	-community_last_two_octets
			x		SRTE Policies Communities Last Two Octets
			x	-enable_extended_community
			x		Enable Ext Community for SRTE Policies
			x	-no_of_extended_community
			x		Number of Extended Communities for SRTE Policies
			x	-ext_communities_type
			x		SRTE Policies Extended Communities Type
			x		Valid choices are:
			x   		admin_as_two_octet - Extended Community type - Administrator AS2 octet
			x   		admin_ip - Extended Community type - Administrator IP
			x   		admin_as_four_octet - Extended Community type - Administrator AS4 octet
			x   		opaque - Extended Community type - Opaque data
			x   		evpn - Extended Community type - EVPN
			x   		admin_as_two_octet_link_bw - Extended Community type - Administrator AS2 Octet Link Bandwidth
			x	-ext_communities_subtype
			x		SRTE Policies Extended Communities SubType
			x		Valid choices are:
			x   		route_target - Extended Community sub type - Route target
			x   		origin - Extended Community sub type - Origin
			x   		extended_bandwidth - Extended Community sub type - Extended bandwidth
			x   		color - Extended Community sub type - Color
			x   		encapsulation - Extended Community sub type - encapsulation
			x   		mac_address - Extended Community sub type - MacAddress
			x	-ext_community_as_number
			x		SRTE Policies Extended Communities AS2 Number
			x	-ext_community_target_assigned_number_4_octets
			x		BGP SRTE Policies Extended Communities Target Assigned Number 4
			x	-ext_community_ip
			x		SRTE Policies Extended Communites IP
			x	-ext_community_as_4_bytes
			x		SRTE Policies Extended Community AS 4 Number
			x	-ext_community_target_assigned_number_2_octets
			x		SRTE Policies Extended Target Assigned Number 2
			x	-ext_community_opaque_data
			x		SRTE Policies Extended Communities Opaque Data (Hex)
			x	-ext_community_colorCObits
			x		SRTE Policies Extended Communities Color CO Bits
			x		Valid choices are:
			x   		00 - Extended Community Color CO Bits - 00
			x   		01 - Extended Community Color CO Bits - 01
			x   		10 - Extended Community Color CO Bits - 10
			x   		11 - Extended Community Color CO Bits - 11
			x	-ext_community_colorReservedBits
			x		SRTE Policies Extended Communities Color Reserved Bits
			x	-ext_community_colorValue
			x		SRTE Policies Extended Communities Color Value
			x	-ext_community_linkBandwidth
			x		SRTE Policies Extended Communities Link Bandwidth
			x	-enable_override_peer_as_set_mode
			x		Enable override Reer as set mode for SRTE Policies
			x	-as_set_mode
			x		Set mode for AS value for SRTE Policies
			x		Valid choices are:
			x   		include_as_seq - Include Local AS as AS-SEQ
			x   		include_as_seq_conf - Include Local AS as AS-SEQ-Confederation
			x   		include_as_set - Include Local AS as AS-SET
			x   		include_as_set_conf - Include Local AS as AS-SET-Confederation
			x   		no_include - Don't include Local AS
			x   		prepend_as - Prepend Local AS to first segment
			x	-enable_as_path_segments
			x		Enable AS Path Segments for IPv4 SRTE Policies
			x	-no_of_as_path_segments
			x		Number of AS Path Segments for IPv4 SRTE Policies
			x	-enable_as_path_segment
			x		Enable AS Path Segment for BGP SRTE Policies
			x	-as_path_segment_type
			x		AS Path Segment Type for BGP SRTE Policies
			x		Valid choices are:
			x   		as_set - AS Path Segment Type - Include Local AS as AS-SEQ
			x   		as_seq - AS Path Segment Type - Include Local AS as AS-SEQ-Confederation
			x   		as_set_confederation - AS Path Segment Type - Include Local AS as AS-SET
			x   		as_seq_confederation - AS Path Segment Type - Include Local AS as AS-SET-Confederation
			x	-number_of_as_number_in_segment
			x		Number of AS Path Segments for BGP SRTE Policies
			x	-as_path_segment_enable_as_number
			x		Enable AS number for BGP SRTE Policies
			x	-as_path_segment_as_number
			x		AS Path Segments AS Number for BGP SRTE Policies
			x	-enable_cluster
			x		Enable cluster for SRTE Policies
			x	-no_of_clusters
			x		Number of Clusters for SRTE Policies
			x	-cluster_id
			x		BGP LS Cluster ID for SRTE Policies
			x	-active_tunnel_tlv
			x		Select the Active check box to activate the Tunnel TLV in SRTE Policies. This means that the Tunnel TLV in SRTE Policies can be started or stopped and is usable in the state machine.
			x		If this check box is not selected, the element is not able to respond to any action including Start and Stop.
			x	-no_of_segment_lists
			x		Number of Segment Lists for SRTE Policies
			x	-enable_remote_endpoint_subtlv
			x		Enable Remote Endpoint Sub-TLV
			x	-as_number
			x		AS Number for Tunnel TLV
			x	-address_family
			x		Address Family for Tunnel TLV
			x		Valid choices are:
			x   		ipv4 - IPv4 Address Family
			x   		ipv6 - IPv6 Address Family
			x	-ipv4_address
			x		IPv4 Address for Tunnel TLV
			x	-ipv6_address
			x		IPv6 Address for Tunnel TLV
			x	-enable_color_subtlv
			x		Enable Color Sub-TLV for Tunnel TLV
			x	-color_co_bits
			x		Color CO Bits for Tunnel TLV
			x		Valid choices are:
			x   		00 - Color CO Bits - 00
			x   		01 - Color CO Bits - 01
			x   		10 - Color CO Bits - 10
			x   		11 - Color CO Bits - 11
			x	-color_reserved_bits
			x		Color Reserved Bits for Tunnel TLV
			x	-color_value
			x		Color Value for Tunnel TLV
			x	-enable_preference_sub_tlv
			x		Enable Preference Sub-TLV for Tunnel TLV
			x	-perference
			x		Preference for Tunnel TLV
			x	-enable_binding_subtlv
			x		Enable Binding Sub-TLV for Tunnel TLV
			x	-binding_SIDType
			x		Binding SID Type for Tunnel TLV
			x		Valid choices are:
			x   		nobinding - NoBinding
			x   		sid4 - 4 Octet SID
			x   		ipv6sid - IPv6 SID
			x	-sid_4octet
			x		4 Octet SID for Tunnel TLV
			x	-bsid_as_mpls_label
			x		BSID As MPLS Label for Tunnel TLV
			x	-tunnel_tlv_ipv6_sid
			x		IPv6 SID for Tunnel TLV
			x	-active_segment_lists
			x		Select the Active check box to activate the Sgement Lists in SRTE Policies. This means that the Sgement Lists in SRTE Policies can be started or stopped and is usable in the state machine.
			x		If this check box is not selected, the element is not able to respond to any action including Start and Stop.
			x	-enable_weight
			x		Enable Weight for Segment List
			x	-weight
			x		Weight for Segment Lists
			x	-no_of_segments
			x		Number of Segment per Segments Lists
			x	-active_segments
			x		Select the Active check box to activate the Sgements in SRTE Policies. This means that the Segments in SRTE Policies can be started or stopped and is usable in the state machine.
			x		If this check box is not selected, the element is not able to respond to any action including Start and Stop.
			x	-segment_type
			x		Segments Type for Segements
			x		Valid choices are:
			x   		mplssid - MPLS SID
			x   		ipv6sid - IPv6 SID
			x   		ipv4nodeaddress - IPv4 Node Address
			x   		ipv6nodeaddress - IPv6 Node Address
			x   		ipv4nodeaddressindex - IPv4 Node Address Index
			x   		ipv6nodeaddressindex - IPv6 Node Address Index
			x   		ipv6localandremoteaddress - IPv6 Local and Remote Address
			x	-label
			x		Label for Segments
			x	-traffic_class
			x		Traffic Class for Segments
			x	-bottom_of_stack
			x		Bottom Of Stack for Segment List
			x	-ttl
			x		Time to live for Segments
			x	-ipv6_sid
			x		IPv6 SID for Segments
			x	-ipv4_nodeaddress
			x		IPv4 Node address for Segments
			x	-ipv6_nodeaddress
			x		IPv6 Node address for Segments
			x	-interface_index
			x		Interface Index for Segments
			x	-ipv4_localaddress
			x		IPv4 Local address for Segments
			x	-ipv4_remoteaddress
			x		IPv4 Remote address for Segments
			x	-ipv6_localaddress
			x		IPv6 Local address for Segments
			x	-ipv6_remoteaddress
			x		IPv6 Remote address for Segments
			x	-optional_tlv_type
			x		Optional TLV Type for Segments
			x		Valid choices are:
			x   		none - Optional TLV Type not defined
			x   		mpls - Optional TLV Type MPLS
			x   		ipv6 - Optional TLV Type IPv6
			x	-optional_label
			x		Optional Label for Segments
			x	-optional_traffic_class
			x		Optional Traffic Class for Segments
			x	-optional_time_to_live
			x		Optional Time to live for Segments
			x	-optional_ipv6_sid
			x		Optional IPv6 SID for Segments
		
		Return Values:
		A list containing the bgpSRTEPoliciesListV6 protocol stack handles that were added by the command (if any).
			xkey:bgpSRTEPoliciesListV6_handle  value:A list containing the bgpSRTEPoliciesListV6 protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE
			 key:status                        value:$::SUCCESS | $::FAILURE
		When status is $::FAILURE, contains more information
			 key:log                           value:When status is $::FAILURE, contains more information
		Handle of bgpSRTEPoliciesListV4 configured
			 key:bgpSRTEPoliciesListV4_handle  value:Handle of bgpSRTEPoliciesListV4 configured
		Item Handle of any bgpSRTEPoliciesListV4 or bgpSRTEPoliciesListV6 configured
			 key:handles                       value:Item Handle of any bgpSRTEPoliciesListV4 or bgpSRTEPoliciesListV6 configured
		
		Examples:
		See files starting with BGP_ in the Samples subdirectory.  Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the BGP usage.
		See the BGP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		{status $::SUCCESS}
		{bgpSRTEPoliciesListV4 {/topology:1/deviceGroup:1/ethernet:1/ipv4:1/bgpIpv4Peer:1/bgpSRTEPoliciesListV4:1/}}
		{bgpSRTEPoliciesListV6 {/topology:1/deviceGroup:1/ethernet:1/ipv4:1/bgpIpv4Peer:1/bgpSRTEPoliciesListV6:1/}}
		
		Notes:
		Coded versus functional specification.
		When a -handle is provided with a BGP/BGP+ protocol stack handle or a protocol session handle, the api will create IPv4/IPv6 SRTE Policies
		When a -handle is provided with a BGP SRTE Policies Handle, the api will modify the created IPv4/IPv6 SRTE Policies
		
		See Also:
		
		"""
		return self._run_keyword("emulation_bgp_srte_policies_config", kwargs)

	def emulation_bondedgre_config(self, **kwargs):
		""" This procedure will configure BondedGRE with a provision to add config related parameters on a given interface.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_bondedgre_config
			x	[-port_handle             REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-reset                   FLAG]
			 	[-handle                  ANY]
			x	[-return_detailed_handles CHOICES 0 1
			x                          DEFAULT 0]
			 	[-mode                    CHOICES create
			                           CHOICES modify
			                           CHOICES delete
			                           CHOICES getAttribute
			                           DEFAULT create]
			x	[-attributeName           CHOICES bSessionInfo
			x                          CHOICES homeGatewayInfo
			x                          CHOICES errorCode
			x                          CHOICES dhcpIp]
			 	[-count                   RANGE 1-8000
			                           DEFAULT 1]
			x	[-id_name                 ANY]
			x	[-dsl_sync_rate           ANY]
			x	[-bypass_traffic          ANY]
			x	[-ipv6_prefix             ANY]
			x	[-ipv6_prefix_len         ANY]
			x	[-active                  ANY]
			x	[-create_full_stack       CHOICES 0 1
			x                          DEFAULT 0]
			x	[-haap_router             CHOICES 0 1]
			x	[-router_mac              MAC]
			x	[-key                     CHOICES 0 1]
			x	[-wait_for_lte            CHOICES 0 1]
			x	[-tunnel_type             CHOICES dsl lte]
		
		Arguments:
			x	-port_handle
			x		Ixia interface upon which to act.
			x	-reset
			x		If this option is selected, this will clear any BondedGRE device.
			 	-handle
			 		BondedGRE device handle for using the modes delete, modify, enable, and disable.
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			 	-mode
			 		Action to take on the port specified the handle argument.
			 		Valid choices are:
			    		create - Adds a new BondedGRE configuration on the port.
			    		modify - Modifies an existing BondedGRE configuration (specified by -handle).
			    		delete - Remove an existing BondedGRE configuration (specified by -handle).
			    		getAttribute - Get attribute status for existing BondedGRE configuration (specified by -handle).
			x	-attributeName
			x		Attribute name for fetching value.
			x		Valid choices are:
			x   		bSessionInfo - bSessionInfo
			x   		homeGatewayInfo - homeGatewayInfo
			x   		errorCode - errorCode
			x   		dhcpIp - dhcpIp
			 	-count
			 		Defines the number of BondedGRE devices to be configured on the -port_handle.
			x	-id_name
			x		This is a 40-byte string value(Allowed upto 80 bytes). It is used as the identification of the HG in the operator's network.
			x	-dsl_sync_rate
			x		DSL Synchronization Rate is used to notify the HAAP about the downstream bandwidth of the DSL link.
			x	-bypass_traffic
			x		Bypass Traffic Rate is used to inform the HG of how frequently the bypass bandwidth should be checked.
			x	-ipv6_prefix
			x		IPv6 Prefix Assigned to Host.
			x	-ipv6_prefix_len
			x		IPv6 Prefix length.
			x	-active
			x		Activate/Deactivate Configuration
			x	-create_full_stack
			x		flag to create full stack. this flag is introduced mainly for Scripgen Issue.
			x	-haap_router
			x		If enabled, MAC address will be same for all control messages from all tunnels.
			x	-router_mac
			x		MAC address of the emulated HAAP Router.
			x	-key
			x		If enabled then key will be included in the GRE header for control messages.
			x	-wait_for_lte
			x		If enabled then DSL will wait for LTE to start, otherwise DSL can start anytime.
			x	-tunnel_type
			x		Determines the Tunnel type to be used
			x		Valid choices are:
			x   		dsl -
			x   		lte -
		
		Return Values:
		A list containing the bondedgre device protocol stack handles that were added by the command (if any).
			xkey:bondedgre_device_handle  value:A list containing the bondedgre device protocol stack handles that were added by the command (if any).
		A list containing the dhcpv4 device protocol stack handles that were added by the command (if any).
			xkey:dhcpv4_device_handle     value:A list containing the dhcpv4 device protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:interface_handle         value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		$::SUCCESS or $::FAILURE
			 key:status                   value:$::SUCCESS or $::FAILURE
		If failure, will contain more information
			 key:log                      value:If failure, will contain more information
		BondedGRE device Handles Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:handle                   value:BondedGRE device Handles Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) Coded versus functional specification.
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle, interface_handle
		
		See Also:
		
		"""
		return self._run_keyword("emulation_bondedgre_config", kwargs)

	def emulation_bondedgre_control(self, **kwargs):
		""" This procedure is used to execute all actions for BondedGRE protocol.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_bondedgre_control
			 	[-port_handle REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle      ANY]
			x	[-index       NUMERIC
			x              DEFAULT 1]
			 	[-values      RANGE 1-10000]
			 	-mode         CHOICES stop
			               CHOICES start
			               CHOICES restart
			               CHOICES diagBondingTunnel
			               CHOICES diagDslTunnel
			               CHOICES diagLteTunnel
			               CHOICES endDiag
			               CHOICES switchDsl
			               CHOICES overflowLte
			               CHOICES dslLinkFailure
			               CHOICES lteLinkFailure
			               CHOICES tearDown
			               CHOICES resumehello
			               CHOICES stophello]
			x	[-error_code  NUMERIC
			x              DEFAULT 0]
		
		Arguments:
			 	-port_handle
			 		A list of ports on which to control the BondedGRE protocol. If this option
			 		is not present, the port in the handle option will be applied.
			 	-handle
			 		BondedGRE device handle.It is returned by emulation_bondedgre_config call.
			x	-index
			x		Index on which the action defined by the mode parameter will be applied.
			 	-values
			 		The values for action to trigger on Ixia interface.
			 	-mode
			 		This option defines the action to be taken on the BondedGRE Instance.
			 		Note: Valid options are:
			 		1)stop
			 		2)start
			 		3)restart
			 		4)diagBondingTunnel
			 		5)diagDslTunnel
			 		6)diagLteTunnel
			 		7)endDiag
			 		8)switchDsl
			 		9)overflowLte
			 		10)dslLinkFailure
			 		11)lteLinkFailure
			 		Valid choices are:
			    		stop - Sends a stop message for the given BondedGRE instance.
			    		start - Sends a start message for the given BondedGRE instance.
			    		restart - Sends a start message for the given BondedGRE instance.
			    		diagBondingTunnel - Sends a Bonding tunnel Diagnostic start message.
			    		diagDslTunnel - Sends a DSL tunnel Diagnostic start message.
			    		diagLteTunnel - Sends an LTE tunnel Diagnostic start message.
			    		endDiag - Sends an End diagnostic message for the tunnel.
			    		switchDsl - Sends a Message for switching to DSL tunnel.
			    		overflowLte - Sends a Message for Overflowing on LTE tunnel.
			    		dslLinkFailure - Sends a Message for Emulating DSL Link Failure.
			    		lteLinkFailure - Sends a Message for Emulating LTE Link Failure.
			    		tearDown - Sends a Message for Emulating Tunnel Tear down.
			    		resumehello - Sends a Message for Emulating Resume hello.
			    		stophello - Sends a Message for Emulating Stop hello.
			x	-error_code
			x		The error code for Tear down message
		
		Return Values:
		$::SUCCESS or $::FAILURE
			 key:status  value:$::SUCCESS or $::FAILURE
		If failure, will contain more information
			 key:log     value:If failure, will contain more information
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_bondedgre_control", kwargs)

	def emulation_bondedgre_info(self, **kwargs):
		""" Retrieves information about the BondedGRE protocol.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_bondedgre_info
			x	-mode         CHOICES per_port_stats
			x              CHOICES per_session_stats
			x              CHOICES clear_stats]
			 	-handle       ANY]
			 	[-port_handle REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
		
		Arguments:
			x	-mode
			x   		per_port_stats - Retrieves BondedGRE per port stats.
			x   		per_session_stats - Retrieves BondedGRE per session stats.
			x   		clear_stats - Clear BondedGRE statistics.
			 	-handle
			 		The BondedGRE handle to act upon.
			 	-port_handle
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                     value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                        value:If status is failure, detailed information provided.
		BondedGRE Up
			xkey:sessions_up                value:BondedGRE Up
		BondedGRE Down
			xkey:sessions_down              value:BondedGRE Down
		BondedGRE Not Started
			xkey:sessions_not_started       value:BondedGRE Not Started
		BondedGRE Total
			xkey:sessions_total             value:BondedGRE Total
		DSL Tunnel Up
			xkey:dsl_Tunnel_Up              value:DSL Tunnel Up
		LTE Tunnel Up
			xkey:lte_Tunnel_Up              value:LTE Tunnel Up
		Total Tunnel Up
			xkey:total_Tunnel_Up            value:Total Tunnel Up
		DSL Tunnel Down
			xkey:dsl_Tunnel_Down            value:DSL Tunnel Down
		LTE Tunnel Down
			xkey:lte_Tunnel_Down            value:LTE Tunnel Down
		Total Tunnel Down
			xkey:total_Tunnel_Down          value:Total Tunnel Down
		Setup Message Tx
			xkey:setup_Msg_Tx               value:Setup Message Tx
		Accept Message Rx
			xkey:accept_Msg_Rx              value:Accept Message Rx
		Setup Deny Message Rx
			xkey:setup_Deny_Msg_Rx          value:Setup Deny Message Rx
		Tunnel Hello Tx
			xkey:tunnel_Hello_Tx            value:Tunnel Hello Tx
		Tunnel Hello Rx
			xkey:tunnel_Hello_Rx            value:Tunnel Hello Rx
		Tunnel Tear Down Rx
			xkey:tunnel_TearDown_Rx         value:Tunnel Tear Down Rx
		Tunnel Notify Tx
			xkey:tunnel_Notify_Tx           value:Tunnel Notify Tx
		Tunnel Notify Rx
			xkey:tunnel_Notify_Rx           value:Tunnel Notify Rx
		Total GRE Messages Tx
			xkey:total_GRE_Msg_Tx           value:Total GRE Messages Tx
		Total GRE Messages Rx
			xkey:total_GRE_Msg_Rx           value:Total GRE Messages Rx
		Tunnel Verification
			xkey:tunnel_Verification        value:Tunnel Verification
		Switching to DSL Tunnel
			xkey:switching_To_Dsl_Tunnel    value:Switching to DSL Tunnel
		Overflowing to LTE Tunnel
			xkey:overflowing_To_Lte_Tunnel  value:Overflowing to LTE Tunnel
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_bondedgre_info", kwargs)

	def emulation_cfm_config(self, **kwargs):
		""" This procedure will configure CFM bridges. This protocol is available only when using IxTclNetwork. The GUI equivalent is in the section Protocols/Carrier Ethernet where CFM/Y.1731/PBB-TE is enabled.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_cfm_config
			 	-mode                              ANY
			 	-port_handle                       ANY
			 	[-ais_interval                     ANY]
			 	[-allow_cfm_maid_formats           ANY]
			 	[-bridge_id                        ANY]
			 	[-bridge_id_step                   ANY]
			 	[-count                            ANY]
			 	[-enable_ais                       ANY]
			 	[-enable_optional_tlv_validation   ANY]
			 	[-enable_out_of_sequence_detection ANY]
			 	[-ether_type                       ANY]
			 	[-garbage_collect_time             ANY]
			 	[-handle                           ANY]
			 	[-interface_handle                 ANY]
			 	[-mac_address_init                 ANY]
			 	[-mac_address_step                 ANY]
			 	[-operation_mode                   ANY]
			 	[-override_existence_check         ANY]
			 	[-override_tracking                ANY]
			 	[-receive_ccm                      ANY]
			 	[-reset                            ANY]
			 	[-send_ccm                         ANY]
			 	[-vlan_enable                      ANY]
			 	[-vlan_id                          ANY]
			 	[-vlan_id_step                     ANY]
			 	[-vlan_user_priority               ANY]
		
		Arguments:
			 	-mode
			 		Action to perform. This parameter is supported using the following:
			 		Valid choices are:
			    		create -Create new CFM Bridges on -port_handle.
			    		modify- - Modify CFM Bridge specified with -handle parameter.
			    		enable- - Enable CFM Bridges specified with -handle parameter.
			    		disable-Disable CFM Bridges specified with -handle parameter.
			    		remove-Remove CFM Bridges specified with -handle parameter.
			 	-port_handle
			 		Parameter -port_handle specifies the port to be configured with CFM. This parameter is supported using the following APIs: IxN.This parameter is used only when -mode is "create".
			 	-ais_interval
			 		The interval between AIS messages sent from this CFM bridge.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		one_sec - The interval is one second.
			    		one_min - The interval is one minute.
			 	-allow_cfm_maid_formats
			 		If checked, allows to use CFM's MD Name types and Short MA Name types when the Operation Mode is Y.1731. This parameter can be enabled and becomes active only when the operation mode is Y.1731. This parameter is disabled when operation mode is either CFM (IEEE 802.1ag) or PBB-TE.
			 	-bridge_id
			 		The bridge MAC address. This parameter is supported using the following APIs: IxN.
			 	-bridge_id_step
			 		The bridge MAC address step. This parameter is supported using the following APIs: IxN.
			 	-count
			 		Number of bridges to configure on port port_handle. This parameter is supported using the following APIs: IxN.
			 	-enable_ais
			 		If 1, enables the use of AIS messages. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0- Enable.
			    		1- Disable.
			 	-enable_optional_tlv_validation
			 		This parameter is configured for all CFM Bridges. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Enable.
			    		1- Disable.
			 	-enable_out_of_sequence_detection
			 		If 1, enables the detection of out of sequence CCM messages.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Enable.
			    		1- Disable.
			 	-ether_type
			 		Selects the ether type for the bridge. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		8902 - 0x8902.
			    		88E6 - 0x88E6.
			 	-garbage_collect_time
			 		Integer value denotes the interval for holding the expired database. This parameter is supported using the following APIs: IxN.
			 	-handle
			 		CFM Bridge handle. Used when -mode is modify|enable|disable|remove. When mode is "modify" this parameter supports only one CFM Bridge handle.When mode is enable|disable|remove this parameter supports a list of CFM Bridges. This parameter is supported using the following APIs: IxN.
			 	-interface_handle
			 		List of interface_handles to associate with CFM Bridges. Length must be equal to the value of -count parameter. Interface handles are obtained using ::<namespace>::interface_config procedure. This parameter is supported using the following APIs: IxN.This parameter is used only when -mode is create|modify.When -mode is "modify" this parameter will map the protocol interface specified with -interface_handle to the CFM Bridge specified with -handle parameter.
			 	-mac_address_init
			 		Protocol interface parameter. Starting MAC address. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
			 	-mac_address_step
			 		Protocol interface parameter. Mac address step. This parameter is supported using the following APIs: IxN.This parameter is used only when -mode is "create".
			 	-operation_mode
			 		Selects the type of CFM to enable. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		cfm - Uses the IEEE 802.1ag version.
			    		y1731 - Uses the ITU-T Y.1731 version.
			 	-override_existence_check
			 		If this option is enabled, the interface existence check is skipped but the list of interfaces is still created and maintained in order to keep track of existing interfaces if required. Using this option will speed up the the creation of the interfaces.
			 	-override_tracking
			 		If this option is enabled, the list of interfaces won't be created and maintained anymore, thus, speeding up the interfaces' creation even more. Also, it will enable -override_existence_check in case it was not already enabled because checking for interface existence becomes impossible if the the list of interfaces does not exist anymore.
			 	-receive_ccm
			 		If 1, the CFM protocol can receive CFM CCMs on this port.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0- Disabled.
			    		1- Enabled.
			 	-reset
			 		If present deletes all CFM bridges created on port -port_handle before creating new ones. This parameter is supported using the following APIs: IxN.
			 	-send_ccm
			 		If 1, the CFM protocol can send CFM CCMs from this port.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0- Disabled.
			    		1- Enabled.
			 	-vlan_enable
			 		Protocol interface paramater. This parameter is supported using the following APIs: IxN. Enables or disables vlan tag.This parameter is used only when -mode is "create".
			 	-vlan_id
			 		Protocol interface paramater. This parameter is supported using the following APIs: IxN.This parameter is used only when -mode is "create".
			 	-vlan_id_step
			 		Protocol interface paramater. This parameter is supported using the following APIs: IxN.This parameter is used only when -mode is "create".
			 	-vlan_user_priority
			 		Protocol interface parameter. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information.
			 key:log     value:When status is failure, contains more information.
		The list of CFM Bridge handles created.
			 key:handle  value:The list of CFM Bridge handles created.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_cfm_config", kwargs)

	def emulation_cfm_control(self, **kwargs):
		""" This procedure controls CFM actions.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_cfm_control
			 	-mode         ANY
			 	-port_handle  ANY
		
		Arguments:
			 	-mode
			 		Action to perform. This parameter is supported using the following:
			 		Valid choices are:
			    		start- Start CFM emulation.
			    		stop- Stop CFM emulation.
			 	-port_handle
			 		Parameter -port_handle specifies the port on which the CFM action is performed. Emulation is started | stopped for all CFM bridges on this port.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information.
			 key:log     value:When status is failure, contains more information.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_cfm_control", kwargs)

	def emulation_cfm_custom_tlv_config(self, **kwargs):
		""" This procedure configures Custom TLV properties on the bridge specified with bridge_handle.This protocol is available only when using IxTclNetwork.The GUI equivalent is in the section Protocols
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_cfm_custom_tlv_config
			 	[-bridge_handle  ANY]
			 	-mode            ANY
			 	[-count          ANY]
			 	[-handle         ANY]
			 	[-include_in_ccm ANY]
			 	[-include_in_lbm ANY]
			 	[-include_in_lbr ANY]
			 	[-include_in_ltm ANY]
			 	[-include_in_ltr ANY]
			 	[-length         ANY]
			 	[-reset          ANY]
			 	[-type           ANY]
			 	[-value          ANY]
			 	[-value_step     ANY]
		
		Arguments:
			 	-bridge_handle
			 		The value of the -bridge_handle parameter must be a bridge handle returned by ::<namespace>::emulation_cfm_config procedure.Mandatory when -mode is add. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
			 	-mode
			 		Action to perform. This parameter is supported using the following APIs: IxN. Valid choices are:
			    		create - Create new Custom TLV on -port_handle.
			    		modify - Modify Custom TLV specified with -handle parameter.
			    		enable - Enable Custom TLV specified with -handle parameter.
			    		disable - Disable Custom TLV specified with -handle parameter.
			    		remove - Remove Custom TLV specified with -handle parameter.
			 	-count
			 		Number of Custom TLVs that will be created for the CFM Bridge specified with -bridge_handle. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
			 	-handle
			 		CFM Custom TLV handle. Used when -mode is modify|enable|disable|remove.When mode is "modify" this parameter supports only one CFM Custom TLV handle.When mode is enable|disable|remove this parameter supports a list of CFM Custom TLV handles.This parameter is supported using the following APIs: IxN.
			 	-include_in_ccm
			 		If true, a custom TLV is included in the bridge CCM messages.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - False
			    		1 - True
			 	-include_in_lbm
			 		If true, a custom TLV is included in the bridge loopback messages.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - False.
			    		1 - True.
			 	-include_in_lbr
			 		If true, a custom TLV is included in the bridge loopback responses messages. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - False
			    		1 - True
			 	-include_in_ltm
			 		If true, a custom TLV is included in the bridge link trace messages. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - False
			    		1 - True
			 	-include_in_ltr
			 		If true, a custom TLV is included in the bridge link trace response messages. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - False
			    		1 - True
			 	-length
			 		TLV Length in octets. This parameter is supported using the following APIs: IxN.
			 	-reset
			 		If present deletes all CFM Custom TLVs created on CFM Bridge -bridge_handle before creating new ones. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
			 	-type
			 		TLV Type. This parameter is supported using the following APIs: IxN.
			 	-value
			 		TLV Value in HEX format. Use one of the following formats: 
			 		0x001122 
			 		{00 11 22} 
			 		00:11:22 
			 		00.11.22 
			 		001122 
			 		The number of octets must not exceed the value of the -length parameter. If the number of octets is smaller than the value of the -length parameter, then -value will be left padded with zeros. 
			 		This parameter is supported using the following APIs: IxN. 
			 	-value_step
			 		Step to increment TLV Value when -count > 1. HEX Field. Use one of the following formats:
			 		0x001122
			 		{00 11 22}
			 		00:11:22
			 		00.11.22
			 		001122
			 		The number of octets must not exceed the value of the -length parameter.If the number of octets is smaller than the value of the -length parameter,then -value_step will be left padded with zeros. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information.
			 key:log     value:When status is failure, contains more information.
		A list of Custom TLV handles.
			 key:handle  value:A list of Custom TLV handles.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_cfm_custom_tlv_config", kwargs)

	def emulation_cfm_info(self, **kwargs):
		""" This procedure will configure CFM statistic filters and gathers various CFM statistics based on the -mode parameter.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_cfm_info
			 	-mode                        ANY
			 	[-bridge_handle              ANY]
			 	[-user_cvlan                 ANY]
			 	[-user_cvlan_id              ANY]
			 	[-user_cvlan_priority        ANY]
			 	[-user_cvlan_tpid            ANY]
			 	[-user_delay_type            ANY]
			 	[-user_dst_mac_address       ANY]
			 	[-user_dst_mep_id            ANY]
			 	[-user_dst_type              ANY]
			 	[-user_learned_info_time_out ANY]
			 	[-user_mdlevel               ANY]
			 	[-user_periodic_oam_type     ANY]
			 	[-user_send_type             ANY]
			 	[-user_short_ma_name         ANY]
			 	[-user_short_ma_name_format  ANY]
			 	[-user_src_mac_address       ANY]
			 	[-user_src_mep_id            ANY]
			 	[-user_src_type              ANY]
			 	[-user_svlan                 ANY]
			 	[-user_svlan_id              ANY]
			 	[-user_svlan_priority        ANY]
			 	[-user_svlan_tpid            ANY]
			 	[-user_transaction_id        ANY]
			 	[-user_ttl_interval          ANY]
			 	[-user_usability_option      ANY]
		
		Arguments:
			 	-mode
			 		Deterines whether statistic filters are set or if statistic are gathered and returned in keyed lists. The supported parameters are:
			 		Valid choices are:
			    		set_filters -Configure statistic filtersfor bridge specified with -bridge_handle parameter.
			    		get_ccm- Return CMM learned information keys for bridge specified with -bridge_handle parameter.
			    		get_cfm_itu-Return CFM ITU delay measurement informaton keys for the CFM bridge specified with -bridge_handle parameter.
			    		get_cfm_lt- Return CFM Link Trace information keys for bridge specified with -bridge_handle parameter.
			    		get_cfm_lb- Return CFM Loopback information keys for bridge specified with -bridge_handle parameter.
			    		get_periodic_oam_lt-Return OAM link trace learned information keys for bridge specified with -bridge_handle parameter.
			    		get_periodic_oam_lb-Return OAM loopback learned information keys for bridge specified with -bridge_handle parameter.
			    		get_periodic_oam_dm -Return OAM delay measurement learned information keys for bridge specified with -bridge_handle parameter.
			    		get_all-Return all keys available.
			 	-bridge_handle
			 		CFM Bridge handle. Statistic filters will be set on this bridge handle if -mode is set_filters. Statistic keys will be returned from this bridge handle for all other modes.This parameter is supported using the following APIs: IxN.
			 	-user_cvlan
			 		Sets the bridge filter for learned information for a single VLAN. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		all_vlan_id - Filters on all VLANs.
			    		no_vlan_id - Filters on no VLAN.
			    		vlan_id - Filters on a VLAN specified in user_cvlan_Id.
			 	-user_cvlan_id
			 		Sets the single VLAN identifier for filtering learned information. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_cvlan_priority
			 		Sets the single VLAN priority for filtering learned information. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_cvlan_tpid
			 		Sets the single VLAN TPID for filtering learned information. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.Valid options are: 
			 		8100 
			 		9100 
			 		9200 
			 		88A8
			 	-user_delay_type
			 		Sets the type of delay measurement to use. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		dm - Delay Measurement. The amount of delay in seconds.
			    		dvm - Delay Variation Measurement. The difference in the amount of delay between messages.
			 	-user_dst_mac_address
			 		Filters on the destination MAC address specified. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_dst_mep_id
			 		Sets the MEP identifier for use with userSelectDstMepById. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_dst_type
			 		. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.Valid options are:mep_macmep_idmep_mac_allmep_id_all
			 	-user_learned_info_time_out
			 		The interval in millisecond for the learned record to timeout. Default: 5000.. Use this parameter when -mode is set_filters.This parameter is supported using the following APIs: IxN.
			 	-user_mdlevel
			 		Filters on the specified MD level. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - .
			    		1 - .
			    		2 - .
			    		3 - .
			    		4 - .
			    		5 - .
			    		6 - .
			    		7 - .
			    		all_md - Filters on all MD levels.
			 	-user_periodic_oam_type
			 		Sets the type of periodic OAM. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN. Valid options are:
			 		link_trace
			 		loopback
			 		delay_measurement
			 	-user_send_type
			 		Filters on the the send type. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN. Valid options are:
			 		unicast 
			 		multicast 
			 	-user_short_ma_name
			 		Filters on the specified Short MA Name. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_short_ma_name_format
			 		Filters on the Short MA Name Format. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		all_formats - Filters on all formats.
			    		primary_vid - .
			    		character_string - .
			    		two_octet_integer - .
			    		rfc2685_vpn_id - .
			 	-user_src_mac_address
			 		Filters on the specified source MAC address. Use this parameter when -mode #is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_src_mep_id
			 		Sets the MEP identifier for use with userSelectSrcMepById. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_src_type
			 		Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.Valid options are:
			 		mep_mac 
			 		mep_id 
			 		mep_mac_all 
			 		mep_id_all 
			 	-user_svlan
			 		Sets the bridge filter for learned information for a stacked VLAN. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		all_vlan_id - Filters on all VLANs.
			    		no_vlan_id - Filters on no VLAN.
			    		vlan_id - Filters on a VLAN specified in user_cvlan_Id.
			 	-user_svlan_id
			 		Sets the stacked VLAN identifier for filtering learned information. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_svlan_priority
			 		Sets the stacked VLAN priority for filtering learned information. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_svlan_tpid
			 		Sets the stacked VLAN TPID for filtering learned information. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.Valid options are:
			 		8100 
			 		9100 
			 		9200 
			 		88A8 
			 	-user_transaction_id
			 		The transaction identifier for the LTM packet if the configured MEP not found. Default: 1. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_ttl_interval
			 		Time to live value, in seconds. Default is 64. Use this parameter when -modeis set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_usability_option
			 		Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.Valid options are: manual, one_to_one, one_to_all, all_to_one, all_to_all
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                            value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information.
			 key:log                                               value:When status is failure, contains more information.
		If 1, indicates this MEP is receiving none of the remote MEPs' CCMs. Key returned when -mode is get_ccm.
			 key:ccm.all_rmep_dead                                 value:If 1, indicates this MEP is receiving none of the remote MEPs' CCMs. Key returned when -mode is get_ccm.
		The stacked VLAN identifier. Key returned when -mode is get_ccm.
			 key:ccm.c_vlan                                        value:The stacked VLAN identifier. Key returned when -mode is get_ccm.
		The Continuity Check interval. Key returned when -mode is get_ccm.
			 key:ccm.cci_interval                                  value:The Continuity Check interval. Key returned when -mode is get_ccm.
		If 1, a CCM defect error has been detected. Key returned when -mode is get_ccm.
			 key:ccm.err_ccm_defect                                value:If 1, a CCM defect error has been detected. Key returned when -mode is get_ccm.
		The MD level for the CCM message. Key returned when -mode is get_ccm.
			 key:ccm.md_level                                      value:The MD level for the CCM message. Key returned when -mode is get_ccm.
		The MD name associated with the CCM message. Key returned when -mode is get_ccm.
			 key:ccm.md_name                                       value:The MD name associated with the CCM message. Key returned when -mode is get_ccm.
		The MD Name Format of the CCM message. Key returned when -mode is get_ccm.
			 key:ccm.md_name_format                                value:The MD Name Format of the CCM message. Key returned when -mode is get_ccm.
		The MEP identifier of the CCM message. Key returned when -mode is get_ccm.
			 key:ccm.mep_id                                        value:The MEP identifier of the CCM message. Key returned when -mode is get_ccm.
		The MEP MAC address of the CCM message. Key returned when -mode is get_ccm.
			 key:ccm.mep_mac_address                               value:The MEP MAC address of the CCM message. Key returned when -mode is get_ccm.
		The number of Out of Sequence CCM messages received. Key returned when -mode is get_ccm.
			 key:ccm.out_ofsequence_ccm_count                      value:The number of Out of Sequence CCM messages received. Key returned when -mode is get_ccm.
		If 1, AIS messages have been detected. Key returned when -mode is get_ccm.
			 key:ccm.received_ais                                  value:If 1, AIS messages have been detected. Key returned when -mode is get_ccm.
		If 1, interface TLV defect messages have been detected. Key returned when -mode is get_ccm.
			 key:ccm.received_iface_tlv_defect                     value:If 1, interface TLV defect messages have been detected. Key returned when -mode is get_ccm.
		If 1, port TLV defect messages have been detected. Key returned when -mode is get_ccm.
			 key:ccm.received_port_tlv_defect                      value:If 1, port TLV defect messages have been detected. Key returned when -mode is get_ccm.
		If 1, RDI messages have been detected. Key returned when -mode is get_ccm.
			 key:ccm.received_rdi                                  value:If 1, RDI messages have been detected. Key returned when -mode is get_ccm.
		If 1, remote MEP CCM defect messages have been detected. Key returned when -mode is get_ccm.
			 key:ccm.rmep_ccm_defect                               value:If 1, remote MEP CCM defect messages have been detected. Key returned when -mode is get_ccm.
		The single VLAN associated with the CCM message. Key returned when -mode is get_ccm.
			 key:ccm.s_vlan                                        value:The single VLAN associated with the CCM message. Key returned when -mode is get_ccm.
		The Short MA Name associated with the CCM message. Key returned when -mode is get_ccm.
			 key:ccm.short_maname                                  value:The Short MA Name associated with the CCM message. Key returned when -mode is get_ccm.
		The Short MA Name format associated with the CCM message. Key returned when -mode is get_ccm.
			 key:ccm.short_maname_format                           value:The Short MA Name format associated with the CCM message. Key returned when -mode is get_ccm.
		Indicates the aggregate state of the Remote MEP State Machines. If 1, at least one of the Remote MEP State Machines is not receiving valid CCMs from its remote MEPs. If false, all Remote MEP State Machines are receiving valid CCMs. Key returned when -mode is get_ccm.
			 key:ccm.some_rmep_defect                              value:Indicates the aggregate state of the Remote MEP State Machines. If 1, at least one of the Remote MEP State Machines is not receiving valid CCMs from its remote MEPs. If false, all Remote MEP State Machines are receiving valid CCMs. Key returned when -mode is get_ccm.
		The learned C-VLAN identifier. Key returned when -mode is get_cfm_itu.
			 key:itu.c_vlan                                        value:The learned C-VLAN identifier. Key returned when -mode is get_cfm_itu.
		The learned destination MAC address for the bridge. Key returned when -mode is get_cfm_itu.
			 key:itu.dst_mac_address                               value:The learned destination MAC address for the bridge. Key returned when -mode is get_cfm_itu.
		The learned MD level for the bridge. Key returned when -mode is get_cfm_itu.
			 key:itu.md_level                                      value:The learned MD level for the bridge. Key returned when -mode is get_cfm_itu.
		The learned S-VLAN identifier. Key returned when -mode is get_cfm_itu.
			 key:itu.s_vlan                                        value:The learned S-VLAN identifier. Key returned when -mode is get_cfm_itu.
		The learned source MAC address for the bridge. Key returned when -mode is get_cfm_itu.
			 key:itu.src_mac_address                               value:The learned source MAC address for the bridge. Key returned when -mode is get_cfm_itu.
		The delay measurement in nanoseconds. Key returned when -mode is get_cfm_itu.
			 key:itu.value_in_nano_sec                             value:The delay measurement in nanoseconds. Key returned when -mode is get_cfm_itu.
		The delay measurement in seconds. Key returned when -mode is get_cfm_itu.
			 key:itu.value_in_sec                                  value:The delay measurement in seconds. Key returned when -mode is get_cfm_itu.
		The stacked VLAN identifier for the loopback message. Key returned when -mode is get_cfm_lb.
			 key:lb.c_vlan                                         value:The stacked VLAN identifier for the loopback message. Key returned when -mode is get_cfm_lb.
		The destination MAC address for the loopback message. Key returned when -mode is get_cfm_lb.
			 key:lb.dst_mac_address                                value:The destination MAC address for the loopback message. Key returned when -mode is get_cfm_lb.
		The MD level for the loopback message. Key returned when -mode is get_cfm_lb.
			 key:lb.md_level                                       value:The MD level for the loopback message. Key returned when -mode is get_cfm_lb.
		Indiates the status of the Ping. If true, the ping was responded to. Key returned when -mode is get_cfm_lb.
			 key:lb.reachability                                   value:Indiates the status of the Ping. If true, the ping was responded to. Key returned when -mode is get_cfm_lb.
		The round trip time for the loopback message. Key returned when -mode is get_cfm_lb.
			 key:lb.rtt                                            value:The round trip time for the loopback message. Key returned when -mode is get_cfm_lb.
		The single VLAN identifier for the loopback message. Key returned when -mode is get_cfm_lb.
			 key:lb.s_vlan                                         value:The single VLAN identifier for the loopback message. Key returned when -mode is get_cfm_lb.
		The source MAC address for the loopback message. Key returned when -mode is get_cfm_lb.
			 key:lb.src_mac_address                                value:The source MAC address for the loopback message. Key returned when -mode is get_cfm_lb.
		The transaction identifier attached to the loopback message. Key returned when -mode is get_cfm_lb.
			 key:lb.transaction_id                                 value:The transaction identifier attached to the loopback message. Key returned when -mode is get_cfm_lb.
		The stacked VLAN identifier for the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.c_vlan                                         value:The stacked VLAN identifier for the link trace message. Key returned when -mode is get_cfm_lt.
		The destination MAC address associated with the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.dst_mac_address                                value:The destination MAC address associated with the link trace message. Key returned when -mode is get_cfm_lt.
		The hop count for the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.hop_count                                      value:The hop count for the link trace message. Key returned when -mode is get_cfm_lt.
		The MD level associated with the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.md_level                                       value:The MD level associated with the link trace message. Key returned when -mode is get_cfm_lt.
		Indicates the status of the reply for the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.reply_status                                   value:Indicates the status of the reply for the link trace message. Key returned when -mode is get_cfm_lt.
		The single VLAN identifier associated with the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.s_vlan                                         value:The single VLAN identifier associated with the link trace message. Key returned when -mode is get_cfm_lt.
		The source MAC address associated with the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.src_mac_address                                value:The source MAC address associated with the link trace message. Key returned when -mode is get_cfm_lt.
		The transaction identifier sent with the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.transaction_id                                 value:The transaction identifier sent with the link trace message. Key returned when -mode is get_cfm_lt.
		The id set by HLT for this link trace message. Use it to get learned_hop keys.  Key returned when -mode is get_cfm_lt.
			 key:lt.hlt_id                                         value: The id set by HLT for this link trace message. Use it to get learned_hop keys.  Key returned when -mode is get_cfm_lt.
		The link trace message egress MAC address. Key returned when -mode is get_cfm_lt.
			 key:lt.learned_hop.<hlt_id>.egress_mac                value:The link trace message egress MAC address. Key returned when -mode is get_cfm_lt.
		The link trace message ingress MAC address. Key returned when -mode is get_cfm_lt.
			 key:lt.learned_hop.<hlt_id>.ingress_mac               value:The link trace message ingress MAC address. Key returned when -mode is get_cfm_lt.
		The time-to-live value of the link trace hop information, in milliseconds. Key returned when -mode is get_cfm_lt.
			 key:lt.learned_hop.<hlt_id>.reply_ttl                 value:The time-to-live value of the link trace hop information, in milliseconds. Key returned when -mode is get_cfm_lt.
		The learned average delay in nanoseconds. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.average_delay_nano_sec            value:The learned average delay in nanoseconds. Key returned when -mode is get_periodic_oam_dm.
		The learned average delay in seconds. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.average_delay_sec                 value:The learned average delay in seconds. Key returned when -mode is get_periodic_oam_dm.
		The learned C-VLAN identifier. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.c_vlan                            value:The learned C-VLAN identifier. Key returned when -mode is get_periodic_oam_dm.
		The learned number of DMMs sent. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.dmm_count_sent                    value:The learned number of DMMs sent. Key returned when -mode is get_periodic_oam_dm.
		The learned destination MAC address. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.dst_mac_address                   value:The learned destination MAC address. Key returned when -mode is get_periodic_oam_dm.
		The learned MD level for the periodic OAM. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.md_level                          value:The learned MD level for the periodic OAM. Key returned when -mode is get_periodic_oam_dm.
		The learned number of periodic OAM no replies. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.no_reply_count                    value:The learned number of periodic OAM no replies. Key returned when -mode is get_periodic_oam_dm.
		The learned most recent delay measurement in nanoseconds. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.recent_delay_nano_sec             value:The learned most recent delay measurement in nanoseconds. Key returned when -mode is get_periodic_oam_dm.
		The learned most recent delay measurement in seconds. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.recent_delay_sec                  value:The learned most recent delay measurement in seconds. Key returned when -mode is get_periodic_oam_dm.
		The learned S-VLAN identifier. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.s_vlan                            value:The learned S-VLAN identifier. Key returned when -mode is get_periodic_oam_dm.
		The learned source MAC address. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.src_mac_address                   value:The learned source MAC address. Key returned when -mode is get_periodic_oam_dm.
		The learned average periodic OAM Round-Trip-Time. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.average_rtt                       value:The learned average periodic OAM Round-Trip-Time. Key returned when -mode is get_periodic_oam_lb.
		The learned periodic OAM C-VLAN identifier. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.c_vlan                            value:The learned periodic OAM C-VLAN identifier. Key returned when -mode is get_periodic_oam_lb.
		The learned periodic OAM destination MAC address. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.dst_mac_address                   value:The learned periodic OAM destination MAC address. Key returned when -mode is get_periodic_oam_lb.
		The learned number of periodic OAM loopback messages sent. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.lbm_sent_count                    value:The learned number of periodic OAM loopback messages sent. Key returned when -mode is get_periodic_oam_lb.
		The learned MD level for the periodic OAM. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.md_level                          value:The learned MD level for the periodic OAM. Key returned when -mode is get_periodic_oam_lb.
		The learned number of periodic OAM no replies. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.no_reply_count                    value:The learned number of periodic OAM no replies. Key returned when -mode is get_periodic_oam_lb.
		Indicates the status of the Ping. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.recent_reachability               value:Indicates the status of the Ping. Key returned when -mode is get_periodic_oam_lb.
		Indicates the status of the round-trip-time. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.recent_rtt                        value:Indicates the status of the round-trip-time. Key returned when -mode is get_periodic_oam_lb.
		The learned periodic OAM S-VLAN identifier. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.s_vlan                            value:The learned periodic OAM S-VLAN identifier. Key returned when -mode is get_periodic_oam_lb.
		The learned periodic OAM source MAC address. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.src_mac_address                   value:The learned periodic OAM source MAC address. Key returned when -mode is get_periodic_oam_lb.
		The learned average hop count. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.average_hop_count                 value:The learned average hop count. Key returned when -mode is get_periodic_oam_lt.
		The learned C-VLAN identifier. (CFM only). Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.c_vlan                            value:The learned C-VLAN identifier. (CFM only). Key returned when -mode is get_periodic_oam_lt.
		The learned number of complete replies. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.complete_reply_count              value:The learned number of complete replies. Key returned when -mode is get_periodic_oam_lt.
		The learned destination MAC address. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.dst_mac_address                   value:The learned destination MAC address. Key returned when -mode is get_periodic_oam_lt.
		The learned number of Link Trace messages sent. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.ltm_sent_count                    value:The learned number of Link Trace messages sent. Key returned when -mode is get_periodic_oam_lt.
		The learned MD level. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.md_level                          value:The learned MD level. Key returned when -mode is get_periodic_oam_lt.
		The learned number of no replies. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.no_reply_count                    value:The learned number of no replies. Key returned when -mode is get_periodic_oam_lt.
		The learned number of partial replies. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.partial_reply_count               value:The learned number of partial replies. Key returned when -mode is get_periodic_oam_lt.
		The learned recent hop count. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.recent_hop_count                  value:The learned recent hop count. Key returned when -mode is get_periodic_oam_lt.
		The learned recent hops. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.recent_hops                       value:The learned recent hops. Key returned when -mode is get_periodic_oam_lt.
		The learned recent replies. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.recent_reply_status               value:The learned recent replies. Key returned when -mode is get_periodic_oam_lt.
		The learned S-VLAN identifier. (CFM only). Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.s_vlan                            value:The learned S-VLAN identifier. (CFM only). Key returned when -mode is get_periodic_oam_lt.
		The learned source MAC address. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.src_mac_address                   value:The learned source MAC address. Key returned when -mode is get_periodic_oam_lt.
		The id set by HLT for this link trace message. Use it to get learned_hop keys.  Key returned when -mode is get_cfm_lt.
			 key:periodic_oam_lt.hlt_id                            value: The id set by HLT for this link trace message. Use it to get learned_hop keys.  Key returned when -mode is get_cfm_lt.
		The link trace message egress MAC address. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.learned_hop.<hlt_id>.egress_mac   value:The link trace message egress MAC address. Key returned when -mode is get_periodic_oam_lt.
		The link trace message ingress MAC address. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.learned_hop.<hlt_id>.ingress_mac  value:The link trace message ingress MAC address. Key returned when -mode is get_periodic_oam_lt.
		The time-to-live value of the link trace hop information, in milliseconds. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.learned_hop.<hlt_id>.reply_ttl    value:The time-to-live value of the link trace hop information, in milliseconds. Key returned when -mode is get_periodic_oam_lt.
		The learned error string for the delay measurement
			 key:delay_learned_error_string                        value:The learned error string for the delay measurement
		If true, indicates the delay packet was sent
			 key:is_delay_learned_packet_sent                      value:If true, indicates the delay packet was sent
		If true, indicates if the configured MEP for the loopback measurement was found
			 key:is_lblearned_config_mep                           value:If true, indicates if the configured MEP for the loopback measurement was found
		If true, indicates the loopback packet was sent
			 key:is_lblearned_packet_sent                          value:If true, indicates the loopback packet was sent
		If true, indicates if the configured MEP for the link trace measurement was found
			 key:is_ltlearned_config_mep                           value:If true, indicates if the configured MEP for the link trace measurement was found
		If true, indicates the link trace packet was sent
			 key:is_ltlearned_packet_sent                          value:If true, indicates the link trace packet was sent
		The learned error string for the loopback measurement
			 key:lb_learned_error_string                           value:The learned error string for the loopback measurement
		The learned error string for the link trace measurement
			 key:lt_learned_error_string                           value:The learned error string for the link trace measurement
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_cfm_info", kwargs)

	def emulation_cfm_links_config(self, **kwargs):
		""" This procedure configures Link object properties on the bridge specified with bridge_handle.This protocol is available only when using IxTclNetwork.The GUI equivalent is in the section Protocols
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_cfm_links_config
			 	[-bridge_handle                  ANY]
			 	-mode                            ANY
			 	[-count                          ANY]
			 	[-handle                         ANY]
			 	[-link_type                      ANY]
			 	[-mip_mep_broadcast_handle_count ANY]
			 	[-mip_mep_broadcast_handle_list  ANY]
			 	[-mip_mep_outwards_handle_list   ANY]
			 	[-mip_mep_towards_handle_list    ANY]
			 	[-reset                          ANY]
		
		Arguments:
			 	-bridge_handle
			 		The value of the -bridge_handle parameter must be a bridge handle returned by ::<namespace>::emulation_cfm_config procedure.Mandatory when -mode is add. This parameter is supported using the following APIs: IxN.
			 	-mode
			 		Action to perform. This parameter is supported using the following:
			 		Valid choices are:
			    		create - Create new Link object on -port_handle.
			    		modify - Modify Link object specified with -handle parameter.
			    		enable - Enable Link object specified with -handle parameter.
			    		disable - Disable Link object specified with -handle parameter.
			    		remove - Remove Link object specified with -handle parameter.
			    		stop- Stop CFM emulation.
			 	-count
			 		Number of Link objects that will be created for the CFM Bridge specified with -bridge_handle. This parameter is supported using the following APIs: IxN.
			 	-handle
			 		CFM Link object handle. Used when -mode is modify|enable|disable|remove.When mode is "modify" this parameter supports only one CFM Link handle.When mode is enable|disable|remove this parameter supports a list of CFM Link handles.This parameter is supported using the following APIs: IxN.
			 	-link_type
			 		Sets the link type. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		broadcast - Link is a broadcast.
			    		linkp2p - Link is a point-to-point link.
			 	-mip_mep_broadcast_handle_count
			 		Number of mip_mep handles to use for each link (when count > 1).If the mip_mep_broadcast_handle_list is depleted ($count * mip_mep_broadcast_handle_count > length of mip_mep_broadcast_handle_list) the links will have no mip_mep_broadcast_handles. The mip mep handles from mip_mep_broadcast_handle_list will NOT be distributed round robin.This parameter is supported using the following APIs: IxN.
			 	-mip_mep_broadcast_handle_list
			 		List of handles from ::<namespace>::emulation_cfm_mip_mep_config. Only when -link_typebroadcast type. If the mip_mep_broadcast_handle_list is depleted ($count * mip_mep_broadcast_handle_count > length of mip_mep_broadcast_handle_list) the links will have no mip_mep_broadcast_handles. The mip mep handles from mip_mep_broadcast_handle_list will NOT be distributed round robin.This parameter is supported using the following APIs: IxN.
			 	-mip_mep_outwards_handle_list
			 		List of handles returned by ::<namespace>::emulation_cfm_mip_mep_config. Length must zero or equal to the value specified with -count parameter. The handles from mip_mep_outwards_handle_list are mapped one to one with the handles from mip_mep_towards_handle_list based on the index in the list. This parameter is supported using the following APIs: IxN.
			 	-mip_mep_towards_handle_list
			 		List of handles returned by ::<namespace>::emulation_cfm_mip_mep_config. Length must zero or equal to the value specified with -count parameter. The handles from mip_mep_outwards_handle_list are mapped one to one with the handles from mip_mep_towards_handle_list based on the index in the list. This parameter is supported using the following APIs: IxN.
			 	-reset
			 		If present deletes all CFM Link objects created on CFM Bridge -bridge_handle before creating new ones. This parameter is supported using the following APIs: IxN.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information.
			 key:log     value:When status is failure, contains more information.
		A list of Link object handles.
			 key:handle  value:A list of Link object handles.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_cfm_links_config", kwargs)

	def emulation_cfm_md_meg_config(self, **kwargs):
		""" This procedure configures the CFM Maintenance Domain properties.This protocol is available only when using IxTclNetwork.The GUI equivalent is in the section Protocols
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_cfm_md_meg_config
			 	[-bridge_handle                  ANY]
			 	-mode                            ANY
			 	[-count                          ANY]
			 	[-handle                         ANY]
			 	[-level_id_repeat_count          ANY]
			 	[-level_id_start                 ANY]
			 	[-level_id_step                  ANY]
			 	[-name                           ANY]
			 	[-name_format                    ANY]
			 	[-name_mac_repeat_count          ANY]
			 	[-name_mac_step                  ANY]
			 	[-name_wildcard_enable           ANY]
			 	[-reset                          ANY]
			 	[-wildcard_question_repeat_count ANY]
			 	[-wildcard_question_start        ANY]
			 	[-wildcard_question_step         ANY]
		
		Arguments:
			 	-bridge_handle
			 		The value of the -bridge_handle parameter must be a bridge handle returned by ::<namespace>::emulation_cfm_config procedure. CFM Maintenance Domain properties will be asociated with the CFM Bridge specified with this parameter.Mandatory when -mode is add.This parameter is supported using the following APIs: IxN.
			 	-mode
			 		Action to perform. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		create - Create new CFM Maintenance Domains on -port_handle.
			    		modify - Modify CFM Maintenance Domain specified with the -handle parameter.
			    		enable - Enable CFM Maintenance Domains specified with the -handle parameter.
			    		disable - Disable CFM Maintenance Domains specified with the -handle parameter.
			    		remove - Remove CFM Maintenance Domains specified with the -handle parameter.
			 	-count
			 		Number of CFM Maintenance Domain that will be created for the CFM Bridge specified with -bridge_handle. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
			 	-handle
			 		CFM Maintenance Domain handle. Used when -mode is modify|enable|disable|remove.When mode is "modify" this parameter supports only one CFM Maintenance Domain handle.When mode is enable|disable|remove this parameter supports a list of CFM Maintenance Domain handles.This parameter is supported using the following APIs: IxN.
			 	-level_id_repeat_count
			 		Configure how many CFM Maintenance Domains will be configured before level_id_start value is incremented. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
			 	-level_id_start
			 		Sets the MD level identifier starting value. This parameter is supported using the following APIs: IxN.
			 	-level_id_step
			 		Increment step for level_id_start when -count > 1. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
			 	-name
			 		Sets the MD name. This parameter is supported using the following APIs: IxN.
			 	-name_format
			 		Sets the MD Name format. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		none - (no MD name format).
			    		string - Parameter -name is used to configure the MD Name. Use '?' to configure wildcard.
			    		domain_name - Parameter -name is used to configure the MD Name. Use '?' to configure wildcard.
			    		mac_plus_2_octets - Parameter -name is used to configure MD Name (MAC Address format plus two octets, e.g. 00:11:22:33:44:55:66:77).
			 	-name_mac_repeat_count
			 		Determines how many Maintenance Domains are configured before the MD name is incremented. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
			 	-name_mac_step
			 		When -name_format is mac_plus_2_octets this will be the step used to increment the 8 octet value from the -name parameter. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
			 	-name_wildcard_enable
			 		Enable wildcard incrementing for MD Name when -name_format is string or domain_name. Wildcard '?' will be substituted in the -name parameter value with value of -wildcard_start parameter and incremented using wildcard_step parameter. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".0 - Disable.1 - Enable.
			 	-reset
			 		If present deletes all CFM Maintenance Domains created on CFM Bridge 'bridge_handle' before creating new ones. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
			 	-wildcard_question_repeat_count
			 		Determines how many Maintenance Domains are configured before wildcard is incremented. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
			 	-wildcard_question_start
			 		Starting value for wildcard substitution. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
			 	-wildcard_question_step
			 		Step value for the wildcard substitution. This parameter is supportedusing the following APIs: IxN. This parameter is used only when -mode is "create".
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information.
			 key:log     value:When status is failure, contains more information.
		The list of CFM Maintenance Domain handles created.
			 key:handle  value:The list of CFM Maintenance Domain handles created.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_cfm_md_meg_config", kwargs)

	def emulation_cfm_mip_mep_config(self, **kwargs):
		""" This procedure configures the Maintenance Point properties. This protocol is available only when using IxTclNetwork. The GUI equivalent is in the section Protocols/Carrier Ethernet where CFM/Y.1731/PBB-TE is enabled.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_cfm_mip_mep_config
			 	[-bridge_handle                        ANY]
			 	-mode                                  ANY
			 	[-add_ccm_custom_tlvs                  ANY]
			 	[-add_data_tlv                         ANY]
			 	[-add_interface_status_tlv             ANY]
			 	[-add_lbm_custom_tlvs                  ANY]
			 	[-add_lbr_custom_tlvs                  ANY]
			 	[-add_ltm_custom_tlvs                  ANY]
			 	[-add_ltr_custom_tlvs                  ANY]
			 	[-add_organization_specific_tlv        ANY]
			 	[-add_port_status_tlv                  ANY]
			 	[-add_sender_id_tlv                    ANY]
			 	[-auto_dm_all_destination              ANY]
			 	[-auto_dm_destination                  ANY]
			 	[-auto_dm_iteration                    ANY]
			 	[-auto_dm_timeout                      ANY]
			 	[-auto_dm_timer                        ANY]
			 	[-auto_lb_all_destination              ANY]
			 	[-auto_lb_destination                  ANY]
			 	[-auto_lb_iteration                    ANY]
			 	[-auto_lb_timeout                      ANY]
			 	[-auto_lb_timer                        ANY]
			 	[-auto_lt_all_destination              ANY]
			 	[-auto_lt_destination                  ANY]
			 	[-auto_lt_iteration                    ANY]
			 	[-auto_lt_timeout                      ANY]
			 	[-auto_lt_timer                        ANY]
			 	[-cci_interval                         ANY]
			 	[-ccm_priority                         ANY]
			 	[-chassis_id                           ANY]
			 	[-chassis_id_length                    ANY]
			 	[-chassis_id_step                      ANY]
			 	[-chassis_id_sub_type                  ANY]
			 	[-count                                ANY]
			 	[-data_tlv_length                      ANY]
			 	[-data_tlv_step                        ANY]
			 	[-data_tlv_value                       ANY]
			 	[-dmm_priority                         ANY]
			 	[-enable_auto_dm                       ANY]
			 	[-enable_auto_lb                       ANY]
			 	[-enable_auto_lt                       ANY]
			 	[-handle                               ANY]
			 	[-lbm_priority                         ANY]
			 	[-ltm_priority                         ANY]
			 	[-mac_address                          ANY]
			 	[-mac_address_step                     ANY]
			 	[-management_address                   ANY]
			 	[-management_address_step              ANY]
			 	[-management_address_domain            ANY]
			 	[-management_address_domain_length     ANY]
			 	[-management_address_domain_step       ANY]
			 	[-management_address_length            ANY]
			 	[-md_meg_handle_distribution           ANY]
			 	[-md_meg_handle_list                   ANY]
			 	[-md_meg_handle_repeat_count           ANY]
			 	[-meg_id                               ANY]
			 	[-meg_id_format                        ANY]
			 	[-mep_id                               ANY]
			 	[-mep_id_step                          ANY]
			 	[-mip_id                               ANY]
			 	[-mip_id_step                          ANY]
			 	[-mp_type                              ANY]
			 	[-organization_specific_tlv_length     ANY]
			 	[-organization_specific_tlv_value      ANY]
			 	[-organization_specific_tlv_value_step ANY]
			 	[-override_vlan_priority               ANY]
			 	[-reset                                ANY]
			 	[-short_ma_name                        ANY]
			 	[-short_ma_name_format                 ANY]
			 	[-ttl                                  ANY]
			 	[-vlan_handle_list                     ANY]
			 	[-vlan_handle_list_distribution        ANY]
			 	[-vlan_handle_list_repeat_count        ANY]
		
		Arguments:
			 	-bridge_handle
			 		The value of the -bridge_handle parameter must be a bridge handle returned by ::<namespace>::emulation_cfm_config procedure. Maintenance Point properties will be asociated with the CFM Bridge specified with this parameter.Mandatory when -mode is add.This parameter is supported using the following APIs: IxN.
			 	-mode
			 		Action to perform. This parameter is supported using the following
			 		Valid choices are:
			    		create - Create new Maintenance Points on -port_handle.
			    		modify - Modify Maintenance Point specified with -handle parameter.
			    		enable - Enable Maintenance Points specified with -handle parameter.
			    		disable - Disable Maintenance Points specified with -handle parameter.
			    		remove - Remove Maintenance Points specified with -handle parameter.
			 	-add_ccm_custom_tlvs
			 		If true, adds a custom CCM TLV to bridge messages. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-add_data_tlv
			 		If true, adds a data TLV to bridge messages. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-add_interface_status_tlv
			 		If true, adds an interface status TLV to bridge messages.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-add_lbm_custom_tlvs
			 		If true, adds a custom loopback message TLV to bridge messages.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-add_lbr_custom_tlvs
			 		If true, adds a custom loopback response message TLV to bridge messages. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-add_ltm_custom_tlvs
			 		If true, adds a custom link trace message TLV to bridge messages.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-add_ltr_custom_tlvs
			 		If true, adds a custom link trace message TLV to bridge messages.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-add_organization_specific_tlv
			 		If true, adds a custom organization specific message TLV to bridge messages. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-add_port_status_tlv
			 		If true, adds a custom port statust message TLV to bridge messages. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-add_sender_id_tlv
			 		If true, adds a custom sender ID message TLV to bridge messages.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-auto_dm_all_destination
			 		If true, enables the automatic sending of DM Messages.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-auto_dm_destination
			 		The sent MAC address for the DM, if auto_dm_all_destination is set to true. This parameter is supported using the following APIs: IxN.
			 	-auto_dm_iteration
			 		The count for how many times DMMs will be transmitted. Default is 0 (no limit). This parameter is supported using the following APIs: IxN.
			 	-auto_dm_timeout
			 		The timeout period in seconds to wait for a response to DMMs. This value should be less than the Auto LB Timer. This parameter is supported using the following APIs: IxN.
			 	-auto_dm_timer
			 		The time period in seconds between DMMs. Default is 60.This parameter is supported using the following APIs: IxN.
			 	-auto_lb_all_destination
			 		If true, enables the automatic sending of Loopback Messages.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-auto_lb_destination
			 		Sets the loopback destination MAC address. This parameter is supported using the following APIs: IxN.
			 	-auto_lb_iteration
			 		The count for how many times LBM will be transmitted. Default is 0 (no limit). This parameter is supported using the following APIs: IxN.
			 	-auto_lb_timeout
			 		The timeout period in seconds to wait for a response to LTMs. This value should be less than the Auto LT Timer. Default is 30.This parameter is supported using the following APIs: IxN.
			 	-auto_lb_timer
			 		The time period in seconds between LBMs. Default is 60.This parameter is supported using the following APIs: IxN.
			 	-auto_lt_all_destination
			 		If true, enables the automatic sending to Link Trace Messages.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-auto_lt_destination
			 		Sets the link trance destination MAC address. This parameter is supported using the following APIs: IxN.
			 	-auto_lt_iteration
			 		The count for how many times LTM will be transmitted. Default is 0 (no limit). This parameter is supported using the following APIs: IxN.
			 	-auto_lt_timeout
			 		The timeout period in seconds to wait for a response to LTMs. This value should be less than the Auto LT Timer. Default is 30.This parameter is supported using the following APIs: IxN.
			 	-auto_lt_timer
			 		The time period in seconds between LTMs. This parameter is supported using the following APIs: IxN.
			 	-cci_interval
			 		Sets the Continuity Check Interval (CCI). This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		3.33msec - Enable.
			    		10msec - Enable.
			    		100msec - Enable.
			    		1sec - Enable.
			    		10sec - Enable.
			    		1min - Enable.
			    		10min - Enable.
			 	-ccm_priority
			 		Sets the priority for Continuity Check Messages. This parameter is supported using the following APIs: IxN.
			 	-chassis_id
			 		Sets the chassis identification. TLV Value in HEX format. Use one of the following formats: 
			 		0x001122 
			 		{00 11 22} 
			 		00:11:22 
			 		00.11.22 
			 		001122 
			 		The number of octets must not exceed the value of the -chassis_id_length parameter. 
			 		If the number of octets is smaller than the value of the -chassis_id_length parameter, then -chassis_id will be left padded with zeros. 
			 		This parameter is supported using the following APIs: IxN. 
			 	-chassis_id_length
			 		Sets the length of the Chassis ID field. This parameter is supported using the following APIs: IxN.
			 	-chassis_id_step
			 		Step TLV Value for -chassis_id when -count > 1 in HEX format. 
			 		Sets the chassis increment step when count >1. This will take Hex value as input (0-255 byte). Use one of the following formats: 
			 		0x001122 
			 		{00 11 22} 
			 		00:11:22 
			 		00.11.22 
			 		001122 
			 		The number of octets must not exceed the value of the -chassis_id_length parameter.If the number of octets is smaller than the value of the -chassis_id_length parameter, then -chassis_id_step will be left padded with zeros. 
			 		This parameter is used only when -mode is "create".This parameter is supported using the following APIs: IxN. 
			 	-chassis_id_sub_type
			 		Sets the chassis identifier sub-type for the optional TLV messages. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		chassis_component - Enable.
			    		interface_alias - Enable.
			    		port_component - Enable.
			    		mac_address - Enable.
			    		network_address - Enable.
			    		interface_name - Enable.
			    		locally_assigned - Enable.
			 	-count
			 		Number of Maintenance Point that will be created for the CFM Bridge specified with -bridge_handle. This parameter is used only when -mode is "create". This parameter is supported using the following APIs: IxN.
			 	-data_tlv_length
			 		Sets the length of the Data TLV field. This parameter is supported using the following APIs: IxN.
			 	-data_tlv_step
			 		Step TLV Value for -data_tlv_value when -count > 1 in HEX format. 
			 		This attribute will take Hex value of data. Increment step for data_tlv_value. 
			 		Use one of the following formats: 
			 		0x001122 
			 		{00 11 22} 
			 		00:11:22 
			 		00.11.22 
			 		001122 
			 		The number of octets must not exceed the value of the -data_tlv_length parameter.If the number of octets is smaller than the value of the -data_tlv_length parameter, then -data_tlv_step will be left padded with zeros. 
			 		This parameter is used only when -mode is "create".This parameter is supported using the following APIs: IxN. 
			 	-data_tlv_value
			 		This attribute will take Hex value of data. This data TLV will be added both for periodic LBM and requested LBM transmit. 
			 		TLV Value in HEX format. Use one of the following formats: 
			 		0x001122 
			 		{00 11 22} 
			 		00:11:22 
			 		00.11.22 
			 		001122 
			 		The number of octets must not exceed the value of the -data_tlv_length parameter. 
			 		If the number of octets is smaller than the value of the -data_tlv_length parameter, then -data_tlv_value will be left padded with zeros.This parameter is supported using the following APIs: IxN. 
			 	-dmm_priority
			 		Sets the priority for DM Messages. This priority will be used only for periodic DMMs. This parameter is supported using the following APIs: IxN.
			 	-enable_auto_dm
			 		If true, enables the automatic sending of DM Messages.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-enable_auto_lb
			 		If true, enables the automatic sending of Loopback messages.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-enable_auto_lt
			 		If true, enables the automatic sending of Link Trace messages.This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-handle
			 		CFM Maintenance Point handle. Used when -mode is modify|enable|disable|remove.When mode is "modify" this parameter supports only one CFM Maintenance Point handle.When mode is enable|disable|remove this parameter supports a list of CFM Maintenance Point handles.This parameter is supported using the following APIs: IxN.
			 	-lbm_priority
			 		Sets the priority for Loopback Messages. This priority will be used only for periodic LBMs. This parameter is supported using the following APIs: IxN.
			 	-ltm_priority
			 		Sets the priority for Link Trace Messages. This priority will be used only for periodic LTMs. This parameter is supported using the following APIs: IxN.
			 	-mac_address
			 		The MAC address of the MP. This parameter is supported using the following APIs: IxN.
			 	-mac_address_step
			 		The MAC address step when -count > 1. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is "create".
			 	-management_address
			 		TLV Value in HEX format. Sets the MP management address. Input type is HEX (0-255 byte).Use one of the following formats: 
			 		0x001122 
			 		{00 11 22} 
			 		00:11:22 
			 		00.11.22 
			 		001122 
			 		The number of octets must not exceed the value of the -management_address_length parameter. 
			 		If the number of octets is smaller than the value of the -management_address_length parameter, then -management_address will be left padded with zeros. 
			 		This parameter is supported using the following APIs: IxN. 
			 	-management_address_step
			 		Step for TLV Value in HEX format when -count > 1.Sets the MP management address step when -count > 1. This will take HEX input (0-255 byte).Use one of the following formats: 
			 		0x001122
			 		{00 11 22}
			 		00:11:22
			 		00.11.22
			 		001122
			 		The number of octets must not exceed the value of the -management_address_length parameter.If the number of octets is smaller than the value of the -management_address_length parameter, then -management_address_step will be left padded with zeros. 
			 		This parameter is used only when -mode is "create".This parameter is supported using the following APIs: IxN.
			 	-management_address_domain
			 		Sets the MP management address domain. This will take HEX input (0-255 byte).TLV Value in HEX format. Use one of the following formats: 
			 		0x001122 
			 		{00 11 22} 
			 		00:11:22 
			 		00.11.22 
			 		001122 
			 		The number of octets must not exceed the value of the -management_address_domain_length parameter. If the number of octets is smaller than the value of the -management_address_domain_length parameter, then -management_address_domain will be left padded with zeros. 
			 		This parameter is supported using the following APIs: IxN.
			 	-management_address_domain_length
			 		Sets the length of the Management address domain field.This parameter is supported using the following APIs: IxN.
			 	-management_address_domain_step
			 		Sets the MP management address domain step when -count > 1. This will take HEX input (0-255 byte).Step for TLV Value in HEX format when -count > 1.Use one of the following formats: 
			 		0x001122 
			 		{00 11 22} 
			 		00:11:22 
			 		00.11.22 
			 		001122 
			 		The number of octets must not exceed the value of the -management_address_domain_length parameter. If the number of octets is smaller than the value of the -management_address_domain_length parameter, then -management_address_domain_step will be left padded with zeros. 
			 		This parameter is used only when -mode is "create".This parameter is supported using the following APIs: IxN.
			 	-management_address_length
			 		Sets the length of the Management address field. This parameter is supported using the following APIs: IxN.
			 	-md_meg_handle_distribution
			 		This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		round_robin - Distribute the MD handles in a round robin manner.
			    		repeat_count - Use next MD handle every time -md_meg_handle_repeat_countexpires.
			 	-md_meg_handle_list
			 		List of handles from ::<namespace>::emulation_cfm_md_meg_config. These handles will be associated with MPs in the manner specified with -md_meg_handle_distributionand -md_meg_handle_repeat_count. This parameter is supported using the following APIs: IxN.When mode is -modify this parameter must have only one md_meg handle. The md_meg handle associated with the mip_mep handle specified with -handle parameter will be changed with the md_meg handle from -md_meg_handle_list parameter.
			 	-md_meg_handle_repeat_count
			 		How many MPs to configure with the same MP Name before using the next MD handle from the list. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is create.
			 	-meg_id
			 		The MEG identifier of the MP. This is for use with ITU-T Y.1731.This parameter is supported using the following APIs: IxN.
			 	-meg_id_format
			 		The MEG identifier format. This parameter is supported using the following APIs: IxN. Valid when allow_cfm_maid_formats is 1.icc_based_format - Use next MD handle every time -md_meg_handle_repeat_count expires. primary_vid - a number from 0 to 4095. char_string - a valid string. 2_octet_integer - a number from 0 to 65535. rfc_2685_vpn_id - must be formatted <number1>-<number2> where <number1> is from 0 to 16777215 and <number2> is from 0 to 4292967295.
			 	-mep_id
			 		The MEP identifier. This parameter is supported using the following APIs: IxN.
			 	-mep_id_step
			 		The MEP identifier step when -count > 1.This parameter is used only when -mode is "create". This parameter is supported using the following APIs: IxN.
			 	-mip_id
			 		The MIP identifier. This parameter is supported using the following APIs: IxN.
			 	-mip_id_step
			 		The MIP identifier step when -count > 1. This parameter is used only when -mode is "create". This parameter is supported using the following APIs: IxN.
			 	-mp_type
			 		Sets the MP type. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		mip - Maintenance Intermediate Point.
			    		mep - Maintenance Point.
			 	-organization_specific_tlv_length
			 		Sets the length of the organizational specific TLV field.This parameter is supported using the following APIs: IxN.
			 	-organization_specific_tlv_value
			 		Sets the value of the organizational specific TLV.TLV Value in HEX format. Use one of the following formats:0x001122{00 11 22}00:11:2200.11.22001122The number of octets must not exceed the value of the -organization_specific_tlv_length parameter. If the number of octets is smaller than the value of the -organization_specific_tlv_length parameter, then -organization_specific_tlv_value will be left padded with zeros.This parameter is supported using the following APIs: IxN.
			 	-organization_specific_tlv_value_step
			 		Sets the value of the organizational specific TLV step.Step TLV Value for -organization_specific_tlv_value when -count > 1 in HEX format.Use one of the following formats:0x001122{00 11 22}00:11:2200.11.22001122The number of octets must not exceed the value of the -organization_specific_tlv_length parameter. If the number of octets is smaller than the value of the -organization_specific_tlv_length parameter, then -organization_specific_tlv_value_step will be left padded with zeros.This parameter is used only when -mode is "create". This parameter is supported using the following APIs: IxN.
			 	-override_vlan_priority
			 		If true, overrides the set VLAN priority for this bridge, and uses the advanced settings instead. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		0 - Disable.
			    		1 - Enable.
			 	-reset
			 		If present deletes all CFM Maintenance Points created on CFM Bridge -bridge_handlebefore creating new ones. This parameter is supported using the following APIs: IxN.
			 	-short_ma_name
			 		Sets the Short MA name. The format is determined in short_ma_name_format.When -short_ma_name_format is:
			 		<choices><choice><choiceName>primary_vid</choiceName><choiceText>short_ma_name must be a number from 0 to 4095.</choiceText></choice><choice><choiceName>char_string</choiceName><choiceText>short_ma_name must be valid string</choiceText></choice><choice><choiceName>2_octet_integer</choiceName><choiceText>short_ma_name must be a number from 0 to 65535</choiceText></choice><choice><choiceName>rfc_2685_vpn_id</choiceName><choiceText>short_ma_name must be formatted.</choiceText></choice></choices>
			 		number1>-<number2> where <number1> is from 0 to 16777215 and <number2> is from 0 to 4292967295.This is used with IEEE 802.1ag.This parameter is supported using the following APIs: IxN.
			 	-short_ma_name_format
			 		Sets the Short MA Name format. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		primary_vid - Uses the primary VLAN identifer as the name format.
			    		char_string - Uses character string as the name format.
			    		2_octet_integer - Uses a 2 octet integer as the name format.
			    		rfc_2685_vpn_id - Uses the RFC 2685 VPN identifer as the name format.
			 	-ttl
			 		Sets the MP Time-to-live value. Default is 64. This parameter is supported using the following APIs: IxN.
			 	-vlan_handle_list
			 		List of handles from ::<namespace>::emulation_cfm_vlan_config. These handles will be associated with MPs in the manner specified with -vlan_handle_list_distributionand -vlan_handle_list_repeat_count. This parameter is supported using the following APIs: IxN.When mode is -modify this parameter must have only one vlan handle. The vlan handle associated with the mip mep handle specified with -handle parameter will be changed with the vlan handle from -vlan_handle_list parameter.
			 	-vlan_handle_list_distribution
			 		This parameter is supported using the following APIs: IxN. This parameter is used only with -mode is create.
			 		Valid choices are:
			    		round_robin - Distribute the Vlan handles in a round robin manner.
			    		repeat_count - Use next Vlan handle every time -vlan_handle_list_repeat_countexpires.
			 	-vlan_handle_list_repeat_count
			 		How many MPs to configure with the same Vlan before using the next Vlan handle from the list. This parameter is supported using the following APIs: IxN. This parameter is used only when -mode is create.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information.
			 key:log     value:When status is failure, contains more information.
		The list of CFM Maintenance Point handles created.
			 key:handle  value:The list of CFM Maintenance Point handles created.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_cfm_mip_mep_config", kwargs)

	def emulation_cfm_vlan_config(self, **kwargs):
		""" This procedure configures Vlan properties on the bridge specified with bridge_handle. The mac range handles returned with 'mac_range_handles.$vlan' key can be used as endpoints for traffic. Traffic is configured using ::<namespace>::traffic config using '-circuit_endpoint_type ethernet_vlan' and '-circuit_type none'. This protocol is available only when using IxTclNetwork. The GUI equivalent is in the section Protocols/Carrier Ethernet where CFM/Y.1731/PBB-TE is enabled.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_cfm_vlan_config
			 	[-bridge_handle       ANY]
			 	-mode                 ANY
			 	[-count               ANY]
			 	[-handle              ANY]
			 	[-mr_count            ANY]
			 	[-mr_inter_range_step ANY]
			 	[-mr_inter_vlan_step  ANY]
			 	[-mr_mac_address      ANY]
			 	[-mr_mac_address_step ANY]
			 	[-mr_mac_count        ANY]
			 	[-reset               ANY]
			 	[-s_vlan_id           ANY]
			 	[-s_vlan_id_step      ANY]
			 	[-s_vlan_priority     ANY]
			 	[-s_vlan_tp_id        ANY]
			 	[-type                ANY]
			 	[-vlan_id             ANY]
			 	[-vlan_id_step        ANY]
			 	[-vlan_priority       ANY]
			 	[-vlan_tp_id          ANY]
		
		Arguments:
			 	-bridge_handle
			 		The value of the -bridge_handle parameter must be a bridge handle returned by ::<namespace>::emulation_cfm_config procedure.Mandatory when -mode is add. This parameter is supported using the following APIs: IxN.
			 	-mode
			 		Action to perform. This parameter is supported using the following APIs: IxN.
			 		Valid choices are:
			    		create - Create new Vlan on -port_handle.
			    		modify - Modify Vlan specified with -handle parameter.
			    		enable - Enable Vlan specified with -handle parameter.
			    		disable - Disable Vlan specified with -handle parameter.
			    		remove - Remove Vlan specified with -handle parameter.
			 	-count
			 		Number of Vlan objects that will be created for the CFM Bridge specified with -bridge_handle.This parameter is used only when -mode is "create". This parameter is supported using the following APIs: IxN.
			 	-handle
			 		CFM Vlan handle. Used when -mode is modify|enable|disable|remove.When mode is "modify" this parameter supports only one CFM Vlan handle.When mode is enable|disable|remove this parameter supports a list of CFM Vlan handles.This parameter is supported using the following APIs: IxN.
			 	-mr_count
			 		Number of mac ranges per vlan.If -mode is modify and -mr_count parameter is present, all mac ranges previously configured on the CFM Vlan handle passed with -handle parameter will be erased and new mac ranges will be configured.This parameter is supported using the following APIs: IxN.
			 	-mr_inter_range_step
			 		When -mr_count > 1 this will be the step used to increment -mr_mac_address from one mac range to the next.This parameter is used only when -mode is "create" | "modify". It is used with mode "modify" only if -mr_count parameter is passed. In this case all mac ranges previously configured on the CFM Vlan handle will be erased and new mac ranges will be configured.This parameter is supported using the following APIs: IxN.
			 	-mr_inter_vlan_step
			 		When -count > 1 this will be the step used to increment -mr_mac_addressfrom one vlan to the next.This parameter is used only when -mode is "create".This parameter is supported using the following APIs: IxN.
			 	-mr_mac_address
			 		Mac range starting address.This parameter is used only when -mode is "create" | "modify". It is used with mode "modify" only if -mr_count parameter is passed. In this case all mac ranges previously configured on the CFM Vlan handle will be erased and new mac ranges will be configured.This parameter is supported using the following APIs: IxN.
			 	-mr_mac_address_step
			 		When -mr_mac_count > 1 this will be the step used to increment -mr_mac_addresswithing the mac range.This parameter is used only when -mode is "create" | "modify". It is used with mode "modify" only if -mr_count parameter is passed. In this case all mac ranges previously configured on the CFM Vlan handle will be erased and new mac ranges will be configured.This parameter is supported using the following APIs: IxN.
			 	-mr_mac_count
			 		Configures number of mac addresses per mac range.This parameter is used only when -mode is "create" | "modify". It is used with mode "modify" only if -mr_count parameter is passed. In this case all mac ranges previously configured on the CFM Vlan handle will be erased and new mac ranges will be configured.This parameter is supported using the following APIs: IxN.
			 	-reset
			 		If present deletes all CFM Vlans created on CFM Bridge -bridge_handle before creating new ones.This parameter is used only when -mode is "create".This parameter is supported using the following APIs: IxN.
			 	-s_vlan_id
			 		The stacked VLAN Identifier. This parameter is supported using the following APIs: IxN.
			 	-s_vlan_id_step
			 		If -count > 1 this is the step used to increment -s_vlan_id.This parameter is used only when -mode is "create".This parameter is supported using the following APIs: IxN.
			 	-s_vlan_priority
			 		The stacked vlan priority. This parameter is supported using the following APIs: IxN.
			 	-s_vlan_tp_id
			 		The stacked VLAN TPID. EtherTypes identify the protocol that follows the VLAN header. This parameter is supported using the following APIs: IxN. 
			 		8100 
			 		9100 
			 		9200 
			 		88a8 
			 	-type
			 		Vlan type. This parameter is supported using the following APIs: IxN. single - The VLAN is a single VLAN.qinq - The VLAN is a stacked VLAN.
			 	-vlan_id
			 		The single VLAN Identifier. This parameter is supported using the following APIs: IxN.
			 	-vlan_id_step
			 		If -count > 1 this is the step used to increment -vlan_id.This parameter is used only when -mode is "create".This parameter is supported using the following APIs: IxN.
			 	-vlan_priority
			 		The single vlan priority. This parameter is supported using the following APIs: IxN.
			 	-vlan_tp_id
			 		The single VLAN TPID. EtherTypes identify the protocol that follows the VLAN header. This parameter is supported using the following APIs: IxN.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information.
			 key:log     value:When status is failure, contains more information.
		A list of Vlan handles.
			 key:handle  value:A list of Vlan handles.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_cfm_vlan_config", kwargs)

	def emulation_dhcp_config(self, **kwargs):
		""" This procedure configures the DHCP emulation client. It creates, modifies, or resets an emulated Dynamic Host Configuration Protocol (DHCP) client or Dynamic Host Configuration Protocol for the specified HLTAPI port or handle.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_dhcp_config
			 	[-handle                        ANY]
			 	[-mode                          CHOICES create modify reset
			                                 DEFAULT create]
			 	[-msg_timeout                   NUMERIC
			                                 DEFAULT 4]
			 	[-outstanding_releases_count    RANGE 1-100000
			                                 DEFAULT 500]
			 	[-outstanding_session_count     NUMERIC
			                                 DEFAULT 50]
			 	[-port_handle                   REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-release_rate                  RANGE 1-100000
			                                 DEFAULT 50]
			 	[-release_rate_increment        ANY]
			 	[-request_rate                  RANGE 1-100000
			                                 DEFAULT 10]
			 	[-request_rate_increment        ANY]
			 	[-retry_count                   RANGE 1-65536
			                                 DEFAULT 3]
			 	[-client_port                   NUMERIC
			                                 DEFAULT 68]
			 	[-start_scale_mode              CHOICES device_group port
			                                 DEFAULT port]
			 	[-stop_scale_mode               CHOICES device_group port
			                                 DEFAULT port]
			 	[-interval_stop                 NUMERIC
			                                 DEFAULT 1000]
			 	[-interval_start                NUMERIC
			                                 DEFAULT 1000]
			 	[-min_lifetime                  NUMERIC
			                                 DEFAULT 1]
			 	[-max_restarts                  NUMERIC
			                                 DEFAULT 10]
			 	[-max_lifetime                  NUMERIC
			                                 DEFAULT 10]
			 	[-enable_restart                CHOICES 0 1
			                                 DEFAULT 0]
			 	[-enable_lifetime               CHOICES 0 1
			                                 DEFAULT 0]
			x	[-unlimited_restarts            CHOICES 0 1
			x                                DEFAULT 0]
			 	[-server_port                   RANGE 0-65535
			                                 DEFAULT 67]
			x	[-dhcp6_echo_ia_info            CHOICES 0 1
			x                                DEFAULT 0]
			x	[-dhcp6_reb_max_rt              RANGE 1-10000
			x                                DEFAULT 600]
			x	[-dhcp6_reb_timeout             RANGE 1-100
			x                                DEFAULT 10]
			x	[-dhcp6_rel_max_rc              RANGE 1-100
			x                                DEFAULT 5]
			x	[-dhcp6_rel_timeout             RANGE 1-100
			x                                DEFAULT 1]
			x	[-dhcp6_ren_max_rt              RANGE 1-10000
			x                                DEFAULT 600]
			x	[-dhcp6_ren_timeout             RANGE 1-100
			x                                DEFAULT 10]
			x	[-dhcp6_req_max_rc              RANGE 1-100
			x                                DEFAULT 5]
			x	[-dhcp6_req_max_rt              RANGE 1-10000
			x                                DEFAULT 30]
			x	[-dhcp6_req_timeout             RANGE 1-100
			x                                DEFAULT 1]
			x	[-dhcp6_sol_max_rc              RANGE 1-65536
			x                                DEFAULT 3]
			x	[-dhcp6_sol_max_rt              RANGE 1-10000
			x                                DEFAULT 120]
			x	[-dhcp6_sol_timeout             RANGE 1-100
			x                                DEFAULT 1]
			x	[-dhcp6_info_req_timeout        NUMERIC
			x                                DEFAULT 4]
			x	[-dhcp6_info_req_max_rt         NUMERIC
			x                                DEFAULT 120]
			x	[-dhcp6_info_req_max_rc         NUMERIC
			x                                DEFAULT 3]
			x	[-msg_timeout_factor            RANGE 1-100
			x                                DEFAULT 2]
			x	[-msg_max_timeout               RANGE 1-100
			x                                DEFAULT 2]
			x	[-override_global_setup_rate    CHOICES 0 1
			x                                DEFAULT 1]
			x	[-override_global_teardown_rate CHOICES 0 1
			x                                DEFAULT 1]
			x	[-skip_release_on_stop          CHOICES 0 1
			x                                DEFAULT 0]
			x	[-renew_on_link_up              CHOICES 0 1
			x                                DEFAULT 0]
			 	[-accept_partial_config         ANY]
			 	[-lease_time                    ANY]
			 	[-max_dhcp_msg_size             ANY]
			 	[-wait_for_completion           ANY]
			x	[-associates                    ANY]
			x	[-no_write                      ANY]
			x	[-release_rate_max              ANY]
			x	[-request_rate_max              ANY]
			x	[-reset                         ANY]
			x	[-version                       ANY]
			n	[-response_wait                 ANY]
			n	[-retry_timer                   ANY]
			x	[-ip_version                    CHOICES 4 6
			x                                DEFAULT 4]
			x	[-dhcp4_arp_gw                  CHOICES 0 1]
			x	[-dhcp6_ns_gw                   CHOICES 0 1]
		
		Arguments:
			 	-handle
			 		Specifies the handle of the port upon which emulation is configured.
			 		Mandatory for the mode -modify.
			 		Valid for -version ixtclhal, ixnetwork.
			 		When -handle is provided with the /globals value the arguments that configure global protocol
			 		setting accept both multivalue handles and simple values.
			 		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
			 		that configure global settings will only accept simple values. In this situation, these arguments will
			 		configure only the settings of the parent device group or the ports associated with the parent topology.
			 	-mode
			 		This option defines the action to be taken on the port specified by
			 		the port_handle argument.
			 		Valid for -version ixtclhal, ixnetwork.
			 		Valid choices are:
			    		create - Creates an DHCP session,requires the use of -port_handle.
			    		modify - Modifies an DHCP session, requires the use of -handle.
			    		reset - Stops the emulation locally without attempting to clear the bound address from the DHCP server.
			 	-msg_timeout
			 		Specifies the maximum time to wait in milliseconds for receipt of an
			 		offer or ack message after the sending of a corresponding discover or
			 		request message.
			 		Valid for -version ixnetwork.
			 	-outstanding_releases_count
			 		The maximum number of release sessions opened at any time by the DHCPv6
			 		network stack element. The default is 500.
			 		Valid for -version ixnetwork.
			 	-outstanding_session_count
			 		Specifies the maximum number of outstanding sessions (unacknowledged
			 		discover or request message) allowed to exist. In effect, this is a
			 		rate limiting mechanism that stops dhcp servers from being
			 		overwhelmed with reqests.
			 		Valid for -version ixnetwork.
			 	-port_handle
			 		This parameter specifies the port upon which emulation is configured.
			 		Mandatory for the modes -create and -reset.
			 		Valid for -version ixtclhal, ixnetwork.
			 	-release_rate
			 		The number of addresses to release in the first second after stop command
			 		is received. The default is 50.
			 		Valid for -version ixnetwork.
			 	-release_rate_increment
			 		The number by which the actual release rate is incremented in every second. The default is 50. Valid for -version ixnetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-request_rate
			 		Specifies the desired request rate in sessions per second.
			 		Valid for -version ixnetwork.
			 	-request_rate_increment
			 		The number by which the actual request rate is incremented in every second. The default value is 10. Valid for -version ixnetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-retry_count
			 		Limits the number of additional transmissions of either a discover or
			 		request message when no acknowledgement is received.
			 		Valid for -version ixnetwork.
			 	-client_port
			 		UDP port that the client listens on for DHCP responses.
			 		Valid for dhcpv4 client.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-start_scale_mode
			 		Indicates whether the control is specified per port or per device group.
			 		This setting is global for all the dhcp client protocols configured in the ixncfg
			 		and can be configured just when handle is /globals (when the user wants to configure just the global settings)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		device_group -
			    		port -
			 	-stop_scale_mode
			 		Indicates whether the control is specified per port or per device group.
			 		This setting is global for all the dhcp client protocols configured in the ixncfg
			 		and can be configured just when handle is /globals (when the user wants to configure just the global settings)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		device_group -
			    		port -
			 	-interval_stop
			 		Time interval used to calculate the rate for triggering an action.
			 		Valid for both dhcpv4 and dhcpv6 client.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-interval_start
			 		Time interval used to calculate the rate for triggering an action.
			 		Valid for both dhcpv4 and dhcpv6 client.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-min_lifetime
			 		Minimum session lifetime (in seconds).
			 		Valid for both dhcpv4 and dhcpv6 client.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-max_restarts
			 		Maximum number of times each session is automatically restarted.
			 		Valid for both dhcpv4 and dhcpv6 client.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-max_lifetime
			 		Maximum session lifetime(in seconds).
			 		Valid for both dhcpv4 and dhcpv6 client.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-enable_restart
			 		Enable automatic session restart after stop at lifetime expiry.
			 		Valid for both dhcpv4 and dhcpv6 client.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-enable_lifetime
			 		Enable session lifetime.
			 		Valid for both dhcpv4 and dhcpv6 client.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-unlimited_restarts
			x		Allow each session to always be automatically restarted
			x		Valid for both dhcpv4 and dhcpv6 client.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-server_port
			 		The UDP port to which the client addresses its server requests. The
			 		default value port number is 67.
			 		Valid for -version ixnetwork.
			x	-dhcp6_echo_ia_info
			x		If true, the DHCPv6 client will send Request messages to any server that has the
			x		same IA information (addresses and options) as presented in the previous
			x		Advertisement message.
			x		Valid for -version ixnetwork.
			x	-dhcp6_reb_max_rt
			x		The maximum rebind timeout value, in seconds. The default value is 600.
			x		Valid for -version ixnetwork.
			x	-dhcp6_reb_timeout
			x		The initial rebind timeout, in seconds. The default value is 10.
			x		Valid for -version ixnetwork.
			x	-dhcp6_rel_max_rc
			x		The number of release attempts. The default value is 5.
			x		Valid for -version ixnetwork.
			x	-dhcp6_rel_timeout
			x		The initial release timeout, in seconds. The default value is 1.
			x		Valid for -version ixnetwork.
			x	-dhcp6_ren_max_rt
			x		The maximum renew request timeout value, in seconds. The default value
			x		is 600.
			x		Valid for -version ixnetwork.
			x	-dhcp6_ren_timeout
			x		The initial renew timeout, in seconds. The default value is 10.
			x		Valid for -version ixnetwork.
			x	-dhcp6_req_max_rc
			x		The number of release attempts. The default value is 5.
			x		Valid for -version ixnetwork.
			x	-dhcp6_req_max_rt
			x		The maximum request timeout value, in seconds. The default value is 30.
			x		Valid for -version ixnetwork.
			x	-dhcp6_req_timeout
			x		The initial request timeout value, in seconds. The default value is 1.
			x		Valid for -version ixnetwork.
			x	-dhcp6_sol_max_rc
			x		The maximum solicit retry attempts. The default value is 3.
			x		Valid for -version ixnetwork.
			x	-dhcp6_sol_max_rt
			x		The maximum solicit timeout value, in seconds. The default value is 120.
			x		Valid for -version ixnetwork.
			x	-dhcp6_sol_timeout
			x		The Initial solicit timeout, in seconds. The default value is 1.
			x		Valid for -version ixnetwork.
			x	-dhcp6_info_req_timeout
			x		Initial information-request timeout value, in seconds.
			x		Valid for dhcpv6 client.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_info_req_max_rt
			x		Max Information-request timeout value, in seconds.
			x		Valid for dhcpv6 client.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_info_req_max_rc
			x		Info request attempts.
			x		Valid for dhcpv6 client.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-msg_timeout_factor
			x		The value by which the timeout will be multiplied each time the response
			x		timeout has been reached.
			x		Valid for -version ixnetwork.
			x	-msg_max_timeout
			x		The max value, in seconds, that the discover timeout can reach though Discover Timeout Factor.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-override_global_setup_rate
			x		If enabled, all the rate settings defined at the global level will be
			x		overridden by the rate settings defined on this port.
			x		Valid for -version ixnetwork.
			x	-override_global_teardown_rate
			x		If enabled, all the rate settings defined at the session level will be
			x		overridden by rate settings defined on this port.
			x		Valid for -version ixnetwork.
			x	-skip_release_on_stop
			x		If enabled, the client does not send a DHCP release packet when the stop command is given.
			x		Valid for both dhcpv4 and dhcpv6 client.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-renew_on_link_up
			x		Indicate to renew the active DHCP sessions after link status goes down and up.
			x		Valid for both dhcpv4 and dhcpv6 client.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-accept_partial_config
			 		This attribute controls how the negotiation process reports success or failure: When the parameter is enabled, IxNetwork reports success if at least one address is configured. When the parameter is disabled, IxNetwork reports success only if all addresses are configured. Valid for -version ixnetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-lease_time
			 		Specify the lease time in seconds suggested by the emulated client that is sent in the discover message. The default value of this parameter is 3600. Valid for -version ixtclhal, ixnetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-max_dhcp_msg_size
			 		Sets the maximum size of the dhcp message. The default value of this parameter is 576. Valid for -version ixnetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-wait_for_completion
			 		When enabled, the supplicant does not send the initial EAPOL Start message.Instead, it waits for the authenticator (the DUT) to send an EAPOL Request / Identity message. Valid for -version ixnetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-associates
			x		When Ixia ports are used as both the client and the server, this parameter establishes an association between a specific client port and a specific server port. Valid for -version ixnetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-no_write
			x	-release_rate_max
			x   		The maximum number of addresses to release per second. The default is 500. Valid for -version ixnetwork.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-request_rate_max
			x   		The maximum number of addresses to set up per second. The default value is 50. Valid for -version ixnetwork.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-reset
			x   		Clears the hardware. If mode is "create" and the reset parameter is present, all the configurations will be erased from memory and the new config is created using the new given parameters. If mode is "create" and the reset parameter is not present, a new session is added in the local array. If mode is "modify" or "reset", the -reset parameter cannot be used. Valid for -version ixtclhal, ixnetwork.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-version
			x   		Permits the selection of the API used (ixtclhal or ixnetwork).
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			n	-response_wait
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-retry_timer
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-ip_version
			x   		DHCP Client type: IPv4 or IPv6.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		4 - IPv4
			x       		6 - IPv6
			x	-dhcp4_arp_gw
			x   		If enabled, DHCP clients ARP to find their Gateway MAC Addresses.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_ns_gw
			x   		If enabled, DHCP clients NS to find their Gateway MAC Addresses.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log     value:Error message if command returns {status 0}
		Port handle on which DHCP emulation was configured
			 key:handle  value:Port handle on which DHCP emulation was configured
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE 
		Error message if command returns {status 0}
			 key:log     value:Error message if command returns {status 0} 
		handle returned by the dhcp configuration
			 key:handle  value:handle returned by the dhcp configuration
		
		Examples:
		See files starting with DHCP_ in the Samples subdirectory. See the DHCP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		When -handle is provided with the /globals value the arguments that configure global protocol
		setting accept both multivalue handles and simple values.
		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
		that configure global settings will only accept simple values. In this situation, these arguments will
		configure only the settings of the parent device group or the ports associated with the parent topology.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_dhcp_config", kwargs)

	def emulation_dhcp_control(self, **kwargs):
		""" This procedure starts, stops, and restarts the DHCP emulation client on the specified port.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_dhcp_control
			 	[-port_handle      ANY]
			 	[-handle           ANY]
			n	[-no_write         ANY]
			x	[-request_rate     ANY]
			x	[-ping_destination IP]
			 	[-action           CHOICES bind
			                    CHOICES release
			                    CHOICES renew
			                    CHOICES abort
			                    CHOICES abort_async
			                    CHOICES restart_down
			                    CHOICES rebind
			                    CHOICES send_ping
			                    CHOICES start_relay_agent
			                    CHOICES stop_relay_agent
			                    DEFAULT bind]
		
		Arguments:
			 	-port_handle
			 		Specifies the port handle upon which emulation is configured.
			 		Emulation must have been previously enabled on the specified port
			 		via a call to emulation_dhcp_group_config proc.
			 	-handle
			 		Allows the user to optionally select the groups to which the
			 		specified action is to be applied.
			 		If this parameter is not specified, then the specified action is
			 		applied to all groups configured on the port specified by
			 		the -port_handle command. The handle is obtained from the keyed list returned
			 		in the call to emulation_dhcp_group_config proc.
			 		The port handle parameter must have been initialized and dhcp group
			 		emulation must have been configured prior to calling this function.
			n	-no_write
			x	-request_rate
			x   		Specifies the desired request rate in sessions per second.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-ping_destination
			x   		Specifies the ip destination for ping.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-action
			    		Action to take on the specified handle.
			    		The parameters specified in the emulation_dhcp_group_config proc
			    		are used to control the bind/renew/release rates.
			    		Valid choices are:
			        		bind - starts the discover/request message transmission.
			        		release - causes the system to issue release message for all currently bound subscribers.
			        		renew - issues a renew request for all currently bound subscribers.This option is a Cisco option.
			        		abort - aborts the DHCP sessions for a DHCP emulation. The command
returns when the operation is completed. This option is valid only using IxTclNetwork.
			        		abort_async - aborts the DHCP sessions for a DHCP emulation. The command
returns immediately and the operation is executed in the backgronud. This option is valid only using IxTclNetwork.
			        		restart_down - restart the sessions that are down
			        		rebind - rebind
			        		send_ping - send ping to the specified address
			        		start_relay_agent - starts the dhcp relay agent stack
			        		stop_relay_agent - stops the dhcp relay agent stack
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information
			 key:log     value:When status is failure, contains more information
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE 
		
		Examples:
		See files starting with DHCP_ in the Samples subdirectory. See the DHCP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_dhcp_control", kwargs)

	def emulation_dhcp_group_config(self, **kwargs):
		""" This procedure configures and modifies a group of DHCP subscribers where each group share a set of common characteristics.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_dhcp_group_config
			 	[-encap                                        CHOICES ethernet_ii
			                                                CHOICES ethernet_ii_vlan
			                                                CHOICES ethernet_ii_qinq
			                                                CHOICES vc_mux_ipv4_routed
			                                                CHOICES vc_mux_fcs
			                                                CHOICES vc_mux
			                                                CHOICES vc_mux_ipv6_routed
			                                                CHOICES llcsnap_routed
			                                                CHOICES llcsnap_fcs
			                                                CHOICES llcsnap
			                                                CHOICES llcsnap_ppp
			                                                CHOICES vc_mux_ppp
			                                                DEFAULT ethernet_ii]
			 	[-mac_addr                                     MAC]
			 	[-mac_addr_step                                MAC
			                                                DEFAULT 00.00.00.00.00.01]
			 	[-num_sessions                                 RANGE 1-65536]
			 	[-pvc_incr_mode                                ANY]
			 	[-qinq_incr_mode                               CHOICES inner outer both
			                                                DEFAULT inner]
			 	[-sessions_per_vc                              ANY]
			 	[-vci                                          ANY]
			 	[-vci_count                                    ANY]
			 	[-vci_step                                     ANY]
			 	[-vlan_id                                      RANGE 0-4095
			                                                DEFAULT 4094]
			 	[-vlan_id_count                                RANGE 0-4095
			                                                DEFAULT 4094]
			 	[-vlan_id_outer                                NUMERIC]
			 	[-vlan_id_outer_count                          RANGE 1-4094]
			 	[-vlan_id_outer_step                           RANGE 1-4094]
			 	[-vlan_id_step                                 RANGE 0-4095]
			 	[-vpi                                          ANY]
			 	[-vpi_count                                    ANY]
			 	[-vpi_step                                     ANY]
			x	[-dhcp6_range_duid_enterprise_id               NUMERIC
			x                                               DEFAULT 10]
			x	[-dhcp6_range_duid_type                        CHOICES duid_llt duid_en duid_ll
			x                                               DEFAULT duid_llt]
			x	[-dhcp6_range_duid_vendor_id                   NUMERIC
			x                                               DEFAULT 10]
			x	[-dhcp6_range_duid_vendor_id_increment         NUMERIC
			x                                               DEFAULT 1]
			x	[-dhcp6_range_ia_id                            NUMERIC
			x                                               DEFAULT 10]
			x	[-dhcp6_range_ia_id_increment                  NUMERIC
			x                                               DEFAULT 1]
			x	[-dhcp6_range_ia_t1                            NUMERIC
			x                                               DEFAULT 302400]
			x	[-dhcp6_range_ia_t2                            NUMERIC
			x                                               DEFAULT 483840]
			x	[-dhcp6_range_ia_type                          CHOICES iana iata iapd iana_iapd
			x                                               DEFAULT iana]
			x	[-dhcp6_range_max_no_per_client                NUMERIC
			x                                               DEFAULT 1]
			x	[-dhcp6_range_iana_count                       NUMERIC
			x                                               DEFAULT 1]
			x	[-dhcp6_range_iapd_count                       NUMERIC
			x                                               DEFAULT 1]
			x	[-dhcp6_range_ia_id_inc                        NUMERIC
			x                                               DEFAULT 1]
			x	[-dhcp6_range_param_request_list               ANY]
			x	[-dhcp_range_ip_type                           CHOICES ipv4 ipv6
			x                                               DEFAULT ipv4]
			x	[-dhcp_range_param_request_list                ANY]
			x	[-dhcp_range_renew_timer                       NUMERIC
			x                                               DEFAULT 0]
			x	[-dhcp_range_server_address                    IP
			x                                               DEFAULT 10.0.0.1]
			x	[-dhcp_range_use_first_server                  CHOICES 0 1
			x                                               DEFAULT 1]
			x	[-dhcp_range_use_trusted_network_element       ANY]
			x	[-mac_mtu                                      RANGE 500-9216
			x                                               DEFAULT 1500]
			x	[-no_write                                     ANY]
			x	[-server_id                                    ANY]
			n	[-target_subport                               ANY]
			x	[-use_vendor_id                                CHOICES 0 1
			x                                               DEFAULT 0]
			x	[-vendor_id                                    ANY
			x                                               DEFAULT Ixia]
			x	[-version                                      ANY]
			x	[-vlan_id_outer_increment_step                 RANGE 0-4093
			x                                               DEFAULT 1]
			x	[-vlan_id_increment_step                       RANGE 0-4093
			x                                               DEFAULT 1]
			x	[-vlan_id_outer_priority                       RANGE 0-7
			x                                               DEFAULT 0]
			x	[-vlan_user_priority                           RANGE 0-7
			x                                               DEFAULT 0]
			 	[-mode                                         CHOICES create
			                                                CHOICES create_relay_agent
			                                                CHOICES modify
			                                                CHOICES reset
			                                                DEFAULT create]
			 	-handle                                        ANY]
			n	[-release_rate                                 ANY]
			n	[-request_rate                                 ANY]
			x	[-use_rapid_commit                             CHOICES 0 1
			x                                               DEFAULT 0]
			x	[-protocol_name                                ALPHA]
			x	[-dhcp4_broadcast                              CHOICES 0 1
			x                                               DEFAULT 0]
			x	[-enable_stateless                             CHOICES 0 1
			x                                               DEFAULT 0]
			x	[-dhcp6_use_pd_global_address                  CHOICES 0 1
			x                                               DEFAULT 0]
			x	[-dhcp_range_relay_type                        CHOICES normal lightweight
			x                                               DEFAULT normal]
			x	[-dhcp_range_use_relay_agent                   CHOICES 0 1
			x                                               DEFAULT 0]
			x	[-dhcp_range_relay_count                       RANGE 1-1000000
			x                                               DEFAULT 1]
			x	[-dhcp_range_relay_override_vlan_settings      CHOICES 0 1
			x                                               DEFAULT 0]
			x	[-dhcp_range_relay_first_vlan_id               RANGE 0-4095
			x                                               DEFAULT 1]
			x	[-dhcp_range_relay_vlan_increment              RANGE 0-4093
			x                                               DEFAULT 1]
			x	[-dhcp_range_relay_vlan_count                  RANGE 1-4094
			x                                               DEFAULT 1]
			x	[-dhcp_range_relay_destination                 IP
			x                                               DEFAULT 20.0.0.1]
			x	[-dhcp_range_relay_first_address               IP
			x                                               DEFAULT 20.0.0.100]
			x	[-dhcp_range_relay_address_increment           IP
			x                                               DEFAULT 0.0.0.1]
			x	[-dhcp_range_relay_subnet                      RANGE 1-128
			x                                               DEFAULT 24]
			x	[-dhcp_range_relay_gateway                     IP
			x                                               DEFAULT 20.0.0.1]
			x	[-dhcp_range_relay_use_circuit_id              ANY]
			x	[-dhcp_range_relay_circuit_id                  ANY]
			x	[-dhcp_range_relay_hosts_per_circuit_id        ANY]
			x	[-dhcp_range_relay_use_remote_id               ANY]
			x	[-dhcp_range_relay_remote_id                   ANY]
			x	[-dhcp_range_relay_hosts_per_remote_id         ANY]
			x	[-dhcp_range_relay_use_suboption6              ANY]
			x	[-dhcp_range_suboption6_address_subnet         ANY]
			x	[-dhcp_range_suboption6_first_address          ANY]
			x	[-dhcp_range_relay6_use_opt_interface_id       ANY]
			x	[-dhcp_range_relay6_opt_interface_id           ANY]
			x	[-dhcp_range_relay6_hosts_per_opt_interface_id ANY]
			x	[-dhcp4_gateway_address                        IP
			x                                               DEFAULT 0.0.0.0]
			x	[-dhcp4_gateway_mac                            MAC
			x                                               DEFAULT 00.00.00.00.00.00]
			x	[-use_custom_link_local_address                CHOICES 0 1]
			x	[-custom_link_local_address                    IPV6]
			x	[-dhcp6_gateway_address                        IPV6
			x                                               DEFAULT 0:0:0:0:0:0:0:0]
			x	[-dhcp6_gateway_mac                            MAC
			x                                               DEFAULT 00.00.00.00.00.00]
			x	[-reconf_via_relay                             CHOICES 0 1]
			x	[-dhcpv6_multiplier                            NUMERIC]
		
		Arguments:
			 	-encap
			 		Note: ethernet_ii_qinq is not supported with IxTclHal.
			 		Valid for IxTclHal and IxTclNetwork.
			 		Valid choices are:
			    		ethernet_ii - Ethernet II (default for Ethernet cards)
			    		ethernet_ii_vlan - Ethernet II with a single vlan tag
			    		ethernet_ii_qinq - Inner vlan capability
			    		vc_mux_ipv4_routed - VC Mux IPv4 Routed (valid only for -version ixnetwork). Not supported in ixiangpf namespace.
			    		vc_mux_fcs - VC Mux Bridged Ethernet (FCS) (valid only for -version ixnetwork). Not supported in ixiangpf namespace.
			    		vc_mux - VC Mux Bridged Ethernet (no FCS). Not supported in ixiangpf namespace.
			    		vc_mux_ipv6_routed - VC Mux IPv6 Routed (valid only for -version ixnetwork). Not supported in ixiangpf namespace.
			    		llcsnap_routed - LLC Routed AAL5 Snap (valid only for -version ixnetwork). Not supported in ixiangpf namespace.
			    		llcsnap_fcs - LLC Bridged Ethernet (FCS) (valid only for -version ixnetwork). Not supported in ixiangpf namespace.
			    		llcsnap - LLC Bridged Ethernet (no FCS) (default for ATM cards). Not supported in ixiangpf namespace.
			    		llcsnap_ppp - LLC Encap PPP (valid only for -version ixnetwork). Not supported in ixiangpf namespace.
			    		vc_mux_ppp - VC Mux PPP (valid only for -version ixnetwork). Not supported in ixiangpf namespace.
			 	-mac_addr
			 		Specifies the base (first) MAC address to use when emulating
			 		multiple clients. This parameter is mandatory when -mode is "create".
			 		Valid for IxTclHal and IxTclNetwork.
			 	-mac_addr_step
			 		Specifies the step value applied to the base MAC address for each
			 		subsequent emulated client. It must be provided in the integer format
			 		(unlike ixTclHal where it is provided in MAC address format). The
			 		step MAC address is arithmetically added to the base MAC address with
			 		any overflow beyond 48 bits silently discarded.
			 		Valid for IxTclHal and IxTclNetwork.
			 	-num_sessions
			 		Indicates the number of DHCP clients emulated.
			 		The default value is 4096.
			 		Valid for IxTclHal and IxTclNetwork.
			 	-pvc_incr_mode
			 		Specifies the increment to be used when selecting the next VPI value to be used for emulation of clients over ATM interfaces. Valid for ATM interfaces only. The default value is pvc. Valid for IxTclHal and IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-qinq_incr_mode
			 		The Method used to increment VLAN IDs.
			 		Valid for IxTclHal and IxTclNetwork.
			 		Valid choices are:
			    		inner - (default) inner first
			    		outer - outer first
			    		both - both
			 	-sessions_per_vc
			 		Specifies the the number of VPI's or VCI's sessions used for emulation of clients over ATM interfaces. Used in conjuction with the -pvc_incr_mode to allow multiple sessions per VCC. Valid for ATM interfaces only.Valid for IxTclHal and IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vci
			 		Specifies the base (first) VCI (virtual circuit) value applied used when emulating multiple DHCP clients over ATM interfaces. Valid for IxTclHal and IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vci_count
			 		Specifies the the number of VCI's used for the emulation of clients over ATM interfaces. Valid for ATM interfaces only. Valid for IxTclHal and IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vci_step
			 		Specifies the increment to be used when selecting the next VCI value to be used for emulation of clients over ATM interfaces. Valid for ATM interfaces only. VCI values are incremented by addition modulo 65536.  Valid for IxTclHal and IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vlan_id
			 		The first VLAN ID to be used for the outer VLAN tag.
			 		Valid for IxTclHal and IxTclNetwork.
			 	-vlan_id_count
			 		The number of unique outer VLAN IDs that will be created. The default
			 		value is 4094.
			 		Valid for IxTclHal and IxTclNetwork.
			 	-vlan_id_outer
			 		The first VLAN ID to be used for the inner VLAN tag.
			 		Valid for IxTclNetwork.
			 	-vlan_id_outer_count
			 		The number of unique inner VLAN IDs that will be created.
			 		Valid for IxTclNetwork.
			 	-vlan_id_outer_step
			 		The value to be added to the inner VLAN ID for each new assignment.
			 		Valid for IxTclNetwork.
			 	-vlan_id_step
			 		The value to be added to the outer VLAN ID for each new assignment.
			 		Valid for IxTclHal and IxTclNetwork.
			 	-vpi
			 		Specifies the base (first) VPI (virtual path) value applied used when emulating multiple DHCP clients over ATM interfaces. Valid for IxTclHal and IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vpi_count
			 		Specifies the the number of VPI's used for the emulation of clients over ATM interfaces. Valid for ATM interfaces only.  Valid for IxTclHal and IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vpi_step
			 		Specifies the increment to be used when selecting the next VPI value to be used for emulation of clients over ATM interfaces. Valid for ATM interfaces only. VCI values are incremented by addition modulo 256. The default value is 1. Valid for IxTclHal and IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_range_duid_enterprise_id
			x		The vendor's registered Private Enterprise Number maintained by IANA.
			x		The default value is 10.
			x		Valid for IxTclNetwork.
			x	-dhcp6_range_duid_type
			x		DHCP Unique Identifier (DUID) Type.
			x		Valid for IxTclNetwork.
			x		Valid choices are:
			x   		duid_llt -
			x   		duid_en -
			x   		duid_ll -
			x	-dhcp6_range_duid_vendor_id
			x		The Option Request option is used to identify a list of options in a
			x		message between a client and a server.
			x		Valid for IxTclNetwork.
			x	-dhcp6_range_duid_vendor_id_increment
			x		The value by which the VENDOR-ID is incremented for each DHCP client.
			x		The default value is 1.
			x		Valid for IxTclNetwork.
			x	-dhcp6_range_ia_id
			x		Identity Association (IA) Unique Identifier. This Id is incremented
			x		automatically for each DHCP client. The default value is 10.
			x		Valid for IxTclNetwork.
			x	-dhcp6_range_ia_id_increment
			x		The value by which the IA-ID is incremented for each DHCP client.
			x		The default is 1.
			x		Valid for IxTclNetwork.
			x	-dhcp6_range_ia_t1
			x		The suggested time, in seconds, at which the client contacts the server
			x		to extend the lifetimes of the assigned addresses. The default value is
			x		302400.
			x		Valid for IxTclNetwork.
			x	-dhcp6_range_ia_t2
			x		The suggested time, in seconds, at which the client contacts any
			x		available server to extend the lifetimes of the addresses assigned.
			x		The default value is 483840.
			x		Valid for IxTclNetwork.
			x	-dhcp6_range_ia_type
			x		The Identity Association Type. The IA types are IANA, IATA, and IAPD.
			x		The default is IANA.
			x		Valid for IxTclNetwork.
			x		Valid choices are:
			x   		iana -
			x   		iata -
			x   		iapd -
			x   		iana_iapd -
			x	-dhcp6_range_max_no_per_client
			x		The maximum number of addresses/prefixes that can be negotiated by a DHCPv6 Client.
			x		The default value is 1. Valid for IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_range_iana_count
			x		The number of IANA IAs requested in a single negotiation. The default value is 1.
			x		Valid for IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_range_iapd_count
			x		The number of IAPD IAs requested in a single negotiation. The default value is 1.
			x		Valid for IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_range_ia_id_inc
			x		The increment with which IAID is incremented for each IA solicited by a DHCPv6 Client.
			x		The default value is 1. Valid for IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dhcp6_range_param_request_list
			x		The Option Request option is used to identify a list of options in a message between a client and a server. The available client request options are 2 - Server Identifier, 7 - Preference, 11 - Authentication, 12 - Server Unicast, 13 - Status Code, 17 - Vendor-specific Information, 18 - Interface-Id, 23 - DNS Resolvers, and 24 - DNS List. Valid for IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp_range_ip_type
			x		Defines the IP address version to be used for the range: IPv4 or IPv6.
			x		The default value is IPv4.
			x		Valid for IxTclNetwork.
			x		Valid choices are:
			x   		ipv4 -
			x   		ipv6 -
			x	-dhcp_range_param_request_list
			x		The Option Request option is used to identify a list of options in a message between a client and a server.
			x		The available client request options are
			x		- 1 - Subnet Mask- 3 - Router- 6 - Domain Name Server- 15 - Domain Name- 33 - Static Route- 44 - NetBIOS over TCP/IP Name Server- 46 - NetBIOS over TCP/IP Name Type- 51 - IP Address Lease Time- 54 - Server Identifier- 58 - Renewal (T1) Time Value- 59 - Rebinding (T2) Time Value- 90 - Authentication (RFC3118). Valid for IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp_range_renew_timer
			x		When an address is allocated or reallocated, the client starts two timers
			x		that control the renewal process. The renewal process is designed to
			x		ensure that a client's lease can be extended before it is scheduled to end.
			x		Valid for IxTclNetwork.
			x	-dhcp_range_server_address
			x		The address of the DHCP server from which the subnet will accept IP addresses.
			x		Valid for IxTclNetwork.
			x	-dhcp_range_use_first_server
			x		If enabled, the subnet accepts the IP addresses offered by the first
			x		server to respond to the DHCPDISCOVER message.
			x		Valid for IxTclNetwork.
			x	-dhcp_range_use_trusted_network_element
			x		If true, the plug-in emulates trusted network elements on the port, rather than emulating relay agents. Valid for IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-mac_mtu
			x		The maximum transmission unit for the interfaces created with this range.
			x		The default value is 1500.
			x		Valid for IxTclNetwork.
			x	-no_write
			x	-server_id
			x   		The IP address of a particular DHCP server. DHCP negotiation will only occur with that particular server. The default value is 0.0.0.0, meaning that any existing server on the network will be used. Valid for IxTclHal, IxTclNetwork.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			n	-target_subport
			x   	-use_vendor_id
			x       		Enables or disables the use of the Vendor Class Identifier.
			x       		Valid for IxTclNetwork.
			x   	-vendor_id
			x       		The vendor ID associated with the client.
			x       		The default value is "Ixia".
			x       		Valid for IxTclHal, IxTclNetwork.
			x   	-version
			x       		Permits the selection of the API used (ixtclhal or ixnetwork). The default value is ixtclhal.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-vlan_id_outer_increment_step
			x       		How often a new outer VLAN ID is generated, if encapsulation is ethernet_ii_qinq.
			x       		Valid for IxTclNetwork.
			x   	-vlan_id_increment_step
			x       		How often a new outer VLAN ID is generated, if encapsulation is ethernet_ii_vlan. Otherwise, specifies
			x       		how often a new inner VLAN ID is generated, if encapsulation is ethernet_ii_qinq.
			x       		Valid for IxTclNetwork.
			x   	-vlan_id_outer_priority
			x       		The 802.1Q priority for the inner VLAN.
			x       		Valid for IxTclNetwork.
			x   	-vlan_user_priority
			x       		The 802.1Q priority for the outer VLAN.
			x       		Valid for IxTclNetwork.
			    	-mode
			        		Action to take on the port specified the handle argument.
			        		Valid choices are:
			            		create - starts emulation on the port
			            		create_relay_agent - only creates a DHCP Relay Agent stack, without the DHCP client behind it.
			            		modify - applies the parameters specified in subsequent arguments.
			            		reset - stops the emulation locally without attempting to clear the bound addresses from the DHCP server. This mode is only valid for IxNetwork-FT (P type of HLTSET).
			    	-handle
			        		Specifies the port and group upon which emulation is configured.If
			        		the -mode is "modify", -handle specifies the group upon which
			        		emulation is configured, otherwise it specifies the session upon
			        		which emulation is configured.
			        		Valid for IxTclHal and IxTclNetwork.
			n   	-release_rate
			n       		...
			n       		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n   	-request_rate
			n       		...
			n       		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x   	-use_rapid_commit
			x       		Enable DHCP Client to negotiate leases with rapid commit.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-protocol_name
			x       		Name of the dhcp protocol as it should appear in the IxNetwork GUI.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-dhcp4_broadcast
			x       		If enabled, ask the server or relay agent to use the broadcast IP address in the replies.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_stateless
			x       		Enable DHCP stateless.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-dhcp6_use_pd_global_address
			x       		Use DHCPc6-PD global addressing.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-dhcp_range_relay_type
			x       		Defines the relay agent type to be used: normal or lightweight.
			x       		The default value is normal. Valid only for dhcpv6.
			x       		Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		normal -
			x           		lightweight -
			x   	-dhcp_range_use_relay_agent
			x       		If true, the subnet will emulate a DHCP relay agent (added before the DHCP device group).
			x       		Valid for IxTclNetwork.
			x   	-dhcp_range_relay_count
			x       		The number of relay agents to use in this range. Note that the number
			x       		of Ethernet or ATM interfaces used by a range has to be equal to the
			x       		number of DHCP clients plus the number of relay agents, and the relay
			x       		agent count cannot exceed the number of DHCP clients defined on the Ixia
			x       		port. The default is 1.
			x       		Valid for IxTclNetwork.
			x   	-dhcp_range_relay_override_vlan_settings
			x       		If true, the DHCP plug-in overrides the VLAN settings, thereby allowing
			x       		you to specify how VLANs are assigned.
			x       		Valid for IxTclNetwork.
			x   	-dhcp_range_relay_first_vlan_id
			x       		The first (outer) VLAN ID to allocate to relay agent interfaces. The
			x       		default is 1.
			x       		Valid for IxTclNetwork.
			x   	-dhcp_range_relay_vlan_increment
			x       		The VLAN increment to use for relay interfaces. The default is 1.
			x       		Valid for IxTclNetwork.
			x   	-dhcp_range_relay_vlan_count
			x       		The number of different VLAN IDs to use. The default is 1.
			x       		Valid for IxTclNetwork.
			x   	-dhcp_range_relay_destination
			x       		The address to which the requests from DHCP clients are forwarded. The
			x       		default value is 20.0.0.1.
			x       		Valid for IxTclNetwork.
			x   	-dhcp_range_relay_first_address
			x       		The IP address of the first emulated DHCP Relay Agent. The DHCP network
			x       		stack element will create one relay agent on each port contained in the
			x       		current port and current range. The default value is 20.0.0.100.
			x       		Valid for IxTclNetwork.
			x   	-dhcp_range_relay_address_increment
			x       		The value by which to increment the IP address for each relay agent.
			x       		The default value is 0.0.0.1.
			x       		Valid for IxTclNetwork.
			x   	-dhcp_range_relay_subnet
			x       		The network mask (expressed as a prefix length) used for all relay agents.
			x       		The default value is 24.
			x       		Valid for IxTclNetwork.
			x   	-dhcp_range_relay_gateway
			x       		The gateway address used for all relay agents. Default value is 20.0.0.1.
			x       		Valid for IxTclNetwork.
			x   	-dhcp_range_relay_use_circuit_id
			x       		This sub-option can be added by DHCP relay agents who terminate switched or permanent circuits. Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-dhcp_range_relay_circuit_id
			x       		If enabled, the CIRCUIT-ID option is sent along with the other options. This parameter is disabled by default. Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-dhcp_range_relay_hosts_per_circuit_id
			x       		The Number of consecutive hosts with the same Circuit ID. Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-dhcp_range_relay_use_remote_id
			x       		If enabled, the REMOTE-ID option is sent along with the other options.This parameter is disabled by default. Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-dhcp_range_relay_remote_id
			x       		This sub-option can be added by DHCP relay agents that terminate switched or permanent circuits and have mechanisms to identify the remote host end of the circuit. Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-dhcp_range_relay_hosts_per_remote_id
			x       		The Number of consecutive hosts with the same Circuit ID. Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-dhcp_range_relay_use_suboption6
			x       		When true, relay agents will add suboption 6 (RFC3993) to the DHCP packets they send to DHCP servers. Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-dhcp_range_suboption6_address_subnet
			x       		The network mask used for all suboption 6 addresses. Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-dhcp_range_suboption6_first_address
			x       		The first suboption6 IP address to use. Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-dhcp_range_relay6_use_opt_interface_id
			x       		When true, the relay INTERFACE-ID option is sent along with the other options.This parameter is disabled by default. Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-dhcp_range_relay6_opt_interface_id
			x       		This option can be added by DHCP relay agents that terminate switched or permanent circuits and have mechanisms to identify the remote host-end of the circuit (see RFC 3315, section 22.18). Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-dhcp_range_relay6_hosts_per_opt_interface_id
			x       		The number of consecutive hosts with the same interface ID option. Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-dhcp4_gateway_address
			x       		The Gateway IP Address for the session.
			x       		Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-dhcp4_gateway_mac
			x       		The Gateway Mac for the session.
			x       		Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-use_custom_link_local_address
			x       		Enables users to manually set non-EUI link local addresses
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-custom_link_local_address
			x       		Configures the Manual Link-Local IPv6 Address for the DHCPv6 Client.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-dhcp6_gateway_address
			x       		The Gateway IPv6 Address for the session.
			x       		Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-dhcp6_gateway_mac
			x       		The Gateway Mac for the session.
			x       		Valid for IxTclNetwork.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-reconf_via_relay
			x       		If Enabled allows Reconfigure to be sent from server to Client via RelayAgent
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-dhcpv6_multiplier
			x       		Number of layer instances per parent instance (multiplier)
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		   A list containing the dhcpv6 iapd protocol stack handles that were added by the command (if any).
			x   key:dhcpv6_iapd_handle       value:A list containing the dhcpv6 iapd protocol stack handles that were added by the command (if any).
		   A list containing the dhcpv6 iana protocol stack handles that were added by the command (if any).
			x   key:dhcpv6_iana_handle       value:A list containing the dhcpv6 iana protocol stack handles that were added by the command (if any).
		   $::SUCCESS | $::FAILURE
			    key:status                   value:$::SUCCESS | $::FAILURE
		   When status is failure, contains more info
			    key:log                      value:When status is failure, contains more info
		   Handle of the dhcp endpoint configured Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			    key:handle                   value:Handle of the dhcp endpoint configured Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   Handle of any dhcpv4 endpoints configured
			    key:dhcpv4client_handle      value:Handle of any dhcpv4 endpoints configured
		   Handle of any dhcpv6 endpoints configured
			    key:dhcpv6client_handle      value:Handle of any dhcpv6 endpoints configured
		   Handle of any dhcpv4 relay agents configured
			    key:dhcpv4relayagent_handle  value:Handle of any dhcpv4 relay agents configured
		   Handle of any dhcpv6 relay agents configured
			    key:dhcpv6relayagent_handle  value:Handle of any dhcpv6 relay agents configured
		   $::SUCCESS | $::FAILURE
			    key:status                   value:$::SUCCESS | $::FAILURE 
		   When status is failure, contains more info
			    key:log                      value:When status is failure, contains more info 
		   Handle of the dhcp endpoint configured
			    key:handle                   value:Handle of the dhcp endpoint configured
		
		Examples:
		   See files starting with DHCP_ in the Samples subdirectory. See the DHCP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		   If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		
		See Also:
		
		"""
		return self._run_keyword("emulation_dhcp_group_config", kwargs)

	def emulation_dhcp_server_config(self, **kwargs):
		""" This procedure configures the DHCP emulation server. It creates, modifies, or resets an emulated Dynamic Host Configuration Protocol (DHCP) server or Dynamic Host Configuration Protocol for the specified Ixia port.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_dhcp_server_config
			 	[-count                                 RANGE 1-100000
			                                         DEFAULT 1]
			x	[-ip_count                              NUMERIC
			x                                        DEFAULT 1]
			x	[-dhcp6_ia_type                         CHOICES iana iata iapd iana_iapd
			x                                        DEFAULT iana]
			n	[-dhcp_ack_circuit_id                   ANY]
			n	[-dhcp_ack_cisco_server_id_override     ANY]
			n	[-dhcp_ack_link_selection               ANY]
			n	[-dhcp_ack_options                      ANY]
			n	[-dhcp_ack_remote_id                    ANY]
			n	[-dhcp_ack_router_address               ANY]
			n	[-dhcp_ack_server_id_override           ANY]
			n	[-dhcp_ack_subnet_mask                  ANY]
			n	[-dhcp_ack_time_offset                  ANY]
			n	[-dhcp_ack_time_server_address          ANY]
			n	[-dhcp_ignore_mac                       ANY]
			n	[-dhcp_ignore_mac_mask                  ANY]
			n	[-dhcp_mac_nak                          ANY]
			n	[-dhcp_mac_nak_mask                     ANY]
			n	[-dhcp_offer_circuit_id                 ANY]
			n	[-dhcp_offer_cisco_server_id_override   ANY]
			n	[-dhcp_offer_link_selection             ANY]
			 	[-dhcp_offer_options                    CHOICES 0 1
			                                         DEFAULT 0]
			n	[-dhcp_offer_remote_id                  ANY]
			 	[-dhcp_offer_router_address             IP
			                                         DEFAULT 0.0.0.0]
			x	[-dhcp_offer_router_address_step        IP
			x                                        DEFAULT 0.0.0.0]
			x	[-dhcp_offer_router_address_inside_step IP
			x                                        DEFAULT 0.0.0.0]
			n	[-dhcp_offer_server_id_override         ANY]
			n	[-dhcp_offer_subnet_mask                ANY]
			n	[-dhcp_offer_time_offset                ANY]
			n	[-dhcp_offer_time_server_address        ANY]
			 	[-encapsulation                         ANY]
			 	[-handle                                ANY]
			 	[-ip_address                            IP
			                                         DEFAULT 10.10.0.1|1000::100]
			x	[-ip_dns1                               IP]
			x	[-ip_dns1_step                          IP
			x                                        DEFAULT 0.1.0.0|0:0:0:0:0:0:0:0100]
			x	[-ip_dns1_inside_step                   IP
			x                                        DEFAULT 0.0.0.1|0:0:0:0:0:0:0:1]
			x	[-ip_dns2                               IP]
			x	[-ip_dns2_step                          IP
			x                                        DEFAULT 0.1.0.0|0:0:0:0:0:0:0:0100]
			x	[-ip_dns2_inside_step                   IP
			x                                        DEFAULT 0.0.0.1|0:0:0:0:0:0:0:1]
			 	[-ip_gateway                            IP]
			x	[-ip_gateway_step                       IP
			x                                        DEFAULT 0.1.0.0]
			x	[-ip_gateway_inside_step                IP]
			 	[-ip_prefix_length                      RANGE 0-128
			                                         DEFAULT 16|120]
			 	[-ip_prefix_step                        NUMERIC
			                                         DEFAULT 1]
			x	[-ip_prefix_inside_step                 NUMERIC
			x                                        DEFAULT 1]
			 	[-ip_repeat                             NUMERIC
			                                         DEFAULT 1]
			 	[-ip_step                               IP
			                                         DEFAULT 0.1.0.0|0:0:0:0:0:0:0:0100]
			x	[-ip_inside_step                        IP
			x                                        DEFAULT 0.1.0.0|0:0:0:0:0:0:0:0100]
			x	[-ip_version                            CHOICES 4 6
			x                                        DEFAULT 4]
			 	[-ipaddress_count                       RANGE 1-1000000
			                                         DEFAULT 16000]
			n	[-ipaddress_increment                   ANY]
			 	[-ipaddress_pool                        IP
			                                         DEFAULT 10.10.1.1|::A0A:101]
			x	[-ipaddress_pool_step                   IP
			x                                        DEFAULT 0.1.0.0|0:0:0:0:0:0:0:0100]
			x	[-ipaddress_pool_inside_step            IP
			x                                        DEFAULT 0.1.0.0|0:0:0:0:0:0:0:0100]
			x	[-ipaddress_pool_prefix_length          RANGE 0-128
			x                                        DEFAULT 16|120]
			x	[-ipaddress_pool_prefix_step            NUMERIC
			x                                        DEFAULT 1]
			x	[-ipaddress_pool_prefix_inside_step     NUMERIC
			x                                        DEFAULT 1]
			x	[-ipv6_gateway                          IPV6
			x                                        DEFAULT 1000::1]
			x	[-ipv6_gateway_step                     IPV6
			x                                        DEFAULT 0:0:0:0:0:0:0:0100]
			x	[-ipv6_gateway_inside_step              IPV6
			x                                        DEFAULT 0:0:0:0:0:0:0:0100]
			 	[-lease_time                            RANGE 300-30000000
			                                         DEFAULT 3600]
			x	[-lease_time_max                        ANY]
			x	[-lease_time_increment                  NUMERIC]
			 	[-local_mac                             MAC
			                                         DEFAULT 0000.0000.0001]
			x	[-local_mac_outer_step                  MAC
			x                                        DEFAULT 0000.0001.0000]
			x	[-local_mac_step                        MAC
			x                                        DEFAULT 0000.0000.0001]
			x	[-local_mtu                             RANGE 500-9216
			x                                        DEFAULT 1500]
			 	[-mode                                  CHOICES create modify reset
			                                         DEFAULT create]
			x	[-ping_check                            CHOICES 0 1
			x                                        DEFAULT 0]
			x	[-ping_timeout                          RANGE 1-100
			x                                        DEFAULT 1]
			x	[-offer_timeout                         NUMERIC]
			x	[-advertise_timeout                     NUMERIC]
			x	[-init_force_renew_timeout              NUMERIC]
			x	[-force_renew_factor                    NUMERIC]
			x	[-force_renew_max_rc                    NUMERIC]
			x	[-reconfigure_timeout                   NUMERIC]
			x	[-reconfigure_max_rc                    NUMERIC]
			 	[-port_handle                           ANY]
			x	[-pvc_incr_mode                         ANY]
			x	[-qinq_incr_mode                        CHOICES inner outer both
			x                                        DEFAULT both]
			n	[-remote_mac                            ANY]
			x	[-single_address_pool                   ANY]
			n	[-spfc_mac_ipaddress_count              ANY]
			n	[-spfc_mac_ipaddress_increment          ANY]
			n	[-spfc_mac_ipaddress_pool               ANY]
			n	[-spfc_mac_mask_pool                    ANY]
			n	[-spfc_mac_pattern_pool                 ANY]
			x	[-vci                                   ANY]
			x	[-vci_count                             ANY]
			x	[-vci_repeat                            ANY]
			x	[-vci_step                              ANY]
			n	[-vlan_ethertype                        ANY]
			 	[-vlan_id                               RANGE 0-4095]
			x	[-vlan_id_count                         RANGE 0-4095
			x                                        DEFAULT 1]
			x	[-vlan_id_count_inner                   RANGE 0-4095
			x                                        DEFAULT 1]
			x	[-vlan_id_inner                         RANGE 0-4095]
			x	[-vlan_id_repeat                        NUMERIC
			x                                        DEFAULT 1]
			x	[-vlan_id_repeat_inner                  NUMERIC
			x                                        DEFAULT 1]
			x	[-vlan_id_step                          RANGE 0-4095
			x                                        DEFAULT 1]
			x	[-vlan_id_step_inner                    RANGE 0-4095
			x                                        DEFAULT 1]
			x	[-vlan_id_inter_device_step             RANGE 0-4095
			x                                        DEFAULT 1]
			x	[-vlan_id_inner_inter_device_step       RANGE 0-4095
			x                                        DEFAULT 1]
			x	[-vlan_user_priority                    RANGE 0-7
			x                                        DEFAULT 0]
			x	[-vlan_user_priority_inner              RANGE 0-7
			x                                        DEFAULT 0]
			x	[-vpi                                   ANY]
			x	[-vpi_count                             ANY]
			x	[-vpi_repeat                            ANY]
			x	[-vpi_step                              ANY]
			x	[-functional_specification              CHOICES v4_compatible
			x                                        CHOICES v4_v6_compatible
			x                                        DEFAULT v4_compatible]
			n	[-args                                  ANY]
			n	[-dhcp_mac_ignore_mask                  ANY]
			n	[-spfc_mac_address_pool                 ANY]
			x	[-protocol_name                         ALPHA]
			x	[-use_rapid_commit                      CHOICES 0 1]
			x	[-echo_relay_info                       CHOICES 0 1
			x                                        DEFAULT 1]
			x	[-pool_address_increment                IP]
			x	[-pool_address_increment_step           IP]
			x	[-start_pool_prefix                     IPV6]
			x	[-start_pool_prefix_step                IPV6]
			x	[-pool_prefix_increment                 IPV6]
			x	[-pool_prefix_increment_step            IPV6]
			x	[-pool_prefix_size                      NUMERIC]
			x	[-prefix_length                         NUMERIC]
			x	[-dns_domain                            ALPHA]
			x	[-custom_renew_time                     NUMERIC]
			x	[-custom_rebind_time                    NUMERIC]
			x	[-use_custom_times                      CHOICES 0 1
			x                                        DEFAULT 0]
			x	[-enable_resolve_gateway                CHOICES 0 1
			x                                        DEFAULT 1]
			x	[-manual_gateway_mac                    MAC]
			x	[-manual_gateway_mac_step               MAC
			x                                        DEFAULT 0000.0000.0001]
			x	[-reconfigure_rate_scale_mode           CHOICES port device_group
			x                                        DEFAULT port]
			x	[-reconfigure_rate_enabled              CHOICES 0 1]
			x	[-reconfigure_rate_max_outstanding      NUMERIC]
			x	[-reconfigure_rate_interval             NUMERIC]
			x	[-reconfigure_rate                      NUMERIC]
			x	[-pool_count                            NUMERIC]
			x	[-enable_address_match_duid             CHOICES 0 1]
			x	[-address_duid_mask                     HEX]
			x	[-address_duid_pattern                  HEX]
			x	[-addresses_per_ia                      NUMERIC]
			x	[-enable_prefix_match_duid              CHOICES 0 1]
			x	[-prefix_duid_start                     HEX]
			x	[-prefix_duid_increment                 HEX]
			x	[-prefixes_per_ia                       NUMERIC]
			x	[-duid_match_nak                        CHOICES 0 1]
			x	[-duid_nak_mask                         HEX]
			x	[-duid_nak_pattern                      HEX]
			x	[-duid_match_ignore                     CHOICES 0 1]
			x	[-duid_ignore_mask                      HEX]
			x	[-duid_ignore_pattern                   HEX]
			x	[-subnet_addr_assign                    CHOICES 0 1]
			x	[-reconf_via_relay                      CHOICES 0 1]
			x	[-subnet                                CHOICES relay
			x                                        CHOICES link_selection
			x                                        CHOICES server_id_override]
		
		Arguments:
			 	-count
			 		Number of emulated dhcp server devices. This parameter is supported
			 		using the following APIs: IxTclNetwork.
			 		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-ip_count
			x		The number of IPv4 values in sequence.
			x	-dhcp6_ia_type
			x		The Identity Association type for DHCP V6.
			x		Valid for functional_specification: v4_v6_compatible.
			x		Valid choices are:
			x   		iana -
			x   		iata -
			x   		iapd -
			x   		iana_iapd -
			n	-dhcp_ack_circuit_id
			n		Configure the client ID option (61).
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_ack_cisco_server_id_override
			n		Configure the Cisco server ID override IP address (suboption 152).
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_ack_link_selection
			n		Configure the link selection subnet IP address (RFC 3527).
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_ack_options
			n		Enable DHCP ACK Options.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_ack_remote_id
			n		Configure the remote ID sub-option of relay agent option (82).
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_ack_router_address
			n		DHCP ACK Option router option IP address. Dependencies: -dhcp_offer_options.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_ack_server_id_override
			n		Configure the server ID override IP address (suboption 182).
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_ack_subnet_mask
			n		DHCP ACK Options subnet mask. Dependencies: -dhcp_ack_options.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_ack_time_offset
			n		DHCP ACK Option time offset. Dependencies: -dhcp_ack_options.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_ack_time_server_address
			n		DHCP ACK Option timer server address. Dependencies: -dhcp_ack_options.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_ignore_mac
			n		DHCP MAC address or pattern to ignore. Dependencies: -dhcp_mac_ignore_mask
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_ignore_mac_mask
			n		DHCP mask bit to be compared with -dhcp_ignore_mac address or pattern. Dependencies: -dhcp_ignore_mac.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_mac_nak
			n		DHCP MAC address or pattern to be sent a NAK PDU. Dependencies: -dhcp_mac_nak_mask.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_mac_nak_mask
			n		DHCP bit mask to be compared with -dhcp_mac_nak address or pattern. Dependencies: -dhcp_mac_nak.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_offer_circuit_id
			n		Configure the client ID option (61).
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_offer_cisco_server_id_override
			n		Configure the Cisco server ID override IP address (suboption 152).
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_offer_link_selection
			n		Configure the link selection subnet IP address (RFC 3527).
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-dhcp_offer_options
			 		Dhcp offer options
			n	-dhcp_offer_remote_id
			n		Configure the remote ID sub-option of relay agent option (82).
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-dhcp_offer_router_address
			 		DHCP Offer Option router option IP address. Dependencies:
			 		-dhcp_offer_options.
			 		Valid for functional_specification: v4_v6_compatible.
			x	-dhcp_offer_router_address_step
			x		DHCP Offer Option router option IP address step. Dependencies:
			x		-dhcp_offer_options.
			x		Valid for functional_specification: v4_v6_compatible.
			x	-dhcp_offer_router_address_inside_step
			x		DHCP Offer Option router option IP address step inside the dhcp range. Dependencies:
			x		-dhcp_offer_options.
			x		Valid for functional_specification: v4_v6_compatible.
			n	-dhcp_offer_server_id_override
			n		Configure the server ID override IP address (suboption 182).
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_offer_subnet_mask
			n		DHCP Offer Options subnet mask. Dependencies: -dhcp_offer_options.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_offer_time_offset
			n		DHCP Offer Option time offset. Dependencies: -dhcp_offer_options.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dhcp_offer_time_server_address
			n		DHCP Offer Option timer server address. Dependencies: -dhcp_offer_options.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-encapsulation
			 		The encapsulation for this port. This parameter is supported using the following APIs: IxTclNetwork.Valid for functional_specification: v4_compatible, v4_v6_compatible. ETHERNET_IISAP - not supportedSNAP- LLC Routed AAL5 Snapethernet_ii- Ethernet II (default for Ethernet cards)ethernet_ii_vlan- Ethernet II with a single vlan tagethernet_ii_qinq- Inner vlan capability vc_mux_ipv4_routed- VC Mux IPv4 Routedvc_mux_fcs- VC Mux Bridged Ethernet (FCS)vc_mux- VC Mux Bridged Ethernet (no FCS)vc_mux_ipv6_routed- VC Mux IPv6 Routedllcsnap_routed- LLC Routed AAL5 Snapllcsnap_fcs- LLC Bridged Ethernet (FCS)llcsnap- LLC Bridged Ethernet (no FCS) (default for ATM cards)llcsnap_ppp- LLC Encap PPPvc_mux_ppp- VC Mux PPP
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-handle
			 		The DHCP Server handle for which the configuration will be made. Valid
			 		for -mode modify and reset. This parameter is supported using the
			 		following APIs: IxTclNetwork.
			 		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			 		When -handle is provided with the /globals value the arguments that configure global protocol
			 		setting accept both multivalue handles and simple values.
			 		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
			 		that configure global settings will only accept simple values. In this situation, these arguments will
			 		configure only the settings of the parent device group or the ports associated with the parent topology.
			 	-ip_address
			 		IPv4 or IPv6 address of the emulated device. This parameter is supported
			 		using the following APIs: IxTclNetwork.
			 		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-ip_dns1
			x		First DNS Server.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-ip_dns1_step
			x		First DNS Server step when creating multiple DHCP Servers.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-ip_dns1_inside_step
			x		First DNS Server step inside DHCP range.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ip_dns2
			x		Second DNS Server.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-ip_dns2_step
			x		Second DNS Server step when creating multiple DHCP Servers.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-ip_dns2_inside_step
			x		Second DNS Server step inside the Dhcp server range.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-ip_gateway
			 		The IPv4 or IPv6 address of the DUT. This parameter is supported using
			 		the following APIs: IxTclNetwork.
			 		Valid for functional_specification:
			 		v4_compatible - ip_gateway represents the gateway for the IPv4 address pool and the default value is 10.10.0.2
			 		v4_v6_compatible - ip_gateway represents the gateway for the IPv4/v6 server address and there is no default value
			x	-ip_gateway_step
			x		The incrementing step for the IPv4 (or 6) address of the DUT. Valid only for -mode create and when -count is greater than 1. This parameter is
			x		supported using the following APIs: IxTclNetwork.
			x		Valid for functional_specification:
			x		v4_compatible - represents the gateway step for the IPv4 address pool
			x		v4_v6_compatible - represents the gateway step for the IPv4/v6 server address
			x	-ip_gateway_inside_step
			x		The incrementing step for the IPv4 (or 6) address of the DUT inside the dhcp server range.
			x		Valid only for -mode create and when -count is greater than 1. This parameter is
			x		supported using the following APIs: IxTclNetwork.
			x		Valid for functional_specification:
			x		v4_compatible - represents the gateway step for the IPv4 address pool
			x		v4_v6_compatible - represents the gateway step for the IPv4/v6 server address
			 	-ip_prefix_length
			 		The bit position at which the prefix step is applied. This parameter is
			 		supported using the following APIs: IxTclNetwork.
			 		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			 	-ip_prefix_step
			 		The size of the step applied to the prefix length bit position.
			 		Depends on ip_prefix_length if ip_step is not used. Valid only
			 		for -mode create and when -count is greater than 1. This parameter is
			 		supported using the following APIs: IxTclNetwork.
			 		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-ip_prefix_inside_step
			x		The size of the step applied to the prefix length bit position, inside the dhcp server range.
			x		Depends on ip_prefix_length if ip_step is not used. Valid only
			x		for -mode create and when -count is greater than 1. This parameter is
			x		supported using the following APIs: IxTclNetwork.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-ip_repeat
			 		The number of times to repeat a value before incrementing. Valid only
			 		for -mode create and when -count is greater than 1. This parameter is
			 		supported using the following APIs: IxTclNetwork.
			 		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			 	-ip_step
			 		Incrementing step for the IPv4 (or 6) address of the emulated device. Valid
			 		only for -mode create and when -count is greater than 1. This parameter
			 		is supported using the following APIs: IxTclNetwork.
			 		Valid for functional_specification: v4_compatible (default 0.1.0.0|0:0:0:0:0:0:0:0100) , v4_v6_compatible (default 0.0.0.1|0:0:0:0:0:0:0:0001).
			x	-ip_inside_step
			x		Incrementing step for the IPv4 (or 6) address of the emulated device, inside the dhpc server range. Valid
			x		only for -mode create and when -count is greater than 1. This parameter
			x		is supported using the following APIs: IxTclNetwork.
			x		Valid for functional_specification: v4_compatible (default 0.0.0.1|0:0:0:0:0:0:0:0001), v4_v6_compatible (default 0.1.0.0|0:0:0:0:0:0:0:0100)
			x	-ip_version
			x		DHCP Server type: IPv4 or IPv6. Added support for IPv6 in HLT 4.00.
			x		Valid for functional_specification: v4_v6_compatible.
			x		Valid choices are:
			x   		4 - IPv4
			x   		6 - IPv6
			 	-ipaddress_count
			 		Number of ip addresses in the pool. This parameter is supported using
			 		the following APIs: IxTclNetwork.
			 		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			n	-ipaddress_increment
			n		The amount to increment each ip address in the pool.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-ipaddress_pool
			 		The first IP address in the DHCP server address pool. This parameter is
			 		supported using the following APIs: IxTclNetwork.
			 		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-ipaddress_pool_step
			x		The incrementing step for the IPv4 address of the DHCP pool when creating multiple DHCP Servers. Valid only for -mode create and when -count is greater than 1. This parameter is
			x		supported using the following APIs: IxTclNetwork.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-ipaddress_pool_inside_step
			x		The incrementing step for the IPv4 address of the DHCP pool inside the dhcp server range.
			x		Valid only for -mode create and when -count is greater than 1. This parameter is
			x		supported using the following APIs: IxTclNetwork.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipaddress_pool_prefix_length
			x		The bit position at which the prefix step is applied. This parameter is
			x		supported using the following APIs: IxTclNetwork.
			x		Valid for functional_specification: v4_v6_compatible.
			x	-ipaddress_pool_prefix_step
			x		The size of the step applied to the prefix length bit position.
			x		Depends on ipaddress_pool_prefix_length if ipaddress_pool_step is not used. Valid only
			x		for -mode create and when -count is greater than 1. This parameter is
			x		supported using the following APIs: IxTclNetwork.
			x		Valid for functional_specification: v4_v6_compatible.
			x	-ipaddress_pool_prefix_inside_step
			x		The size of the step applied to the prefix length bit position, inside the dhcp server range.
			x		Valid only for -mode create and when -count is greater than 1. This parameter is
			x		supported using the following APIs: IxTclNetwork.
			x		Valid for functional_specification: v4_v6_compatible.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_gateway
			x		The IPv6 address of the DUT.
			x	-ipv6_gateway_step
			x		The incrementing step for the IPv6 address of the DUT. Valid only for -mode create and when -count is greater than 1. This parameter is
			x		supported using the following APIs: IxTclNetwork.
			x		Valid for functional_specification:
			x		v4_v6_compatible - ipc6_gateway represents the gateway step for the IPv6 server address
			x	-ipv6_gateway_inside_step
			x		The incrementing step for the IPv6 address of the DUT, inside the dhcp server range.
			x		Valid only for -mode create and when -count is greater than 1. This parameter is
			x		supported using the following APIs: IxTclNetwork.
			x		Valid for functional_specification:
			x		v4_v6_compatible - ipc6_gateway represents the gateway step for the IPv6 server address
			 	-lease_time
			 		Lease duration is seconds. This parameter is supported using the
			 		following APIs: IxTclNetwork. This is a global setting, valid for all servers.
			 		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-lease_time_max
			x		The maximum lease duration, in seconds. This parameter is supported using the following APIs: IxTclNetwork. This is a global setting, valid for all servers. Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-lease_time_increment
			x		The value with which Lease Time is incremented when assigning many Addresses/Prefixes per IA.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-local_mac
			 		The mac address of the emulated device(s). This parameter is supported
			 		using the following APIs: IxTclNetwork.
			 		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-local_mac_outer_step
			x		The mac address step when creating multiple emulated device(s). This
			x		parameter is supported using the following APIs: IxTclNetwork.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-local_mac_step
			x		The mac address step when enabling multiple VLAN domains. This
			x		parameter is supported using the following APIs: IxTclNetwork.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-local_mtu
			x		Maximum Transmission Unit (MTU) is the largest packet that a given
			x		network medium can carry. Ethernet, for example, has a fixed MTU of
			x		1500 bytes, ATM has a fixed MTU of 48 bytes, and PPP has a negotiated
			x		MTU that is usually between 500 and 2000 bytes. The parameter defines
			x		the MTU value for the Access Node. This parameter is supported using
			x		the following APIs: IxTclNetwork.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			 	-mode
			 		Action to perform. This parameter is supported using the following
			 		APIs: IxTclNetwork.
			 		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			 		Valid choices are:
			    		create - Create new DHCP range on -port_handle.
			    		modify - Modify DHCP range specified with -handle parameter.
			    		reset - Remove DHCP range specified with -handle parameter.
			x	-ping_check
			x		When enabled, the DHCP server issues ICMP echo requests (pings) to
			x		check for the existence of IP addresses in the network. The DHCP will
			x		not assign an IP address to a node that responds to the ICMP echo
			x		requests within the time period specified by Ping Timeout. Note that
			x		using this option will diminish the performance of the test. This
			x		option is disabled by default. This parameter is supported using
			x		the following APIs: IxTclNetwork. This is a global setting, valid for all servers.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-ping_timeout
			x		The number of seconds the DHCP server will wait for an ICMP Echo
			x		response before assigning the address. The default is 1, the minimum
			x		is 1, and the maximum is 100. This parameter is supported using
			x		the following APIs: IxTclNetwork. This is a global setting, valid for all servers.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-offer_timeout
			x		Offer timeout in seconds
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-advertise_timeout
			x		Advertise timeout in seconds
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-init_force_renew_timeout
			x		Force Renew timeout in seconds
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-force_renew_factor
			x		Force Renew timeout factor
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-force_renew_max_rc
			x		Force Renew Attempts
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-reconfigure_timeout
			x		RFC 3315 Reconfigure timeout in seconds
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-reconfigure_max_rc
			x		RFC 3315 Reconfigure retry attempts
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-port_handle
			 		This parameter specifies the port handle upon which emulation is
			 		configured. Mandatory for -mode create. This parameter is supported using the following APIs: IxTclNetwork.
			 		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-pvc_incr_mode
			x		The incrementing mode for VCI/VPI. This parameter is supported using the following APIs: IxTclNetwork.Valid for functional_specification: v4_compatible, v4_v6_compatible.vci - The VCI is incremented first.vpi - The VPI vlan is incremented first.both - Both vlan tags are incremented.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-qinq_incr_mode
			x		The incrementing mode for Stacked Vlan. This parameter is supported
			x		using the following APIs: IxTclNetwork.
			x		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x		Valid choices are:
			x		inner -
			x		Valid choices are:
			x   		inner - The inner vlan is incremented first.
			x   		outer - The outer vlan is incremented first.
			x   		both - Both vlan tags are incremented.
			n	-remote_mac
			n		The remote (DUT) mac address.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-single_address_pool
			x		When enabled, the DHCP leases are collected into a common pool and assigned to clients as needed. Consider using this option when the number of address pools is large and the interface on which the lease is issued is not important. This option is disabled by default. Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			n	-spfc_mac_ipaddress_count
			n		Number of addresses in the ip address pool.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-spfc_mac_ipaddress_increment
			n		Amount by which each IP address in the pool is incremented.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-spfc_mac_ipaddress_pool
			n		First IP address of the MAC specific IP address pool. Dependencies: -spfc_mac_address_pool.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-spfc_mac_mask_pool
			n		Mask bits to be compared to the pattern. Dependencies: -spfc_mac_pattern_pool.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-spfc_mac_pattern_pool
			n		Bit pattern to match. Dependencies: -spfc_mac_mask_pool.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-vci
			x		The VCI value when configuring ATM interfaces.Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vci_count
			x		The number of unique VCI values.Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vci_repeat
			x		The repeat value for the VCI of the interface.Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vci_step
			x		The incrementing step for the VCI of the interface.Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			n	-vlan_ethertype
			 	-vlan_id
			    		Vlan ID of the emulated device. This parameter is supported using the
			    		following APIs: IxTclNetwork.
			    		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-vlan_id_count
			x   		Defines the number of Vlan IDs. This parameter is supported using the
			x   		following APIs: IxTclNetwork.
			x   		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-vlan_id_count_inner
			x   		Defines the number of Inner Vlan IDs. This parameter is supported using
			x   		the following APIs: IxTclNetwork.
			x   		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-vlan_id_inner
			x   		Defines the Inner Vlan ID for Access Node. Doesn't support a list of
			x   		vlan IDs. This parameter is supported using the following APIs:
			x   		IxTclNetwork.
			x   		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-vlan_id_repeat
			x   		Defines the repeat count of VLAN ID. This parameter is supported using
			x   		the following APIs: IxTclNetwork.
			x   		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-vlan_id_repeat_inner
			x   		Defines the repeat count of Inner VLAN ID. This parameter is supported
			x   		using the following APIs: IxTclNetwork.
			x   		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-vlan_id_step
			x   		Defines the Vlan ID incrementing step. This parameter is supported
			x   		using the following APIs: IxTclNetwork. This is valid when emulating a single DHCP device that distributes IP addresses over multiple VLAN domains.
			x   		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-vlan_id_step_inner
			x   		Defines the Inner Vlan ID incrementing step. This parameter is
			x   		supported using the following APIs: IxTclNetwork.
			x   		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-vlan_id_inter_device_step
			x   		Defines the Vlan ID incrementing step when creating multiple DHCP devices. This parameter is supported
			x   		using the following APIs: IxTclNetwork. This parameter is valid only on -mode create when -count is greater than one.
			x   		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-vlan_id_inner_inter_device_step
			x   		Defines the Inner Vlan ID incrementing step when creating multiple DHCP devices. This parameter is supported
			x   		using the following APIs: IxTclNetwork. This parameter is valid only on -mode create when -count is greater than one.
			x   		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-vlan_user_priority
			x   		Defines the Vlan user priority for Access Node. This parameter is
			x   		supported using the following APIs: IxTclNetwork.
			x   		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-vlan_user_priority_inner
			x   		Defines the Inner Vlan user priority for Access Node. This parameter is
			x   		supported using the following APIs: IxTclNetwork.
			x   		Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x	-vpi
			x   		The VPI value when configuring ATM interfaces.Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vpi_count
			x   		The number of unique VPI values.Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vpi_repeat
			x   		The repeat value for the VPI of the interface.Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vpi_step
			x   		The incrementing step for the VPI of the interface.Valid for functional_specification: v4_compatible, v4_v6_compatible.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-functional_specification
			x       		v4_compatible - implementation for DHCPv4 server upto HLT 3.90 (inclusive)
In this implementation parameters are NOT coded vs Cisco FS.
			x       		v4_v6_compatible - implementation for DHCPv4 and DHCPv6 server starting HLT 4.0 (inclusive)
In this implementation parameters are coded vs Cisco FS.
			n	-args
			n   	-dhcp_mac_ignore_mask
			n       	-spfc_mac_address_pool
			x           	-protocol_name
			x               		Name of the dhcp protocol as it should appear in the IxNetwork GUI
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-use_rapid_commit
			x               		Enable DHCP Server to negotiate leases with rapid commit for DHCP Clients that request it.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-echo_relay_info
			x               		Enable echoing of DHCP option 82.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-pool_address_increment
			x               		The increment value for the lease address within the lease pool.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-pool_address_increment_step
			x               		The increment step value for the lease address within the lease pool.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-start_pool_prefix
			x               		The prefix of the first lease pool.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-start_pool_prefix_step
			x               		The prefix step of the first lease pool.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-pool_prefix_increment
			x               		The increment value for the lease prefix within the lease pool.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-pool_prefix_increment_step
			x               		The increment step value for the lease prefix within the lease pool.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-pool_prefix_size
			x               		The number of leases to be allocated per each server prefix.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-prefix_length
			x               		The subnet address length advertised in DHCP Offer and Replay messages
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-dns_domain
			x               		The domain name to be searched during name resolution advertised in DHCP Offer and Reply messages.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-custom_renew_time
			x               		The time (in seconds) after the client will start renewing the leases from the server.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-custom_rebind_time
			x               		The time (in seconds) after the client will start rebinding the leases from the server.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-use_custom_times
			x               		Use Custom Renew/Rebind Times instead of the ones computed from the valability times of the leases.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-enable_resolve_gateway
			x               		Autoresolve gateway MAC addresses.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-manual_gateway_mac
			x               		The manual gateway MAC addresses.
			x               		This option has no effect unless enable_resolve_gateway is set to 0.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-manual_gateway_mac_step
			x               		The step of the manual gateway MAC addresses.
			x               		This option has no effect unless enable_resolve_gateway is set to 0.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-reconfigure_rate_scale_mode
			x               		Indicates whether the control is specified per port or per device group
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x               		Valid choices are:
			x                   		port -
			x                   		device_group -
			x           	-reconfigure_rate_enabled
			x               		Enabled
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-reconfigure_rate_max_outstanding
			x               		The number of triggered instances of an action that is still awaiting a response or completion
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-reconfigure_rate_interval
			x               		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-reconfigure_rate
			x               		Number of times an action is triggered per time interval
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-pool_count
			x               		The number of DHCP pools a single server has
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-enable_address_match_duid
			x               		If enabled, the requests with DUIDs matching the mask and pattern will be assigned addresses from this pool.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-address_duid_mask
			x               		The mask based on which the DUIDs are chosen for address assignment.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-address_duid_pattern
			x               		The pattern based on which the DUIDs are chosen for address assignment.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-addresses_per_ia
			x               		The number of Addreses the Server offers for each IA.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-enable_prefix_match_duid
			x               		If enabled, the requests with DUIDs matching DUID start and increment will be given a specific prefix from this pool.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-prefix_duid_start
			x               		The first DUID which will be chosen for prefix assignment.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-prefix_duid_increment
			x               		The increment used to generate the DUIDs which will be chosen for prefix assignment.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-prefixes_per_ia
			x               		The number of Prefixes the Server offers for each IA.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-duid_match_nak
			x               		If enabled, the requests with DUIDs matching the mask and pattern will be NAKed by the Server.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-duid_nak_mask
			x               		The mask based on which the DUIDs of NAKed addresses are chosen.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-duid_nak_pattern
			x               		The pattern based on which the DUIDs of NAKed addresses are chosen.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-duid_match_ignore
			x               		If enabled, the requests with DUIDs matching the mask and pattern will be ignored by the Server.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-duid_ignore_mask
			x               		The mask based on which the DUIDs of ignored addresses are chosen.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-duid_ignore_pattern
			x               		The pattern based on which the DUIDs of ignored addresses are chosen.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-subnet_addr_assign
			x               		Enables DHCP Server to assign addresses based on subnet
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-reconf_via_relay
			x               		If Enabled allows Reconfigure to be sent from server to Client via RelayAgent
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-subnet
			x               		Subnet to be used for address assignment
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x               		Valid choices are:
			x                   		relay - Relay Agent IP Address Subnet
			x                   		link_selection - Link Selection Subnet
			x                   		server_id_override - Server ID Override Subnet
		       
		       Return Values:
		           A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x           key:handle               value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		           $::SUCCESS | $::FAILURE Status of procedure call.
			            key:status               value:$::SUCCESS | $::FAILURE Status of procedure call.
		           When status is failure, contains more information.
			            key:log                  value:When status is failure, contains more information.
		           The port handle on which DHCP emulation was configured.
			            key:handle.port_handle   value:The port handle on which DHCP emulation was configured.
		           The handle of the DHCP emulation.
			            key:handle.dhcp_handle   value:The handle of the DHCP emulation.
		           Handle of any dhcpv4 endpoints configured
			            key:dhcpv4server_handle  value:Handle of any dhcpv4 endpoints configured
		           Handle of any dhcpv6 endpoints configured
			            key:dhcpv6server_handle  value:Handle of any dhcpv6 endpoints configured
		       
		       Examples:
		       
		       Sample Input:
		       
		       Sample Output:
		       
		       Notes:
		           When -handle is provided with the /globals value the arguments that configure global protocol
		           setting accept both multivalue handles and simple values.
		           When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
		           that configure global settings will only accept simple values. In this situation, these arguments will
		           configure only the settings of the parent device group or the ports associated with the parent topology.
		           If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		       
		       See Also:
		       
		"""
		return self._run_keyword("emulation_dhcp_server_config", kwargs)

	def emulation_dhcp_server_control(self, **kwargs):
		""" This procedure controls DHCP Server actions on an Ixia port.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_dhcp_server_control
			 	[-dhcp_handle ANY]
			 	[-port_handle ANY]
			n	[-args        ANY]
			 	-action       CHOICES abort
			               CHOICES abort_async
			               CHOICES renew
			               CHOICES reset
			               CHOICES collect
			               CHOICES restart_down
			               CHOICES force_renew
			               CHOICES reconfigure
		
		Arguments:
			 	-dhcp_handle
			 		DHCP Server range to perform action for. This parameter is supported using
			 		the following APIs: IxTclNetwork.
			 	-port_handle
			 		The port handle to perform action for. This parameter is supported using
			 		the following APIs: IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			n	-args
			 	-action
			    		This is a mandatory argument. Used to select the task to perform.
			    		This parameter is supported using the following APIs: IxTclNetwork.
			    		Valid choices are: abort abort_async renew reset collect restart_down force_renew reconfigure.
			        		abort -
			        		abort_async -
			        		renew -
			        		reset -
			        		collect -
			        		restart_down -
			        		force_renew - This should be used with DHCPv4 Server.
			        		reconfigure - This should be used with DHCPv6 Server.
		
		Return Values:
		$::SUCCESS | $::FAILURE Status of procedure call.
			 key:status  value:$::SUCCESS | $::FAILURE Status of procedure call.
		When status is failure, contains more information.
			 key:log     value:When status is failure, contains more information.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_dhcp_server_control", kwargs)

	def emulation_dhcp_server_stats(self, **kwargs):
		""" This procedure retrieves DHCP Server statistics for the specified Ixia port.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_dhcp_server_stats
			 	[-dhcp_handle       ANY]
			 	[-handle            ANY]
			 	[-port_handle       ANY]
			 	[-ip_version        CHOICES 4 6
			                     DEFAULT 4]
			 	-action             CHOICES clear collect
			x	[-execution_timeout NUMERIC
			x                    DEFAULT 1800]
		
		Arguments:
			 	-dhcp_handle
			 		DHCP Server range to perform action for. This parameter is supported using
			 		the following APIs: IxTclNetwork. The DHCP Server stats per handle are not supported.
			 		The aggregated ones will be returned instead, for the port_handle on which the DHCP Server handle belongs.
			 		This parameter acts in the same way as handle. It is implemented for backwards compatibility.
			 	-handle
			 		DHCP Server range to perform action for. This parameter is supported using
			 		the following APIs: IxTclNetwork. The DHCP Server stats per handle are not supported.
			 		The aggregated ones will be returned instead, for the port_handle on which the DHCP Server handle belongs.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-port_handle
			 		The port handle to perform action for. This parameter is supported using
			 		the following APIs: IxTclNetwork.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ip_version
			 		DHCP Server IP type. This parameter is supported using
			 		the following APIs: IxTclNetwork. The DHCP Server stats per handle are not supported.
			 		The aggregated ones will be returned instead, for the port_handle on which the DHCP Server handle belogs.
			 		Valid choices are:
			    		4 - dhcpv4server
			    		6 - dhcpv6server
			 	-action
			 		This is a mandatory argument. Used to select the task to perform.
			 		This parameter is supported using the following APIs: IxTclNetwork.Valid choices are: clear collect.
			    		clear -
			    		collect -
			x	-execution_timeout
			x		This is the timeout for the function.
			x		The setting is in seconds.
			x		Setting this setting to 60 it will mean that the command must complete in under 60 seconds.
			x		If the command will last more than 60 seconds the command will be terminated by force.
			x		This flag can be used to prevent dead locks occuring in IxNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE Status of procedure call.
			 key:status                                               value:$::SUCCESS | $::FAILURE Status of procedure call.
		When status is failure, contains more information.
			 key:log                                                  value:When status is failure, contains more information.
		Valid for ip_version 4
			xkey:aggregate.<port_handle>.tx.advertisement             value:Valid for ip_version 4
		Valid for ip_version 6
			xkey:aggregate.<port_handle>.rx.confirm                   value:Valid for ip_version 6
		Valid for ip_version 4,6
			 key:aggregate.<port_handle>.rx.decline                   value:Valid for ip_version 4,6
		Valid for ip_version 4
			 key:aggregate.<port_handle>.rx.discover                  value:Valid for ip_version 4
		Valid for ip_version 4,6
			 key:aggregate.<port_handle>.rx.inform                    value:Valid for ip_version 4,6
			nkey:aggregate.<port_handle>.rx.offer                     value:
		Valid for ip_version 6
			xkey:aggregate.<port_handle>.rx.rebind                    value:Valid for ip_version 6
		Valid for ip_version 6
			xkey:aggregate.<port_handle>.rx.relay_forward             value:Valid for ip_version 6
		Valid for ip_version 6
			xkey:aggregate.<port_handle>.rx.relay_reply               value:Valid for ip_version 6
		Valid for ip_version 6
			xkey:aggregate.<port_handle>.reconfigure_tx               value:Valid for ip_version 6
		Valid for ip_version 6
			xkey:aggregate.<port_handle>.nak_sent                     value:Valid for ip_version 6
		Valid for ip_version 6
			xkey:aggregate.<port_handle>.solicits_ignored             value:Valid for ip_version 6
		Valid for ip_version 4,6
			 key:aggregate.<port_handle>.rx.release                   value:Valid for ip_version 4,6
		Valid for ip_version 6
			xkey:aggregate.<port_handle>.rx.renew                     value:Valid for ip_version 6
		Valid for ip_version 4,6
			 key:aggregate.<port_handle>.rx.request                   value:Valid for ip_version 4,6
		Valid for ip_version 6
			 key:aggregate.<port_handle>.rx.solicit                   value:Valid for ip_version 6
			nkey:aggregate.<port_handle>.rx.ack                       value:
			nkey:aggregate.<port_handle>.rx.nak                       value:
			nkey:aggregate.<port_handle>.rx.force_renew               value:
			nkey:aggregate.<port_handle>.rx.relay_agent               value:
			nkey:aggregate.<port_handle>.tx.discover                  value:
		Valid for ip_version 4
			 key:aggregate.<port_handle>.tx.offer                     value:Valid for ip_version 4
			nkey:aggregate.<port_handle>.tx.request                   value:
		Valid for ip_version 4
			xkey:aggregate.<port_handle>.tx.reply                     value:Valid for ip_version 4
			nkey:aggregate.<port_handle>.tx.decline                   value:
		Valid for ip_version 4
			 key:aggregate.<port_handle>.tx.ack                       value:Valid for ip_version 4
		Valid for ip_version 4
			 key:aggregate.<port_handle>.tx.nak                       value:Valid for ip_version 4
			nkey:aggregate.<port_handle>.tx.release                   value:
			nkey:aggregate.<port_handle>.tx.inform                    value:
			 key:aggregate.<port_handle>.tx.force_renew               value:
			nkey:aggregate.<port_handle>.allocated.ip                 value:
			nkey:aggregate.<port_handle>.port_name                    value:
			xkey:aggregate.<port_handle>.total_leases_allocated       value:
			xkey:aggregate.<port_handle>.total_leases_renewed         value:
			xkey:aggregate.<port_handle>.current_leases_allocated     value:
		Valid for ip_version 6
			xkey:aggregate.<port_handle>.total_addresses_allocated    value:Valid for ip_version 6
		Valid for ip_version 6
			xkey:aggregate.<port_handle>.total_addresses_renewed      value:Valid for ip_version 6
		Valid for ip_version 6
			xkey:aggregate.<port_handle>.current_addresses_allocated  value:Valid for ip_version 6
		Valid for ip_version 6
			xkey:aggregate.<port_handle>.total_prefixes_allocated     value:Valid for ip_version 6
		Valid for ip_version 6
			xkey:aggregate.<port_handle>.total_prefixes_renewed       value:Valid for ip_version 6
		Valid for ip_version 6
			xkey:aggregate.<port_handle>.current_prefixes_allocated   value:Valid for ip_version 6
			 key:<device_group>.aggregate.force_renew_count           value:
		Valid for ip_version 6
			 key:<device_group>.aggregate.reconfigure_count           value:Valid for ip_version 6
		Valid for ip_version 6
			 key:<device_group>.aggregate.nak_sent                    value:Valid for ip_version 6
		Valid for ip_version 6
			 key:<device_group>.aggregate.solicits_ignored            value:Valid for ip_version 6
			nkey:dhcp_handle.<dhcp_handle>.rx.discover                value:
			nkey:dhcp_handle.<dhcp_handle>.rx.offer                   value:
			nkey:dhcp_handle.<dhcp_handle>.rx.request                 value:
			nkey:dhcp_handle.<dhcp_handle>.rx.decline                 value:
			nkey:dhcp_handle.<dhcp_handle>.rx.ack                     value:
			nkey:dhcp_handle.<dhcp_handle>.rx.nak                     value:
			nkey:dhcp_handle.<dhcp_handle>.rx.release                 value:
			nkey:dhcp_handle.<dhcp_handle>.rx.inform                  value:
			nkey:dhcp_handle.<dhcp_handle>.rx.force_renew             value:
			nkey:dhcp_handle.<dhcp_handle>.rx.relay_agent             value:
		Valid for ip_version 6
			nkey:aggregate.<port_handle>.tx.discover                  value:Valid for ip_version 6
		Valid for ip_version 6
			nkey:aggregate.<port_handle>.tx.offer                     value:Valid for ip_version 6
			nkey:dhcp_handle.<dhcp_handle>.tx.request                 value:
			nkey:dhcp_handle.<dhcp_handle>.tx.decline                 value:
			nkey:dhcp_handle.<dhcp_handle>.tx.ack                     value:
			nkey:dhcp_handle.<dhcp_handle>.tx.nak                     value:
			nkey:dhcp_handle.<dhcp_handle>.tx.release                 value:
			nkey:dhcp_handle.<dhcp_handle>.tx.inform                  value:
			nkey:dhcp_handle.<dhcp_handle>.tx.force_renew             value:
			nkey:dhcp_handle.<dhcp_handle>.allocated.ipn              value:
		Valid for ip_version 4
			 key:aggregate.<port_handle>.tx.advertisement             value: Valid for ip_version 4
		Valid for ip_version 6
			 key:aggregate.<port_handle>.rx.confirm                   value: Valid for ip_version 6
		Valid for ip_version 4,6
			 key:aggregate.<port_handle>.rx.decline                   value: Valid for ip_version 4,6
		Valid for ip_version 4
			 key:aggregate.<port_handle>.rx.discover                  value: Valid for ip_version 4
		Valid for ip_version 4,6
			 key:aggregate.<port_handle>.rx.inform                    value: Valid for ip_version 4,6
		Valid for ip_version 6
			 key:aggregate.<port_handle>.rx.rebind                    value: Valid for ip_version 6
		Valid for ip_version 6
			 key:aggregate.<port_handle>.rx.relay_forward             value: Valid for ip_version 6
		Valid for ip_version 6
			 key:aggregate.<port_handle>.rx.relay_reply               value: Valid for ip_version 6
		Valid for ip_version 4,6
			 key:aggregate.<port_handle>.rx.release                   value: Valid for ip_version 4,6
		Valid for ip_version 6
			 key:aggregate.<port_handle>.rx.renew                     value: Valid for ip_version 6
		Valid for ip_version 4,6
			 key:aggregate.<port_handle>.rx.request                   value: Valid for ip_version 4,6
		Valid for ip_version 6
			 key:aggregate.<port_handle>.rx.solicit                   value: Valid for ip_version 6
		Valid for ip_version 4
			 key:aggregate.<port_handle>.tx.offer                     value: Valid for ip_version 4
		Valid for ip_version 4
			 key:aggregate.<port_handle>.tx.reply                     value: Valid for ip_version 4
		Valid for ip_version 4
			 key:aggregate.<port_handle>.tx.ack                       value: Valid for ip_version 4
		Valid for ip_version 4
			 key:aggregate.<port_handle>.tx.nak                       value: Valid for ip_version 4
		Valid for ip_version 6
			 key:aggregate.<port_handle>.total_addresses_allocated    value: Valid for ip_version 6
		Valid for ip_version 6
			 key:aggregate.<port_handle>.total_addresses_renewed      value: Valid for ip_version 6
		Valid for ip_version 6
			 key:aggregate.<port_handle>.current_addresses_allocated  value: Valid for ip_version 6
		Valid for ip_version 6
			 key:aggregate.<port_handle>.total_prefixes_allocated     value: Valid for ip_version 6
		Valid for ip_version 6
			 key:aggregate.<port_handle>.total_prefixes_renewed       value: Valid for ip_version 6
		Valid for ip_version 6
			 key:aggregate.<port_handle>.current_prefixes_allocated   value: Valid for ip_version 6
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) The not supported parameters or options of the parameters will be
		silently ignored.
		1) The not supported parameters or options of the parameters will be silently ignored.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_dhcp_server_stats", kwargs)

	def emulation_dhcp_stats(self, **kwargs):
		""" This procedure returns statistics about the DHCP or DHCP subscriber group activity on the specified port. Statistics include the connection status, number and type of messages sent or received from the specified port.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_dhcp_stats
			 	[-port_handle       ANY]
			 	[-action            CHOICES clear]
			 	[-handle            ANY]
			 	[-mode              CHOICES session
			                     CHOICES aggregate_stats
			                     CHOICES aggregate_stats_relay_agent
			                     DEFAULT aggregate_stats]
			 	[-dhcp_version      CHOICES dhcp4 dhcp6]
			x	[-dhcp_relay_type   CHOICES normal lightweight
			x                    DEFAULT normal]
			x	[-no_write          ANY]
			x	[-version           ANY]
			x	[-execution_timeout NUMERIC
			x                    DEFAULT 1800]
		
		Arguments:
			 	-port_handle
			 		Specifies the port upon which emulation id configured.
			 		This parameter is returned from emulation_dhcp_config proc.
			 		Emulation must have been previously enabled on the specified port
			 		via a call to emulation_dhcp_group_config proc.
			 		This option is mandatory when -version is ixtclhal.
			 		When -version is ixnetwork, one of -port_handle or -handle parameters
			 		should be provided.
			 	-action
			 		Clear - reset the statistics for the specified port/subscriber group
			 		to 0. This parameter will be ignored if it is used.
			 		Valid choices are:
			    		clear -
			 	-handle
			 		Allows the user to optionally select the groups to which the
			 		specified action is to be applied.
			 		If this parameter is not specified, then the specified action is
			 		applied to all groups configured on the port specified by
			 		the -port_handle command. The handle is obtained from the keyed list returned
			 		in the call to emulation_dhcp_group_config proc.
			 		The port handle parameter must have been initialized and dhcp group
			 		emulation must have been configured prior to calling this function.
			 		This option is not supported with IxTclAccess and will be ignored if it is used.
			 		For IxTclNetwork the statistics will be aggregated at port level (the
			 		port on which this handle has been configured). The stats aggregate.<stat key>
			 		will represent the aggregated port stats for the first port if multiple
			 		handles are provided.
			 	-mode
			    		session - retrieves session statistics for configured DHCP v4/v6 clients.Supported with IxTclNetwork.
			    		aggregate_stats - retrieves aggregate statistics for the selected port with configured DHCP v4/v6 clients.Supported with IxTclnetwork and IxTclHal.
			    		aggregate_stats_relay_agent - retrieves aggregate for the selected port with configured DHCP v4/v6 relay agents. Supported with IxTclnetwork and IxTclHal.
			 	-dhcp_version
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			    		dhcp4 - retrieves session statistics for configured DHCP v4.
			    		dhcp6 - retrieves session statistics for configured DHCP v6.
			x	-dhcp_relay_type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		normal -
			x   		lightweight -
			x	-no_write
			x		If this option is present, the configuration is not written to the hardware. This option can be used to queue up multiple configurations before writing to the hardware.This option is not supported with IxNetwork and will be ignored if it is used.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-version
			x		Defines whether the target program is IxTclHal or IxTclAccess or IxTclNetwork. The default value is ixtclhal.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-execution_timeout
			x		This is the timeout for the function.
			x		The setting is in seconds.
			x		Setting this setting to 60 it will mean that the command must complete in under 60 seconds.
			x		If the command will last more than 60 seconds the command will be terminated by force.
			x		This flag can be used to prevent dead locks occuring in IxNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                             value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information
			 key:log                                                value:When status is failure, contains more information
		Port Name
			 key:aggregate.port_name                                value:Port Name
		Number of currently attempting interfaces. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.currently_attempting                     value:Number of currently attempting interfaces. Supported with IxTclHal, IxTclNetwork.
		Number of interfaces not bounded. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.currently_idle                           value:Number of interfaces not bounded. Supported with IxTclHal, IxTclNetwork.
		Number of addresses learned. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.currently_bound                          value:Number of addresses learned. Supported with IxTclHal, IxTclNetwork.
		Percent rate of addresses learned. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.success_percentage                       value:Percent rate of addresses learned. Supported with IxTclHal, IxTclNetwork.
		Number of discovered messages sent. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.discover_tx_count                        value:Number of discovered messages sent. Supported with IxTclHal, IxTclNetwork.
		Number of requests sent. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.request_tx_count                         value:Number of requests sent. Supported with IxTclHal, IxTclNetwork.
		Number of releases sent. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.release_tx_count                         value:Number of releases sent. Supported with IxTclHal, IxTclNetwork.
		Number of acks received. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.ack_rx_count                             value:Number of acks received. Supported with IxTclHal, IxTclNetwork.
		Number of nacks received. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.nak_rx_count                             value:Number of nacks received. Supported with IxTclHal, IxTclNetwork.
		Number of offers received. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.offer_rx_count                           value:Number of offers received. Supported with IxTclHal, IxTclNetwork.
		Number of DHCPv4 DHCPDECLINE messages sent. A DHCPDECLINE message is sent to the server if the DHCP client is assigned any IP address from the 10.0.x.x subnet, any multicast address, or any of the following addresses: 0.0.0.0, 255.255.255.255, 127.0.0.1. Supported with IxTclNetwork.
			 key:aggregate.declines_tx_count                        value:Number of DHCPv4 DHCPDECLINE messages sent. A DHCPDECLINE message is sent to the server if the DHCP client is assigned any IP address from the 10.0.x.x subnet, any multicast address, or any of the following addresses: 0.0.0.0, 255.255.255.255, 127.0.0.1. Supported with IxTclNetwork.
		Number of enabled DHCPv4 interfaces. Supported with IxTclNetwork.
			 key:aggregate.enabled_interfaces                       value:Number of enabled DHCPv4 interfaces. Supported with IxTclNetwork.
		Number of addresses learned. Supported with IxTclNetwork.
			 key:aggregate.addr_discovered                          value:Number of addresses learned. Supported with IxTclNetwork.
		Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork.
			 key:aggregate.setup_initiated                          value:Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork.
		Number of addresses that were successful configured. Supported with IxTclNetwork.
			 key:aggregate.setup_success                            value:Number of addresses that were successful configured. Supported with IxTclNetwork.
		The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork.
			 key:aggregate.setup_success_rate                       value:The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork.
		Number of addresses that could not be configured until the Number of Retransmissions was exceeded. Supported with IxTclNetwork.
			 key:aggregate.setup_fail                               value:Number of addresses that could not be configured until the Number of Retransmissions was exceeded. Supported with IxTclNetwork.
		Number of address teardowns that were initiated. Supported with IxTclNetwork.
			 key:aggregate.teardown_initiated                       value:Number of address teardowns that were initiated. Supported with IxTclNetwork.
		Number of addresses that were successful torn down. Supported with IxTclNetwork.
			 key:aggregate.teardown_success                         value:Number of addresses that were successful torn down. Supported with IxTclNetwork.
		Number of addresses that could not be torn down until the Number of Retransmissions was exceeded. Supported with IxTclNetwork.
			 key:aggregate.teardown_failed                          value:Number of addresses that could not be torn down until the Number of Retransmissions was exceeded. Supported with IxTclNetwork.
		Number of relay agent sessions that are up. Supported with IxTclNetwork.
			 key:aggregate.relay_agent_sessions_up                  value:Number of relay agent sessions that are up. Supported with IxTclNetwork.
		Number of relay agent sessions that are down. Supported with IxTclNetwork.
			 key:aggregate.relay_agent_sessions_down                value:Number of relay agent sessions that are down. Supported with IxTclNetwork.
		Number of relay agent sessions that are not started. Supported with IxTclNetwork.
			 key:aggregate.relay_agent_sessions_not_started         value:Number of relay agent sessions that are not started. Supported with IxTclNetwork.
		Total number of relay agent sessions. Supported with IxTclNetwork.
			 key:aggregate.relay_agent_sessions_total               value:Total number of relay agent sessions. Supported with IxTclNetwork.
		Force Renew Rx
			 key:aggregate.rx.force_renew                           value:Force Renew Rx
		Port Name
			 key:<port_handle>.aggregate.port_name                  value:Port Name
		Number of enabled interfaces. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.currently_attempting       value:Number of enabled interfaces. Supported with IxTclNetwork.
		Number of interfaces not bounded. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.currently_idle             value:Number of interfaces not bounded. Supported with IxTclNetwork.
		Number of addresses learned. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.currently_bound            value:Number of addresses learned. Supported with IxTclNetwork.
		Percent rate of addresses learned. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.success_percentage         value:Percent rate of addresses learned. Supported with IxTclNetwork.
		Number of discovered messages sent. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.discover_tx_count          value:Number of discovered messages sent. Supported with IxTclNetwork.
		Number of requests sent. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.request_tx_count           value:Number of requests sent. Supported with IxTclNetwork.
		Number of releases sent. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.release_tx_count           value:Number of releases sent. Supported with IxTclNetwork.
		Number of acks received. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.ack_rx_count               value:Number of acks received. Supported with IxTclNetwork.
		Number of nacks received. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.nak_rx_count               value:Number of nacks received. Supported with IxTclNetwork.
		Number of offers received. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.offer_rx_count             value:Number of offers received. Supported with IxTclNetwork.
		Number of DHCPv4 DHCPDECLINE messages sent. A DHCPDECLINE message is sent to the server if the DHCP client is assigned any IP address from the 10.0.x.x subnet, any multicast address, or any of the following addresses: 0.0.0.0, 255.255.255.255, 127.0.0.1. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.declines_tx_count          value:Number of DHCPv4 DHCPDECLINE messages sent. A DHCPDECLINE message is sent to the server if the DHCP client is assigned any IP address from the 10.0.x.x subnet, any multicast address, or any of the following addresses: 0.0.0.0, 255.255.255.255, 127.0.0.1. Supported with IxTclNetwork.
		Number of enabled DHCPv4 interfaces. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.enabled_interfaces         value:Number of enabled DHCPv4 interfaces. Supported with IxTclNetwork.
		Number of addresses learned. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.addr_discovered            value:Number of addresses learned. Supported with IxTclNetwork.
		Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.setup_initiated            value:Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork.
		Number of addresses that were successful configured. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.setup_success              value:Number of addresses that were successful configured. Supported with IxTclNetwork.
		The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.setup_success_rate         value:The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork.
		Number of addresses that could not be configured until the Number of Retransmissions was exceeded. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.setup_fail                 value:Number of addresses that could not be configured until the Number of Retransmissions was exceeded. Supported with IxTclNetwork.
		Number of address teardowns that were initiated. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.teardown_initiated         value:Number of address teardowns that were initiated. Supported with IxTclNetwork.
		Number of addresses that were successful torn down. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.teardown_success           value:Number of addresses that were successful torn down. Supported with IxTclNetwork.
		Number of addresses that could not be torn down until the Number of Retransmissions was exceeded. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.teardown_failed            value:Number of addresses that could not be torn down until the Number of Retransmissions was exceeded. Supported with IxTclNetwork.
		Requests NAKed
			 key:<port_handle>.aggregate.rx.nak                     value:Requests NAKed
		Requests NAKed
			 key:aggregate.rx.nak                                   value:Requests NAKed
		Reconfigure Received
			 key:<port_handle>.aggregate.reconfigure_rx             value:Reconfigure Received
		Reconfigure Received
			 key:aggregate.reconfigure_rx                           value:Reconfigure Received
		Force Renew Rx
			 key:<port_handle>.aggregate.rx.force_renew             value:Force Renew Rx
		Force Renew Rx
			 key:<device_group>.aggregate.rx.force_renew            value:Force Renew Rx
		Reconfigure Received
			 key:<device_group>.aggregate.reconfigure_rx            value:Reconfigure Received
			 key:<device_group>.aggregate.rx.nak                    value:
		Port Name
			 key:ipv6.aggregate.port_name                           value:Port Name
		Number of currently attempting interfaces. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.currently_attempting                value:Number of currently attempting interfaces. Supported with IxTclHal, IxTclNetwork.
		Number of interfaces not bounded. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.currently_idle                      value:Number of interfaces not bounded. Supported with IxTclHal, IxTclNetwork.
		Number of addresses learned. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.currently_bound                     value:Number of addresses learned. Supported with IxTclHal, IxTclNetwork.
		Number of solicit messages sent. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.solicits_tx_count                   value:Number of solicit messages sent. Supported with IxTclHal, IxTclNetwork.
		Number of advertisement messages received. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.adv_rx_count                        value:Number of advertisement messages received. Supported with IxTclHal, IxTclNetwork.
		Number of advertisement messages received but ignored. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.adv_ignored                         value:Number of advertisement messages received but ignored. Supported with IxTclHal, IxTclNetwork.
		Number of requests sent. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.request_tx_count                    value:Number of requests sent. Supported with IxTclHal, IxTclNetwork.
		The number of DHCPv6 addresses learned. Supported with IxTclNetwork.
			 key:ipv6.aggregate.addr_discovered                     value:The number of DHCPv6 addresses learned. Supported with IxTclNetwork.
		The number of DHCPv6 enabled interfaces. Supported with IxTclNetwork.
			 key:ipv6.aggregate.enabled_interfaces                  value:The number of DHCPv6 enabled interfaces. Supported with IxTclNetwork.
		Number of reply messages received. Supported with IxTclNetwork.
			 key:ipv6.aggregate.reply_rx_count                      value:Number of reply messages received. Supported with IxTclNetwork.
		Number of release messages sent. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.release_tx_count                    value:Number of release messages sent. Supported with IxTclHal, IxTclNetwork.
		Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork.
			 key:ipv6.aggregate.setup_initiated                     value:Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork.
		Number of addresses that were successful configured. Supported with IxTclNetwork.
			 key:ipv6.aggregate.setup_success                       value:Number of addresses that were successful configured. Supported with IxTclNetwork.
		The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork.
			 key:ipv6.aggregate.setup_success_rate                  value:The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork.
		Number of addresses that could not be configured until the REQ_MAX_RC was exceeded. Supported with IxTclNetwork.
			 key:ipv6.aggregate.setup_fail                          value:Number of addresses that could not be configured until the REQ_MAX_RC was exceeded. Supported with IxTclNetwork.
		Number of address teardowns that were initiated. Supported with IxTclNetwork.
			 key:ipv6.aggregate.teardown_initiated                  value:Number of address teardowns that were initiated. Supported with IxTclNetwork.
		Number of addresses that were successful torn down. Supported with IxTclNetwork.
			 key:ipv6.aggregate.teardown_success                    value:Number of addresses that were successful torn down. Supported with IxTclNetwork.
		Number of interfaces that could not be configured until the REL_MAX_RC was exceeded. Supported with IxTclNetwork.
			 key:ipv6.aggregate.teardown_failed                     value:Number of interfaces that could not be configured until the REL_MAX_RC was exceeded. Supported with IxTclNetwork.
		Port Name
			 key:ipv6.<port_handle>.aggregate.port_name             value:Port Name
		Number of currently attempting interfaces. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.currently_attempting  value:Number of currently attempting interfaces. Supported with IxTclHal, IxTclNetwork.
		Number of interfaces not bounded. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.currently_idle        value:Number of interfaces not bounded. Supported with IxTclHal, IxTclNetwork.
		Number of addresses learned. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.currently_bound       value:Number of addresses learned. Supported with IxTclHal, IxTclNetwork.
		Number of solicit messages sent. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.solicits_tx_count     value:Number of solicit messages sent. Supported with IxTclHal, IxTclNetwork.
		Number of advertisement messages received. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.adv_rx_count          value:Number of advertisement messages received. Supported with IxTclHal, IxTclNetwork.
		Number of advertisement messages received but ignored. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.adv_ignored           value:Number of advertisement messages received but ignored. Supported with IxTclHal, IxTclNetwork.
		Number of requests sent. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.request_tx_count      value:Number of requests sent. Supported with IxTclHal, IxTclNetwork.
		The number of DHCPv6 addresses learned. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.addr_discovered       value:The number of DHCPv6 addresses learned. Supported with IxTclNetwork.
		The number of DHCPv6 enabled interfaces. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.enabled_interfaces    value:The number of DHCPv6 enabled interfaces. Supported with IxTclNetwork.
		Number of reply messages received. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.reply_rx_count        value:Number of reply messages received. Supported with IxTclNetwork.
		Number of release messages sent. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.release_tx_count      value:Number of release messages sent. Supported with IxTclHal, IxTclNetwork.
		Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.setup_initiated       value:Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork.
		Number of addresses that were successful configured. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.setup_success         value:Number of addresses that were successful configured. Supported with IxTclNetwork.
		The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.setup_success_rate    value:The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork.
		Number of addresses that could not be configured until the REQ_MAX_RC was exceeded. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.setup_fail            value:Number of addresses that could not be configured until the REQ_MAX_RC was exceeded. Supported with IxTclNetwork.
		Number of address teardowns that were initiated. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.teardown_initiated    value:Number of address teardowns that were initiated. Supported with IxTclNetwork.
		Number of addresses that were successful torn down. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.teardown_success      value:Number of addresses that were successful torn down. Supported with IxTclNetwork.
		Number of interfaces that could not be configured until the REL_MAX_RC was exceeded. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.teardown_failed       value:Number of interfaces that could not be configured until the REL_MAX_RC was exceeded. Supported with IxTclNetwork.
		No of enabled interfaces on that group. Supported with IxTclHal.
			 key:group.<group>.currently_attempting                 value:No of enabled interfaces on that group. Supported with IxTclHal.
		No of interfaces not bounded on that group. Supported with IxTclHal.
			 key:group.<group>.currently_idle                       value:No of interfaces not bounded on that group. Supported with IxTclHal.
		No of addresses learned on that group. Supported with IxTclHal.
			 key:group.<group>.currently_bound                      value:No of addresses learned on that group. Supported with IxTclHal.
		Port Name
			 key:session.<session ID>.port_name                     value:Port Name
		Session Name
			 key:session.<session ID>.session_name                  value:Session Name
		Port handle
			nkey:session.<session ID>.port_handle                   value:Port handle
		DHCP group handle
			nkey:session.<session ID>.dhcp_group                    value:DHCP group handle
		Discovers Sent (valid only for DHCPv4)
			 key:session.<session ID>.discovers_sent                value:Discovers Sent (valid only for DHCPv4)
		Offers Received (valid only for DHCPv4)
			 key:session.<session ID>.offers_received               value:Offers Received (valid only for DHCPv4)
		Requests Sent
			 key:session.<session ID>.requests_sent                 value:Requests Sent
		ACKs Received (valid only for DHCPv4)
			 key:session.<session ID>.acks_received                 value:ACKs Received (valid only for DHCPv4)
		NACKs Received (valid only for DHCPv4)
			 key:session.<session ID>.nacks_received                value:NACKs Received (valid only for DHCPv4)
		Releases Sent
			 key:session.<session ID>.releases_sent                 value:Releases Sent
		Declines Sent (valid only for DHCPv4)
			 key:session.<session ID>.declines_sent                 value:Declines Sent (valid only for DHCPv4)
		IP Address
			 key:session.<session ID>.ip_address                    value:IP Address
		Gateway Address
			 key:session.<session ID>.gateway_address               value:Gateway Address
		Lease Time
			 key:session.<session ID>.lease_time                    value:Lease Time
		Solicits Sent (valid only for DHCPv6)
			 key:session.<session ID>.solicits_sent                 value:Solicits Sent (valid only for DHCPv6)
		Advertisements Received (valid only for DHCPv6)
			 key:session.<session ID>.advertisements_received       value:Advertisements Received (valid only for DHCPv6)
		Advertisements Ignored (valid only for DHCPv6)
			 key:session.<session ID>.advertisements_ignored        value:Advertisements Ignored (valid only for DHCPv6)
		Replies Received (valid only for DHCPv6)
			 key:session.<session ID>.replies_received              value:Replies Received (valid only for DHCPv6)
		Force Renew (valid only for DHCPv4)
			 key:session.<session ID>.rx.force_renew                value:Force Renew (valid only for DHCPv4)
		Reconfigure Rx (valid only for DHCPv6)
			 key:session.<session ID>.reconfigure_rx                value:Reconfigure Rx (valid only for DHCPv6)
		Cisco only
			nkey:aggregate.elapsed_time                             value:Cisco only
		Cisco only
			nkey:aggregate.total_attempted                          value:Cisco only
		Cisco only
			nkey:aggregate.total_retried                            value:Cisco only
		Cisco only
			nkey:aggregate.total_bound                              value:Cisco only
		Cisco only
			nkey:aggregate.bound_renewed                            value:Cisco only
		Cisco only
			nkey:aggregate.total_failed                             value:Cisco only
		Cisco only
			nkey:aggregate.bind_rate                                value:Cisco only
		Cisco only
			nkey:aggregate.attempted_rate                           value:Cisco only
		Cisco only
			nkey:aggregate.minimum_setup_time                       value:Cisco only
		Cisco only
			nkey:aggregate.maximum_setup_time                       value:Cisco only
		Cisco only
			nkey:aggregate.average_setup_time                       value:Cisco only
		Cisco only
			nkey:group.<group>.elapsed_time                         value:Cisco only
		Cisco only
			nkey:group.<group>.total_attempted                      value:Cisco only
		Cisco only
			nkey:group.<group>.total_retried                        value:Cisco only
		Cisco only
			nkey:group.<group>.bound_renewed                        value:Cisco only
		Cisco only
			nkey:group.<group>.total_bound                          value:Cisco only
		Cisco only
			nkey:group.<group>.total_failed                         value:Cisco only
		Cisco only
			nkey:group.<group>.bind_rate                            value:Cisco only
		Cisco only
			nkey:group.<group>.attempt_rate                         value:Cisco only
		Cisco only
			nkey:group.<group>.request_rate                         value:Cisco only
		Cisco only
			nkey:group.<group>.release_rate                         value:Cisco only
		Cisco only
			nkey:group.<group>.discover_tx_count                    value:Cisco only
		Cisco only
			nkey:group.<group>.request_tx_count                     value:Cisco only
		Cisco only
			nkey:group.<group>.release_tx_count                     value:Cisco only
		Cisco only
			nkey:group.<group>.ack_rx_count                         value:Cisco only
		Cisco only
			nkey:group.<group>.nak_rx_count                         value:Cisco only
		Cisco only
			nkey:group.<group>.offer_rx_count                       value:Cisco only
		Cisco only
			nkey:<port_handle>.<group>.inform_tx_count              value:Cisco only
		Cisco only
			nkey:<port_handle>.<group>.decline_tx_count             value:Cisco only
		$::SUCCESS | $::FAILURE
			 key:status                                             value:$::SUCCESS | $::FAILURE 
		When status is failure, contains more information
			 key:log                                                value:When status is failure, contains more information 
		Number of currently attempting interfaces. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.currently_attempting                     value:Number of currently attempting interfaces. Supported with IxTclHal, IxTclNetwork. 
		Number of interfaces not bounded. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.currently_idle                           value:Number of interfaces not bounded. Supported with IxTclHal, IxTclNetwork. 
		Number of addresses learned. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.currently_bound                          value:Number of addresses learned. Supported with IxTclHal, IxTclNetwork. 
		Percent rate of addresses learned. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.success_percentage                       value:Percent rate of addresses learned. Supported with IxTclHal, IxTclNetwork. 
		Number of discovered messages sent. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.discover_tx_count                        value:Number of discovered messages sent. Supported with IxTclHal, IxTclNetwork. 
		Number of requests sent. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.request_tx_count                         value:Number of requests sent. Supported with IxTclHal, IxTclNetwork. 
		Number of releases sent. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.release_tx_count                         value:Number of releases sent. Supported with IxTclHal, IxTclNetwork. 
		Number of acks received. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.ack_rx_count                             value:Number of acks received. Supported with IxTclHal, IxTclNetwork. 
		Number of nacks received. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.nak_rx_count                             value:Number of nacks received. Supported with IxTclHal, IxTclNetwork. 
		Number of offers received. Supported with IxTclHal, IxTclNetwork.
			 key:aggregate.offer_rx_count                           value:Number of offers received. Supported with IxTclHal, IxTclNetwork. 
		Number of DHCPv4 DHCPDECLINE messages sent. A DHCPDECLINE message is sent to the server if the DHCP client is assigned any IP address from the 10.0.x.x subnet, any multicast address, or any of the following addresses: 0.0.0.0, 255.255.255.255, 127.0.0.1. Supported with IxTclNetwork.
			 key:aggregate.declines_tx_count                        value:Number of DHCPv4 DHCPDECLINE messages sent. A DHCPDECLINE message is sent to the server if the DHCP client is assigned any IP address from the 10.0.x.x subnet, any multicast address, or any of the following addresses: 0.0.0.0, 255.255.255.255, 127.0.0.1. Supported with IxTclNetwork. 
		Number of enabled DHCPv4 interfaces. Supported with IxTclNetwork.
			 key:aggregate.enabled_interfaces                       value:Number of enabled DHCPv4 interfaces. Supported with IxTclNetwork. 
		Number of addresses learned. Supported with IxTclNetwork.
			 key:aggregate.addr_discovered                          value:Number of addresses learned. Supported with IxTclNetwork. 
		Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork.
			 key:aggregate.setup_initiated                          value:Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork. 
		Number of addresses that were successful configured. Supported with IxTclNetwork.
			 key:aggregate.setup_success                            value:Number of addresses that were successful configured. Supported with IxTclNetwork. 
		The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork.
			 key:aggregate.setup_success_rate                       value:The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork. 
		Number of addresses that could not be configured until the Number of Retransmissions was exceeded. Supported with IxTclNetwork.
			 key:aggregate.setup_fail                               value:Number of addresses that could not be configured until the Number of Retransmissions was exceeded. Supported with IxTclNetwork. 
		Number of address teardowns that were initiated. Supported with IxTclNetwork.
			 key:aggregate.teardown_initiated                       value:Number of address teardowns that were initiated. Supported with IxTclNetwork. 
		Number of addresses that were successful torn down. Supported with IxTclNetwork.
			 key:aggregate.teardown_success                         value:Number of addresses that were successful torn down. Supported with IxTclNetwork. 
		Number of addresses that could not be torn down until the Number of Retransmissions was exceeded. Supported with IxTclNetwork.
			 key:aggregate.teardown_failed                          value:Number of addresses that could not be torn down until the Number of Retransmissions was exceeded. Supported with IxTclNetwork. 
		Number of enabled interfaces. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.currently_attempting       value:Number of enabled interfaces. Supported with IxTclNetwork. 
		Number of interfaces not bounded. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.currently_idle             value:Number of interfaces not bounded. Supported with IxTclNetwork. 
		Number of addresses learned. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.currently_bound            value:Number of addresses learned. Supported with IxTclNetwork. 
		Percent rate of addresses learned. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.success_percentage         value:Percent rate of addresses learned. Supported with IxTclNetwork. 
		Number of discovered messages sent. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.discover_tx_count          value:Number of discovered messages sent. Supported with IxTclNetwork. 
		Number of requests sent. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.request_tx_count           value:Number of requests sent. Supported with IxTclNetwork. 
		Number of releases sent. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.release_tx_count           value:Number of releases sent. Supported with IxTclNetwork. 
		Number of acks received. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.ack_rx_count               value:Number of acks received. Supported with IxTclNetwork. 
		Number of nacks received. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.nak_rx_count               value:Number of nacks received. Supported with IxTclNetwork. 
		Number of offers received. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.offer_rx_count             value:Number of offers received. Supported with IxTclNetwork. 
		Number of DHCPv4 DHCPDECLINE messages sent. A DHCPDECLINE message is sent to the server if the DHCP client is assigned any IP address from the 10.0.x.x subnet, any multicast address, or any of the following addresses: 0.0.0.0, 255.255.255.255, 127.0.0.1. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.declines_tx_count          value:Number of DHCPv4 DHCPDECLINE messages sent. A DHCPDECLINE message is sent to the server if the DHCP client is assigned any IP address from the 10.0.x.x subnet, any multicast address, or any of the following addresses: 0.0.0.0, 255.255.255.255, 127.0.0.1. Supported with IxTclNetwork. 
		Number of enabled DHCPv4 interfaces. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.enabled_interfaces         value:Number of enabled DHCPv4 interfaces. Supported with IxTclNetwork. 
		Number of addresses learned. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.addr_discovered            value:Number of addresses learned. Supported with IxTclNetwork. 
		Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.setup_initiated            value:Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork. 
		Number of addresses that were successful configured. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.setup_success              value:Number of addresses that were successful configured. Supported with IxTclNetwork. 
		The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.setup_success_rate         value:The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork. 
		Number of addresses that could not be configured until the Number of Retransmissions was exceeded. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.setup_fail                 value:Number of addresses that could not be configured until the Number of Retransmissions was exceeded. Supported with IxTclNetwork. 
		Number of address teardowns that were initiated. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.teardown_initiated         value:Number of address teardowns that were initiated. Supported with IxTclNetwork. 
		Number of addresses that were successful torn down. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.teardown_success           value:Number of addresses that were successful torn down. Supported with IxTclNetwork. 
		Number of addresses that could not be torn down until the Number of Retransmissions was exceeded. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.teardown_failed            value:Number of addresses that could not be torn down until the Number of Retransmissions was exceeded. Supported with IxTclNetwork. 
		Number of currently attempting interfaces. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.currently_attempting                value:Number of currently attempting interfaces. Supported with IxTclHal, IxTclNetwork. 
		Number of interfaces not bounded. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.currently_idle                      value:Number of interfaces not bounded. Supported with IxTclHal, IxTclNetwork. 
		Number of addresses learned. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.currently_bound                     value:Number of addresses learned. Supported with IxTclHal, IxTclNetwork. 
		Number of solicit messages sent. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.solicits_tx_count                   value:Number of solicit messages sent. Supported with IxTclHal, IxTclNetwork. 
		Number of advertisement messages received. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.adv_rx_count                        value:Number of advertisement messages received. Supported with IxTclHal, IxTclNetwork. 
		Number of advertisement messages received but ignored. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.adv_ignored                         value:Number of advertisement messages received but ignored. Supported with IxTclHal, IxTclNetwork. 
		Number of requests sent. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.request_tx_count                    value:Number of requests sent. Supported with IxTclHal, IxTclNetwork. 
		The number of DHCPv6 addresses learned. Supported with IxTclNetwork.
			 key:ipv6.aggregate.addr_discovered                     value:The number of DHCPv6 addresses learned. Supported with IxTclNetwork. 
		The number of DHCPv6 enabled interfaces. Supported with IxTclNetwork.
			 key:ipv6.aggregate.enabled_interfaces                  value:The number of DHCPv6 enabled interfaces. Supported with IxTclNetwork. 
		Number of reply messages received. Supported with IxTclNetwork.
			 key:ipv6.aggregate.reply_rx_count                      value:Number of reply messages received. Supported with IxTclNetwork. 
		Number of release messages sent. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.aggregate.release_tx_count                    value:Number of release messages sent. Supported with IxTclHal, IxTclNetwork. 
		Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork.
			 key:ipv6.aggregate.setup_initiated                     value:Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork. 
		Number of addresses that were successful configured. Supported with IxTclNetwork.
			 key:ipv6.aggregate.setup_success                       value:Number of addresses that were successful configured. Supported with IxTclNetwork. 
		The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork.
			 key:ipv6.aggregate.setup_success_rate                  value:The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork. 
		Number of addresses that could not be configured until the REQ_MAX_RC was exceeded. Supported with IxTclNetwork.
			 key:ipv6.aggregate.setup_fail                          value:Number of addresses that could not be configured until the REQ_MAX_RC was exceeded. Supported with IxTclNetwork. 
		Number of address teardowns that were initiated. Supported with IxTclNetwork.
			 key:ipv6.aggregate.teardown_initiated                  value:Number of address teardowns that were initiated. Supported with IxTclNetwork. 
		Number of addresses that were successful torn down. Supported with IxTclNetwork.
			 key:ipv6.aggregate.teardown_success                    value:Number of addresses that were successful torn down. Supported with IxTclNetwork. 
		Number of interfaces that could not be configured until the REL_MAX_RC was exceeded. Supported with IxTclNetwork.
			 key:ipv6.aggregate.teardown_failed                     value:Number of interfaces that could not be configured until the REL_MAX_RC was exceeded. Supported with IxTclNetwork. 
		Port Name
			 key:ipv6.<port_handle>.aggregate.port_name             value:Port Name 
		Number of currently attempting interfaces. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.currently_attempting  value:Number of currently attempting interfaces. Supported with IxTclHal, IxTclNetwork. 
		Number of interfaces not bounded. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.currently_idle        value:Number of interfaces not bounded. Supported with IxTclHal, IxTclNetwork. 
		Number of addresses learned. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.currently_bound       value:Number of addresses learned. Supported with IxTclHal, IxTclNetwork. 
		Number of solicit messages sent. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.solicits_tx_count     value:Number of solicit messages sent. Supported with IxTclHal, IxTclNetwork. 
		Number of advertisement messages received. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.adv_rx_count          value:Number of advertisement messages received. Supported with IxTclHal, IxTclNetwork. 
		Number of advertisement messages received but ignored. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.adv_ignored           value:Number of advertisement messages received but ignored. Supported with IxTclHal, IxTclNetwork. 
		Number of requests sent. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.request_tx_count      value:Number of requests sent. Supported with IxTclHal, IxTclNetwork. 
		The number of DHCPv6 addresses learned. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.addr_discovered       value:The number of DHCPv6 addresses learned. Supported with IxTclNetwork. 
		The number of DHCPv6 enabled interfaces. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.enabled_interfaces    value:The number of DHCPv6 enabled interfaces. Supported with IxTclNetwork. 
		Number of reply messages received. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.reply_rx_count        value:Number of reply messages received. Supported with IxTclNetwork. 
		Number of release messages sent. Supported with IxTclHal, IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.release_tx_count      value:Number of release messages sent. Supported with IxTclHal, IxTclNetwork. 
		Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.setup_initiated       value:Number of clients that were started. This corresponds to number of started DHCP discovery sessions. Supported with IxTclNetwork. 
		Number of addresses that were successful configured. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.setup_success         value:Number of addresses that were successful configured. Supported with IxTclNetwork. 
		The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.setup_success_rate    value:The rate at which addresses were successful configured (addresses set up per second). Supported with IxTclNetwork. 
		Number of addresses that could not be configured until the REQ_MAX_RC was exceeded. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.setup_fail            value:Number of addresses that could not be configured until the REQ_MAX_RC was exceeded. Supported with IxTclNetwork. 
		Number of address teardowns that were initiated. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.teardown_initiated    value:Number of address teardowns that were initiated. Supported with IxTclNetwork. 
		Number of addresses that were successful torn down. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.teardown_success      value:Number of addresses that were successful torn down. Supported with IxTclNetwork. 
		Number of interfaces that could not be configured until the REL_MAX_RC was exceeded. Supported with IxTclNetwork.
			 key:ipv6.<port_handle>.aggregate.teardown_failed       value:Number of interfaces that could not be configured until the REL_MAX_RC was exceeded. Supported with IxTclNetwork. 
		Elapsed Time
			 key:aggregate.elapsed_time                             value:Elapsed Time
		Total Attempted
			 key:aggregate.total_attempted                          value:Total Attempted
		Total Retried
			 key:aggregate.total_retried                            value:Total Retried
		Total Bound
			 key:aggregate.total_bound                              value:Total Bound
		Bound Renewed
			 key:aggregate.bound_renewed                            value:Bound Renewed
		Total Failed
			 key:aggregate.total_failed                             value:Total Failed
		Bind Rate
			 key:aggregate.bind_rate                                value:Bind Rate
		Attempted Rate
			 key:aggregate.attempted_rate                           value:Attempted Rate
		Minimum Setup Time
			 key:aggregate.minimum_setup_time                       value:Minimum Setup Time
		Maximum Setup Time
			 key:aggregate.maximum_setup_time                       value:Maximum Setup Time
		Average Setup Time
			 key:aggregate.average_setup_time                       value:Average Setup Time
		
		Examples:
		See files starting with DHCP_ in the Samples subdirectory. See the DHCP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		.
		
		Sample Output:
		.
		
		Notes:
		When retrieving IxTclHal stats, there will be a difference between the
		aggregate and per group stats, because they are not extracted at the
		same time. There is a delay between the time when aggregate are extracted
		and the time  when per group stats are extracted. But in the end, when
		all bindings are finished the results should correspond.
		When retrieving IxTclHal stats, there will be a difference between the aggregate and per group stats, because they are not extracted at the same time. There is a delay between the time when aggregate are extracted and the time  when per group stats are extracted. But in the end, when all bindings are finished the results should correspond.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_dhcp_stats", kwargs)

	def emulation_dotonex_config(self, **kwargs):
		""" This procedure will add Dotonex to a particular Ixia Interface.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_dotonex_config
			x	[-port_handle                    REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-reset                          FLAG]
			 	[-handle                         ANY]
			x	[-return_detailed_handles        CHOICES 0 1
			x                                 DEFAULT 0]
			 	[-mode                           CHOICES create
			                                  CHOICES modify
			                                  CHOICES delete
			                                  CHOICES getAttribute
			                                  DEFAULT create]
			x	[-attribute_name                 CHOICES sessionInfo]
			 	[-count                          RANGE 1-8000
			                                  DEFAULT 1]
			x	[-tls_version                    CHOICES tls1_0 tls1_1 tls1_2]
			x	[-user_name                      ANY]
			x	[-user_pwd                       ANY]
			x	[-host_auth_mode                 CHOICES none
			x                                 CHOICES hostonly
			x                                 CHOICES hostuserreauth
			x                                 CHOICES hostuserboth]
			x	[-host_name                      ANY]
			x	[-host_pwd                       ANY]
			x	[-wait_id                        ANY]
			x	[-fast_provision_mode            CHOICES authenticated
			x                                 CHOICES unauthenticated
			x                                 CHOICES load_from_file
			x                                 CHOICES authenticated_save_to_file
			x                                 CHOICES unauthenticated_save_to_file]
			x	[-fast_inner_method              CHOICES mschapv2]
			x	[-runtime_certificate_generation ANY]
			x	[-fast_stateless_resume          CHOICES yes no]
			x	[-send_ca_cert_only              ANY]
			x	[-certificate_directory          ANY]
			x	[-private_key_file               ANY]
			x	[-peer_certificate_file          ANY]
			x	[-host_key_file                  ANY]
			x	[-host_certificate_file          ANY]
			x	[-verify_peer_certificate        ANY]
			x	[-ca_certificate_file            ANY]
			x	[-certificate_key_in_same_file   ANY]
			x	[-active                         ANY]
			x	[-dut_test_mode                  CHOICES singlehost
			x                                 CHOICES multihost
			x                                 CHOICES multiauth]
			x	[-machine_auth_prefix            ANY]
			x	[-disable_logoff                 CHOICES 0 1]
			x	[-multicast                      CHOICES 0 1]
			x	[-identify_using_VLAN            CHOICES 0 1]
			x	[-authorized_on_no_response      CHOICES 0 1]
			x	[-wait_before_run                RANGE 0-500
			x                                 DEFAULT 0]
			x	[-certificate_server_url         ANY]
			x	[-get_ca_certificate_only        ANY]
			x	[-company                        ANY]
			x	[-department                     ANY]
			x	[-city                           ANY]
			x	[-state                          ANY]
			x	[-country                        CHOICES ax
			x                                 CHOICES ad
			x                                 CHOICES ae
			x                                 CHOICES af
			x                                 CHOICES ag
			x                                 CHOICES ai
			x                                 CHOICES al
			x                                 CHOICES am
			x                                 CHOICES an
			x                                 CHOICES ao
			x                                 CHOICES aq
			x                                 CHOICES ar
			x                                 CHOICES as
			x                                 CHOICES at
			x                                 CHOICES au
			x                                 CHOICES aw
			x                                 CHOICES az
			x                                 CHOICES ba
			x                                 CHOICES bb
			x                                 CHOICES bd
			x                                 CHOICES be
			x                                 CHOICES bf
			x                                 CHOICES bg
			x                                 CHOICES bh
			x                                 CHOICES bi
			x                                 CHOICES bj
			x                                 CHOICES bm
			x                                 CHOICES bn
			x                                 CHOICES bo
			x                                 CHOICES br
			x                                 CHOICES bs
			x                                 CHOICES bt
			x                                 CHOICES bv
			x                                 CHOICES bw
			x                                 CHOICES by
			x                                 CHOICES bz
			x                                 CHOICES ca
			x                                 CHOICES cc
			x                                 CHOICES cf
			x                                 CHOICES cg
			x                                 CHOICES cd
			x                                 CHOICES ch
			x                                 CHOICES ci
			x                                 CHOICES ck
			x                                 CHOICES cl
			x                                 CHOICES cm
			x                                 CHOICES cn
			x                                 CHOICES co
			x                                 CHOICES cr
			x                                 CHOICES cs
			x                                 CHOICES cu
			x                                 CHOICES cv
			x                                 CHOICES cx
			x                                 CHOICES cy
			x                                 CHOICES cz
			x                                 CHOICES de
			x                                 CHOICES dj
			x                                 CHOICES dk
			x                                 CHOICES dm
			x                                 CHOICES do
			x                                 CHOICES dz
			x                                 CHOICES ec
			x                                 CHOICES ee
			x                                 CHOICES eg
			x                                 CHOICES eh
			x                                 CHOICES er
			x                                 CHOICES es
			x                                 CHOICES et
			x                                 CHOICES fi
			x                                 CHOICES fj
			x                                 CHOICES fk
			x                                 CHOICES fm
			x                                 CHOICES fo
			x                                 CHOICES fr
			x                                 CHOICES fx
			x                                 CHOICES ga
			x                                 CHOICES gb
			x                                 CHOICES gd
			x                                 CHOICES ge
			x                                 CHOICES gf
			x                                 CHOICES gg
			x                                 CHOICES gi
			x                                 CHOICES gl
			x                                 CHOICES gm
			x                                 CHOICES gn
			x                                 CHOICES gp
			x                                 CHOICES gq
			x                                 CHOICES gr
			x                                 CHOICES gs
			x                                 CHOICES gt
			x                                 CHOICES gu
			x                                 CHOICES gw
			x                                 CHOICES gy
			x                                 CHOICES hk
			x                                 CHOICES hm
			x                                 CHOICES hn
			x                                 CHOICES hr
			x                                 CHOICES ht
			x                                 CHOICES hu
			x                                 CHOICES id
			x                                 CHOICES ie
			x                                 CHOICES il
			x                                 CHOICES im
			x                                 CHOICES in
			x                                 CHOICES io
			x                                 CHOICES iq
			x                                 CHOICES ir
			x                                 CHOICES is
			x                                 CHOICES it
			x                                 CHOICES je
			x                                 CHOICES jm
			x                                 CHOICES jo
			x                                 CHOICES jp
			x                                 CHOICES ke
			x                                 CHOICES kg
			x                                 CHOICES kh
			x                                 CHOICES ki
			x                                 CHOICES km
			x                                 CHOICES kn
			x                                 CHOICES kp
			x                                 CHOICES kr
			x                                 CHOICES kw
			x                                 CHOICES ky
			x                                 CHOICES kz
			x                                 CHOICES la
			x                                 CHOICES lb
			x                                 CHOICES lc
			x                                 CHOICES li
			x                                 CHOICES lk
			x                                 CHOICES lr
			x                                 CHOICES ls
			x                                 CHOICES lt
			x                                 CHOICES lu
			x                                 CHOICES lv
			x                                 CHOICES ly
			x                                 CHOICES ma
			x                                 CHOICES mc
			x                                 CHOICES md
			x                                 CHOICES me
			x                                 CHOICES mg
			x                                 CHOICES mh
			x                                 CHOICES mk
			x                                 CHOICES ml
			x                                 CHOICES mm
			x                                 CHOICES mn
			x                                 CHOICES mo
			x                                 CHOICES mp
			x                                 CHOICES mq
			x                                 CHOICES mr
			x                                 CHOICES ms
			x                                 CHOICES mt
			x                                 CHOICES mu
			x                                 CHOICES mv
			x                                 CHOICES mw
			x                                 CHOICES mx
			x                                 CHOICES my
			x                                 CHOICES mz
			x                                 CHOICES na
			x                                 CHOICES nc
			x                                 CHOICES ne
			x                                 CHOICES nf
			x                                 CHOICES ng
			x                                 CHOICES ni
			x                                 CHOICES nl
			x                                 CHOICES no
			x                                 CHOICES np
			x                                 CHOICES nr
			x                                 CHOICES nt
			x                                 CHOICES nu
			x                                 CHOICES nz
			x                                 CHOICES om
			x                                 CHOICES pa
			x                                 CHOICES pe
			x                                 CHOICES pf
			x                                 CHOICES pg
			x                                 CHOICES ph
			x                                 CHOICES pk
			x                                 CHOICES pl
			x                                 CHOICES pm
			x                                 CHOICES pn
			x                                 CHOICES pr
			x                                 CHOICES ps
			x                                 CHOICES pt
			x                                 CHOICES pw
			x                                 CHOICES py
			x                                 CHOICES qa
			x                                 CHOICES re
			x                                 CHOICES ro
			x                                 CHOICES rs
			x                                 CHOICES rw
			x                                 CHOICES sa
			x                                 CHOICES sb
			x                                 CHOICES sc
			x                                 CHOICES sd
			x                                 CHOICES se
			x                                 CHOICES sg
			x                                 CHOICES sh
			x                                 CHOICES si
			x                                 CHOICES sj
			x                                 CHOICES sk
			x                                 CHOICES sl
			x                                 CHOICES sm
			x                                 CHOICES sn
			x                                 CHOICES so
			x                                 CHOICES sr
			x                                 CHOICES st
			x                                 CHOICES su
			x                                 CHOICES sv
			x                                 CHOICES sy
			x                                 CHOICES sz
			x                                 CHOICES tc
			x                                 CHOICES td
			x                                 CHOICES tf
			x                                 CHOICES tg
			x                                 CHOICES th
			x                                 CHOICES tj
			x                                 CHOICES tk
			x                                 CHOICES tm
			x                                 CHOICES tn
			x                                 CHOICES to
			x                                 CHOICES tp
			x                                 CHOICES tr
			x                                 CHOICES tt
			x                                 CHOICES tv
			x                                 CHOICES tw
			x                                 CHOICES tz
			x                                 CHOICES ua
			x                                 CHOICES ug
			x                                 CHOICES um
			x                                 CHOICES us
			x                                 CHOICES uy
			x                                 CHOICES uz
			x                                 CHOICES va
			x                                 CHOICES vc
			x                                 CHOICES ve
			x                                 CHOICES vg
			x                                 CHOICES vi
			x                                 CHOICES vn
			x                                 CHOICES vu
			x                                 CHOICES wf
			x                                 CHOICES ws
			x                                 CHOICES ye
			x                                 CHOICES yt
			x                                 CHOICES za
			x                                 CHOICES zm
			x                                 CHOICES zw]
			x	[-key_usage_extensions           CHOICES critical
			x                                 CHOICES digitalsignature
			x                                 CHOICES nonrepudiation
			x                                 CHOICES keyencipherment
			x                                 CHOICES dataencipherment
			x                                 CHOICES keyagreement
			x                                 CHOICES keycertsign
			x                                 CHOICES crlsign
			x                                 CHOICES encipheronly
			x                                 CHOICES decipheronly]
			x	[-key_size                       CHOICES 512 1024 2048]
			x	[-authentication_wait_period     RANGE 1-3600
			x                                 DEFAULT 30]
			x	[-organization_name              ANY]
			x	[-start_period                   RANGE 1-3600
			x                                 DEFAULT 30]
			x	[-max_start                      RANGE 1-100
			x                                 DEFAULT 3]
			x	[-successive_start               RANGE 1-100
			x                                 DEFAULT 1]
			x	[-fragment_size                  RANGE 500-1400
			x                                 DEFAULT 1400]
			x	[-max_outstanding_requests       RANGE 1-1024
			x                                 DEFAULT 10]
			x	[-max_teardown_rate              RANGE 1-1024
			x                                 DEFAULT 10]
			x	[-protocol_type                  CHOICES tls
			x                                 CHOICES md5
			x                                 CHOICES peapv0
			x                                 CHOICES peapv1
			x                                 CHOICES ttls
			x                                 CHOICES fast]
			x	[-max_setup_rate                 RANGE 1-1024
			x                                 DEFAULT 10]
		
		Arguments:
			x	-port_handle
			x		Ixia interface upon which to act.
			x	-reset
			x		If this option is selected, this will clear any 802.1x device.
			 	-handle
			 		802.1x device handle for using the modes delete, modify, enable, and disable.
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			 	-mode
			 		Action to take on the port specified the handle argument.
			 		Valid choices are:
			    		create - Adds a new 802.1x configuration on the port.
			    		modify - Modifies an existing 802.1x configuration (specified by -handle).
			    		delete - Remove an existing 802.1x configuration (specified by -handle).
			    		getAttribute - get attribute status for existing 802.1xconfiguration (specified by -handle).
			x	-attribute_name
			x		attribute name for fetching value.
			x		Valid choices are:
			x   		sessionInfo - Current 802.1x session state.
			 	-count
			 		Defines the number of dotonex devices to configure on the -port_handle.
			x	-tls_version
			x		TLS version selecction
			x		Valid choices are:
			x   		tls1_0 -
			x   		tls1_1 -
			x   		tls1_2 -
			x	-user_name
			x		Credential of the user for authentication
			x	-user_pwd
			x		Password of the user for authentication
			x	-host_auth_mode
			x		Host Authentication Mode
			x		Valid choices are:
			x   		none -
			x   		hostonly -
			x   		hostuserreauth -
			x   		hostuserboth -
			x	-host_name
			x		Credential of the host for authentication
			x	-host_pwd
			x		Password of the host for authentication
			x	-wait_id
			x		When enabled, the supplicant does not send the initial EAPOL Start message. Instead, it waits for the authenticator (the DUT) to send an EAPOL Request / Identity message.
			x	-fast_provision_mode
			x		FAST Provision Mode
			x		Valid choices are:
			x   		authenticated -
			x   		unauthenticated -
			x   		load_from_file -
			x   		authenticated_save_to_file -
			x   		unauthenticated_save_to_file -
			x	-fast_inner_method
			x		FAST Inner Method
			x		Valid choices are:
			x   		mschapv2 -
			x	-runtime_certificate_generation
			x		Generate Certificate during Run time. Configure details in Global parameters. Common Name will be User Name. Certificate and Key file names will be generated based on corresponding Client User name. Eg: If Client User name is IxiaUser1 then Certificate File will be IxiaUser1.pem, Key File will be IxiaUser1_key.pem, CA certificate File will be root.pem
			x	-fast_stateless_resume
			x		FAST Stateless Resume
			x		Valid choices are:
			x   		yes -
			x   		no -
			x	-send_ca_cert_only
			x		Use this option to send CA Certificate only to Port. Eg: For PEAPv0/v1 case there is no need to send User Certificate to port.
			x	-certificate_directory
			x		The location to the saved certificates
			x	-private_key_file
			x		The private key certificate to be used
			x	-peer_certificate_file
			x		The Peer certificate to be used
			x	-host_key_file
			x		The private key certificate to be used by the host
			x	-host_certificate_file
			x		The Peer certificate to be used by the host
			x	-verify_peer_certificate
			x		Verifies the provided peer certificate
			x	-ca_certificate_file
			x		The CA certificate to be used
			x	-certificate_key_in_same_file
			x		flag to determine whether to use same Certificate file for both Private Key and User Certificate
			x	-active
			x		Activate/Deactivate Configuration
			x	-dut_test_mode
			x		Specify what is the dut port mode
			x		Valid choices are:
			x   		singlehost -
			x   		multihost -
			x   		multiauth -
			x	-machine_auth_prefix
			x		When using machine authentication,
			x		a prefix is needed to differentiate between users and machines.
			x	-disable_logoff
			x		Do not send Logoff message when closing a session.
			x	-multicast
			x		Specify if destination MAC address can be multicast.
			x	-identify_using_VLAN
			x		Specify if VLAN is to be used to identify the supplicants
			x	-authorized_on_no_response
			x		If the DUT is not responding to EAPoL Start after configured
			x		number of retries, declare the session a success
			x	-wait_before_run
			x		The number of secs to wait before running the protocol.Maximum wait is 500
			x	-certificate_server_url
			x		Certificate Server URL
			x	-get_ca_certificate_only
			x		Use this option to get CA Certificate Only. Eg: For PEAPv0/v1 case there is no need to get User Certificate.
			x	-company
			x		Identification Info - Company
			x	-department
			x		Identification Info - Department
			x	-city
			x		Identification Info - City
			x	-state
			x		Identification Info - State
			x	-country
			x		Identification Info - Country
			x		Valid choices are:
			x   		ax -
			x   		ad -
			x   		ae -
			x   		af -
			x   		ag -
			x   		ai -
			x   		al -
			x   		am -
			x   		an -
			x   		ao -
			x   		aq -
			x   		ar -
			x   		as -
			x   		at -
			x   		au -
			x   		aw -
			x   		az -
			x   		ba -
			x   		bb -
			x   		bd -
			x   		be -
			x   		bf -
			x   		bg -
			x   		bh -
			x   		bi -
			x   		bj -
			x   		bm -
			x   		bn -
			x   		bo -
			x   		br -
			x   		bs -
			x   		bt -
			x   		bv -
			x   		bw -
			x   		by -
			x   		bz -
			x   		ca -
			x   		cc -
			x   		cf -
			x   		cg -
			x   		cd -
			x   		ch -
			x   		ci -
			x   		ck -
			x   		cl -
			x   		cm -
			x   		cn -
			x   		co -
			x   		cr -
			x   		cs -
			x   		cu -
			x   		cv -
			x   		cx -
			x   		cy -
			x   		cz -
			x   		de -
			x   		dj -
			x   		dk -
			x   		dm -
			x   		do -
			x   		dz -
			x   		ec -
			x   		ee -
			x   		eg -
			x   		eh -
			x   		er -
			x   		es -
			x   		et -
			x   		fi -
			x   		fj -
			x   		fk -
			x   		fm -
			x   		fo -
			x   		fr -
			x   		fx -
			x   		ga -
			x   		gb -
			x   		gd -
			x   		ge -
			x   		gf -
			x   		gg -
			x   		gi -
			x   		gl -
			x   		gm -
			x   		gn -
			x   		gp -
			x   		gq -
			x   		gr -
			x   		gs -
			x   		gt -
			x   		gu -
			x   		gw -
			x   		gy -
			x   		hk -
			x   		hm -
			x   		hn -
			x   		hr -
			x   		ht -
			x   		hu -
			x   		id -
			x   		ie -
			x   		il -
			x   		im -
			x   		in -
			x   		io -
			x   		iq -
			x   		ir -
			x   		is -
			x   		it -
			x   		je -
			x   		jm -
			x   		jo -
			x   		jp -
			x   		ke -
			x   		kg -
			x   		kh -
			x   		ki -
			x   		km -
			x   		kn -
			x   		kp -
			x   		kr -
			x   		kw -
			x   		ky -
			x   		kz -
			x   		la -
			x   		lb -
			x   		lc -
			x   		li -
			x   		lk -
			x   		lr -
			x   		ls -
			x   		lt -
			x   		lu -
			x   		lv -
			x   		ly -
			x   		ma -
			x   		mc -
			x   		md -
			x   		me -
			x   		mg -
			x   		mh -
			x   		mk -
			x   		ml -
			x   		mm -
			x   		mn -
			x   		mo -
			x   		mp -
			x   		mq -
			x   		mr -
			x   		ms -
			x   		mt -
			x   		mu -
			x   		mv -
			x   		mw -
			x   		mx -
			x   		my -
			x   		mz -
			x   		na -
			x   		nc -
			x   		ne -
			x   		nf -
			x   		ng -
			x   		ni -
			x   		nl -
			x   		no -
			x   		np -
			x   		nr -
			x   		nt -
			x   		nu -
			x   		nz -
			x   		om -
			x   		pa -
			x   		pe -
			x   		pf -
			x   		pg -
			x   		ph -
			x   		pk -
			x   		pl -
			x   		pm -
			x   		pn -
			x   		pr -
			x   		ps -
			x   		pt -
			x   		pw -
			x   		py -
			x   		qa -
			x   		re -
			x   		ro -
			x   		rs -
			x   		rw -
			x   		sa -
			x   		sb -
			x   		sc -
			x   		sd -
			x   		se -
			x   		sg -
			x   		sh -
			x   		si -
			x   		sj -
			x   		sk -
			x   		sl -
			x   		sm -
			x   		sn -
			x   		so -
			x   		sr -
			x   		st -
			x   		su -
			x   		sv -
			x   		sy -
			x   		sz -
			x   		tc -
			x   		td -
			x   		tf -
			x   		tg -
			x   		th -
			x   		tj -
			x   		tk -
			x   		tm -
			x   		tn -
			x   		to -
			x   		tp -
			x   		tr -
			x   		tt -
			x   		tv -
			x   		tw -
			x   		tz -
			x   		ua -
			x   		ug -
			x   		um -
			x   		us -
			x   		uy -
			x   		uz -
			x   		va -
			x   		vc -
			x   		ve -
			x   		vg -
			x   		vi -
			x   		vn -
			x   		vu -
			x   		wf -
			x   		ws -
			x   		ye -
			x   		yt -
			x   		za -
			x   		zm -
			x   		zw -
			x	-key_usage_extensions
			x		Select key usage extensions
			x		Valid choices are:
			x   		critical -
			x   		digitalsignature -
			x   		nonrepudiation -
			x   		keyencipherment -
			x   		dataencipherment -
			x   		keyagreement -
			x   		keycertsign -
			x   		crlsign -
			x   		encipheronly -
			x   		decipheronly -
			x	-key_size
			x		Key Options - Key Size
			x		Valid choices are:
			x   		512 -
			x   		1024 -
			x   		2048 -
			x	-authentication_wait_period
			x		The maximum time interval, measured in seconds, that a Supplicant will wait for an Authenticator response.Maximum value is 3600
			x	-organization_name
			x		Other Options - Alternative Subject Name
			x	-start_period
			x		The time interval between successive EAPOL Start messages sent by a Supplicant.Maxium value is 3600
			x	-max_start
			x		The number of times to send EAPOL Start frames for which no response is received before declaring that the sessions have timed out.
			x		Max value is 100
			x	-successive_start
			x		The number of EAPOL Start messages sent when the supplicant starts the process of authentication.
			x		Max value is 100
			x	-fragment_size
			x		The maximum size of a fragment that can be sent on the wire for TLS fragments that comprise the phase 1 conversation (tunnel establishment).
			x		Max value is 1400
			x	-max_outstanding_requests
			x		The maximum number of sessions that can be negotiated at one moment. Max value is 1024
			x	-max_teardown_rate
			x		The number of interfaces to tear down per second. Max value is 1024
			x	-protocol_type
			x		protocol for authentication
			x		Valid choices are:
			x   		tls -
			x   		md5 -
			x   		peapv0 -
			x   		peapv1 -
			x   		ttls -
			x   		fast -
			x	-max_setup_rate
			x		The number of interfaces to setup per second. Max rate is 1024
		
		Return Values:
		A list containing the dotonex device protocol stack handles that were added by the command (if any).
			xkey:dotonex_device_handle  value:A list containing the dotonex device protocol stack handles that were added by the command (if any).
		A list containing the ipv4 device protocol stack handles that were added by the command (if any).
			xkey:ipv4_device_handle     value:A list containing the ipv4 device protocol stack handles that were added by the command (if any).
		A list containing the ipv6 device protocol stack handles that were added by the command (if any).
			xkey:ipv6_device_handle     value:A list containing the ipv6 device protocol stack handles that were added by the command (if any).
		A list containing the dhcpv4 device protocol stack handles that were added by the command (if any).
			xkey:dhcpv4_device_handle   value:A list containing the dhcpv4 device protocol stack handles that were added by the command (if any).
		A list containing the dhcpv6 device protocol stack handles that were added by the command (if any).
			xkey:dhcpv6_device_handle   value:A list containing the dhcpv6 device protocol stack handles that were added by the command (if any).
		A list containing the pppox client protocol stack handles that were added by the command (if any).
			xkey:pppox_client_handle    value:A list containing the pppox client protocol stack handles that were added by the command (if any).
		A list containing the pppox server protocol stack handles that were added by the command (if any).
			xkey:pppox_server_handle    value:A list containing the pppox server protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:interface_handle       value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		$::SUCCESS or $::FAILURE
			 key:status                 value:$::SUCCESS or $::FAILURE
		If failure, will contain more information
			 key:log                    value:If failure, will contain more information
		802.1x device Handles Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:handle                 value:802.1x device Handles Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) Coded versus functional specification.
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle, interface_handle
		
		See Also:
		
		"""
		return self._run_keyword("emulation_dotonex_config", kwargs)

	def emulation_dotonex_control(self, **kwargs):
		""" This procedure will we be used to execute all actions for 802.1x protocol.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_dotonex_control
			 	[-port_handle REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle      ANY]
			x	[-index       NUMERIC
			x              DEFAULT 1]
			 	[-values      RANGE 1-10000]
			 	-mode         CHOICES stop start restart abort]
		
		Arguments:
			 	-port_handle
			 		A list of ports on which to control the 802.1x protocol. If this option
			 		is not present, the port in the handle option will be applied.
			 	-handle
			 		802.1x device handle.It is returned by emulation_dotonex_config call.
			x	-index
			x		index on which the action defined by the mode parameter will be applied
			 	-values
			 		The values for action to trigger on Ixia interface.
			 	-mode
			 		This option defines the action to be taken.Note: Valid options are:
			 		stop
			 		start
			 		restart
			 		Valid choices are:
			    		stop - Stop the IEEE 802.1X session(s) on the specified device.
			    		start - Start the IEEE 802.1X session(s) on the specified device.
			    		restart - Restart the IEEE 802.1X session(s) on the specified device.
			    		abort - Terminate abruptly IEEE 802.1x session(s) of the specified device without sending any logoff packet.
		
		Return Values:
		$::SUCCESS or $::FAILURE
			 key:status  value:$::SUCCESS or $::FAILURE
		If failure, will contain more information
			 key:log     value:If failure, will contain more information
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_dotonex_control", kwargs)

	def emulation_dotonex_info(self, **kwargs):
		""" Retrieves information about the Dotonex protocol.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_dotonex_info
			x	-mode         CHOICES per_port_stats
			x              CHOICES per_session_stats
			x              CHOICES clear_stats]
			 	-handle       ANY]
			 	[-port_handle REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
		
		Arguments:
			x	-mode
			x   		per_port_stats - Retrieves 802.1x per port stats.
			x   		per_session_stats - Retrieves 802.1x per session stats.
			x   		clear_stats - Clear 802.1x statistics.
			 	-handle
			 		The 802.1x handle to act upon.
			 	-port_handle
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                       value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                          value:If status is failure, detailed information provided.
		IEEE 802.1X Up
			xkey:sessions_up                  value:IEEE 802.1X Up
		IEEE 802.1X Down
			xkey:sessions_down                value:IEEE 802.1X Down
		IEEE 802.1X Not Started
			xkey:sessions_not_started         value:IEEE 802.1X Not Started
		IEEE 802.1X Total
			xkey:sessions_total               value:IEEE 802.1X Total
		Establishment Time
			xkey:establishment_time           value:Establishment Time
		Sessions Initiated
			xkey:sessions_initiated           value:Sessions Initiated
		Sessions Succeeded
			xkey:sessions_succeeded           value:Sessions Succeeded
		Sessions Failed
			xkey:sessions_failed              value:Sessions Failed
		Setup Rate * 100
			xkey:setup_rate                   value:Setup Rate * 100
		Min Setup Rate * 100
			xkey:min_setup_rate               value:Min Setup Rate * 100
		Max Setup Rate * 100
			xkey:max_setup_rate               value:Max Setup Rate * 100
		Avg Setup Rate * 100
			xkey:avg_setup_rate               value:Avg Setup Rate * 100
		Sessions Teardown Succeeded
			xkey:sessions_teardown_succeeded  value:Sessions Teardown Succeeded
		Sessions Teardown Failed
			xkey:sessions_teardown_failed     value:Sessions Teardown Failed
		Teardown Rate * 100
			xkey:teardown_rate                value:Teardown Rate * 100
		Min Teardown Rate * 100
			xkey:min_teardown_rate            value:Min Teardown Rate * 100
		Max Teardown Rate * 100
			xkey:max_teardown_rate            value:Max Teardown Rate * 100
		Avg Teardown Rate * 100
			xkey:avg_teardown_rate            value:Avg Teardown Rate * 100
		EAPOL Start Tx
			xkey:eapol_start_tx               value:EAPOL Start Tx
		EAPOL Logoff
			xkey:eapol_logoff                 value:EAPOL Logoff
		EAP ID Responses
			xkey:eapid_responses              value:EAP ID Responses
		EAP Non ID Responses
			xkey:eapnonid_responses           value:EAP Non ID Responses
		EAP ID Requests
			xkey:eapid_requests               value:EAP ID Requests
		EAP Non ID Requests
			xkey:eapnonid_requests            value:EAP Non ID Requests
		EAP Success
			xkey:eap_success                  value:EAP Success
		EAP Failure
			xkey:eap_failure                  value:EAP Failure
		EAP Length Error Rx
			xkey:eap_length_err_rx            value:EAP Length Error Rx
		EAP Alert Rx
			xkey:eap_alert_rx                 value:EAP Alert Rx
		EAP Unexpected Failure
			xkey:eap_unexpected_failure       value:EAP Unexpected Failure
		MD5 Sessions
			xkey:md5_sessions                 value:MD5 Sessions
		MD5 Success
			xkey:md5_success                  value:MD5 Success
		MD5 Timeout Failed
			xkey:md5_timeout_failed           value:MD5 Timeout Failed
		MD5 EAP Failed
			xkey:md5_eap_failed               value:MD5 EAP Failed
		MD5 Latency [ms]
			xkey:md5_latency                  value:MD5 Latency [ms]
		TLS Sessions
			xkey:tls_sessions                 value:TLS Sessions
		TLS Success
			xkey:tls_success                  value:TLS Success
		TLS Timeout Failed
			xkey:tls_timeout_failed           value:TLS Timeout Failed
		TLS EAP Failed
			xkey:tls_eap_failed               value:TLS EAP Failed
		TLS Latency [ms]
			xkey:tls_latency                  value:TLS Latency [ms]
		PEAP Sessions
			xkey:peap_sessions                value:PEAP Sessions
		PEAP Success
			xkey:peap_success                 value:PEAP Success
		PEAP Timeout Failed
			xkey:peap_timeout_failed          value:PEAP Timeout Failed
		PEAP EAP Failed
			xkey:peap_eap_failed              value:PEAP EAP Failed
		PEAP Latency [ms]
			xkey:peap_latency                 value:PEAP Latency [ms]
		TTLS Sessions
			xkey:ttls_sessions                value:TTLS Sessions
		TTLS Success
			xkey:ttls_success                 value:TTLS Success
		TTLS Timeout Failed
			xkey:ttls_timeout_failed          value:TTLS Timeout Failed
		TTLS EAP Failed
			xkey:ttls_eap_failed              value:TTLS EAP Failed
		TTLS Latency [ms]
			xkey:ttls_latency                 value:TTLS Latency [ms]
		FAST Sessions
			xkey:fast_sessions                value:FAST Sessions
		FAST Success
			xkey:fast_success                 value:FAST Success
		FAST Timeout Failed
			xkey:fast_timeout_failed          value:FAST Timeout Failed
		FAST EAP Failed
			xkey:fast_eap_failed              value:FAST EAP Failed
		FAST Latency [ms]
			xkey:fast_latency                 value:FAST Latency [ms]
		Host Sessions
			xkey:host_sessions                value:Host Sessions
		Host Success
			xkey:host_success                 value:Host Success
		Host Timeout Failed
			xkey:host_timeout_failed          value:Host Timeout Failed
		Host EAP Failed
			xkey:host_eap_failed              value:Host EAP Failed
		User Sessions
			xkey:user_sessions                value:User Sessions
		User Success
			xkey:user_success                 value:User Success
		User Timeout Failed
			xkey:user_timeout_failed          value:User Timeout Failed
		User EAP Failed
			xkey:user_eap_failed              value:User EAP Failed
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_dotonex_info", kwargs)

	def emulation_efm_config(self, **kwargs):
		""" Configures EFM emulation for a given port. Also has the ability to toggle certain EFM
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_efm_config
			 	-port_handle                     ANY
			 	[-critical_event                 ANY]
			 	[-dying_gasp                     ANY]
			 	[-error_frame_period_threshold   ANY]
			 	[-error_frame_period_window      ANY]
			 	[-error_frame_summary_threshold  ANY]
			 	[-error_frame_summary_window     ANY]
			 	[-error_frame_threshold          ANY]
			 	[-error_frame_window             ANY]
			 	[-error_symbol_period_threshold  ANY]
			 	[-error_symbol_period_window     ANY]
			 	[-link_events                    ANY]
			 	[-link_fault                     ANY]
			 	[-mac_local                      ANY]
			 	[-oui_value                      ANY]
			 	[-size                           ANY]
			 	[-variable_retrieval             ANY]
			 	[-vsi_value                      ANY]
			x	[-api_used                       ANY]
			x	[-disable_information_pdu_tx     ANY]
			x	[-disable_non_information_pdu_tx ANY]
			x	[-enable_loopback                ANY]
			x	[-enable_loopback_response       ANY]
			x	[-enable_oam                     ANY]
			x	[-enable_optional_tlv            ANY]
			x	[-enable_variable_response       ANY]
			x	[-event_interval                 ANY]
			x	[-error_symbol_period_count      ANY]
			x	[-error_frame_count              ANY]
			x	[-error_frame_period_count       ANY]
			x	[-error_frame_summary_count      ANY]
			x	[-idle_timer                     ANY]
			x	[-information_pdu_rate           ANY]
			x	[-length_mode                    ANY]
			x	[-link_event_tx_mode             ANY]
			x	[-link_events_l1                 ANY]
			x	[-local_lost_link_timer          ANY]
			x	[-loopback_cmd                   ANY]
			x	[-loopback_timeout               ANY]
			x	[-local_information_oui_value    ANY]
			x	[-local_information_vsi_value    ANY]
			x	[-mac_local_l1                   ANY]
			x	[-oam_mode                       ANY]
			x	[-oampdu_type                    ANY]
			x	[-os_event_tlv_oui               ANY]
			x	[-os_event_tlv_value             ANY]
			x	[-os_oampdu_data_oui             ANY]
			x	[-os_oampdu_data_value           ANY]
			x	[-oui_value_l1                   ANY]
			x	[-override_local_evaluating      ANY]
			x	[-override_local_satisfied       ANY]
			x	[-override_local_stable          ANY]
			x	[-override_remote_evaluating     ANY]
			x	[-override_remote_stable         ANY]
			x	[-override_revision              ANY]
			x	[-remote_information_oui_value   ANY]
			x	[-remote_information_vsi_value   ANY]
			x	[-revision                       ANY]
			x	[-sequence_id                    ANY]
			x	[-sequence_id_step               ANY]
			x	[-size_l1                        ANY]
			x	[-supports_remote_loopback       ANY]
			x	[-supports_unidir_mode           ANY]
			x	[-tlv_type                       ANY]
			x	[-tlv_value                      ANY]
			x	[-variable_response_timeout      ANY]
			x	[-version                        ANY]
		
		Arguments:
			 	-port_handle
			 		Port to configure EFM emulation messages on.(DEFAULT =N/A)
			 	-critical_event
			 		Send Critical Event message to EFM peer. Enables critical event flag on all OAMPDUs. When IxNetwork/IxProtocol Tcl Api is used, this parameter configures the OAMPDUs from the current EFM Link.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =0)
			 	-dying_gasp
			 		Send Dying Gasp message to EFM peer. Enables dying gasp flag on all all OAMPDUs. When IxNetwork/IxProtocol Tcl Api is used, this parameter configures the OAMPDUs from the current EFM Link.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =0)
			 	-error_frame_period_threshold
			 		Define the threshold for Errored Frame Period Events. Builds an OAMPDU code 'Event Notification' and adds an error_frame_period TLV to it, or appends an error_frame_period TLV to the existing OAMPDU.When IxNetwork/IxProtocol Tcl Api is used, one EFM Link can have only one 'Event Notification' OAMPDU. If none of the error_frame, error_frame_period, error_frame_summary, error_symbol_period TLV parameters are specified than the EFM Link will have no 'Event Notification' OAMPDU. This parameter enables the error_frame_period TLV on the 'Event Notification' OAMPDU and configures its threshold value. With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =30)
			 	-error_frame_period_window
			 		Define the window for Errored Frame Period Events. Builds an OAMPDU code 'Event Notification' and adds an error_frame_period TLV to it, or appends an error_frame_period TLV to the existing OAMPDU.When IxNetwork/IxProtocol Tcl Api is used, one EFM Link can have only one 'Event Notification' OAMPDU. If none of the error_frame, error_frame_period, error_frame_summary, error_symbol_period TLV parameters are specified than the EFM Link will have no 'Event Notification' OAMPDU. This parameter enables the error_frame_period TLV on the 'Event Notification' OAMPDU and configures its window value. With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running. (DEFAULT =300)
			 	-error_frame_summary_threshold
			 		Define the threshold for Errored Frame Second Summary Events. Builds an OAMPDU with code 'Event Notification' and adds an error_frame_summary TLV to it, or appends an error_frame_summary TLV to the existing OAMPDU. When IxNetwork/IxProtocol Tcl Api is used, one EFM Link can have only one 'Event Notification' OAMPDU. If none of the error_frame, error_frame_period, error_frame_summary, error_symbol_period TLV parameters are specified than the EFM Link will have no 'Event Notification' OAMPDU. This parameter enables the error_frame_summary TLV on the 'Event Notification' OAMPDU and configures its threshold value.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =30)
			 	-error_frame_summary_window
			 		Define the window for Errored Frame Second Summary Events. Builds an OAMPDU with code 'Event Notification' and adds an error_frame_summary TLV to it, or appends an error_frame_summary TLV to the existing OAMPDU.When IxNetwork/IxProtocol Tcl Api is used, one EFM Link can have only one 'Event Notification' OAMPDU. If none of the error_frame, error_frame_period, error_frame_summary, error_symbol_period TLV parameters are specified than the EFM Link will have no 'Event Notification' OAMPDU. This parameter enables the error_frame_summary TLV on the 'Event Notification' OAMPDU and configures its window value.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =300)
			 	-error_frame_threshold
			 		Define the threshold for Errored Frame Events. Builds an OAMPDU with code 'Event Notification' and adds an error_frame TLV to it, or appends an error_frame TLV to the existing OAMPDU.When IxNetwork/IxProtocol Tcl Api is used, one EFM Link can have only one 'Event Notification' OAMPDU. If none of the error_frame, error_frame_period, error_frame_summary, error_symbol_period TLV parameters are specified than the EFM Link will have no 'Event Notification' OAMPDU. This parameter enables the error_frame TLV on the 'Event Notification' OAMPDU and configures its threshold value.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =40)
			 	-error_frame_window
			 		Define the window for Errored Frame Events. Builds an OAMPDU with code 'Event Notification' and adds an error_frame TLV to it, or appends an error_frame TLV to the existing OAMPDU.When IxNetwork/IxProtocol Tcl Api is used, one EFM Link can have only one 'Event Notification' OAMPDU. If none of the error_frame, error_frame_period, error_frame_summary, error_symbol_period TLV parameters are specified than the EFM Link will have no 'Event Notification' OAMPDU. This parameter enables the error_frame TLV on the 'Event Notification' OAMPDU and configures its window value.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =400)
			 	-error_symbol_period_threshold
			 		Define the threshold for Errored Symbol Period Events. Builds an OAMPDU with code 'Event Notification' and adds an error_symbol_period TLV to it, or appends an error_symbol_period TLV to the existing OAMPDU.When IxNetwork/IxProtocol Tcl Api is used, one EFM Link can have only one 'Event Notification' OAMPDU. If none of the error_frame, error_frame_period, error_frame_summary, error_symbol_period TLV parameters are specified than the EFM Link will have no 'Event Notification' OAMPDU. This parameter enables the error_symbol_period TLV on the 'Event Notification' OAMPDU and configures its threshold value.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =50)
			 	-error_symbol_period_window
			 		Define the window for Errored Symbol Period Events. Builds an OAMPDU with code 'Event Notification' and adds an error_symbol_period TLV to it, or appends an error_symbol_period TLV to the existing OAMPDU.When IxNetwork/IxProtocol Tcl Api is used, one EFM Link can have only one 'Event Notification' OAMPDU. If none of the error_frame, error_frame_period, error_frame_summary, error_symbol_period TLV parameters are specified than the EFM Link will have no 'Event Notification' OAMPDU. This parameter enables the error_symbol_period TLV on the 'Event Notification' OAMPDU and configures its window value.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =500)
			 	-link_events
			 		Specify that TGEN EFM emulation should have link-events enabled. Enables link events flag in the "Information" OAMPDUs.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =0)
			 	-link_fault
			 		Send Link Fault message to EFM peer. Enables link fault flag on all OAMPDUs.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =0)
			 	-mac_local
			 		The mac address of the emulated device(s). (DEFAULT =00de.<chassis><card>.<port>00)
			 	-oui_value
			 		Allows configuration of the organization unique identifier on the Ixia port. 6 HEX chars. When IxNetwork/IxProtocol Tcl API is used, this parameter configures the organization unique identifier for this EFM Link.
			 	-size
			 		The size of the OAMPDU datagrams to send. When IxNetwork/IxProtocol Tcl Api is used, this parameter configures the maximum OAMPDU size for this EFM Link.(DEFAULT =64)
			 	-variable_retrieval
			 		Specify that TGEN EFM emulation should have variable retrieval enabled. Creates an OAMPDU with code "Information" having variable retrieval capability flag enabled. When IxNetwork/IxProtocol Tcl Api is used, the OAMPDUs with code "Information" are controlled by the Ixia port. They cannot be send on demand. When EFM emulation is started, the EFM Link will use send the Information OAMPDUs accordingly to establish discovery.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =0)
			 	-vsi_value
			 		Allows configuration of the vendor specific information on the Ixia port. 8 HEX chars.When IxNetwork/IxProtocol Tcl API is used, this parameter configures the vendor specific information for this EFM Link.
			x	-api_used
			x   		ixnetwork - Use IxNetwork implementation. Valid only if the HLTSET used loads IxNetwork TCL API.
			x   		x - Use IxNetwork implementation. Valid only if the HLTSET used loads IxNetwork TCL API.
			x   		ixprotocol - Use IxProtocol implementation. Valid only if the HLTSET used loads IxProtocol TCL API.
			x   		ixos - Use IxOS implementation. This is the default if the HLTSET does not load
			x	-disable_information_pdu_tx
			x		Control the transmission of information PDU.Valid values are:1 - true (disable transmission of information pdu)Supported only with IxNetwork/IxProtocol Tcl Api. With IxNetwork/IxProtocol Tcl API this parameter will be updated even if the protocol is running.
			x	-disable_non_information_pdu_tx
			x		Control the transmission of non-information PDU.Valid values are:1 - true (disable transmission of non-information pdu)Supported only with IxNetwork/IxProtocol Tcl Api. With IxNetwork/IxProtocol Tcl API this parameter will be updated even if the protocol is running.
			x	-enable_loopback
			x		If true, enables the loopback when an ixia port goes to loopback mode, then all non oam packets coming to that port gets looped back.Valid values are:0 - false (disable loopback)1 - true
			x	-enable_loopback_response
			x		Valid values are:0 - false (disable loopback response)Supported only with IxNetwork/IxProtocol Tcl Api. With IxNetwork/IxProtocol Tcl API this parameter will be updated even if the protocol is running.
			x	-enable_oam
			x		This parameter enables OAM.Valid values are:0 - false (disable OAM)1 - true (disable OAM)
			x	-enable_optional_tlv
			x		Valid values are:0 - false (disable tlv option)1 - true
			x	-enable_variable_response
			x		Valid values are:0 - false (disable loopback response)This is different from variable_retrieval. variable_retrieval parameter is configures a flag and will be transmitted in information OAMPDU.enable_variable_response will be used to specifiy whether to respond to Variable request or not.Supported only with IxNetwork/IxProtocol Tcl Api. With IxNetwork/IxProtocol Tcl API this parameter will be updated even if the protocol is running.
			x	-event_interval
			x		Supported only with IxNetwork/IxProtocol Tcl Api.Periodic interval in seconds of event pdu when event pdu is to be sent periodically (link_event_tx_mode is 'periodic'). Minimum value is 1 sec and Maximum value is 10 secs.
			x	-error_symbol_period_count
			x		Define the number of symbol errors in the period. Builds an OAMPDU with code 'Event Notification' and adds an error_symbol_period TLV to it, or appends an error_symbol_period TLV to the existing OAMPDU.When IxNetwork/IxProtocol Tcl Api is used, one EFM Link can have only one 'Event Notification' OAMPDU. If none of the error_frame, error_frame_period, error_frame_summary, error_symbol_period TLV parameters are specified than the EFM Link will have no 'Event Notification' OAMPDU. This parameter enables the error_symbol_period TLV on the 'Event Notification' OAMPDU and configures its count value.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =50)
			x	-error_frame_count
			x		Define the number of detected Errored Frames in the period. Builds an OAMPDU with code 'Event Notification' and adds an error_frame TLV to it, or appends an error_frame TLV to the existing OAMPDU.When IxNetwork/IxProtocol Tcl Api is used, one EFM Link can have only one 'Event Notification' OAMPDU. If none of the error_frame, error_frame_period, error_frame_summary, error_symbol_period TLV parameters are specified than the EFM Link will have no 'Event Notification' OAMPDU. This parameter enables the error_frame TLV on the 'Event Notification' OAMPDU and configures its count value.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =40)
			x	-error_frame_period_count
			x		Define the number of detected Errored Frames in the Period. Builds an OAMPDU with code 'Event Notification' and adds an error_frame_period TLV to it, or appends an error_frame_period TLV to the existing OAMPDU.When IxNetwork/IxProtocol Tcl Api is used, one EFM Link can have only one 'Event Notification' OAMPDU. If none of the error_frame, error_frame_period, error_frame_summary, error_symbol_period TLV parameters are specified than the EFM Link will have no 'Event Notification' OAMPDU. This parameter enables the error_frame_period TLV on the 'Event Notification' OAMPDU and configures its count value.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =30)
			x	-error_frame_summary_count
			x		Define the number of Errored Frame Second in the period. Builds an OAMPDU with code 'Event Notification' and adds an error_frame_summary TLV to it, or appends an error_frame_summary TLV to the existing OAMPDU.When IxNetwork/IxProtocol Tcl Api is used, one EFM Link can have only one 'Event Notification' OAMPDU. If none of the error_frame, error_frame_period, error_frame_summary, error_symbol_period TLV parameters are specified than the EFM Link will have no 'Event Notification' OAMPDU. This parameter enables the error_frame_summary TLV on the 'Event Notification' OAMPDU and configures its count value.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.(DEFAULT =30)
			x	-idle_timer
			x		The timer used to ensure OAM sub layer adheres to maximum number of OAMPDUs per second and emits at least one OAMPDU per second.(DEFAULT =5)
			x	-information_pdu_rate
			x		Supported only with IxNetwork/IxProtocol Tcl Api.Timer used to ensure OAM sub layer adheres to maximum number of OAMPDUs per second and emits at least one OAMPDU per second. Minimum value is 1 and Maximum value is 10.
			x	-length_mode
			x		Not supported with IxTclNetwork.fixed - The OAMPDU size is fixed. Size of the OAMPDU is configured using the -size argument.random - The OAMPDU size is random. The minimum value will be the minimum needed to fit the OAMPDU. The maximum value will be specified using the -size argument. If the -size argument is smaller than the minimum size required to fit the OAMPDU, the value will be fixed and set to the value of the size argument.
			x	-link_event_tx_mode
			x		Supported only with IxNetwork/IxProtocol Tcl Api.
			x		Valid choices are:
			x   		periodic - send Event Notification PDUs until emulation_efm_control -action stop is called.
			x   		single - send Event Notification PDU than stop.
			x	-link_events_l1
			x		Enables link events flag in the layer1 configuration OAM. This paramater is available only when using IxTclNetwork path.(DEFAULT =0)
			x	-local_lost_link_timer
			x		Supported only with IxNetwork/IxProtocol Tcl Api. Timer used to reset the Discovery state machine. Minimum value is 2 seconds and Maximum value is 90 seconds.
			x	-loopback_cmd
			x		Supported only with IxNetwork/IxProtocol Tcl Api. Valid values are:enable_oam_remote_loopback (DEFAULT)disable_oam_remote_loopback
			x	-loopback_timeout
			x		Supported only with IxNetwork/IxProtocol Tcl Api.Loopback timeout. Minimum value is 0.5 sec and maximum value is 10 seconds.
			x	-local_information_oui_value
			x		Not supported with IxNetwork/IxProtocol Tcl API.Organization unique identifier for Local Information TLV. 6 HEX chars.
			x	-local_information_vsi_value
			x		Not supported with IxNetwork/IxProtocol Tcl API.Configures Vendor Specific Information for Local Information TLV. An unspecified list of hex bytes. May be used to differentiate a vendor's product models/versions. 8 HEX chars.
			x	-mac_local_l1
			x		The mac address of Layer1 configuration OAM. This parameter is available only when using IxTclNetwork. For IxTclHal path, use -mac_local.(DEFAULT =00de.<chassis><card>.<port>00)
			x	-oam_mode
			x		Available only with IxNetwork/IxProtocol Tcl API. Define the EFM OAM mode to use.Valid options are:active - EFM Link is activepassive - EFM Link is passive (DEFAULT)
			x	-oampdu_type
			x		Not supported with IxNetwork/IxProtocol Tcl API. Configures the OAMPDU types that will be configured. When IxNetwork/IxProtocol Tcl API is used, Information OAMPDUs are controlled by the Ixia port and send accordingly to accomplish discovery. Only one Event Notification OAMPDU is created per EFM Link.
			x		Valid choices are:
			x   		none - only configure OAM port properties. Does not create any OAMPDUs.
			x   		information - creates an Information OAMPDU
			x   		event_notification - creates an Event Notification OAMPDU
			x   		info_and_event - creates an Information OAMPDU and an Event Notification OAMPDU
			x	-os_event_tlv_oui
			x		Supported only with IxNetwork/IxProtocol Tcl Api. Three octets field in hex. Organizationally Unique Identifier for Organization Specific Event TLV.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.
			x	-os_event_tlv_value
			x		Supported only with IxNetwork/IxProtocol Tcl Api. This field indicates the value of the Organization Specific Event. This field's length is unspecified. Any hex value can be given (use 0x0011 format).With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.
			x	-os_oampdu_data_oui
			x		Supported only with IxNetwork/IxProtocol Tcl Api. Three octets field in hex. Organizationally Unique Identifier for Organization Specific Tlvs .
			x	-os_oampdu_data_value
			x		Supported only with IxNetwork/IxProtocol Tcl Api. This field indicates the value of the Organization Specific Tlvs. This field's length is unspecified. Any hex value can be given (use 0x0011 format).
			x	-oui_value_l1
			x		This parameter configures the organization unique identifier for layer1 OAM. 6 HEX chars. Valid only for IxNetwork/IxProtocol Tcl API is used, For IxOS path, use -oui_value.
			x	-override_local_evaluating
			x		Supported only with IxNetwork/IxProtocol Tcl Api. Indicate whether local evaluating flag is to be overridden or not.Valid values are:0 - false (DEFAULT)1 - true (overridde local evaluating flag)With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.
			x	-override_local_satisfied
			x		Supported only with IxNetwork/IxProtocol Tcl Api. Indicate whether local satisfied flag is to be overridden or not.Valid values are:0 - false (DEFAULT)1 - true (overridde local satisfied flag)With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.
			x	-override_local_stable
			x		Supported only with IxNetwork/IxProtocol Tcl Api. Indicate whether local stable flag is to be overridden or not.Valid values are:0 - false (DEFAULT)1 - true (overridde local stable flag)With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.
			x	-override_remote_evaluating
			x		Supported only with IxNetwork/IxProtocol Tcl Api. Indicate whether remote evaluating flag is to be overridden or not.Valid values are:0 - false (DEFAULT)1 - true (overridde remote evaluating flag)With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.
			x	-override_remote_stable
			x		Supported only with IxNetwork/IxProtocol Tcl Api. Indicate whether remote stable flag is to be overridden or not.Valid values are:0 - false (DEFAULT)1 - true (overridde remote stable flag)With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.
			x	-override_revision
			x		Supported only with IxNetwork/IxProtocol Tcl Api. Indicate whether revision field is to be overridden or not.Valid values are:0 - false (DEFAULT)1 - true (overridde revision field)With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.
			x	-remote_information_oui_value
			x		Not supported with IxNetwork/IxProtocol Tcl API. Organization unique identifier for Remote Information TLV. 6 HEX chars.
			x	-remote_information_vsi_value
			x		Not supported with IxNetwork/IxProtocol Tcl API. Configures Vendor Specific Information for Remote Information TLV. An unspecified list of hex bytes. May be used to differentiate a vendor's product models/versions. 8 HEX chars.
			x	-revision
			x		Supported only with IxNetwork/IxProtocol Tcl Api. If override_revision is 1 this is the value used for revision field. Maximum value is 65535.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.
			x	-sequence_id
			x		The OAM Sequence Number for each unique Event Notification OAMPDU. When IxNetwork/IxProtocol Tcl API is used, the sequence id is assigned and managed by the Ixia EFM Link. Specifing this parameter will cause the sequence id to be overridden.With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.
			x	-sequence_id_step
			x		Not supported with IxNetwork/IxProtocol Tcl API. The step used to increment OAM Sequence Number per packet.(DEFAULT 1)
			x	-size_l1
			x		This parameter configures the maximum OAMPDU size for layer1 OAM. Valid only for IxTclNetworkpath. For IxOS path, use -size parameter.(DEFAULT =64)
			x	-supports_remote_loopback
			x		Supported only with IxNetwork/IxProtocol Tcl Api. Indicate whether remote DTE is capable of remote loopback mode.Valid values are:0 - false1 - true (DEFAULT)With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.
			x	-supports_unidir_mode
			x		Supported only with IxNetwork/IxProtocol Tcl Api. Enable or disable unidirectional mode in ixia port.Valid values are:0 - disable1 - enable (DEFAULT)With IxNetwork/IxProtocol TCL API this parameter will be updated even if the protocol is running.
			x	-tlv_type
			x		Field that indicates the TLV Type. Minimum value is 0x00 and Maximum value is 0xFF.
			x	-tlv_value
			x		Field that indicates the TLV Value.
			x	-variable_response_timeout
			x		Supported only with IxNetwork/IxProtocol Tcl Api. Maximum time in seconds to wait for variable response pdu. Minimum value is 0.5 sec and maximum value is 10 seconds.
			x	-version
			x		Supported only with IxNetwork/IxProtocol Tcl Api.Field indicates the version supported by this local DTE. Minimum value is 0x00 and Maximum value is 0xFF.Default value is 0x01.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                        value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                           value:On status of failure, gives detailed information.
		stream_id of the Information OAMPDU. It can be used with ::<namespace>::traffic_config. When IxNetwork/IxProtocol Tcl API is used, this parameter will return the EFM Link handle for backwards compatibility.
			 key:information_oampdu_id         value:stream_id of the Information OAMPDU. It can be used with ::<namespace>::traffic_config. When IxNetwork/IxProtocol Tcl API is used, this parameter will return the EFM Link handle for backwards compatibility.
		stream_id for Event Notification OAMPDU. It can be used with ::<namespace>::traffic_config. When IxNetwork/IxProtocol Tcl API is used, this parameter will return the EFM Link handle for backwards compatibility.
			 key:event_notification_oampdu_id  value:stream_id for Event Notification OAMPDU. It can be used with ::<namespace>::traffic_config. When IxNetwork/IxProtocol Tcl API is used, this parameter will return the EFM Link handle for backwards compatibility.
		
		Examples:
		See sample file efm_mixed_traffic_capture.tcl in Appendix A.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1. Coded versus functional specification.
		2. key:information_oampdu_id and key:event_notification_oampdu_id cannot be used with ::<namespace>::traffic_config when IxNetwork/IxProtocol TCL Api is used, because IxNetwork/IxProtocol implementation does not use regular streams to emulate OAMPDUs.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_efm_config", kwargs)

	def emulation_efm_control(self, **kwargs):
		""" Start and Stop EFM emulation on a given port. This procedure enables
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_efm_control
			 	-port_handle  ANY
			 	-action       ANY
		
		Arguments:
			 	-port_handle
			 		Port to control EFM emulation on. Mandatory.(DEFAULT =N/A)
			 	-action
			 		Control EFM emulation. Notes: To send/stop EFM OAMPDUs with IxOS Tcl implementation use ::<namespace>::traffic_control -action run/stop. This is supported with IxNetwork/IxProtocol implementation too for backwards compatibility but will become deprecated.start - Enables Ethernet OAM on the Ixia Port. Enables EFM statistics.stop - Disables Ethernet OAM on the Ixia Port. Disables EFM statistics.start_event - Start sending 'Event Notification' OAMPDU. . It will be single or periodic depending on the -link_event_tx_mode value configured in '::<namespace>::emulation_efm_config'. Available only with IxNetwork/IxProtocol Tcl API.stop_event - Stop sending 'Event Notification' OAMPDU if -link_event_tx_mode was configured to 'periodic' in '::<namespace>::emulation_efm_config'. Available only with IxNetwork/IxProtocol Tcl API.restart_discovery - Discovery mechanism is started from the initial state irrespective of its current state. Available only with IxNetwork/IxProtocol Tcl API.send_loopback - Available only with IxNetwork/IxProtocol Tcl API.send_org_specific_pdu - Transmit Organization Specific PDU. The action will not be possible if the Organization Specific OAMPDU data was not configured. The protocol must be running and the discovery must be complete. Available only with IxNetwork/IxProtocol Tcl API.send_variable_request - Available only with IxNetwork/IxProtocol Tcl API.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log     value:On status of failure, gives detailed information.
		
		Examples:
		See sample file efm_mixed_traffic_capture.tcl in Appendix A.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1. Coded versus functional specification.
		2. OAMPDU streams can be mixed only with streams created with -traffic_generator ixos only when IxOS Tcl implementation.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_efm_control", kwargs)

	def emulation_efm_org_var_config(self, **kwargs):
		""" Configure organization specific info tlv, variable response database and variable descriptors on the OAM Link from port -port_handle.This procedure is available only for IxNetwork
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_efm_org_var_config
			 	[-count                  ANY]
			 	[-handle                 ANY]
			 	-mode                    ANY
			 	-port_handle             ANY
			 	[-os_info_tlv_oui        ANY]
			 	[-os_info_tlv_oui_step   ANY]
			 	[-os_info_tlv_value      ANY]
			 	[-os_info_tlv_value_step ANY]
			 	[-reset                  ANY]
			 	[-type                   ANY]
			 	[-variable_branch        ANY]
			 	[-variable_branch_step   ANY]
			 	[-variable_indication    ANY]
			 	[-variable_leaf          ANY]
			 	[-variable_leaf_step     ANY]
			 	[-variable_value         ANY]
			 	[-variable_value_step    ANY]
			 	[-variable_width         ANY]
		
		Arguments:
			 	-count
			 		Number of objects to create. Only for mode create.
			 	-handle
			 		Use when -mode is modify, enable or disable to specify the handles that will be altered.On mode modify only one object must be passed. On modes enable|disable|remove a list of handles can be used. Objects of type variable_descriptors cannot be enabled/disabled.
			 	-mode
			 		Action to perform on the object passed with -handle.create - create new object based on the -type parametermodify - modify the handle specfied with -handle parameter.enable - a list of handles can be used. Objects of type variable_descriptors cannot be enabled/disabled.disable - a list of handles can be used. Objects of type variable_descriptors cannot be enabled/disabled.remove - a list of handles can be used
			 	-port_handle
			 		Port to configure EFM organization_specific_info_tlv, variable_response_database or variable_descriptors on. (DEFAULT =N/A)
			 	-os_info_tlv_oui
			 		Three octets field in hex. Organizationally Unique Identifier for Organization Specific Info TLV. Use 0x format. Parameter -type must be 'organization_specific_info_tlv'.
			 	-os_info_tlv_oui_step
			 		Three octets field in hex. Step to increment Organizationally Unique Identifier when -count > 1.Use 0x format. Parameter -type must be 'organization_specific_info_tlv'. Incrementing will be done round robin.
			 	-os_info_tlv_value
			 		This field indicates the value of the Organization Specific Info TLV. This field's length is unspecified. Any hex value can be given (use 0x format). Parameter -type must be 'organization_specific_info_tlv'.
			 	-os_info_tlv_value_step
			 		Increment step for -os_info_tlv_value when -count > 1. Any hex value can be given (use 0x format). Parameter -type must be 'organization_specific_info_tlv'.
			 	-reset
			 		If present deletes all objects of type -type created on port -port_handle before creating new ones. This parameter is supported using the following APIs: IxN.
			 	-type
			    		organization_specific_info_tlv - Add an organization specific info tlv
			    		variable_response_database - Add a variable response database entry
			    		variable_descriptors - Add a variable descriptor on the OAM
			 	-variable_branch
			 		Variable Branch value in hex (1 octet, use 0x format). Parameter -type must be 'variable_response_database' or 'variable_descriptors'.
			 	-variable_branch_step
			 		Step in hex to increment variable_branch value when -count > 1 (1 octet, use 0x format). Parameter -type must be 'variable_response_database' or 'variable_descriptors'.Incrementing will be done round robin. Only for -mode 'create'.
			 	-variable_indication
			 		Indicate that this Leaf has some error. Valid options are:0 - false (DEFAULT)1 - trueParameter -type must be 'variable_response_database'. If this parameter is '1' parameters variable_width and variable_width_step are used and variable_value and variable_value_step are ignored.If this parameter is '0' parameters variable_width and variable_width_step are ignored and variable_value and variable_value_step are used.
			 	-variable_leaf
			 		Variable Leaf value in hex (2 octets, use 0x format). Parameter -type must be 'variable_response_database' or 'variable_descriptors'.
			 	-variable_leaf_step
			 		Step in hex to increment variable_leaf when -count > 1 (2 octets, use 0x format).Incrementing will be done round robin. Parameter -type must be 'variable_response_database' or 'variable_descriptors'. Only for -mode = 'create'.
			 	-variable_value
			 		The variable_value parameter may be 1 to 128 octets in length. Its width is determined by the variable_width parameter. Hex value; use 0x format.Parameter -type must be 'variable_response_database'. This parameter is used only if -variable_indication is 0.
			 	-variable_value_step
			 		Step to increment -variable_value when -count > 1. It may be 1 to 128 octets in length and must not exceed the length of variable_value.Incrementing will be done round robin. Parameter -type must be 'variable_response_database'. Only for -mode = 'create'. This parameter is used only if -variable_indication is 0.
			 	-variable_width
			 		Configure the width for -variable_value. Parameter -type must be 'variable_response_database'. This parameter is used only if -variable_indication is 1.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log     value:On status of failure, gives detailed information.
		handle or handle list (if -count > 1)
			 key:handle  value:handle or handle list (if -count > 1)
		
		Examples:
		See sample file efm_mixed_traffic_capture.tcl in Appendix A.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_efm_org_var_config", kwargs)

	def emulation_efm_stat(self, **kwargs):
		""" Get EFM port statistics.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_efm_stat
			 	-port_handle   ANY
			 	-action        ANY
			x	[-api_used     ANY]
			x	[-capture_file ANY]
		
		Arguments:
			 	-port_handle
			 		Port to get EFM stats from. (DEFAULT =N/A)
			 	-action
			 		Specify what to do with the EFM stats for the port, either get them or reset.When IxOS TCL API implementation is used it is mandatory to start port capture in order to retrieve EFM statistic keys marked with alarm, otherwise these statistics are N/A (for IxNetwork/IxProtocol implementation this is not required).When IxOS TCL API implementation is used, inspecting capture buffer to provide alarm statistics can be suppressed using the skip_capture_stats flag.
			 		Valid choices are:
			    		get - Get statistics.
			    		reset - Reset statistics. If ::<namespace>::traffic_config -action clear_stats
			x	-api_used
			x   		ixnetwork - Use IxNetwork implementation. Valid only if the HLTSET used loads IxNetwork TCL API.
			x   		x - Use IxNetwork implementation. Valid only if the HLTSET used loads IxNetwork TCL API.
			x   		ixprotocol - Use IxProtocol implementation. Valid only if the HLTSET used loads IxProtocol TCL API.
			x   		ixos - Use IxOS implementation. This is the default if the HLTSET does not load
			x	-capture_file
			x		Path to Ixia compatible capture file. If this parameter is present, alarm statistics will be taken from the capture file. Otherwise the capture buffer from the -port_handle is inspected. If the port capture buffer is empty and no capture_file was specified the alarm statistic keys will have N/A values. Not available with IxNetwork/IxProtocol Tcl API.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                      value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                                         value:On status of failure, gives detailed information.
		Number of Information OAMPDUs sent by Ixia Port when negotiating with an EOAM device. Information OAMPDUs sent as streams are not counted. Subject to reset when using IxProtocol TCL API.
			 key:statistics.oampdu_count.information_tx                      value:Number of Information OAMPDUs sent by Ixia Port when negotiating with an EOAM device. Information OAMPDUs sent as streams are not counted. Subject to reset when using IxProtocol TCL API.
		Subject to reset when using IxProtocol TCL API.
			 key:statistics.oampdu_count.information_rx                      value: Subject to reset when using IxProtocol TCL API.
		Subject to reset when using IxProtocol TCL API.
			 key:statistics.oampdu_count.event_notification_rx               value: Subject to reset when using IxProtocol TCL API.
		Subject to reset when using IxProtocol TCL API.
			 key:statistics.oampdu_count.loopback_control_rx                 value: Subject to reset when using IxProtocol TCL API.
		Subject to reset when using IxProtocol TCL API.
			 key:statistics.oampdu_count.organization_rx                     value: Subject to reset when using IxProtocol TCL API.
		Subject to reset when using IxProtocol TCL API.
			 key:statistics.oampdu_count.variable_request_rx                 value: Subject to reset when using IxProtocol TCL API.
		Subject to reset when using IxProtocol TCL API.
			 key:statistics.oampdu_count.variable_response_rx                value: Subject to reset when using IxProtocol TCL API.
		Not supported with IxProtocol Tcl API
			 key:statistics.oampdu_count.unsupported_rx                      value: Not supported with IxProtocol Tcl API
		(alarm) Number of errored symbol period TLV received in capture.
			 key:statistics.alarms.errored_symbol_period_events              value:(alarm) Number of errored symbol period TLV received in capture.
		(alarm) Number of errored frame TLV received in capture.
			 key:statistics.alarms.errored_frame_events                      value:(alarm) Number of errored frame TLV received in capture.
		(alarm) Number of errored frame period TLV received in capture.
			 key:statistics.alarms.errored_frame_period_events               value:(alarm) Number of errored frame period TLV received in capture.
		(alarm) Number of errored frame seconds summary TLV received in capture.
			 key:statistics.alarms.errored_frame_seconds_summary_events      value:(alarm) Number of errored frame seconds summary TLV received in capture.
			 key:Statistics supported with IxOS Tcl API                      value:
		Not supported with IxNetwork TCL Api.
			 key:statistics.oampdu_count.total_rx                            value:Not supported with IxNetwork TCL Api.
			 key:Statistics supported with IxNetwork and IxProtocol Tcl API  value:
		0 (true) | 1 (false)
			 key:statistics.remote_critical_event                            value:0 (true) | 1 (false)
		0 (true) | 1 (false)
			 key:statistics.remote_dying_gasp                                value:0 (true) | 1 (false)
		0 (true) | 1 (false)
			 key:statistics.remote_evaluating                                value:0 (true) | 1 (false)
		0 (true) | 1 (false)
			 key:statistics.remote_link_fault                                value:0 (true) | 1 (false)
		string
			 key:statistics.remote_mux_action                                value:string
		integer
			 key:statistics.remote_oam_version                               value:integer
		string
			 key:statistics.remote_parser_action                             value:string
		integer
			 key:statistics.remote_revision                                  value:integer
		0 (true) | 1 (false)
			 key:statistics.remote_stable                                    value:0 (true) | 1 (false)
		HEX in format {00:11:22}
			 key:statistics.variable_request.branch                          value:HEX in format {00:11:22}
		0 (true) | 1 (false)
			 key:statistics.variable_request.indication                      value:0 (true) | 1 (false)
		HEX in format {00:11:22}
			 key:statistics.variable_request.leaf                            value:HEX in format {00:11:22}
		HEX in format {00:11:22}
			 key:statistics.variable_request.value                           value:HEX in format {00:11:22}
		integer
			 key:statistics.variable_request.width                           value:integer
		Port name.
			 key:statistics.port_name                                        value:Port name.
		Event Notification PDU Tx. Subject to reset when using IxProtocol TCL API.
			 key:statistics.oampdu_count.event_notification_tx               value:Event Notification PDU Tx. Subject to reset when using IxProtocol TCL API.
		Links Configured. Subject to reset when using IxProtocol TCL API.
			 key:statistics.oampdu_count.links_configured                    value:Links Configured. Subject to reset when using IxProtocol TCL API.
		Links Running. Subject to reset when using IxProtocol TCL API.
			 key:statistics.oampdu_count.links_running                       value:Links Running. Subject to reset when using IxProtocol TCL API.
		Local Discovery Status
			 key:statistics.oampdu_count.local_discovery_status              value:Local Discovery Status
		Variable Request PDU Tx. Subject to reset when using IxProtocol TCL API.
			 key:statistics.oampdu_count.variable_request_tx                 value:Variable Request PDU Tx. Subject to reset when using IxProtocol TCL API.
		Variable Response PDU Tx. Subject to reset when using IxProtocol TCL API.
			 key:statistics.oampdu_count.variable_response_tx                value:Variable Response PDU Tx. Subject to reset when using IxProtocol TCL API.
		Organization Specific PDU Tx. Subject to reset when using IxProtocol TCL API.
			 key:statistics.oampdu_count.organization_tx                     value:Organization Specific PDU Tx. Subject to reset when using IxProtocol TCL API.
		Errored Symbol Period Event Running Total Tx
			 key:statistics.alarms.errored_symbol_period_events_tx           value:Errored Symbol Period Event Running Total Tx
		Errored Symbol Period Error Running Total Tx
			 key:statistics.alarms.errored_symbol_period_errors_tx           value:Errored Symbol Period Error Running Total Tx
		Errored Symbol Period Error Running Total Rx
			 key:statistics.alarms.errored_symbol_period_errors              value:Errored Symbol Period Error Running Total Rx
		Errored Frame Event Running Total Tx
			 key:statistics.alarms.errored_frame_events_tx                   value:Errored Frame Event Running Total Tx
		Errored Frame Error Running Total Tx
			 key:statistics.alarms.errored_frame_errors_tx                   value:Errored Frame Error Running Total Tx
		Errored Frame Error Running Total Rx
			 key:statistics.alarms.errored_frame_errors                      value:Errored Frame Error Running Total Rx
		Errored Frame Period Event Running Total Tx
			 key:statistics.alarms.errored_frame_period_events_tx            value:Errored Frame Period Event Running Total Tx
		Errored Frame Period Error Running Total Tx
			 key:statistics.alarms.errored_frame_period_errors_tx            value:Errored Frame Period Error Running Total Tx
		Errored Frame Period Error Running Total Rx
			 key:statistics.alarms.errored_frame_period_errors               value:Errored Frame Period Error Running Total Rx
		Errored Frame SS Event Running Total Tx
			 key:statistics.alarms.errored_frame_seconds_summary_events_tx   value:Errored Frame SS Event Running Total Tx
		Errored Frame SS Error Running Total Tx
			 key:statistics.alarms.errored_frame_seconds_summary_errors_tx   value:Errored Frame SS Error Running Total Tx
		Errored Frame SS Error Running Total Rx
			 key:statistics.alarms.errored_frame_seconds_summary_errors      value:Errored Frame SS Error Running Total Rx
			 key:statistics.alarms.errored_frame_period_threshold            value:
			 key:statistics.alarms.errored_frame_period_window               value:
			 key:statistics.alarms.errored_frame_seconds_summary_threshold   value:
			 key:statistics.alarms.errored_frame_seconds_summary_window      value:
			 key:statistics.alarms.errored_frame_threshold                   value:
			 key:statistics.alarms.errored_frame_window                      value:
			 key:statistics.alarms.errored_symbol_period_threshold           value:
			 key:statistics.alarms.errored_symbol_period_window              value:
			 key:Statistics supported with IxNetwork Tcl API                 value:
		Unique Information PDU Tx
			 key:statistics.oampdu_count.information_tx_unique               value:Unique Information PDU Tx
		Unique Information PDU Rx
			 key:statistics.oampdu_count.information_rx_unique               value:Unique Information PDU Rx
		Unique Event Notification PDU Tx
			 key:statistics.oampdu_count.event_notification_tx_unique        value:Unique Event Notification PDU Tx
		Unique Event Notification PDU Rx
			 key:statistics.oampdu_count.event_notification_rx_unique        value:Unique Event Notification PDU Rx
		Loopback Enable Control PDU Tx
			 key:statistics.oampdu_count.loopback_control_enable_tx          value:Loopback Enable Control PDU Tx
		Loopback Disable Control PDU Tx
			 key:statistics.oampdu_count.loopback_control_disable_tx         value:Loopback Disable Control PDU Tx
		Loopback Enable Control PDU Rx
			 key:statistics.oampdu_count.loopback_control_enable_rx          value:Loopback Enable Control PDU Rx
		Loopback Disable Control PDU Rx
			 key:statistics.oampdu_count.loopback_control_disable_rx         value:Loopback Disable Control PDU Rx
		Link Fault Tx
			 key:statistics.oampdu_count.remote_link_fault_tx                value:Link Fault Tx
		Link Fault Rx
			 key:statistics.oampdu_count.remote_link_fault_rx                value:Link Fault Rx
		Dying Gasp Tx
			 key:statistics.oampdu_count.remote_dying_gasp_tx                value:Dying Gasp Tx
		Dying Gasp Rx
			 key:statistics.oampdu_count.remote_dying_gasp_rx                value:Dying Gasp Rx
		Critical Event Tx
			 key:statistics.oampdu_count.remote_critical_event_tx            value:Critical Event Tx
		Critical Event Rx
			 key:statistics.oampdu_count.remote_critical_event_rx            value:Critical Event Rx
			 key:Statistics supported only with IxProtocol Tcl API           value:
		Subject to reset when using IxProtocol TCL API.
			 key:statistics.oampdu_count.loopback_control_tx                 value: Subject to reset when using IxProtocol TCL API.
		
		Examples:
		See sample file efm_mixed_traffic_capture.tcl in Appendix A.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.The "statistics.mac_remote.oampdu_count.*"" statistic keys might not updated while EFM OAMPDU stream are sent if the rate is too high (only for IxOS TCL implementation).
		
		See Also:
		
		"""
		return self._run_keyword("emulation_efm_stat", kwargs)

	def emulation_eigrp_config(self, **kwargs):
		""" This command is used to create/modify/delete/enable/disable an EIGRP router. An EIGRP router has only one router interface. A router interface is associated with a protocol interface, that can be either a directly connected interface or a GRE interface(connected via a directly connected interface). By specifying the intf_... parameters there will be created one directly connected interface per EIGRP router. By specifying the gre_... parameters there will be created one GRE tunnel connected via the directly connected interface foreach EIGRP router.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_eigrp_config
			 	[-mac_address_init         ANY]
			 	[-mac_address_step         ANY]
			 	[-mode                     ANY]
			 	[-mtu                      ANY]
			 	[-override_existence_check ANY]
			 	[-override_tracking        ANY]
			 	[-port_handle              ANY]
			 	[-reset                    ANY]
			 	[-router_id                ANY]
			 	[-router_id_step           ANY]
			 	[-vlan                     ANY]
			 	[-vlan_id                  ANY]
			 	[-vlan_id_step             ANY]
			 	[-vlan_user_priority       ANY]
			 	[-vpi                      ANY]
			 	[-vci                      ANY]
			 	[-vpi_step                 ANY]
		
		Arguments:
			 	-mac_address_init
			 		The first MAC address of the first directly connected interface that will be configured.This option is valid only when -mode is create or -mode modify and -handle is a EIGRP router interface.
			 	-mac_address_step
			 		The incrementing step for the MAC address of the directly connected interfaces that will be configured.This option is valid only when -mode is create.-max_tlv_per_pktThe maximum number of Internal/External Route TLVs that will be included in a single Update packet, taking MTU into consideration. The valid range is 0 -255. The default is 30. A value of 0 means that maximum possible packing will be used, which depends on the MTU of the link. This is an optional argument.This option is valid only when -mode is create or -mode is modify and -handle is an EIGRP router.
			 	-mode
			 		The operation that will be executed. This option has the following dependencies:when mode is create, -port_handle is requiredwhen mode is modify/enable/disable/delete, -handle is requiredcreate - create EIGRP router(s)modify - modify EIGRP router(s)enable - enable EIGRP router(s)disable - disable EIGRP router(s)delete - disable EIGRP router(s)
			 	-mtu
			 		This parameter has no effect; it is ignored.The MTU value for the directly connected interfaces.This option is valid only when -mode is create or -mode modify and -handle is a EIGRP router interface.
			 	-override_existence_check
			 		If this option is enabled, the interface existence check is skipped but the list of interfaces is still created and maintained in order to keep track of existing interfaces if required. Using this option will speed up the interfaces' creation.
			 	-override_tracking
			 		If this option is enabled, the list of interfaces won't be created and maintained anymore, thus, speeding up the interfaces' creation even more. Also, it will enable -override_existence_check in case it wasn't already enabled because checking for interface existence becomes impossible if the the list of interfaces doesn't exist anymore.
			 	-port_handle
			 		The port where the action will take place.Mandatory when -mode is create, but otherwise ignored.-reliabilityThe reliability factor. Valid range is 0-255.This is an optional argument. This option is valid only when -mode is create or -mode is modify and -handle is provided.
			 	-reset
			 		If this flag is present all the EIGRP configuration on that specific port is erased. This option is requires -mode create and -port_handle to be provided.
			 	-router_id
			 		The router ID in IPv4 format for the EIGRP router.This option is valid only when -mode is create or -mode is modify and -handle is provided.
			 	-router_id_step
			 		The router ID step in IPv4 format for the EIGRP router.This option is valid only when -mode is create.-split_horizonIf checked/enabled, Poisoned Reverse is used to prevent routing loops. Routes will be sent with infinite metric upon learning (Split Horizon with Poisoned Reverse). The default is unchecked/disabled.This is an optional argument. This option is valid only when -mode is create or -mode is modify and -handle is an EIGRP router.
			 	-vlan
			 		Enables vlan on the directly connected EIGRP router interface. Valid options are: 0 - disable, 1 - enable.This option is valid only when -mode is create or -mode modify and -handle is a EIGRP router interface.
			 	-vlan_id
			 		Sets the vlan ID on the directly connected EIGRP router interface.This option is valid only when -mode is create or -mode modify and -handle is a EIGRP router interface.
			 	-vlan_id_step
			 		The incrementing step for vlan ID when creating directly connected protocol interfaces. This option is valid only when -mode is create.When vlan_id_step causes the vlan_id value to exceed it's maximum value the increment will be done modulo <number of possible vlan ids>.Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			 	-vlan_user_priority
			 		Sets the vlan ID user priority on the directly connected EIGRP router interfaces.This option is valid only when -mode is create or -mode modify and -handle is a EIGRP router interface.
			 	-vpi
			 		Sets the VPI value on the directly connected EIGRP router interfaces.This option is valid only when -mode is create or -mode modify and -handle is a EIGRP router interface.
			 	-vci
			 		Sets the VCI value on the directly connected EIGRP router interfaces.This option is valid only when -mode is create or -mode modify and -handle is a EIGRP router interface.
			 	-vpi_step
			 		The incrementing step for VPI when creating directly connected protocol interfaces.This option is valid only when -mode is create or -mode modify and -handle is a EIGRP router interface.When vpi_step causes the vpi value to exceed it's maximum value the increment will be done modulo <number of possible vpi ids>.Examples: vpi = 254; vpi_step = 2-> new vpi value = 0vpi = 255; vpi_step = 11 -> new vpi value = 10
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status             value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                value:On status of failure, gives detailed information.
		On mode create, list of router handles
			 key:router_handles     value:On mode create, list of router handles
		On mode create, list of all interface handles (connected and gre)
			 key:interface_handles  value:On mode create, list of all interface handles (connected and gre)
		
		Examples:
		See files starting with EIGRP_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_eigrp_config", kwargs)

	def emulation_eigrp_control(self, **kwargs):
		""" This procedure starts/stops a EIGRP configuration.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_eigrp_control
			 	[-handle      ANY]
			 	[-mode        ANY]
			 	[-port_handle ANY]
		
		Arguments:
			 	-handle
			 		The router handle or router interface handle or session handle where EIGRP emulation will be started/stopped. This action will be applied to the port where -handle was created.One of the two parameters is required: port_handle/handle.
			 	-mode
			 		The action to take on the port_handle provided: start/stop the protocol.
			 	-port_handle
			 		The port where EIGRP emulation will be started/stopped. One of the two parameters is required: port_handle/handle.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status           value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log              value:On status of failure, gives detailed information.
		On mode create, list of session handles
			 key:session_handles  value:On mode create, list of session handles
		
		Examples:
		See files starting with EIGRP_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_eigrp_control", kwargs)

	def emulation_eigrp_info(self, **kwargs):
		""" This procedure retrieves information about the EIGRP sessions.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_eigrp_info
			 	[-handle      ANY]
			 	[-mode        ANY]
			 	[-port_handle ANY]
		
		Arguments:
			 	-handle
			 		The routers from which to extract EIGRP route data. One of the two parameters is required: port_handle/handle.
			 	-mode
			 		aggregate_stats - retrieve stats aggregated per portlearned_info - retrieve learned information by the EIGRP protocolclear_stats - clear stats
			 	-port_handle
			 		The ports from which to extract EIGRP route data. One of the two parameters is required: port_handle/handle.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                      value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                                         value:On status of failure, gives detailed information.
		the IP address for the route learned
			 key:<port_handle>.<router_handle>.route.<number>.prefix         value:the IP address for the route learned
		the length of the route IP address prefix
			 key:<port_handle>.<router_handle>.route.<number>.prefix_length  value:the length of the route IP address prefix
		the type of the route: internal or external.
			 key:<port_handle>.<router_handle>.route.<number>.type           value:the type of the route: internal or external.
		the feasible distance
			 key:<port_handle>.<router_handle>.route.<number>.FD             value:the feasible distance
		the IP address of the neighbor from which the route was learned
			 key:<port_handle>.<router_handle>.route.<number>.neighbor       value:the IP address of the neighbor from which the route was learned
		the reported distance of the neighbor
			 key:<port_handle>.<router_handle>.route.<number>.RD             value:the reported distance of the neighbor
		the advertised hop count by the neighbor + 1
			 key:<port_handle>.<router_handle>.route.<number>.hop_count      value:the advertised hop count by the neighbor + 1
		the IP address of the Next Hop, as advertised by the neighbor
			 key:<port_handle>.<router_handle>.route.<number>.next_hop       value:the IP address of the Next Hop, as advertised by the neighbor
			 key:<port_handle>.aggregate.port_name                           value:
			 key:<port_handle>.aggregate.ipv4_routers_configured             value:
			 key:<port_handle>.aggregate.ipv4_routers_running                value:
			 key:<port_handle>.aggregate.ipv6_routers_configured             value:
			 key:<port_handle>.aggregate.ipv6_routers_running                value:
			 key:<port_handle>.aggregate.ipv4_neighbors_learned              value:
			 key:<port_handle>.aggregate.ipv4_neighbors_deleted              value:
			 key:<port_handle>.aggregate.ipv6_neighbors_learned              value:
			 key:<port_handle>.aggregate.ipv6_neighbors_deleted              value:
			 key:<port_handle>.aggregate.ipv4_routes_advertised_tx           value:
			 key:<port_handle>.aggregate.ipv4_routes_advertised_rx           value:
			 key:<port_handle>.aggregate.ipv4_routes_withdrawn_tx            value:
			 key:<port_handle>.aggregate.ipv4_routes_withdraws_rx            value:
			 key:<port_handle>.aggregate.ipv6_routes_advertised_tx           value:
			 key:<port_handle>.aggregate.ipv6_routes_advertised_rx           value:
			 key:<port_handle>.aggregate.ipv6_routes_withdrawn_tx            value:
			 key:<port_handle>.aggregate.ipv6_routes_withdraws_rx            value:
			 key:<port_handle>.aggregate.ipv4_routes_learned                 value:
			 key:<port_handle>.aggregate.ipv6_routes_learned                 value:
			 key:<port_handle>.aggregate.hellos_tx                           value:
			 key:<port_handle>.aggregate.hellos_rx                           value:
			 key:<port_handle>.aggregate.updates_tx                          value:
			 key:<port_handle>.aggregate.updates_rx                          value:
			 key:<port_handle>.aggregate.queries_tx                          value:
			 key:<port_handle>.aggregate.queries_rx                          value:
			 key:<port_handle>.aggregate.replies_tx                          value:
			 key:<port_handle>.aggregate.replies_rx                          value:
			 key:<port_handle>.aggregate.acks_tx                             value:
			 key:<port_handle>.aggregate.acks_rx                             value:
			 key:<port_handle>.aggregate.pkts_tx                             value:
			 key:<port_handle>.aggregate.pkts_rx                             value:
			 key:<port_handle>.aggregate.retransmission_count                value:
		
		Examples:
		See files starting with EIGRP_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_eigrp_info", kwargs)

	def emulation_eigrp_route_config(self, **kwargs):
		""" This command is used to create/modify/delete/enable/disable a EIGRP session on a EIGRP router interface previously created with ::<namespace>::emulation_eigrp_config. One EIGRP session can be added to all router interfaces or just to a specific router interface.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_eigrp_route_config
			 	[-bandwidth             ANY]
			 	[-count                 ANY]
			 	[-delay                 ANY]
			 	[-dst_count             ANY]
			 	[-enable_packing        ANY]
			 	[-ext_flag              ANY]
			 	[-ext_metric            ANY]
			 	[-ext_originating_as    ANY]
			 	[-ext_protocol          ANY]
			 	[-ext_route_tag         ANY]
			 	[-ext_source            ANY]
			 	[-handle                ANY]
			 	[-hop_count             ANY]
			 	[-load                  ANY]
			 	[-mode                  ANY]
			 	[-mtu                   ANY]
			 	[-next_hop              ANY]
			 	[-next_hop_inside_step  ANY]
			 	[-next_hop_outside_step ANY]
			 	[-num_prefixes          ANY]
			 	[-prefix_length         ANY]
			 	[-prefix_start          ANY]
			 	[-prefix_inside_step    ANY]
			 	[-prefix_outside_step   ANY]
			 	[-reliability           ANY]
			 	[-reset                 ANY]
			 	[-route_handle          ANY]
		
		Arguments:
			 	-bandwidth
			 		(in kbps) The minimum amount of bandwidth available on this link. The valid range is 10000-4294967295.This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-count
			 		The number of route ranges to create for an EIGRP router. The valid range is 1-1-16777215.This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-delay
			 		(in 10s of Microseconds) The total of delays on the path to the route/network. The valid range is 0-4294967295.This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-dst_count
			 		Available for use only if enable_packing is enabled. The maximum number of destinations to be packed into a single Internal/External TLV. The valid range is 0-255. The default is 90. A value of 0 means that maximum possible packing will be used, which depends on the MTU of the link.This is an optional argument. If enable_packing is disabled this value is ignored. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-enable_packing
			 		If 1/enabled, Packing is enabled. Multiple destinations will be packed into a single Internal/External TLV. If 0/disabled, only one destination will be packed into a single Internal/External TLV. This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-ext_flag
			 		Available only for external route ranges (-type external). This parameter represents the origin of the advertised route. This is an optional argument.If -type is internal, this parameter is ignored. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 		Valid choices are:
			    		external_route - the route was originated outside the EIGRP domain.
			    		candidate_default - a route that could also serve as a default route.
			 	-ext_metric
			 		Available only for external route ranges (-type external). This parameter represents the EIGRP vector metric for the cost of the path to this route/network. The valid range is 1-4294967295.This is an optional argument. If -type is internal, this parameter is ignored. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-ext_originating_as
			 		Available only for external route ranges (-type external). This parameter represents the external AS where this route was originated. The valid range is 1-4294967295.This is an optional argument. If -type is internal, this parameter is ignored. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-ext_protocol
			 		Available only for external route ranges (-type external). This parameter represents the external protocol where the route was originated, if applicable.This is an optional argument. If -type is internal, this parameter is ignored. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 		Valid choices are:
			    		igrp - Interior Gateway Routing Protocol (the default)
			    		eigrp - Enhanced Interior Gateway Routing Protocol
			    		static - routes are statically-configured; no routing protocol is being used.
			    		rip - Routing Information Protocol
			    		hello - Hello message protocol
			    		ospf - Open Shortest Path First
			    		isis - Intermediate System to Intermediate System
			    		egp - Exterior Gateway Protocol
			    		bgp - Border Gateway Protocol
			    		idrp - Inter-Domain Routing Protocol
			    		connected - direct connection.
			 	-ext_route_tag
			 		An administrative tag applied to the route when it is redistributed between EIGRP and an external protocol, to prevent routing loops. Used as a route mapping filter. The valid range is 0-4294967295. This is an optional argument. If -type is internal, this parameter is ignored. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-ext_source
			 		The IP address for the external source of the route information, in dotted decimal format.This is an optional argument. If -type is internal, this parameter is ignored. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-handle
			 		This is the router handle that needs to be provided when creating an EIGRP route.This is an optional argument. This is mandatory when -mode create.
			 	-hop_count
			 		The number of hops on the way to the destination address. The valid range is 0-255.This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-load
			 		The amount of load on the link. The valid range is 0-255.This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-mode
			 		The action that will be taken for a specified handle or route_handle. This is an optional argument.Parameter -handle is mandatory for -mode create and parameter route_handle is mandatory for -mode modify/enable/disable/delete.provided as an EIGRP router handle. The router handle is obtained from the returned values of a previous call to emulation_eigrp_config.modify/enable/disable/delete - Performs the specified operation for a EIGRP route identified by -route_handle parameter.
			 		Valid choices are:
			    		create - Creates EIGRP route(s). Parameter -handle needs to be
			 	-mtu
			 		(in bytes) The Maximum Transmission Unit allowed on this link. The valid range is 0-16777215.This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-next_hop
			 		The immediate next hop IP address on the way to the destination address, in IP dotted decimal format.This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.(DEFAULT = 0.0.0.0 | 0::0).
			 	-next_hop_inside_step
			 		The immediate next hop IP address step.This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router.(DEFAULT = 0.0.0.0 | 0::0).
			 	-next_hop_outside_step
			 		The immediate next hop IP address step.This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router.(DEFAULT = 0.0.0.0 | 0::0).
			 	-num_prefixes
			 		The number of networks/route ranges to be generated for this route range, based on the network address(prefix_start) plus the network mask(prefix_length). The valid range is 1-16777215.This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-prefix_length
			 		The network mask to be used with the -prefix_start address. The valid range is 0-32. This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.(DEFAULT = 24 | 64).
			 	-prefix_start
			 		The first IP network/destination address to be used in creating this route range, in IP dotted decimal format.Mandatory when -mode create.This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-prefix_inside_step
			 		The step for the first IP network/destination address to be used in creating a set of route ranges for a router. The format is IP dotted decimal format.This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router.(DEFAULT = 0.1.0.0 | 0:0:0:1::0).
			 	-prefix_outside_step
			 		The step for the first IP network/destination address to be used in creating a set of route ranges for multiple routers. Valid only if -handle is provide with a list of router handles. The format is IP dotted decimal format.This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router.(DEFAULT = 1.0.0.0 | 0:0:1:0::0).
			 	-reliability
			 		The reliability factor. The valid range is 0-255.This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router or when -mode modify and -route_handle is provided as an EIGRP route.
			 	-reset
			 		This a flag, and if present, all route ranges for a specific EIGRP router(specified by -handle) will be erased.This is an optional argument. This option is valid only when -mode is create and -handle is provided as an EIGRP router.(DEFAULT = None.
			 	-route_handle
			 		This is the EIGRP route handle that needs to be provided when modifying/enabling/disabling/deleting a EIGRP route. A list of route handles can be provided.This mandatory when -mode modify/enable/disable/delete, otherwise is optional.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status           value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log              value:On status of failure, gives detailed information.
		On mode create, list of session handles
			 key:session_handles  value:On mode create, list of session handles
		
		Examples:
		See files starting with EIGRP_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_eigrp_route_config", kwargs)

	def emulation_elmi_control(self, **kwargs):
		""" This procedure will start, stop or restart the elmi protocol on the ports.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_elmi_control
			x	[-mode        ANY]
			x	[-port_handle ANY]
			x	[-handle      ANY]
		
		Arguments:
			x	-mode
			x		Action to be performed on the port_handles or the handles supplied.
			x		Valid choices are:
			x   		start - starts the protocol
			x   		stop - stops the protocol
			x   		restart - restarts the protocol
			x	-port_handle
			x		The port handle of the port on which the action specified by the -mode argument has to be performed.
			x	-handle
			x		The ELMI handle on which the action specified by the -mode argument has to be performed.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log     value:On status of failure, gives detailed information.
		
		Examples:
		See files starting with ELMI_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_elmi_control", kwargs)

	def emulation_elmi_info(self, **kwargs):
		""" This procedure retrieves information about the ELMI protocol.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_elmi_info
			x	[-mode        ANY]
			x	[-port_handle ANY]
			x	[-handle      ANY]
		
		Arguments:
			x	-mode
			x		Action to be performed on the ports or the handles supplied. Following choices are supported.
			x		Valid choices are:
			x   		aggregate - returns per port aggregated stats
			x   		evc_status_learned_info - returns evc status learned info
			x   		uni_status_learned_info - returns uni status learned info
			x   		lmi_status_learned_info - returns lmi status learned info
			x   		uni_learned_info - returns all status learned info
			x	-port_handle
			x		The port handle of the port on which the action specified by the -mode argument has to be performed.
			x	-handle
			x		The ELMI handle on which the action specified by the -mode argument has to be performed.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                                         value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                                                            value:On status of failure, gives detailed information.
		The port_handle received as a paramater or the port_handle of the handle received as a parameter
			 key:<port_handle>                                                                  value:The port_handle received as a paramater or the port_handle of the handle received as a parameter
		The uni_handle received as a paramater for the handle or the uni handle of the port_handle received as a paramater
			 key:<uni_handle>                                                                   value:The uni_handle received as a paramater for the handle or the uni handle of the port_handle received as a paramater
		evc status learned info handle created on the handle received as a paramater or the evc status learned info handle of the port_handle received as a paramater
			 key:<evc_status_learned_info>                                                      value:evc status learned info handle created on the handle received as a paramater or the evc status learned info handle of the port_handle received as a paramater
		uni status learned info handle created on the handle received as a paramater or the uni status learned info handle of the port_handle received as a paramater
			 key:<uni_status_learned_info>                                                      value:uni status learned info handle created on the handle received as a paramater or the uni status learned info handle of the port_handle received as a paramater
		lmi status learned info handle created on the handle received as a paramater or the lmi status learned info handle of the port_handle received as a paramater
			 key:<lmi_status_learned_info>                                                      value:lmi status learned info handle created on the handle received as a paramater or the lmi status learned info handle of the port_handle received as a paramater
		The ELMI Aggregated Statistics generated for each port
			 key:aggregate                                                                      value:The ELMI Aggregated Statistics generated for each port
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.cbs_multiplier            value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.cbs_magnitude             value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.cf                        value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.cir_multiplier            value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.cir_magnitude             value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.cm                        value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.default_evc               value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.ebs_multiplier            value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.ebs_magnitude             value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.eir_multiplier            value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.eir_magnitude             value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.evc_id_length             value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.evc_id                    value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.evc_type                  value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.per_cos                   value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.reference_id              value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.status_type               value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.un_tagged_priority_tag    value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.user_priority_bits_000    value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.user_priority_bits_001    value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.user_priority_bits_010    value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.user_priority_bits_011    value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.user_priority_bits_100    value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.user_priority_bits_101    value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.user_priority_bits_110    value:
			 key:<port_handle>.<uni_handle>.<evc_status_learned_info>.user_priority_bits_111    value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.cbs_multiplier            value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.cbs_magnitude             value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.cf                        value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.cir_multiplier            value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.cir_magnitude             value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.cm                        value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.ebs_multiplier            value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.ebs_magnitude             value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.eir_multiplier            value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.eir_magnitude             value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.evc_map_type              value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.per_cos                   value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.uni_id_length             value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.uni_id                    value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.user_priority_bits_000    value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.user_priority_bits_001    value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.user_priority_bits_010    value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.user_priority_bits_011    value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.user_priority_bits_100    value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.user_priority_bits_101    value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.user_priority_bits_110    value:
			 key:<port_handle>.<uni_handle>.<uni_status_learned_info>.user_priority_bits_111    value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.data_instance             value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.duplicated_ie             value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.invalid_evc_reference_id  value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.invalid_mandatory_ie      value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.invalid_msg_type          value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.invalid_non_mandatory_ie  value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.invalid_protocol_version  value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.duplicated_ie             value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.lmi_status                value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.mandatory_ie_missing      value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.duplicated_ie             value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.out_of_sequence_ie        value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.protocol_version          value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.receive_sequence_number   value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.send_sequence_number      value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.short_msg_counter         value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.unexpected_ie             value:
			 key:<port_handle>.<uni_handle>.<lmi_status_learned_info>.uncrecognized_ie          value:
			 key:<port_handle>.aggregate.invalid_message_type_rx                                value:
			 key:<port_handle>.aggregate.ce_vlan_id_evc_map_rx                                  value:
			 key:<port_handle>.aggregate.check_rx                                               value:
			 key:<port_handle>.aggregate.mandatory_ie_missing_rx                                value:
			 key:<port_handle>.aggregate.ce_vlan_id_evc_map_tx                                  value:
			 key:<port_handle>.aggregate.uni_status_rx                                          value:
			 key:<port_handle>.aggregate.check_tx                                               value:
			 key:<port_handle>.aggregate.evc_status_rx                                          value:
			 key:<port_handle>.aggregate.uni_status_tx                                          value:
			 key:<port_handle>.aggregate.unexpected_ie_rx                                       value:
			 key:<port_handle>.aggregate.unrecognized_ie_rx                                     value:
			 key:<port_handle>.aggregate.full_status_enquiry_rx                                 value:
			 key:<port_handle>.aggregate.port_name                                              value:
			 key:<port_handle>.aggregate.evc_status_tx                                          value:
			 key:<port_handle>.aggregate.session_flap                                           value:
			 key:<port_handle>.aggregate.full_status_continued_enquiry_rx                       value:
			 key:<port_handle>.aggregate.duplicated_ie_rx                                       value:
			 key:<port_handle>.aggregate.full_status_enquiry_tx                                 value:
			 key:<port_handle>.aggregate.uni_n_running                                          value:
			 key:<port_handle>.aggregate.full_status_rx                                         value:
			 key:<port_handle>.aggregate.full_status_continued_enquiry_tx                       value:
			 key:<port_handle>.aggregate.unsolicited_status_rx                                  value:
			 key:<port_handle>.aggregate.session_operational                                    value:
			 key:<port_handle>.aggregate.uni_c_configured                                       value:
			 key:<port_handle>.aggregate.full_status_continued_rx                               value:
			 key:<port_handle>.aggregate.single_evc_asynchronous_status_rx                      value:
			 key:<port_handle>.aggregate.full_status_tx                                         value:
			 key:<port_handle>.aggregate.full_status_continued_tx                               value:
			 key:<port_handle>.aggregate.single_evc_asynchronous_status_tx                      value:
			 key:<port_handle>.aggregate.remote_protocol_version                                value:
			 key:<port_handle>.aggregate.uni_n_configured                                       value:
			 key:<port_handle>.aggregate.uni_c_running                                          value:
			 key:<port_handle>.aggregate.invalid_status_rx                                      value:
			 key:<port_handle>.aggregate.out_of_sequence_ie_rx                                  value:
			 key:<port_handle>.aggregate.invalid_mandatory_ie_rx                                value:
			 key:<port_handle>.aggregate.short_message_rx                                       value:
		
		Examples:
		See files starting with ELMI_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) This protocol is available only when using IxNetwork Tcl API.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_elmi_info", kwargs)

	def emulation_ftp_config(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_ftp_config
			 	[-handle                         ANY]
			 	[-target                         ANY]
			 	[-property                       ANY]
			 	-mode                            ANY
			 	[-port_handle                    ANY]
			 	[-mac_mapping_mode               ANY]
			 	[-source_port_from               ANY]
			 	[-source_port_to                 ANY]
			 	[-emulated_router_gateway        ANY]
			 	[-emulated_router_subnet         ANY]
			 	[-dns_cache_timeout              ANY]
			 	[-grat_arp_enable                ANY]
			 	[-congestion_notification_enable ANY]
			 	[-time_stamp_enable              ANY]
			 	[-rx_bandwidth_limit_enable      ANY]
			 	[-tx_bandwidth_limit_enable      ANY]
			 	[-fin_timeout                    ANY]
			 	[-keep_alive_interval            ANY]
			 	[-keep_alive_probes              ANY]
			 	[-keep_alive_time                ANY]
			 	[-receive_buffer_size            ANY]
			 	[-retransmit_retries             ANY]
			 	[-rx_bandwidth_limit             ANY]
			 	[-rx_bandwidth_limit_unit        ANY]
			 	[-syn_ack_retries                ANY]
			 	[-syn_retries                    ANY]
			 	[-transmit_buffer_size           ANY]
			 	[-tx_bandwidth_limit             ANY]
			 	[-tx_bandwidth_limit_unit        ANY]
			 	[-ip_address_start               ANY]
			 	[-mac_address_start              ANY]
			 	[-gateway                        ANY]
			 	[-ip_count                       ANY]
			 	[-ip_increment_step              ANY]
			 	[-mac_increment_step             ANY]
			 	[-mss                            ANY]
			 	[-mss_enable                     ANY]
			 	[-network_mask                   ANY]
			 	[-vlan_enable                    ANY]
			 	[-vlan_id                        ANY]
			 	[-dns_server                     ANY]
			 	[-dns_suffix                     ANY]
			 	[-pool_ip_address_start          ANY]
			 	[-pool_ip_count                  ANY]
			 	[-pool_mac_address_start         ANY]
			 	[-pool_network                   ANY]
			 	[-pool_vlan_enable               ANY]
		
		Arguments:
			 	-handle
			 	-target
			    	-property
			        	-mode
			            	-port_handle
			                	-mac_mapping_mode
			                    	-source_port_from
			                        	-source_port_to
			                            	-emulated_router_gateway
			                                	-emulated_router_subnet
			                                    	-dns_cache_timeout
			                                        	-grat_arp_enable
			                                            	-congestion_notification_enable
			                                                	-time_stamp_enable
			                                                    	-rx_bandwidth_limit_enable
			                                                        	-tx_bandwidth_limit_enable
			                                                            	-fin_timeout
			                                                                	-keep_alive_interval
			                                                                    	-keep_alive_probes
			                                                                        	-keep_alive_time
			                                                                            	-receive_buffer_size
			                                                                                	-retransmit_retries
			                                                                                    	-rx_bandwidth_limit
			                                                                                        	-rx_bandwidth_limit_unit
			                                                                                            	-syn_ack_retries
			                                                                                                	-syn_retries
			                                                                                                    	-transmit_buffer_size
			                                                                                                        	-tx_bandwidth_limit
			                                                                                                            	-tx_bandwidth_limit_unit
			                                                                                                                	-ip_address_start
			                                                                                                                    	-mac_address_start
			                                                                                                                        	-gateway
			                                                                                                                            	-ip_count
			                                                                                                                                	-ip_increment_step
			                                                                                                                                    	-mac_increment_step
			                                                                                                                                        	-mss
			                                                                                                                                            	-mss_enable
			                                                                                                                                                	-network_mask
			                                                                                                                                                    	-vlan_enable
			                                                                                                                                                        	-vlan_id
			                                                                                                                                                            	-dns_server
			                                                                                                                                                                	-dns_suffix
			                                                                                                                                                                    	-pool_ip_address_start
			                                                                                                                                                                        	-pool_ip_count
			                                                                                                                                                                            	-pool_mac_address_start
			                                                                                                                                                                                	-pool_network
			                                                                                                                                                                                    	-pool_vlan_enable
		                                                                                                                                                                                   
		                                                                                                                                                                                   Return Values:
		                                                                                                                                                                                       $::SUCCESS | $::FAILURE
			                                                                                                                                                                                        key:status   value:$::SUCCESS | $::FAILURE
		                                                                                                                                                                                       When status is $::FAILURE, contains more information
			                                                                                                                                                                                        key:log      value:When status is $::FAILURE, contains more information
		                                                                                                                                                                                       the handles of a FTP configuration, network,
			                                                                                                                                                                                        key:handles  value:the handles of a FTP configuration, network,
		                                                                                                                                                                                   
		                                                                                                                                                                                   Examples:
		                                                                                                                                                                                       See files starting with ftp_ in the Samples subdirectory.
		                                                                                                                                                                                   
		                                                                                                                                                                                   Sample Input:
		                                                                                                                                                                                   
		                                                                                                                                                                                   Sample Output:
		                                                                                                                                                                                   
		                                                                                                                                                                                   Notes:
		                                                                                                                                                                                       Coded versus functional specification.
		                                                                                                                                                                                   
		                                                                                                                                                                                   See Also:
		                                                                                                                                                                                   
		"""
		return self._run_keyword("emulation_ftp_config", kwargs)

	def emulation_ftp_control(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_ftp_control
			 	-mode                            ANY
			 	[-handle                         ANY]
			 	[-map_handle                     ANY]
			 	[-force_ownership_enable         ANY]
			 	[-release_config_afterrun_enable ANY]
			 	[-reset_ports_enable             ANY]
			 	[-results_dir_enable             ANY]
			 	[-results_dir                    ANY]
		
		Arguments:
			 	-mode
			 	-handle
			    	-map_handle
			        	-force_ownership_enable
			            	-release_config_afterrun_enable
			                	-reset_ports_enable
			                    	-results_dir_enable
			                        	-results_dir
		                       
		                       Return Values:
		                           $::SUCCESS | $::FAILURE
			                            key:status   value:$::SUCCESS | $::FAILURE
		                           When status is $::FAILURE, contains more information
			                            key:log      value:When status is $::FAILURE, contains more information
		                           the handles of a FTP traffic configuration,list of traffic, agent.
			                            key:handles  value:the handles of a FTP traffic configuration,list of traffic, agent.
		                       
		                       Examples:
		                           See files starting with ftp_ in the Samples subdirectory. Also see the FTP section of Appendix A, "Examples."
		                       
		                       Sample Input:
		                       
		                       Sample Output:
		                       
		                       Notes:
		                           Coded versus functional specification.
		                       
		                       See Also:
		                       
		"""
		return self._run_keyword("emulation_ftp_control", kwargs)

	def emulation_ftp_control_config(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_ftp_control_config
			 	[-handle                      ANY]
			 	[-target                      ANY]
			 	[-property                    ANY]
			 	-mode                         ANY
			 	[-direct_server_return_enable ANY]
			 	[-ip_address                  ANY]
			 	[-server_ftp_handle           ANY]
			 	[-type                        ANY]
			 	[-client_iterations           ANY]
			 	[-client_ftp_handle           ANY]
			 	[-client_traffic_handle       ANY]
			 	[-objective_type              ANY]
			 	[-objective_value             ANY]
			 	[-client_offline_time         ANY]
			 	[-port_map_policy             ANY]
			 	[-ramp_down_time              ANY]
			 	[-ramp_up_type                ANY]
			 	[-ramp_up_value               ANY]
			 	[-client_standby_time         ANY]
			 	[-client_sustain_time         ANY]
			 	[-client_total_time           ANY]
			 	[-server_traffic_handle       ANY]
			 	[-match_client_totaltime      ANY]
			 	[-server_iterations           ANY]
			 	[-server_offline_time         ANY]
			 	[-server_standby_time         ANY]
			 	[-server_sustain_time         ANY]
		
		Arguments:
			 	-handle
			 	-target
			    	-property
			        	-mode
			            	-direct_server_return_enable
			                	-ip_address
			                    	-server_ftp_handle
			                        	-type
			                            	-client_iterations
			                                	-client_ftp_handle
			                                    	-client_traffic_handle
			                                        	-objective_type
			                                            	-objective_value
			                                                	-client_offline_time
			                                                    	-port_map_policy
			                                                        	-ramp_down_time
			                                                            	-ramp_up_type
			                                                                	-ramp_up_value
			                                                                    	-client_standby_time
			                                                                        	-client_sustain_time
			                                                                            	-client_total_time
			                                                                                	-server_traffic_handle
			                                                                                    	-match_client_totaltime
			                                                                                        	-server_iterations
			                                                                                            	-server_offline_time
			                                                                                                	-server_standby_time
			                                                                                                    	-server_sustain_time
		                                                                                                   
		                                                                                                   Return Values:
		                                                                                                       $::SUCCESS | $::FAILURE
			                                                                                                        key:status   value:$::SUCCESS | $::FAILURE
		                                                                                                       When status is $::FAILURE, contains more information
			                                                                                                        key:log      value:When status is $::FAILURE, contains more information
		                                                                                                       the handles of a FTP traffic configuration,
			                                                                                                        key:handles  value:the handles of a FTP traffic configuration,
		                                                                                                   
		                                                                                                   Examples:
		                                                                                                       See files starting with ftp_ in the Samples subdirectory.
		                                                                                                   
		                                                                                                   Sample Input:
		                                                                                                   
		                                                                                                   Sample Output:
		                                                                                                   
		                                                                                                   Notes:
		                                                                                                       Coded versus functional specification.
		                                                                                                   
		                                                                                                   See Also:
		                                                                                                   
		"""
		return self._run_keyword("emulation_ftp_control_config", kwargs)

	def emulation_ftp_stats(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_ftp_stats
			 	[-handle           ANY]
			 	-mode              ANY
			 	[-aggregation_type ANY]
			 	[-stat_name        ANY]
			 	[-stat_type        ANY]
			 	[-filter_type      ANY]
		
		Arguments:
			 	-handle
			 	-mode
			    	-aggregation_type
			        	-stat_name
			            	-stat_type
			                	-filter_type
		               
		               Return Values:
		                   $::SUCCESS | $::FAILURE
			                    key:status   value:$::SUCCESS | $::FAILURE
		                   When status is $::FAILURE, contains more information
			                    key:log      value:When status is $::FAILURE, contains more information
		                   the handles of a FTP stats configuration.
			                    key:handles  value:the handles of a FTP stats configuration.
		               
		               Examples:
		                   See files starting with ftp_ in the Samples subdirectory. Also see the FTP example in Appendix A, "Example APIs."
		               
		               Sample Input:
		               
		               Sample Output:
		               
		               Notes:
		                   Coded versus functional specification.
		               
		               See Also:
		               
		"""
		return self._run_keyword("emulation_ftp_stats", kwargs)

	def emulation_ftp_traffic_config(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_ftp_traffic_config
			 	[-handle        ANY]
			 	[-target        ANY]
			 	[-property      ANY]
			 	-mode           ANY
			 	[-esm_enable    ANY]
			 	[-esm           ANY]
			 	[-ftp_mode      ANY]
			 	[-ftp_port      ANY]
			 	[-arguments     ANY]
			 	[-command       ANY]
			 	[-destination   ANY]
			 	[-user_name     ANY]
			 	[-password      ANY]
			 	[-agent_handler ANY]
		
		Arguments:
			 	-handle
			 	-target
			    	-property
			        	-mode
			            	-esm_enable
			                	-esm
			                    	-ftp_mode
			                        	-ftp_port
			                            	-arguments
			                                	-command
			                                    	-destination
			                                        	-user_name
			                                            	-password
			                                                	-agent_handler
		                                               
		                                               Return Values:
		                                                   $::SUCCESS | $::FAILURE
			                                                    key:status   value:$::SUCCESS | $::FAILURE
		                                                   When status is $::FAILURE, contains more information
			                                                    key:log      value:When status is $::FAILURE, contains more information
		                                                   the handles of a FTP traffic configuration, list of traffic, agent.
			                                                    key:handles  value:the handles of a FTP traffic configuration, list of traffic, agent.
		                                               
		                                               Examples:
		                                                   See files starting with ftp_ in the Samples subdirectory. Also see the FTP example in Appendix A, "Examples."
		                                               
		                                               Sample Input:
		                                               
		                                               Sample Output:
		                                               
		                                               Notes:
		                                                   Coded versus functional specification.
		                                               
		                                               See Also:
		                                               
		"""
		return self._run_keyword("emulation_ftp_traffic_config", kwargs)

	def emulation_http_config(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_http_config
			 	[-handle                         ANY]
			 	[-target                         ANY]
			 	[-property                       ANY]
			 	-mode                            ANY
			 	[-port_handle                    ANY]
			 	[-mac_mapping_mode               ANY]
			 	[-source_port_from               ANY]
			 	[-source_port_to                 ANY]
			 	[-emulated_router_gateway        ANY]
			 	[-emulated_router_subnet         ANY]
			 	[-dns_cache_timeout              ANY]
			 	[-grat_arp_enable                ANY]
			 	[-congestion_notification_enable ANY]
			 	[-time_stamp_enable              ANY]
			 	[-rx_bandwidth_limit_enable      ANY]
			 	[-tx_bandwidth_limit_enable      ANY]
			 	[-fin_timeout                    ANY]
			 	[-keep_alive_interval            ANY]
			 	[-keep_alive_probes              ANY]
			 	[-keep_alive_time                ANY]
			 	[-receive_buffer_size            ANY]
			 	[-retransmit_retries             ANY]
			 	[-rx_bandwidth_limit             ANY]
			 	[-rx_bandwidth_limit_unit        ANY]
			 	[-syn_ack_retries                ANY]
			 	[-syn_retries                    ANY]
			 	[-transmit_buffer_size           ANY]
			 	[-tx_bandwidth_limit             ANY]
			 	[-tx_bandwidth_limit_unit        ANY]
			 	[-ip_address_start               ANY]
			 	[-mac_address_start              ANY]
			 	[-gateway                        ANY]
			 	[-ip_count                       ANY]
			 	[-ip_increment_step              ANY]
			 	[-mac_increment_step             ANY]
			 	[-mss                            ANY]
			 	[-mss_enable                     ANY]
			 	[-network_mask                   ANY]
			 	[-vlan_enable                    ANY]
			 	[-vlan_id                        ANY]
			 	[-dns_server                     ANY]
			 	[-dns_suffix                     ANY]
			 	[-pool_ip_address_start          ANY]
			 	[-pool_ip_count                  ANY]
			 	[-pool_mac_address_start         ANY]
			 	[-pool_network                   ANY]
			 	[-pool_vlan_enable               ANY]
		
		Arguments:
			 	-handle
			 	-target
			    	-property
			        	-mode
			            	-port_handle
			                	-mac_mapping_mode
			                    	-source_port_from
			                        	-source_port_to
			                            	-emulated_router_gateway
			                                	-emulated_router_subnet
			                                    	-dns_cache_timeout
			                                        	-grat_arp_enable
			                                            	-congestion_notification_enable
			                                                	-time_stamp_enable
			                                                    	-rx_bandwidth_limit_enable
			                                                        	-tx_bandwidth_limit_enable
			                                                            	-fin_timeout
			                                                                	-keep_alive_interval
			                                                                    	-keep_alive_probes
			                                                                        	-keep_alive_time
			                                                                            	-receive_buffer_size
			                                                                                	-retransmit_retries
			                                                                                    	-rx_bandwidth_limit
			                                                                                        	-rx_bandwidth_limit_unit
			                                                                                            	-syn_ack_retries
			                                                                                                	-syn_retries
			                                                                                                    	-transmit_buffer_size
			                                                                                                        	-tx_bandwidth_limit
			                                                                                                            	-tx_bandwidth_limit_unit
			                                                                                                                	-ip_address_start
			                                                                                                                    	-mac_address_start
			                                                                                                                        	-gateway
			                                                                                                                            	-ip_count
			                                                                                                                                	-ip_increment_step
			                                                                                                                                    	-mac_increment_step
			                                                                                                                                        	-mss
			                                                                                                                                            	-mss_enable
			                                                                                                                                                	-network_mask
			                                                                                                                                                    	-vlan_enable
			                                                                                                                                                        	-vlan_id
			                                                                                                                                                            	-dns_server
			                                                                                                                                                                	-dns_suffix
			                                                                                                                                                                    	-pool_ip_address_start
			                                                                                                                                                                        	-pool_ip_count
			                                                                                                                                                                            	-pool_mac_address_start
			                                                                                                                                                                                	-pool_network
			                                                                                                                                                                                    	-pool_vlan_enable
		                                                                                                                                                                                   
		                                                                                                                                                                                   Return Values:
		                                                                                                                                                                                       $::SUCCESS | $::FAILURE
			                                                                                                                                                                                        key:status   value:$::SUCCESS | $::FAILURE
		                                                                                                                                                                                       When status is $::FAILURE, contains more information
			                                                                                                                                                                                        key:log      value:When status is $::FAILURE, contains more information
		                                                                                                                                                                                       the handles of a HTTP configuration, network, router, pool, dns server
			                                                                                                                                                                                        key:handles  value:the handles of a HTTP configuration, network, router, pool, dns server
		                                                                                                                                                                                   
		                                                                                                                                                                                   Examples:
		                                                                                                                                                                                       See files starting with http_ in the Samples subdirectory. Also see the HTTP section of Appendix A, "Example APIs," for a specific example.
		                                                                                                                                                                                   
		                                                                                                                                                                                   Sample Input:
		                                                                                                                                                                                   
		                                                                                                                                                                                   Sample Output:
		                                                                                                                                                                                   
		                                                                                                                                                                                   Notes:
		                                                                                                                                                                                       Coded versus functional specification.
		                                                                                                                                                                                   
		                                                                                                                                                                                   See Also:
		                                                                                                                                                                                   
		"""
		return self._run_keyword("emulation_http_config", kwargs)

	def emulation_http_control(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_http_control
			 	-mode                            ANY
			 	[-handle                         ANY]
			 	[-map_handle                     ANY]
			 	[-force_ownership_enable         ANY]
			 	[-release_config_afterrun_enable ANY]
			 	[-reset_ports_enable             ANY]
			 	[-results_dir_enable             ANY]
			 	[-results_dir                    ANY]
		
		Arguments:
			 	-mode
			 	-handle
			    	-map_handle
			        	-force_ownership_enable
			            	-release_config_afterrun_enable
			                	-reset_ports_enable
			                    	-results_dir_enable
			                        	-results_dir
		                       
		                       Return Values:
		                           $::SUCCESS | $::FAILURE
			                            key:status   value:$::SUCCESS | $::FAILURE
		                           When status is $::FAILURE, contains more information
			                            key:log      value:When status is $::FAILURE, contains more information
		                           the handles of a HTTP traffic configuration, list of traffic, agent.
			                            key:handles  value:the handles of a HTTP traffic configuration, list of traffic, agent.
		                       
		                       Examples:
		                           See files starting with http_ in the Samples subdirectory. Also see the HTTP example in Appendix A, "Example APIs."
		                       
		                       Sample Input:
		                       
		                       Sample Output:
		                       
		                       Notes:
		                           Coded versus functional specification.
		                       
		                       See Also:
		                       
		"""
		return self._run_keyword("emulation_http_control", kwargs)

	def emulation_http_control_config(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_http_control_config
			 	[-handle                      ANY]
			 	[-target                      ANY]
			 	[-property                    ANY]
			 	-mode                         ANY
			 	[-direct_server_return_enable ANY]
			 	[-ip_address                  ANY]
			 	[-server_http_handle          ANY]
			 	[-type                        ANY]
			 	[-client_iterations           ANY]
			 	[-client_http_handle          ANY]
			 	[-client_traffic_handle       ANY]
			 	[-objective_type              ANY]
			 	[-objective_value             ANY]
			 	[-client_offline_time         ANY]
			 	[-port_map_policy             ANY]
			 	[-ramp_down_time              ANY]
			 	[-ramp_up_type                ANY]
			 	[-ramp_up_value               ANY]
			 	[-client_standby_time         ANY]
			 	[-client_sustain_time         ANY]
			 	[-client_total_time           ANY]
			 	[-server_traffic_handle       ANY]
			 	[-match_client_totaltime      ANY]
			 	[-server_iterations           ANY]
			 	[-server_offline_time         ANY]
			 	[-server_standby_time         ANY]
			 	[-server_sustain_time         ANY]
		
		Arguments:
			 	-handle
			 	-target
			    	-property
			        	-mode
			            	-direct_server_return_enable
			                	-ip_address
			                    	-server_http_handle
			                        	-type
			                            	-client_iterations
			                                	-client_http_handle
			                                    	-client_traffic_handle
			                                        	-objective_type
			                                            	-objective_value
			                                                	-client_offline_time
			                                                    	-port_map_policy
			                                                        	-ramp_down_time
			                                                            	-ramp_up_type
			                                                                	-ramp_up_value
			                                                                    	-client_standby_time
			                                                                        	-client_sustain_time
			                                                                            	-client_total_time
			                                                                                	-server_traffic_handle
			                                                                                    	-match_client_totaltime
			                                                                                        	-server_iterations
			                                                                                            	-server_offline_time
			                                                                                                	-server_standby_time
			                                                                                                    	-server_sustain_time
		                                                                                                   
		                                                                                                   Return Values:
		                                                                                                       $::SUCCESS | $::FAILURE
			                                                                                                        key:status   value:$::SUCCESS | $::FAILURE
		                                                                                                       When status is $::FAILURE, contains more information
			                                                                                                        key:log      value:When status is $::FAILURE, contains more information
		                                                                                                       the handles of a HTTP traffic configuration, list of traffic, agent.
			                                                                                                        key:handles  value:the handles of a HTTP traffic configuration, list of traffic, agent.
		                                                                                                   
		                                                                                                   Examples:
		                                                                                                       See files starting with http_ in the Samples subdirectory. Also see the HTTP example in Appendix A, "Example APIs."
		                                                                                                   
		                                                                                                   Sample Input:
		                                                                                                   
		                                                                                                   Sample Output:
		                                                                                                   
		                                                                                                   Notes:
		                                                                                                       Coded versus functional specification.
		                                                                                                   
		                                                                                                   See Also:
		                                                                                                   
		"""
		return self._run_keyword("emulation_http_control_config", kwargs)

	def emulation_http_stats(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_http_stats
			 	[-handle           ANY]
			 	-mode              ANY
			 	[-aggregation_type ANY]
			 	[-stat_name        ANY]
			 	[-stat_type        ANY]
			 	[-filter_type      ANY]
		
		Arguments:
			 	-handle
			 	-mode
			    	-aggregation_type
			        	-stat_name
			            	-stat_type
			                	-filter_type
		               
		               Return Values:
		                   $::SUCCESS | $::FAILURE
			                    key:status   value:$::SUCCESS | $::FAILURE
		                   When status is $::FAILURE, contains more information
			                    key:log      value:When status is $::FAILURE, contains more information
		                   the handles of a HTTP stats configuration.
			                    key:handles  value:the handles of a HTTP stats configuration.
		               
		               Examples:
		                   See files starting with HTTP_ in the Samples subdirectory. Also see the HTTP example in Appendix A, "Example APIs."
		               
		               Sample Input:
		               
		               Sample Output:
		               
		               Notes:
		                   Coded versus functional specification.
		               
		               See Also:
		               
		"""
		return self._run_keyword("emulation_http_stats", kwargs)

	def emulation_http_traffic_config(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_http_traffic_config
			 	[-handle                    ANY]
			 	[-target                    ANY]
			 	[-property                  ANY]
			 	-mode                       ANY
			 	[-browser_emulation         ANY]
			 	[-cookie_jar_size           ANY]
			 	[-cookie_reject_probability ANY]
			 	[-cookie_support_enable     ANY]
			 	[-esm_enable                ANY]
			 	[-esm                       ANY]
			 	[-http_proxy_enable         ANY]
			 	[-https_proxy_enable        ANY]
			 	[-ip_preference             ANY]
			 	[-follow_http_redirects     ANY]
			 	[-http_proxy                ANY]
			 	[-https_proxy               ANY]
			 	[-http_version              ANY]
			 	[-keep_alive                ANY]
			 	[-max_persistent_requests   ANY]
			 	[-max_sessions              ANY]
			 	[-ssl_enable                ANY]
			 	[-sequential_session_reuse  ANY]
			 	[-ssl_version               ANY]
			 	[-certificate               ANY]
			 	[-certificate_file          ANY]
			 	[-private_key               ANY]
			 	[-private_key_file          ANY]
			 	[-private_key_password      ANY]
			 	[-client_ciphers            ANY]
			 	[-accept_ssl_connections    ANY]
			 	[-http_port                 ANY]
			 	[-https_port                ANY]
			 	[-request_timeout           ANY]
			 	[-tos_enable                ANY]
		
		Arguments:
			 	-handle
			 	-target
			    	-property
			        	-mode
			            	-browser_emulation
			                	-cookie_jar_size
			                    	-cookie_reject_probability
			                        	-cookie_support_enable
			                            	-esm_enable
			                                	-esm
			                                    	-http_proxy_enable
			                                        	-https_proxy_enable
			                                            	-ip_preference
			                                                	-follow_http_redirects
			                                                    	-http_proxy
			                                                        	-https_proxy
			                                                            	-http_version
			                                                                	-keep_alive
			                                                                    	-max_persistent_requests
			                                                                        	-max_sessions
			                                                                            	-ssl_enable
			                                                                                	-sequential_session_reuse
			                                                                                    	-ssl_version
			                                                                                        	-certificate
			                                                                                            	-certificate_file
			                                                                                                	-private_key
			                                                                                                    	-private_key_file
			                                                                                                        	-private_key_password
			                                                                                                            	-client_ciphers
			                                                                                                                	-accept_ssl_connections
			                                                                                                                    	-http_port
			                                                                                                                        	-https_port
			                                                                                                                            	-request_timeout
			                                                                                                                                	-tos_enable
		                                                                                                                               
		                                                                                                                               Return Values:
		                                                                                                                                   $::SUCCESS | $::FAILURE
			                                                                                                                                    key:status                              value:$::SUCCESS | $::FAILURE
		                                                                                                                                   When status is $::FAILURE, contains more information
			                                                                                                                                    key:log                                 value:When status is $::FAILURE, contains more information
		                                                                                                                                   the handles of a HTTP traffic configuration, list of traffic, agent.
			                                                                                                                                    key:handles                             value:the handles of a HTTP traffic configuration, list of traffic, agent.
		                                                                                                                                   the handles of the default pages available when creating a server agent.
			                                                                                                                                    key:page_handles                        value:the handles of the default pages available when creating a server agent.
		                                                                                                                                   the handles of the default headers available when creating a server agent.
			                                                                                                                                    key:header_handles                      value:the handles of the default headers available when creating a server agent.
		                                                                                                                                   the handles of the default cookielists available when creating a server agent.
			                                                                                                                                    key:cookielist_handles                  value:the handles of the default cookielists available when creating a server agent.
		                                                                                                                                   the handles of the default cookies for a cookielist that are available when creating a server agent.
			                                                                                                                                    key:<cookielist_handle>.cookie_handles  value:the handles of the default cookies for a cookielist that are available when creating a server agent.
		                                                                                                                               
		                                                                                                                               Examples:
		                                                                                                                                   See files starting with http_ in the Samples subdirectory. Also see the HTTP section in Appendix A, "Example APIs."
		                                                                                                                               
		                                                                                                                               Sample Input:
		                                                                                                                               
		                                                                                                                               Sample Output:
		                                                                                                                               
		                                                                                                                               Notes:
		                                                                                                                                   Coded versus functional specification.
		                                                                                                                               
		                                                                                                                               See Also:
		                                                                                                                               
		"""
		return self._run_keyword("emulation_http_traffic_config", kwargs)

	def emulation_http_traffic_type_config(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_http_traffic_type_config
			 	-mode                          ANY
			 	[-property                     ANY]
			 	[-handle                       ANY]
			 	[-abort                        ANY]
			 	[-command                      ANY]
			 	[-arguments                    ANY]
			 	[-destination                  ANY]
			 	[-page_handle                  ANY]
			 	[-cookielist_mode              ANY]
			 	[-cookielist_description       ANY]
			 	[-type                         ANY]
			 	[-domain                       ANY]
			 	[-max_age                      ANY]
			 	[-path                         ANY]
			 	[-cookie_name                  ANY]
			 	[-cookie_value                 ANY]
			 	[-code                         ANY]
			 	[-expiration_mode              ANY]
			 	[-expiration_datetime          ANY]
			 	[-expiration_afterrequest      ANY]
			 	[-expiration_afterlastmodified ANY]
			 	[-last_modified_mode           ANY]
			 	[-last_modified_datetime       ANY]
			 	[-last_modified_incr_enable    ANY]
			 	[-last_modified_incr_by        ANY]
			 	[-last_modified_incr_for       ANY]
			 	[-mime_type                    ANY]
			 	[-response_name                ANY]
			 	[-response_description         ANY]
			 	[-key                          ANY]
			 	[-value                        ANY]
			 	[-url                          ANY]
			 	[-payload_type                 ANY]
			 	[-payload_file                 ANY]
			 	[-payload_size                 ANY]
			 	[-cookielist_handle            ANY]
		
		Arguments:
			 	-mode
			 	-property
			    	-handle
			        	-abort
			            	-command
			                	-arguments
			                    	-destination
			                        	-page_handle
			                            	-cookielist_mode
			                                	-cookielist_description
			                                    	-type
			                                        	-domain
			                                            	-max_age
			                                                	-path
			                                                    	-cookie_name
			                                                        	-cookie_value
			                                                            	-code
			                                                                	-expiration_mode
			                                                                    	-expiration_datetime
			                                                                        	-expiration_afterrequest
			                                                                            	-expiration_afterlastmodified
			                                                                                	-last_modified_mode
			                                                                                    	-last_modified_datetime
			                                                                                        	-last_modified_incr_enable
			                                                                                            	-last_modified_incr_by
			                                                                                                	-last_modified_incr_for
			                                                                                                    	-mime_type
			                                                                                                        	-response_name
			                                                                                                            	-response_description
			                                                                                                                	-key
			                                                                                                                    	-value
			                                                                                                                        	-url
			                                                                                                                            	-payload_type
			                                                                                                                                	-payload_file
			                                                                                                                                    	-payload_size
			                                                                                                                                        	-cookielist_handle
		                                                                                                                                       
		                                                                                                                                       Return Values:
		                                                                                                                                           $::SUCCESS | $::FAILURE
			                                                                                                                                            key:status   value:$::SUCCESS | $::FAILURE
		                                                                                                                                           When status is $::FAILURE, contains more information
			                                                                                                                                            key:log      value:When status is $::FAILURE, contains more information
		                                                                                                                                           the handles of a HTTP traffic configuration, list of traffic, agent.
			                                                                                                                                            key:handles  value:the handles of a HTTP traffic configuration, list of traffic, agent.
		                                                                                                                                       
		                                                                                                                                       Examples:
		                                                                                                                                           See files starting with http_ in the Samples subdirectory. Also see the HTTP example in Appendix A, "Example APIs."
		                                                                                                                                       
		                                                                                                                                       Sample Input:
		                                                                                                                                       
		                                                                                                                                       Sample Output:
		                                                                                                                                       
		                                                                                                                                       Notes:
		                                                                                                                                           Coded versus functional specification.
		                                                                                                                                       
		                                                                                                                                       See Also:
		                                                                                                                                       
		"""
		return self._run_keyword("emulation_http_traffic_type_config", kwargs)

	def emulation_igmp_config(self, **kwargs):
		""" This procedure creates, modifies, and deletes Group Management Protocol (IGMP) host(s) for the specified HLTAPI port or handle.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_igmp_config
			 	[-handle                               ANY]
			x	[-protocol_name                        ALPHA]
			 	-mode                                  CHOICES create
			                                        CHOICES delete
			                                        CHOICES modify
			                                        CHOICES enable
			                                        CHOICES disable
			                                        CHOICES enable_all
			                                        CHOICES disable_all
			x	[-return_detailed_handles              CHOICES 0 1
			x                                       DEFAULT 0]
			x	[-active                               CHOICES 0 1]
			x	[-active_flag                          CHOICES 0 1
			x                                       DEFAULT 0]
			x	[-atm_encapsulation                    ANY]
			 	[-count                                NUMERIC
			                                        DEFAULT 1]
			x	[-enable_packing                       ANY]
			 	[-filter_mode                          CHOICES include exclude
			                                        DEFAULT include]
			 	[-general_query                        CHOICES 0 1
			                                        DEFAULT 1]
			 	[-global_settings_enable               CHOICES 0 1]
			 	[-group_query                          CHOICES 0 1
			                                        DEFAULT 1]
			 	[-igmp_version                         CHOICES v1 v2 v3
			                                        DEFAULT v2]
			 	[-inter_stb_start_delay                NUMERIC
			                                        DEFAULT 0]
			x	[-interface_handle                     ANY]
			 	[-intf_ip_addr                         IPV4]
			 	[-intf_ip_addr_step                    IPV4
			                                        DEFAULT 0.0.0.1]
			 	[-intf_prefix_len                      RANGE 1-32
			                                        DEFAULT 24]
			 	[-ip_router_alert                      CHOICES 0 1
			                                        DEFAULT 1]
			x	[-mac_address_init                     MAC]
			x	[-mac_address_step                     MAC
			x                                       DEFAULT 0000.0000.0001]
			 	[-max_groups_per_pkts                  ANY]
			 	[-max_response_control                 CHOICES 0 1
			                                        DEFAULT 0]
			 	[-max_response_time                    NUMERIC]
			 	[-max_sources_per_group                ANY]
			 	[-msg_count_per_interval               NUMERIC
			                                        DEFAULT 0]
			 	[-msg_interval                         NUMERIC
			                                        DEFAULT 0]
			 	[-neighbor_intf_ip_addr                IPV4]
			 	[-neighbor_intf_ip_addr_step           IPV4
			                                        DEFAULT 0.0.0.0]
			x	[-no_write                             ANY]
			x	[-override_existence_check             CHOICES 0 1
			x                                       DEFAULT 0]
			x	[-override_tracking                    CHOICES 0 1
			x                                       DEFAULT 0]
			 	[-port_handle                          REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-reset                                FLAG]
			 	[-suppress_report                      ANY]
			 	[-unsolicited_report_interval          NUMERIC
			                                        DEFAULT 120]
			x	[-vci                                  ANY]
			x	[-vci_step                             ANY]
			x	[-vlan                                 CHOICES 0 1
			x                                       DEFAULT 0]
			 	[-vlan_id                              RANGE 0-4095
			                                        DEFAULT 1]
			 	[-vlan_id_mode                         CHOICES fixed increment
			                                        DEFAULT increment]
			 	[-vlan_id_step                         RANGE 0-4096
			                                        DEFAULT 1]
			 	[-vlan_user_priority                   RANGE 0-7
			                                        DEFAULT 0]
			x	[-vpi                                  ANY]
			x	[-vpi_step                             ANY]
			n	[-older_version_timeout                ANY]
			n	[-robustness                           ANY]
			n	[-vlan_cfi                             ANY]
			x	[-unsolicited_response_mode            CHOICES 0 1
			x                                       DEFAULT 0]
			x	[-join_leave_multiplier                NUMERIC
			x                                       DEFAULT 1]
			n	[-no_of_reports_per_second             ANY]
			x	[-name                                 ALPHA]
			x	[-enable_iptv                          ANY]
			x	[-iptv_name                            ALPHA]
			x	[-stb_leave_join_delay                 NUMERIC]
			x	[-join_latency_threshold               NUMERIC]
			x	[-leave_latency_threshold              NUMERIC]
			x	[-zap_behavior                         CHOICES zaponly zapandview onetime]
			x	[-zap_direction                        CHOICES up down random]
			x	[-zap_interval_type                    CHOICES leavetoleave multicasttoleave]
			x	[-zap_interval                         NUMERIC]
			x	[-num_channel_changes_before_view      NUMERIC]
			x	[-view_duration                        NUMERIC]
			x	[-log_failure_timestamps               CHOICES 0 1]
			x	[-enable_general_query_response        ANY]
			x	[-enable_group_specific_query_response ANY]
			x	[-combined_leave_join                  CHOICES 0 1]
		
		Arguments:
			 	-handle
			 		IGMP Host handle if the option -mode is delete, modify, disable,
			 		enable.
			x	-protocol_name
			x		Name of the igmp protocol as it should appear in the IxNetwork GUI
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-mode
			 		This option defines the action to be taken.
			 		Valid choices are:
			    		create - Creates an IGMP host.
			    		delete - Deletes an IGMP host.
			    		modify - Modifies an IGMP host.
			    		enable - Enables an IGMP host.
			    		disable - Disables an IGMP host.
			    		enable_all - Enables all configured IGMP hosts.
			    		disable_all - Disables all configured IGMP hosts.
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-active
			x		Enable/disable igmp host
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-active_flag
			x		This argument is used for Enable/Disable the igmp host item with it's corresponding item handle.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-atm_encapsulation
			x		The encapsulation of the ATM protocol interface associated with the emulated router. Valid for mode create.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-count
			 		Defines the number of sessions to create on the interface. Valid for
			 		mode create.
			x	-enable_packing
			x		If checked, multiple Sources can be included in each Record, and multiple Records can be included in each Frame, for more efficient transmission. This option is available only for IGMPv3.Valid for mode create and modify. The modification will be applied on all groups configured on the IGMP host.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-filter_mode
			 		Cofigure IGMPv3 Include Filter Mode. Valid for mode create and modify. The
			 		modification will be applied on all groups configured on the IGMP host.
			 		Valid choices are:
			    		include - The specified source(s) is (are) of interest
			    		exclude - The specified source(s) is (are) not of interest
			 	-general_query
			 		If true (1), respond to general queries received on the interface. Valid for
			 		mode create and modify.
			 	-global_settings_enable
			 		Enables the Global Settings for Igmp Host.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-group_query
			 		If true (1), respond to group specific queries
			 		received on the interface. Valid for mode create and modify.
			 	-igmp_version
			 		The version of IGMP to be used: v1, v2, v3. Valid for mode create.
			 		Valid choices are:
			    		v1 - version 1
			    		v2 - version 2
			    		v3 - version 3
			 	-inter_stb_start_delay
			 		Time in milliseconds between Join messages from clients within the same range.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-interface_handle
			x		 A handle or list of the handles that are returned from the
			x		interface_config call. These provide a direct link to an already
			x		existing interface and supercede the use of the intf_ip_addr value. 
			x		 Starting with IxNetwork 5.50 this parameter accepts handles returned by
			x		pppox_config procedure in the following format:
			x		<PPPoX Range Handle>|<interface index X>,<interface index Y>-<interface index Z>, ...
			x		The PPPoX ranges are separated from the Interface Index identifiers with the (|) character.
			x		The Interface Index identifiers are separated with comas (,).
			x		A range of Interface Index identifiers can be defined using the dash (-) character. 
			x		Ranges along with the Interface Index identifiers are grouped together in TCL Lists. The
			x		lists can contain mixed items, protocol interface handles returned by interface_config
			x		and handles returned by pppox_config along with the interface index. 
			x		Example:
			x		count 10 (10 IGMP routers). 3 pppox range handles returned by ::ixia::pppox_config.
			x		Each pppox range has 20 sessions (interfaces). If we pass interface_handle
			x		in the following format: [list $pppox_r1|1,5 $pppox_r2|1-3 $pppox_r3|1,3,5-9,13]
			x		The interfaces will be distributed to the routers in the following manner:
			x		
			x		
			x		-  IGMP Router 1: $pppox_r1 -> interface 1 
			x		-  IGMP Router 2: $pppox_r1 -> interface 5 
			x		-  IGMP Router 3: $pppox_r2 -> interface 1 
			x		-  IGMP Router 4: $pppox_r2 -> interface 2 
			x		-  IGMP Router 5: $pppox_r2 -> interface 3 
			x		-  IGMP Router 6: $pppox_r3 -> interface 1 
			x		-  IGMP Router 7: $pppox_r3 -> interface 3 
			x		-  IGMP Router 8: $pppox_r3 -> interface 5 
			x		-  IGMP Router 9: $pppox_r3 -> interface 6 
			x		-  IGMP Router 10: $pppox_r3 -> interface 7 
			x		-  IGMP Router 11: $pppox_r3 -> interface 8 
			x		-  IGMP Router 12: $pppox_r3 -> interface 9 
			x		-  IGMP Router 13 $pppox_r3 -> interface 13 
			x		
			x		
			x		 Valid for mode create. 
			 	-intf_ip_addr
			 		IP address of the test interface / emulated IGMP Host. Valid for mode create.
			 	-intf_ip_addr_step
			 		The IP address step between each session. Valid for mode create.
			 	-intf_prefix_len
			 		The netmask length value for the interface. Valid for mode create.
			 	-ip_router_alert
			 		If true (1), enable IP Router Alert Option. Valid for mode create and modify.
			x	-mac_address_init
			x		The MAC address for the interface to be created. Valid for mode create.
			x	-mac_address_step
			x		The incrementing step for the MAC address of the interface to be
			x		created. Valid only when using IxNetwork Tcl API. Valid for mode create.
			 	-max_groups_per_pkts
			 		The total number of Group Records to be added to each frame/message. This option is available only for IGMPv3. Valid for mode create and modify. The modification will be applied on all groups configured on the IGMP host.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-max_response_control
			 		If true (1), use -max_response_time to overwrite the value obtained
			 		from the received Query message. Valid for mode create and modify.
			 	-max_response_time
			 		Set the maximum response time (in 1/10 seconds) on receipt of a query.
			 		If set to 0, immediately respond to received Query message.Valid
			 		for mode create and modify.
			 	-max_sources_per_group
			 		The total number of Source addresses to be added to each Group Record. This option is available only for IGMPv3. Valid for mode create and modify. The modification will be applied on all groups configured on the IGMP host.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-msg_count_per_interval
			 		The number of multicast IGMP groups to be advertised during each time period.
			 		A value of 0 disables this feature and transmits all groups
			 		immediately for all updates. Valid for mode create and modify.
			 	-msg_interval
			 		The interval in seconds used for throttling updates. A value of 0 will
			 		cause sending the messages as fast as possible. Valid for mode create and modify.
			 	-neighbor_intf_ip_addr
			 		IP address of the neighbor. Valid for mode create.
			 	-neighbor_intf_ip_addr_step
			 		The IP address step between each session. Valid for mode create.
			x	-no_write
			x		If this option is present, the protocol configuration will not be written to the server.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-override_existence_check
			x		If this option is enabled, the interface existence check is skipped but
			x		the list of interfaces is still created and maintained in order to keep
			x		track of existing interfaces, if required. Using this option will speed
			x		up the creation of interfaces. Valid for mode create.
			x	-override_tracking
			x		If this option is enabled, the list of interfaces will not be created and
			x		maintained anymore, thus speeding up the creation of interfaces even
			x		more. Also, it will enable -override_existence_check in case it was not
			x		already enabled, because checking for interface existence becomes
			x		impossible if the the list of interfaces doesn?t exist anymore. Valid for mode create.
			 	-port_handle
			 		The port on which the session is to be created. Valid for mode create.
			x	-reset
			x		Clear all existent hosts. Valid for mode create.
			 	-suppress_report
			 		If true (1), suppress the transmission of a listener report that duplicates one received on the interface. Valid for mode create and modify.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-unsolicited_report_interval
			 		The interval (in seconds) to wait before re-sending the host's
			 		initial report of membership in a group. If 0, do not send unsolicited
			 		report.
			x	-vci
			x		VCI for emulated router node. Valid for mode create.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vci_step
			x		The step value used for incrementing the -vci option. Valid for mode create.
			x		When vci_step causes the vci value to exceed it's maximum value the increment will be done modulo <number of possible vci ids>.
			x		Examples: vci = 65534; vci_step = 2-> new vci value = 0vci = 65535; vci_step = 11 -> new vci value = 10
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vlan
			x		Enables vlan on the directly connected IGMP router interface.
			x		Valid options are: 0 - disable, 1 - enable.
			x		This option is valid only when -mode is create or -mode is modify
			x		and -handle is an IGMP router handle.
			x		This option is available only when IxNetwork tcl API is used.
			 	-vlan_id
			 		VLAN ID for emulated router node. Valid for mode create.
			 	-vlan_id_mode
			 		For multiple neighbor configuration, configures the VLAN ID mode to
			 		fixed or increment. Valid for mode create.
			 		Valid choices are:
			    		fixed - Use the same vlan id across the ethernet items
			    		increment - Increment the vlan id across the ethernet items using the vlan_id_step value
			 	-vlan_id_step
			 		 When -vlan_id_mode is set to increment, this defines the step for
			 		every VLAN. Valid for mode create. 
			 		 When vlan_id_step causes the vlan_id value to exceed it's maximum value the
			 		increment will be done modulo <number of possible vlan ids>. 
			 		 Examples:
			 		
			 		-  vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0 
			 		-  vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10 
			 		
			 	-vlan_user_priority
			 		VLAN user priority assigned to emulated router node. Valid for mode create.
			x	-vpi
			x		VPI for emulated router node. Valid for mode create.
			x		When vpi_step causes the vpi value to exceed it's maximum value the
			x		increment will be done modulo <number of possible vpi ids>.
			x		Examples:
			x		
			x		
			x		- vpi = 254; vpi_step = 2-> new vpi value = 0 
			x		- vpi = 255; vpi_step = 11 -> new vpi value = 10 
			x		
			x		
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vpi_step
			x		The step value used for incrementing the -vpi option. Valid for mode create.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			n	-older_version_timeout
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-robustness
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-vlan_cfi
			x	-unsolicited_response_mode
			x   		If selected, the emulated IGMP host automatically sends full membership messages at regular intervals, without waiting for a query message.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-join_leave_multiplier
			x   		No. of Join/Leave messages to send per operation
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			n	-no_of_reports_per_second
			x   	-name
			x       		DEPRECATED: use protocol_name instead
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_iptv
			x       		Enable IPTV
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-iptv_name
			x       		Name of NGPF element, guaranteed to be unique in Scenario
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-stb_leave_join_delay
			x       		Time in milliseconds between sending a Leave for the current channel and Join for the next channel.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-join_latency_threshold
			x       		The maximum time that is allowed for a multicast stream to arrive for channel for which a Join has been sent.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-leave_latency_threshold
			x       		The maximum time allowed for a multicast stream to stop for a channel for which a Leave has been sent.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-zap_behavior
			x       		Use Zap Only to change channels without viewing the channel or Zap and View to change traffic and receive traffic for the last channel.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		zaponly - Enables channel change without viewing the channel
			x           		zapandview - Change and receive traffic for the last channel
			x           		onetime - Enabled a single channel change
			x   	-zap_direction
			x       		Specifies the direction of changing channels.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		up -
			x           		down -
			x           		random -
			x   	-zap_interval_type
			x       		Specifies the wait interval type before changing the channels.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		leavetoleave -
			x           		multicasttoleave -
			x   	-zap_interval
			x       		Interval in milliseconds between channel changes based on the selected type.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-num_channel_changes_before_view
			x       		Number of channels to change before stopping on a channel and watching it for View Duration.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-view_duration
			x       		Specifies the time in milliseconds to view the last channel.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-log_failure_timestamps
			x       		If enabled, the timestamps for Join and Leave failures are saved to a log file.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_general_query_response
			x       		If enabled, General Query Response is send.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_group_specific_query_response
			x       		If enabled, Group Specific Response is sent
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-combined_leave_join
			x       		If enabled, Leave for current group and join for next group gets merged in a single multicast packet
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		   A list containing the igmp host protocol stack handles that were added by the command (if any).
			x   key:igmp_host_handle       value:A list containing the igmp host protocol stack handles that were added by the command (if any).
		   A list containing the ethernet protocol stack handles that were added by the command (if any).
			x   key:ethernet_handle        value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		   A list containing the ipv4 protocol stack handles that were added by the command (if any).
			x   key:ipv4_handle            value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		   A list containing the pppox client protocol stack handles that were added by the command (if any).
			x   key:pppox_client_handle    value:A list containing the pppox client protocol stack handles that were added by the command (if any).
		   A list containing the pppox server protocol stack handles that were added by the command (if any).
			x   key:pppox_server_handle    value:A list containing the pppox server protocol stack handles that were added by the command (if any).
		   A list containing the igmp host iptv protocol stack handles that were added by the command (if any).
			x   key:igmp_host_iptv_handle  value:A list containing the igmp host iptv protocol stack handles that were added by the command (if any).
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:interface_handle       value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:iptv_handles           value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   $::SUCCESS | $::FAILURE
			    key:status                 value:$::SUCCESS | $::FAILURE
		   The handles for the IGMP Hosts created. Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			    key:handle                 value:The handles for the IGMP Hosts created. Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   If status is failure, detailed information provided.
			    key:log                    value:If status is failure, detailed information provided.
		   The handles for the IGMP Hosts created
			    key:handle                 value:The handles for the IGMP Hosts created
		
		Examples:
		   See files starting with IGMPv1_, IGMPv2_, or IGMPv3_ in the Samples subdirectory. See the IGMP example in Appendix A, "Examples APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		   If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle, interface_handle, iptv_handles
		
		See Also:
		
		"""
		return self._run_keyword("emulation_igmp_config", kwargs)

	def emulation_igmp_control(self, **kwargs):
		""" This procedure starts, stops and restarts the IGMP protocol on specific Ixia ports with CPUs.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_igmp_control
			 	-mode                   CHOICES stop
			                         CHOICES start
			                         CHOICES restart
			                         CHOICES join
			                         CHOICES leave
			                         CHOICES rejoin
			                         CHOICES releave
			                         CHOICES igmpSendSpecificQuery
			                         CHOICES igmpResumePeriodicGenQuery
			                         CHOICES igmpStopPeriodicGenQuery
			 	[-group_member_handle   ANY]
			x	[-source_member_handle  ANY]
			 	[-handle                ANY]
			 	[-port_handle           REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-start_group_address   IPV4
			x                        DEFAULT 125.0.0.1]
			x	[-group_count           NUMERIC
			x                        DEFAULT 1]
			x	[-start_source_address  IPV4
			x                        DEFAULT 10.10.10.0]
			x	[-source_count          NUMERIC
			x                        DEFAULT 0]
			x	[-source_increment_step NUMERIC
			x                        DEFAULT 1]
		
		Arguments:
			 	-mode
			 		The action that will be performed on the protocol instances.
			 		Valid choices are:
			    		start - Start the protocol.
			    		stop - Stop the protocol.
			    		restart - Restart the protocol.
			    		join - If -port_handle is given,
or -group_member_handle is given as a group item handle or an ip/step/count handle, 
or -source_member_handle is given as a source pool item handle, IGMP join action will be applied.
			    		leave - If -port_handle is given,
or -group_member_handle is given as a group item handle or an ip/step/count handle,
or -source_member_handle is given as a source pool item handle, IGMP leave action will be applied.
			    		rejoin - Rejoin the specified group in -handle.
			    		releave - releave the specified group in -handle.
			    		igmp_send_specific_query - send Specific Query on igmp Querier.
			    		igmp_resume_periodic_gen_query - send resume periodic query on igmp Querier.
			    		igmp_stop_periodic_gen_query - send stop periodic Query on igmp Querier.
			 	-group_member_handle
			 		The IGMP group range handle. This option is available when using IxTclProtocol or IxTclNetwork path.
			 		When using IxTclNetwork, this parameter can be also given as an element or a list of elements in the following
			 		format: (source IP)/(source IP step)/(source count). Eg: 50.0.1.2/0.0.0.1/3.
			x	-source_member_handle
			x		The IGMP source range handle. This option is available when using IxTclProtocol or IxTclNetwork path.
			x		When using IxTclNetwork, this parameter can be also given as an element or a list of elements in the following
			x		format: (group IP)/(group IP step)/(group count). Eg: 50.0.1.2/0.0.0.1/3.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-handle
			 		The IGMP session handle (host or querier). When this parameter is used
			 		with IxTclNetwork, it can also be provided as an IGMP host IP or a list
			 		of IGMP host IPs.
			 	-port_handle
			 		The port where the IGMP is to be controlled. If IxTclNetwork path is used, and port_handle is used
			 		with mode join/leave, the group members on each ports will be enabled/disabled.
			x	-start_group_address
			x		This attribute is used when -mode is "igmp_send_specific_query". The parameter represents the start group address.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-group_count
			x		This attribute is used when -mode is "igmp_send_specific_query". The parameter represents the group count.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-start_source_address
			x		This attribute is used when -mode is "igmp_send_specific_query". The parameter represents the start source address.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-source_count
			x		This attribute is used when -mode is "igmp_send_specific_query". The parameter represents the source count.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-source_increment_step
			x		This attribute is used when -mode is "igmp_send_specific_query". The parameter represents the source increment step.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		See files starting with IGMPv1_, IGMPv2_, or IGMPv3_ in the Samples subdirectory. See the IGMP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		If neither -handle nor -port_handle is provided, the protocol will start on all ports that have IGMP configured. This is valid for IxTclNetwork path only.
		If neither -handle nor -port_handle is provided, the protocol will start on all ports that have IGMP configured. This is valid for IxTclNetwork path only.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_igmp_control", kwargs)

	def emulation_igmp_group_config(self, **kwargs):
		""" This procedure will configure multicast group ranges for a simulated IGMP Host. IGMP is only supported on ports with CPUs.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_igmp_group_config
			 	-mode                     CHOICES create
			                           CHOICES delete
			                           CHOICES modify
			                           CHOICES clear_all
			                           CHOICES enable
			                           CHOICES disable
			x	[-return_detailed_handles CHOICES 0 1
			x                          DEFAULT 0]
			x	[-g_enable_packing        ANY]
			x	[-g_filter_mode           CHOICES include exclude]
			x	[-g_max_groups_per_pkts   ANY]
			x	[-g_max_sources_per_group ANY]
			 	[-group_pool_handle       ANY]
			 	[-handle                  ANY]
			x	[-no_of_grp_ranges        NUMERIC
			x                          DEFAULT 1]
			x	[-no_of_src_ranges        NUMERIC]
			x	[-no_write                ANY]
			x	[-reset                   FLAG]
			 	[-session_handle          ANY]
			 	[-source_pool_handle      ANY]
		
		Arguments:
			 	-mode
			 		This option defines the action to be taken.
			 		Valid choices are:
			    		create - When this mode is used, you must provide -session_handle. The
parameter -group_pool_handle is also mandatory.
			    		delete - Parameter -handle must be provided. In this case, -handle can represent
one or multiple Group Ranges.
			    		modify - Parameter -handle must be provided. When using this mode, -handle can represent
one or multiple Group Ranges.
			    		clear_all - When this mode is used, you must provide -session_handle.
			    		enable - When this mode is used, you must provide -handle.
			    		disable - When this mode is used, you must provide -handle.
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-g_enable_packing
			x		If checked, multiple Sources can be included in each Record, and multiple Records can be included in each Frame, for more efficient transmission. This option is available only for IGMPv3. This is valid only for IxTclNetwork API. If this parameter is not provided, the enable_packing that was set at host level will be used instead.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-g_filter_mode
			x		Cofigure IGMPv3 Include Filter Mode. This is valid only for IxTclNetwork API.
			x		If this parameter is not provided, the filter_mode that was set at host level will be used instead.
			x		Valid choices are:
			x   		include - The specified source(s) is (are) of interest
			x   		exclude - The specified source(s) is (are) not of interest
			x	-g_max_groups_per_pkts
			x		The total number of Group Records to be added to each frame/message. This option is available only for IGMPv3. This is valid only for IxTclNetwork API. If this parameter is not provided, the max_groups_per_pkts that was set at host level will be used instead.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-g_max_sources_per_group
			x		The total number of Source addresses to be added to each Group Record. This option is available only for IGMPv3. This is valid only for IxTclNetwork API. If this parameter is not provided, the max_sources_per_group that was set at host level will be used instead.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-group_pool_handle
			 		Groups to be linked to the session in create mode. Parameter -group_pool_handle can be provided in two ways.
			 		
			 		
			 		-  This parameter should be provided with a multicast group handle or a list of multicast group handles retrieved after calling emulation_multicast_group_config. Multiple handles can be used only for Legacy NGPF, when port_handle is given as argument to the current command.
			 		- This parameter should be provided with one element or a list of elements in the following format: (group IP)/(group IP step)/(group count). Eg: 50.0.1.2/0.0.0.1/3. Valid only when port_handle is given as an argument - Legacy NGPF. 
			 		
			 		
			 	-handle
			 		Group membership handle that associates group pools with an IGMP
			 		session. If modify mode, membership handle must be used in conjunction
			 		with session handle to identify the multicast group pools.
			x	-no_of_grp_ranges
			x		Number of igmp multicast groups in group pool.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-no_of_src_ranges
			x		Number of igmp unicast sources in source pool.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-no_write
			x		If this option is present, the protocol configuration will not be written to the server.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-reset
			x		If the -mode is create and this option exists, then any existing
			x		group ranges will be deleted before creating new ones.
			 	-session_handle
			 		IGMP Host handle on which to configure the IGMP group ranges. There are two ways of providing this parameter.
			 		1. Providing the IP address of the protocol interface that is associated with an IGMP host
			 		on which to configure the IGMP group ranges. Valid for IxTclNetwork only.
			 		2. Providing the IGMP host handle returned by ::ixiangpf::emulation_igmp_config. Valid for both IxTclNetwork and IxTclProtocols.
			 	-source_pool_handle
			 		Associate source pool(s) with group(s). Specify one or more source pool
			 		handle(s) for (S,G) entries. None for (*,G) entries. There are two ways of providing -source_pool_handle. 
			 		1. This parameter should be provided with a multicast source handle or a list of multicast source handles
			 		retrieved after callingemulation_multicast_source_config. Valid for both IxTclNetwork and IxTclProtocols.
			 		2. This parameter should be provided with one element or a list of elements in the following
			 		format: (source group IP)/(source group IP step)/(source group count) .  Eg: 20.0.0.2/0.0.0.1/3. Valid for IxTclNetwork only.
		
		Return Values:
		A list containing the igmp group protocol stack handles that were added by the command (if any).
			xkey:igmp_group_handle   value:A list containing the igmp group protocol stack handles that were added by the command (if any).
		A list containing the igmp source protocol stack handles that were added by the command (if any).
			xkey:igmp_source_handle  value:A list containing the igmp source protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE
			 key:status              value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                 value:If status is failure, detailed information provided.
		The handle for the group member created Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:handle              value:The handle for the group member created Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		The handle for the source created (IGMPv3), only for IxTclNetwork Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:source_handle       value:The handle for the source created (IGMPv3), only for IxTclNetwork Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		The group_pool_handle used for creating the group member
			 key:group_pool_handle   value:The group_pool_handle used for creating the group member
		The source_pool_handles used for creating the group member
			 key:source_pool_handle  value:The source_pool_handles used for creating the group member
		The handle for the group member created
			 key:handle              value:The handle for the group member created
		The handle for the source created (IGMPv3), only for IxTclNetwork
			 key:source_handle       value:The handle for the source created (IGMPv3), only for IxTclNetwork
		
		Examples:
		See files starting with IGMPv1_, IGMPv2_, or IGMPv3_ in the Samples subdirectory. See the IGMP example in Appendix A, "Examples APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle, source_handle
		
		See Also:
		
		"""
		return self._run_keyword("emulation_igmp_group_config", kwargs)

	def emulation_igmp_info(self, **kwargs):
		""" This procedure gathers IGMP statistics for a specific Ixia port. It is only supported for IxTclNetwork and not by IxNetwork-FT.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_igmp_info
			x	-mode         CHOICES stats_per_device_group
			x              CHOICES stats_per_session
			x              CHOICES aggregate
			x              CHOICES clear_stats
			x              CHOICES learned_info
			x              DEFAULT aggregate]
			 	[-port_handle REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-timeout     ANY]
			x	[-handle      ANY]
			x	[-type        CHOICES igmp_over_ppp
			x              CHOICES igmp
			x              CHOICES host
			x              CHOICES querier
			x              CHOICES both
			x              DEFAULT host]
		
		Arguments:
			x	-mode
			x		The statistics that should be retrieved for IGMP hosts/queriers.
			x		Valid choices are:
			x   		stats_per_device_group - Gather IGMP statistics per Device Group.
			x   		stats_per_session - Gather IGMP Statistics per Session
			x   		aggregate - Gather aggregated IGMP statistics
			x   		clear_stats - Clear IGMP statistics
			x   		learned_info - Get learned info for IGMP Querier
			 	-port_handle
			 		This parameter is used to specify the port from which
			 		statistics will be gathered.
			x	-timeout
			x		The timeout value (measured in seconds) for completing the learned_info operation for IGMP Querier.The default value is:
			x		a) 30 seconds times (*) the number of queriers provided to -handle parameter (if -handle isprovided to the emulation_igmp_info command) or 
			x		b) 30 seconds times (*) the number of queriers existing on the -port_handle parameter (if -handle is not provided to the emulation_igmp_info command).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-handle
			x		IGMP session handle for which the IGMP info is applied. The session handle is an emulated IGMP router object reference.
			x	-type
			x		The type of aggregated statistics to be gathered. Valid only for -mode aggregate.
			x		Valid choices are:
			x   		host - statistics gathered from IxNetwork for the igmp sessions configured using emulation_igmp_config.
			x   		querier - statistics gathered from IxNetwork for the igmp sessions configured using emulation_igmp_querier_config.
			x   		both - both host and querier agregated statistics will be retrieved.
			x   		igmp_over_ppp - Not Supported
			x   		igmp - Not Supported
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                                value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information
			 key:log                                                                   value:When status is failure, contains more information
		Sessions Total
			 key:<port_handle>.sessions_total                                          value:Sessions Total
		Sessions Up
			 key:<port_handle>.sessions_up                                             value:Sessions Up
		Sessions Down
			 key:<port_handle>.sessions_down                                           value:Sessions Down
		Sessions Not Started
			 key:<port_handle>.sessions_notstarted                                     value:Sessions Not Started
		Total Frames Tx
			 key:<port_handle>.igmp.aggregate.total_tx                                 value:Total Frames Tx
		Total Frames Rx
			 key:<port_handle>.igmp.aggregate.total_rx                                 value:Total Frames Rx
		Invalid Packets Rx
			 key:<port_handle>.igmp.aggregate.invalid_rx                               value:Invalid Packets Rx
		v1 Membership Reports Tx
			 key:<port_handle>.igmp.aggregate.rprt_v1_tx                               value:v1 Membership Reports Tx
		v1 Membership Reports Rx
			 key:<port_handle>.igmp.aggregate.rprt_v1_rx                               value:v1 Membership Reports Rx
		v2 Membership Reports Tx
			 key:<port_handle>.igmp.aggregate.rprt_v2_tx                               value:v2 Membership Reports Tx
		v2 Membership Reports Rx
			 key:<port_handle>.igmp.aggregate.rprt_v2_rx                               value:v2 Membership Reports Rx
		v3 Membership Reports Tx
			 key:<port_handle>.igmp.aggregate.rprt_v3_tx                               value:v3 Membership Reports Tx
		v3 Membership Reports Rx
			 key:<port_handle>.igmp.aggregate.rprt_v3_rx                               value:v3 Membership Reports Rx
		General Queries Rx
			 key:<port_handle>.igmp.aggregate.gen_query_rx                             value:General Queries Rx
		v2 Group-Specific Queries Rx
			 key:<port_handle>.igmp.aggregate.grp_query_rx                             value:v2 Group-Specific Queries Rx
		v3 Group&Source Specific Queries Rx
			 key:<port_handle>.igmp.aggregate.v3_group_and_source_specific_queries_rx  value:v3 Group&Source Specific Queries Rx
		v2 Leave Tx
			 key:<port_handle>.igmp.aggregate.leave_v2_tx                              value:v2 Leave Tx
		v2 Leave Rx
			 key:<port_handle>.igmp.aggregate.leave_v2_rx                              value:v2 Leave Rx
		v3 MODE_IS_INCLUDE Tx
			 key:<port_handle>.igmp.aggregate.v3_mode_include_tx                       value:v3 MODE_IS_INCLUDE Tx
		v3 MODE_IS_INCLUDE Rx
			 key:<port_handle>.igmp.aggregate.v3_mode_include_rx                       value:v3 MODE_IS_INCLUDE Rx
		v3 MODE_IS_EXCLUDE Tx
			 key:<port_handle>.igmp.aggregate.v3_mode_exclude_tx                       value:v3 MODE_IS_EXCLUDE Tx
		v3 MODE_IS_EXCLUDE Rx
			 key:<port_handle>.igmp.aggregate.v3_mode_exclude_rx                       value:v3 MODE_IS_EXCLUDE Rx
		v3 CHANGE_TO_INCLUDE_MODE Tx
			 key:<port_handle>.igmp.aggregate.v3_change_mode_include_tx                value:v3 CHANGE_TO_INCLUDE_MODE Tx
		v3 CHANGE_TO_INCLUDE_MODE Rx
			 key:<port_handle>.igmp.aggregate.v3_change_mode_include_rx                value:v3 CHANGE_TO_INCLUDE_MODE Rx
		v3 CHANGE_TO_EXCLUDE_MODE Tx
			 key:<port_handle>.igmp.aggregate.v3_change_mode_exclude_tx                value:v3 CHANGE_TO_EXCLUDE_MODE Tx
		v3 CHANGE_TO_EXCLUDE_MODE Rx
			 key:<port_handle>.igmp.aggregate.v3_change_mode_exclude_rx                value:v3 CHANGE_TO_EXCLUDE_MODE Rx
		v3 ALLOW_NEW_SOURCES Tx
			 key:<port_handle>.igmp.aggregate.v3_allow_new_source_tx                   value:v3 ALLOW_NEW_SOURCES Tx
		v3 ALLOW_NEW_SOURCES Rx
			 key:<port_handle>.igmp.aggregate.v3_allow_new_source_rx                   value:v3 ALLOW_NEW_SOURCES Rx
		v3 BLOCK_OLD_SOURCES Tx
			 key:<port_handle>.igmp.aggregate.v3_block_old_source_tx                   value:v3 BLOCK_OLD_SOURCES Tx
		v3 BLOCK_OLD_SOURCES Rx
			 key:<port_handle>.igmp.aggregate.v3_block_old_source_rx                   value:v3 BLOCK_OLD_SOURCES Rx
		Port Name
			 key:<port_handle>.igmp.aggregate.port_name                                value:Port Name
		Pairs Joined
			 key:<port_handle>.igmp.aggregate.pair_joined                              value:Pairs Joined
		Sessions Total
			 key:<port_handle>.sessions_total                                          value:Sessions Total
		Sessions Up
			 key:<port_handle>.sessions_up                                             value:Sessions Up
		Sessions Down
			 key:<port_handle>.sessions_down                                           value:Sessions Down
		Sessions Not Started
			 key:<port_handle>.sessions_notstarted                                     value:Sessions Not Started
		Invalid Packets Rx
			 key:<port_handle>.igmp.aggregate.invalid_rx                               value:Invalid Packets Rx
		v1 General Queries Tx
			 key:<port_handle>.igmp.aggregate.gen_query_v1_tx                          value:v1 General Queries Tx
		v2 General Queries Tx
			 key:<port_handle>.igmp.aggregate.gen_query_v2_tx                          value:v2 General Queries Tx
		v3 General Queries Tx
			 key:<port_handle>.igmp.aggregate.gen_query_v3_tx                          value:v3 General Queries Tx
		v2 Group Specific Queries Tx
			 key:<port_handle>.igmp.aggregate.grp_v2_query_tx                          value:v2 Group Specific Queries Tx
		v3 Group Specific Queries Tx
			 key:<port_handle>.igmp.aggregate.grp_v3_query_tx                          value:v3 Group Specific Queries Tx
		v3 Group and Source Specific Queries Tx
			 key:<port_handle>.igmp.aggregate.grp_src_v3_query_tx                      value:v3 Group and Source Specific Queries Tx
		v1 Membership Reports Rx
			 key:<port_handle>.igmp.aggregate.rprt_v1_rx                               value:v1 Membership Reports Rx
		v2 Membership Reports Rx
			 key:<port_handle>.igmp.aggregate.rprt_v2_rx                               value:v2 Membership Reports Rx
		v3 Membership Reports Rx
			 key:<port_handle>.igmp.aggregate.rprt_v3_rx                               value:v3 Membership Reports Rx
		Leave Rx
			 key:<port_handle>.igmp.aggregate.leave_rx                                 value:Leave Rx
		Total Frames Tx
			 key:<port_handle>.igmp.aggregate.total_tx                                 value:Total Frames Tx
		Total Frames Rx
			 key:<port_handle>.igmp.aggregate.total_rx                                 value:Total Frames Rx
		General Queries Rx
			 key:<port_handle>.igmp.aggregate.gen_query_rx                             value:General Queries Rx
		Group Specific Queries Rx
			 key:<port_handle>.igmp.aggregate.grp_query_rx                             value:Group Specific Queries Rx
		Port Name
			 key:<port_handle>.igmp.aggregate.port_name                                value:Port Name
			 key:<port_handle>.igmp.aggregate.port_name                                value:
			 key:<port_handle>.igmp.aggregate.rprt_v1_tx                               value:
			 key:<port_handle>.igmp.aggregate.rprt_v1_rx                               value:
			 key:<port_handle>.igmp.aggregate.rprt_v2_tx                               value:
			 key:<port_handle>.igmp.aggregate.rprt_v2_rx                               value:
			 key:<port_handle>.igmp.aggregate.rprt_v3_tx                               value:
			 key:<port_handle>.igmp.aggregate.rprt_v3_rx                               value:
			 key:<port_handle>.igmp.aggregate.leave_v2_tx                              value:
			 key:<port_handle>.igmp.aggregate.total_tx                                 value:
			 key:<port_handle>.igmp.aggregate.total_rx                                 value:
			 key:<port_handle>.igmp.aggregate.invalid_rx                               value:
			 key:<port_handle>.igmp.aggregate.gen_query_rx                             value:
			 key:<port_handle>.igmp.aggregate.grp_query_rx                             value:
			 key:<port_handle>.igmp.querier.aggregate.port_name                        value:
			 key:<port_handle>.igmp.querier.aggregate.rprt_v1_rx                       value:
			 key:<port_handle>.igmp.querier.aggregate.rprt_v2_rx                       value:
			 key:<port_handle>.igmp.querier.aggregate.rprt_v3_rx                       value:
			 key:<port_handle>.igmp.querier.aggregate.gen_query_v1_tx                  value:
			 key:<port_handle>.igmp.querier.aggregate.gen_query_v2_tx                  value:
			 key:<port_handle>.igmp.querier.aggregate.gen_query_v3_tx                  value:
			 key:<port_handle>.igmp.querier.aggregate.grp_v2_query_tx                  value:
			 key:<port_handle>.igmp.querier.aggregate.grp_v3_query_tx                  value:
			 key:<port_handle>.igmp.querier.aggregate.grp_src_v3_query_tx              value:
			 key:<port_handle>.igmp.querier.aggregate.leave_rx                         value:
			 key:<port_handle>.igmp.querier.aggregate.total_tx                         value:
			 key:<port_handle>.igmp.querier.aggregate.total_rx                         value:
			 key:<port_handle>.igmp.querier.aggregate.invalid_rx                       value:
			 key:<port_handle>.igmp.querier.aggregate.gen_query_rx                     value:
			 key:<port_handle>.igmp.querier.aggregate.grp_query_rx                     value:
			 key:<port_handle>.<handle>.querier_version                                value:
			 key:<port_handle>.<handle>.querier_address                                value:
			 key:<port_handle>.<handle>.record.<no>.compatibility_mode                 value:
			 key:<port_handle>.<handle>.record.<no>.compatibility_timer                value:
			 key:<port_handle>.<handle>.record.<no>.filter_mode                        value:
			 key:<port_handle>.<handle>.record.<no>.group_adress                       value:
			 key:<port_handle>.<handle>.record.<no>.group_timer                        value:
			 key:<port_handle>.<handle>.record.<no>.source_address                     value:
			 key:<port_handle>.<handle>.record.<no>.source_timer                       value:
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_igmp_info", kwargs)

	def emulation_igmp_querier_config(self, **kwargs):
		""" This procedure is used to configure the IGMP Querier on a specified Ixia port.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_igmp_querier_config
			 	-mode                               CHOICES create
			                                     CHOICES modify
			                                     CHOICES delete
			                                     CHOICES disable
			                                     CHOICES enable
			x	[-atm_encapsulation                 ANY]
			x	[-count                             NUMERIC
			x                                    DEFAULT 1]
			x	[-discard_learned_info              CHOICES 0 1
			x                                    DEFAULT 1]
			x	[-active                            CHOICES 0 1
			x                                    DEFAULT 1]
			x	[-general_query_response_interval   RANGE 1-3174400
			x                                    DEFAULT 10000]
			x	[-handle                            ANY]
			x	[-igmp_version                      CHOICES v1 v2 v3
			x                                    DEFAULT v2]
			x	[-interface_handle                  ANY]
			x	[-intf_ip_addr                      IPV4]
			x	[-intf_ip_addr_step                 IPV4
			x                                    DEFAULT 0.0.0.1]
			x	[-intf_prefix_len                   RANGE 1-32
			x                                    DEFAULT 24]
			x	[-ip_router_alert                   CHOICES 0 1
			x                                    DEFAULT 1]
			x	[-mac_address_init                  MAC]
			x	[-mac_address_step                  MAC
			x                                    DEFAULT 0000.0000.0001]
			x	[-msg_count_per_interval            NUMERIC]
			x	[-msg_interval                      NUMERIC]
			x	[-neighbor_intf_ip_addr             IPV4]
			x	[-neighbor_intf_ip_addr_step        IPV4
			x                                    DEFAULT 0.0.0.0]
			x	[-no_write                          ANY]
			x	[-override_existence_check          CHOICES 0 1
			x                                    DEFAULT 0]
			x	[-override_tracking                 CHOICES 0 1
			x                                    DEFAULT 0]
			 	[-port_handle                       REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-reset                             FLAG]
			x	[-robustness_variable               RANGE 1-7
			x                                    DEFAULT 2]
			x	[-specific_query_response_interval  RANGE 1-3174400
			x                                    DEFAULT 1000]
			x	[-specific_query_transmission_count RANGE 1-255
			x                                    DEFAULT 2]
			x	[-startup_query_count               RANGE 1-255
			x                                    DEFAULT 2]
			x	[-support_election                  CHOICES 0 1
			x                                    DEFAULT 1]
			x	[-support_older_version_host        CHOICES 0 1
			x                                    DEFAULT 1]
			x	[-support_older_version_querier     CHOICES 0 1
			x                                    DEFAULT 1]
			x	[-vci                               ANY]
			x	[-vci_step                          ANY]
			x	[-vlan                              CHOICES 0 1
			x                                    DEFAULT 0]
			x	[-vlan_id                           RANGE 0-4095
			x                                    DEFAULT 1]
			x	[-vlan_id_mode                      CHOICES fixed increment
			x                                    DEFAULT increment]
			x	[-vlan_id_step                      RANGE 0-4096
			x                                    DEFAULT 1]
			x	[-vlan_user_priority                RANGE 0-7
			x                                    DEFAULT 0]
			x	[-vpi                               ANY]
			x	[-vpi_step                          ANY]
			x	[-query_interval                    RANGE 1-31744
			x                                    DEFAULT 125]
			x	[-no_of_queries_per_unit_time       NUMERIC
			x                                    DEFAULT 0]
			x	[-time_period                       NUMERIC
			x                                    DEFAULT 0]
			x	[-global_settings_enable            CHOICES 0 1]
			x	[-name                              ALPHA]
		
		Arguments:
			 	-mode
			 		This option defines the action to be taken.
			 		Valid choices are:
			    		create - Creates the IGMP querier router on the Ixia interface.
			    		modify - Modifies the IGMP querier router on the Ixia interface.
			    		delete - Deletes the IGMP querier router on the Ixia interface.
			    		disable - The IGMP querier router will be disabled.
			    		enable - Enables the IGMP querier router on the Ixia interface.
			x	-atm_encapsulation
			x		The encapsulation of the ATM protocol interface associated with the emulated router. Valid for mode create. Valid options are:
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		VccMuxIPV4Routed - Vcc Mux IPV4 Routed
			x   		VccMuxIPV6Routed - Vcc Mux IPV6 Routed
			x   		VccMuxBridgedEthernetFCS - Vcc Mux Bridged Ethernet FCS
			x   		VccMuxBridgedEthernetNoFCS - Vcc Mux Bridged Ethernet No FCS
			x   		LLCRoutedCLIP - LLC Routed CLIP
			x   		LLCBridgedEthernetFCS - LLC Bridged Ethernet FCS
			x   		LLCBridgedEthernetNoFCS - LLC Bridged Ethernet No FCS
			x	-count
			x		Defines the number of sessions to create on the interface. Valid for
			x		mode create.
			x	-discard_learned_info
			x		When -discard_learned_info is 0, the emulated Querier maintains a complete record state for received reports and send queries (based on timer expiry for received groups and sources).
			x		If -discard_learned_info is 1, the Querier does not maintain any database and only sends periodic general queries. The specific query group/source record information is not calculated based on any earlier received Report, but is based only on the last received report.
			x	-active
			x		Specifies whether the emulated IGMP Querier is active or not.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-general_query_response_interval
			x		General Query Response Interval in milliseconds
			x	-handle
			x		IGMP Host handle if the option -mode is delete, modify, disable, enable.
			x		When -handle is provided with the /globals value the arguments that configure global protocol
			x		setting accept both multivalue handles and simple values.
			x		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
			x		that configure global settings will only accept simple values. In this situation, these arguments will
			x		configure only the settings of the parent device group or the ports associated with the parent topology.
			x	-igmp_version
			x		The version of IGMP to be used: v1, v2, v3. Valid for mode create.
			x		Valid choices are:
			x   		v1 - version 1
			x   		v2 - version 2
			x   		v3 - version 3
			x	-interface_handle
			x		A handle or list of the handles that are returned from the interface_config call. These provide a direct link to an already existing interface and supercede the use of the intf_ip_addr value.
			x		Starting with IxNetwork 5.50 this parameter accepts handles returned by
			x		pppox_config procedure in the following format:
			x		(PPPoX Range Handle)|(interface index X),(interface index Y)-(interface index Z), ... 
			x		The PPPoX ranges are separated from the Interface Index identifiers with the (|) character.
			x		The Interface Index identifiers are separated with comas (,).
			x		A range of Interface Index identifiers can be defined using the dash (-) character. 
			x		 Ranges along with the Interface Index identifiers are grouped together in TCL Lists. The
			x		lists can contain mixed items, protocol interface handles returned by interface_config
			x		and handles returned by pppox_config along with the interface index. Valid for mode create. 
			x	-intf_ip_addr
			x		IP address of the test interface / emulated IGMP Host. Valid for mode create and modify.
			x	-intf_ip_addr_step
			x		The IP address step between each session. Valid for mode create and modify.
			x	-intf_prefix_len
			x		The netmask length value for the interface. Valid for mode create and modify.
			x	-ip_router_alert
			x		If true (1), enable IP Router Alert Option. Valid for mode create and modify.
			x	-mac_address_init
			x		The MAC address for the interface to be created. Valid for mode create and modify.
			x	-mac_address_step
			x		The incrementing step for the MAC address of the interface to be
			x		created. Valid only when using IxNetwork Tcl API. Valid for mode create and modify.
			x	-msg_count_per_interval
			x		The number of reports that an IGMP Querier sends out during the specified time period.
			x		This parameter is only applicable for IGMP Queriers.
			x	-msg_interval
			x		The time period (milliseconds) for sending out IGMP queries. This parameter is only applicable for IGMP Queriers.
			x	-neighbor_intf_ip_addr
			x		IP address of the neighbor.
			x	-neighbor_intf_ip_addr_step
			x		The IP address step between each session.
			x	-no_write
			x		If this option is present, the protocol configuration will not be written to the server.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-override_existence_check
			x		If this option is enabled, the interface existence check is skipped but
			x		the list of interfaces is still created and maintained in order to keep
			x		track of existing interfaces, if required. Using this option will speed
			x		up the creation of interfaces. Valid for mode create.
			x	-override_tracking
			x		If this option is enabled, the list of interfaces will not be created and
			x		maintained anymore, thus speeding up the creation of interfaces even
			x		more. Also, it will enable -override_existence_check in case it was not
			x		already enabled, because checking for interface existence becomes
			x		impossible if the the list of interfaces doesnt exist anymore. Valid for mode create.
			 	-port_handle
			 		The port on which the operation will apply.
			x	-reset
			x		Clear all existent hosts. Valid for mode create.
			x	-robustness_variable
			x		Defines the subnet vulnerability to lost packets. IGMP can recover from
			x		robustness variable minus 1 lost IGMP packets. The robustness variable
			x		should be set to a value of 2 or greater (7 being the maximum).
			x	-specific_query_response_interval
			x		The maximum amount of time in seconds that the IGMP Querier waits to receive
			x		a response to a Specific Query message. The default query response interval
			x		is 1000 milliseconds and must be less than the query interval. This parameter will be set
			x		(-mode create and -modify) only if discard_learned_info is not enabled.
			x	-specific_query_transmission_count
			x		Indicates the total number of specific Query messages sent every Specific
			x		Query Response Interval seconds before assuming that there is no interested
			x		listener for the particular group/source. This parameter will be set
			x		(-mode create and -modify) only if discard_learned_info is not enabled.
			x	-startup_query_count
			x		The number of general query messages sent at startup.
			x	-support_election
			x		Indicates whether or not the Querier participates in querier election.
			x		If disabled, then all incoming query messages are discarded.
			x	-support_older_version_host
			x		Indicates whether the Querier will comply to RFC 3376 Section 7.3.2 and
			x		RFC 3810 Section 8.3.2. If disabled, all membership reports with a version
			x		less than the current version are discarded.
			x	-support_older_version_querier
			x		Indicates whether the Querier downgrades to the lowest version of received
			x		query messages. If disabled, all query messages with a version less than
			x		the current version are discarded.
			x	-vci
			x		VCI for emulated router node. Valid for mode create.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vci_step
			x		The step value used for incrementing the -vci option. Valid for mode create.
			x		When vci_step causes the vci value to exceed it's maximum value the increment will be done modulo <number of possible vci ids>. Examples: 
			x		
			x		
			x		- vci = 65534; vci_step = 2-> new vci value = 0 
			x		- vci = 65535; vci_step = 11 -> new vci value = 10 
			x		
			x		
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vlan
			x		Enables vlan on the directly connected IGMP router interface.
			x		Valid options are: 0 - disable, 1 - enable.
			x		This option is valid only when -mode is create or -mode is modify
			x		and -handle is an IGMP router handle.
			x		This option is available only when IxNetwork tcl API is used.
			x	-vlan_id
			x		VLAN ID for emulated router node. Valid for mode create and modify.
			x	-vlan_id_mode
			x		For multiple neighbor configuration, configures the VLAN ID mode to
			x		fixed or increment. Valid for mode create and modify.
			x	-vlan_id_step
			x		When -vlan_id_mode is set to increment, this defines the step for
			x		every VLAN. Valid for mode create.
			x		When vlan_id_step causes the vlan_id value to exceed it's maximum value the
			x		increment will be done modulo (number of possible vlan ids).
			x		Examples: 
			x		
			x		
			x		- vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0 
			x		- vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10 
			x		
			x		
			x	-vlan_user_priority
			x		VLAN user priority assigned to emulated router node. Valid for mode create and modfiy.
			x	-vpi
			x		VPI for emulated router node. Valid for mode create.
			x		When vpi_step causes the vpi value to exceed it's maximum value the increment will be done modulo <number of possible vpi ids>.
			x		Examples: 
			x		
			x		
			x		- vpi = 254; vpi_step = 2-> new vpi value = 0 
			x		- vpi = 255; vpi_step = 11 -> new vpi value = 10 
			x		
			x		
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vpi_step
			x		The step value used for incrementing the -vpi option. Valid for mode create.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-query_interval
			x		Represents the general query response interval in ms
			x	-no_of_queries_per_unit_time
			x		The number of reports that an IGMP Querier sends out during the specified time period. This parameter is only applicable for IGMP Queriers.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-time_period
			x		The time period (milliseconds) for sending out IGMP queries. This parameter is only applicable for IGMP Queriers.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-global_settings_enable
			x		Enable/Disable Rate Control
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-name
			x		Name of the igmp protocol as it should appear in the IxNetwork GUI
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		A list containing the igmp querier protocol stack handles that were added by the command (if any).
			xkey:igmp_querier_handle   value:A list containing the igmp querier protocol stack handles that were added by the command (if any).
		A list containing the ethernet protocol stack handles that were added by the command (if any).
			xkey:ethernet_handle       value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		A list containing the ipv4 protocol stack handles that were added by the command (if any).
			xkey:ipv4_handle           value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		A list containing the dhcpv4 client protocol stack handles that were added by the command (if any).
			xkey:dhcpv4_client_handle  value:A list containing the dhcpv4 client protocol stack handles that were added by the command (if any).
		A list containing the pppox client protocol stack handles that were added by the command (if any).
			xkey:pppox_client_handle   value:A list containing the pppox client protocol stack handles that were added by the command (if any).
		A list containing the pppox server protocol stack handles that were added by the command (if any).
			xkey:pppox_server_handle   value:A list containing the pppox server protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:igmp_querier_handles  value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:interface_handle      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		$::SUCCESS | $::FAILURE
			 key:status                value:$::SUCCESS | $::FAILURE
		The handles for the IGMP Querier created
			 key:handle                value:The handles for the IGMP Querier created
		If status is failure, detailed information provided.
			 key:log                   value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		When -handle is provided with the /globals value the arguments that configure global protocol
		setting accept both multivalue handles and simple values.
		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
		that configure global settings will only accept simple values. In this situation, these arguments will
		configure only the settings of the parent device group or the ports associated with the parent topology.
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  igmp_querier_handles, interface_handle
		
		See Also:
		
		"""
		return self._run_keyword("emulation_igmp_querier_config", kwargs)

	def emulation_isis_config(self, **kwargs):
		""" This procedure is used to create,modify and delete ISIS routers on an Ixia interface. The user can create a single or multiple ISIS routers. These routers can be either L1, L2, or L1L2.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_isis_config
			 	-mode                                    CHOICES create
			                                          CHOICES modify
			                                          CHOICES delete
			                                          CHOICES disable
			                                          CHOICES enable
			 	-handle                                  ANY]
			x	[-send_p2p_hellos_to_unicast_mac         CHOICES 0 1]
			x	[-rate_control_interval                  NUMERIC]
			x	[-no_of_lsps_or_mgroup_pdus_per_interval NUMERIC]
			x	[-start_rate_scale_mode                  CHOICES port device_group
			x                                         DEFAULT port]
			x	[-start_rate_enabled                     CHOICES 0 1]
			x	[-start_rate_interval                    NUMERIC]
			x	[-start_rate                             ANY]
			x	[-stop_rate_scale_mode                   CHOICES port device_group
			x                                         DEFAULT port]
			x	[-stop_rate_enabled                      CHOICES 0 1]
			x	[-stop_rate_interval                     NUMERIC]
			x	[-stop_rate                              ANY]
			x	[-sr_draft_extension                     CHOICES extension3 extension10]
			x	[-srms_preference_sub_tlv_type           NUMERIC]
			x	[-srlb_sub_tlv_type                      NUMERIC]
			x	[-fa_app_spec_link_attr_sub_tlv_type     NUMERIC]
			x	[-fa_fad_sub_tlv_type                    NUMERIC]
			x	[-fa_eag_sub_tlv_type                    NUMERIC]
			x	[-fa_fai_any_sub_tlv_type                NUMERIC]
			x	[-fa_fai_all_sub_tlv_type                NUMERIC]
			x	[-fa_fadf_sub_tlv_type                   NUMERIC]
			x	[-if_active                              CHOICES 0 1]
			 	[-discard_lsp                            CHOICES 0 1]
			 	[-system_id                              HEX8WITHSPACES]
			x	[-system_id_step                         HEX8WITHSPACES
			x                                         DEFAULT 00:00:00:00:00:01]
			 	[-te_enable                              CHOICES 0 1]
			 	[-te_router_id                           IP]
			x	[-te_router_id_step                      IP
			x                                         DEFAULT 0.0.0.1]
			x	[-enable_ipv6_te                         CHOICES 0 1]
			x	[-ipv6_te_router_id                      IPV6]
			x	[-enable_host_name                       CHOICES 0 1]
			x	[-host_name                              REGEXP ^[0-9,a-f,A-F]+$]
			 	[-wide_metrics                           CHOICES 0 1
			                                          DEFAULT 0]
			x	[-protocol_name                          ALPHA]
			x	[-active                                 CHOICES 0 1]
			 	[-intf_metric                            RANGE 0-16777215]
			x	[-enable_configured_hold_time            CHOICES 0 1]
			x	[-configured_hold_time                   NUMERIC]
			x	[-ipv6_mt_metric                         NUMERIC]
			x	[-intf_type                              CHOICES broadcast ptop]
			x	[-enable3_way_handshake                  CHOICES 0 1]
			x	[-extended_local_circuit_id              NUMERIC]
			n	[-level_type                             ANY]
			x	[-routing_level                          CHOICES L1 L2 L1L2]
			 	[-l1_router_priority                     RANGE 0-127]
			 	[-l2_router_priority                     RANGE 0-255]
			 	[-hello_interval                         RANGE 1-65535]
			x	[-hello_interval_level1                  RANGE 1-65535]
			x	[-level1_dead_interval                   NUMERIC]
			x	[-hello_interval_level2                  RANGE 1-65535]
			x	[-level2_dead_interval                   NUMERIC]
			x	[-bfd_registration                       CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-suppress_hello                         CHOICES 0 1]
			x	[-enable_mt_ipv6                         CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-hello_padding                          CHOICES 0 1]
			x	[-max_area_addresses                     NUMERIC]
			 	[-area_id                                ANY
			                                          DEFAULT 49 00 01]
			x	[-area_id_step                           ANY
			x                                         DEFAULT 00 00 00]
			 	[-graceful_restart                       CHOICES 0 1]
			 	[-graceful_restart_mode                  CHOICES normal
			                                          CHOICES restarting
			                                          CHOICES starting
			                                          CHOICES helper]
			x	[-graceful_restart_version               CHOICES draft3 draft4]
			 	[-graceful_restart_restart_time          ANY]
			 	[-attach_bit                             CHOICES 0 1]
			 	[-partition_repair                       CHOICES 0 1]
			 	[-overloaded                             CHOICES 0 1]
			x	[-override_existence_check               ANY]
			x	[-override_tracking                      ANY]
			 	[-lsp_refresh_interval                   RANGE 1-65535]
			 	[-lsp_life_time                          RANGE 0-65535]
			x	[-psnp_interval                          NUMERIC]
			x	[-csnp_interval                          NUMERIC]
			 	[-max_packet_size                        RANGE 576-32832]
			x	[-pdu_min_tx_interval                    NUMERIC]
			x	[-auto_adjust_mtu                        CHOICES 0 1]
			x	[-auto_adjust_area                       CHOICES 0 1]
			x	[-auto_adjust_supported_protocols        CHOICES 0 1]
			x	[-ignore_receive_md5                     CHOICES 0 1]
			 	[-area_authentication_mode               CHOICES null text md5]
			 	[-area_password                          ALPHA]
			 	[-domain_authentication_mode             CHOICES null text md5]
			 	[-domain_password                        ALPHA]
			x	[-auth_type                              CHOICES none password md5]
			 	[-circuit_tranmit_password_md5_key       ANY]
			x	[-pdu_per_burst                          NUMERIC]
			x	[-pdu_burst_gap                          ANY]
			x	[-enable_sr                              CHOICES 0 1
			x                                         DEFAULT 0]
			 	[-router_id                              IPV4
			                                          DEFAULT 1.1.1.1]
			x	[-node_prefix                            IPV4
			x                                         DEFAULT 1.1.1.1]
			x	[-mask                                   RANGE 1-32
			x                                         DEFAULT 32]
			x	[-d_bit                                  CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-s_bit                                  CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-redistribution                         CHOICES up down
			x                                         DEFAULT up]
			x	[-r_flag                                 CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-n_flag                                 CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-p_flag                                 CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-e_flag                                 CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-v_flag                                 CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-l_flag                                 CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-ipv4_flag                              CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-ipv6_flag                              CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-configure_sid_index_label              CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-sid_index_label                        NUMERIC
			x                                         DEFAULT 0]
			x	[-algorithm                              RANGE 0-255
			x                                         DEFAULT 0]
			x	[-srgb_range_count                       RANGE 1-5
			x                                         DEFAULT 1]
			x	[-start_sid_label                        RANGE 1-1048575
			x                                         DEFAULT 16000]
			x	[-sid_count                              RANGE 1-1048575
			x                                         DEFAULT 8000]
			x	[-interface_enable_adj_sid               CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-interface_adj_sid                      RANGE 1-1048575
			x                                         DEFAULT 9001]
			x	[-interface_override_f_flag              CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-interface_f_flag                       CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-interface_b_flag                       CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-interface_v_flag                       CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-interface_l_flag                       CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-interface_s_flag                       CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-interface_p_flag                       CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-interface_weight                       RANGE 0-255
			x                                         DEFAULT 0]
			x	[-sr_tunnel_active                       CHOICES 0 1]
			x	[-number_of_sr_tunnels                   RANGE 0-1000
			x                                         DEFAULT 0]
			x	[-sr_tunnel_description                  REGEXP ^[0-9,a-f,A-F]+$]
			x	[-using_head_end_node_prefix             CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-source_ipv4                            IPV4
			x                                         DEFAULT 100.0.0.1]
			x	[-source_ipv6                            IPV6
			x                                         DEFAULT 1000::1]
			x	[-number_of_segments                     RANGE 1-20
			x                                         DEFAULT 1]
			x	[-enable_segment                         CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-segment_type                           CHOICES node link
			x                                         DEFAULT node]
			x	[-node_system_id                         HEX8WITHSPACES]
			x	[-neighbour_node_system_id               HEX8WITHSPACES]
			x	[-ipv6_srh_flag_emulated_router          CHOICES 0 1]
			x	[-interface_enable_app_spec_srlg         RANGE 0-10
			x                                         CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-no_of_app_spec_srlg                    RANGE 0-10
			x                                         DEFAULT 0]
			x	[-app_spec_srlg_l_flag                   CHOICES 0 1]
			x	[-app_spec_srlg_std_app_type             ALPHA]
			x	[-app_spec_srlg_usr_def_app_bm_len       RANGE 1-127
			x                                         DEFAULT 1]
			x	[-app_spec_srlg_usr_def_ap_bm            HEX]
			x	[-app_spec_srlg_ipv4_interface_Addr      CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-app_spec_srlg_ipv4_neighbor_Addr       CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-app_spec_srlg_ipv6_interface_Addr      CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-app_spec_srlg_ipv6_neighbor_Addr       CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-interface_enable_srlg                  CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-srlg_value                             NUMERIC]
			x	[-srlg_count                             RANGE 1-5
			x                                         DEFAULT 1]
			x	[-flex_algo_count                        RANGE 0-128
			x                                         DEFAULT 0]
			x	[-flex_algo                              RANGE 0-255
			x                                         DEFAULT 128]
			x	[-fa_metric_type                         NUMERIC]
			x	[-fa_calc_type                           RANGE 0-127
			x                                         DEFAULT 0]
			x	[-fa_priority                            RANGE 0-255
			x                                         DEFAULT 0]
			x	[-fa_enable_exclude_ag                   CHOICES 0 1]
			x	[-fa_exclude_ag_ext_ag_len               RANGE 1-10
			x                                         DEFAULT 1]
			x	[-fa_exclude_ag_ext_ag                   HEX]
			x	[-fa_enable_include_any_ag               CHOICES 0 1]
			x	[-fa_include_any_ag_ext_ag_len           RANGE 1-10
			x                                         DEFAULT 1]
			x	[-fa_include_any_ag_ext_ag               HEX]
			x	[-fa_enable_include_all_ag               CHOICES 0 1]
			x	[-fa_include_all_ag_ext_ag_len           RANGE 1-10
			x                                         DEFAULT 1]
			x	[-fa_include_all_ag_ext_ag               HEX]
			x	[-fa_enable_fadf_tlv                     CHOICES 0 1]
			x	[-fa_fadf_len                            RANGE 1-4
			x                                         DEFAULT 1]
			x	[-fa_fadf_m_flag                         CHOICES 0 1]
			x	[-fa_fsdf_rsrvd                          HEX]
			x	[-fa_dont_adv_in_sr_algo                 CHOICES 0 1]
			x	[-fa_adv_twice_excl_ag                   CHOICES 0 1]
			x	[-fa_adv_twice_incl_any_ag               CHOICES 0 1]
			x	[-fa_adv_twice_incl_all_ag               CHOICES 0 1]
			x	[-s_r_algorithm_count                    RANGE 1-5
			x                                         DEFAULT 1]
			x	[-isis_sr_algorithm                      NUMERIC]
			x	[-advertise_srlb                         CHOICES 0 1]
			x	[-srlb_flags                             HEX]
			x	[-srlb_descriptor_count                  RANGE 1-5
			x                                         DEFAULT 1]
			x	[-srlbDescriptor_startSidLabel           RANGE 1-1048575
			x                                         DEFAULT 16000]
			x	[-srlbDescriptor_sidCount                RANGE 1-1048575
			x                                         DEFAULT 8000]
			x	[-enable_link_protection                 CHOICES 0 1]
			x	[-extra_traffic                          CHOICES 0 1]
			x	[-unprotected                            CHOICES 0 1]
			x	[-shared                                 CHOICES 0 1]
			x	[-dedicated_one_to_one                   CHOICES 0 1]
			x	[-dedicated_one_plus_one                 CHOICES 0 1]
			x	[-enhanced                               CHOICES 0 1]
			x	[-reserved0x40                           CHOICES 0 1]
			x	[-reserved0x80                           CHOICES 0 1]
			x	[-no_of_te_profiles                      RANGE 0-10]
			x	[-traffic_engineering_name               ALPHA]
			 	[-te_admin_group                         HEX]
			 	[-te_metric                              NUMERIC]
			 	[-te_max_bw                              REGEXP ^[0-9]+]
			 	[-te_max_resv_bw                         REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority0                 REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority1                 REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority2                 REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority3                 REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority4                 REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority5                 REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority6                 REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority7                 REGEXP ^[0-9]+$]
			x	[-te_adv_ext_admin_group                 CHOICES 0 1]
			 	[-te_ext_admin_group_len                 NUMERIC]
			x	[-te_ext_admin_group                     HEX]
			x	[-te_adv_uni_dir_link_delay              CHOICES 0 1]
			x	[-te_uni_dir_link_delay_a_bit            CHOICES 0 1]
			 	[-te_uni_dir_link_delay                  NUMERIC]
			x	[-te_adv_min_max_unidir_link_delay       CHOICES 0 1]
			x	[-te_min_max_unidir_link_delay_a_bit     CHOICES 0 1]
			 	[-te_uni_dir_min_link_delay              NUMERIC]
			 	[-te_uni_dir_max_link_delay              NUMERIC]
			x	[-te_adv_unidir_delay_variation          CHOICES 0 1]
			 	[-te_uni_dir_link_delay_variation        NUMERIC]
			x	[-te_adv_unidir_link_loss                CHOICES 0 1]
			x	[-te_unidir_link_loss_a_bit              CHOICES 0 1]
			 	[-te_uni_dir_link_loss                   NUMERIC]
			x	[-te_adv_unidir_residual_bw              CHOICES 0 1]
			 	[-te_uni_dir_residual_bw                 NUMERIC]
			x	[-te_adv_unidir_available_bw             CHOICES 0 1]
			 	[-te_uni_dir_available_bw                NUMERIC]
			x	[-te_adv_unidir_utilized_bw              CHOICES 0 1]
			 	[-te_uni_dir_utilized_bw                 NUMERIC]
			x	[-te_mt_applicability_for_ipv6           CHOICES usesamete specifymtid
			x                                         DEFAULT usesamete]
			 	[-te_mt_id                               NUMERIC]
			x	[-te_adv_app_spec_traffic                CHOICES 0 1]
			x	[-te_app_spec_std_app_type               ALPHA]
			x	[-te_app_spec_l_flag                     CHOICES 0 1]
			x	[-te_app_spec_usr_def_app_bm_len         RANGE 1-127
			x                                         DEFAULT 1]
			x	[-te_app_spec_usr_def_ap_bm              HEX]
			 	[-port_handle                            ANY]
			x	[-atm_encapsulation                      ANY]
			 	[-count                                  ANY
			                                          DEFAULT 1]
			x	[-dce_capability_router_id               ANY]
			x	[-dce_bcast_root_priority                ANY]
			x	[-dce_num_mcast_dst_trees                ANY]
			x	[-dce_device_id                          ANY]
			x	[-dce_device_pri                         ANY]
			x	[-dce_ftag_enable                        ANY]
			x	[-dce_ftag                               ANY]
			 	[-gateway_ip_addr                        IPV4
			                                          DEFAULT 0.0.0.0]
			 	[-gateway_ip_addr_step                   IPV4
			                                          DEFAULT 0.0.1.0]
			 	[-gateway_ipv6_addr                      IPV6
			                                          DEFAULT 0::0]
			 	[-gateway_ipv6_addr_step                 IPV6
			                                          DEFAULT 0:0:0:1::0]
			 	[-hello_password                         ANY]
			 	[-interface_handle                       ANY]
			 	[-intf_ip_addr                           IPV4
			                                          DEFAULT 178.0.0.1]
			x	[-intf_ip_prefix_length                  RANGE 1-32
			x                                         DEFAULT 24]
			 	[-intf_ip_addr_step                      IPV4
			                                          DEFAULT 0.0.1.0]
			 	[-intf_ipv6_addr                         IPV6
			                                          DEFAULT 4000::1]
			 	[-intf_ipv6_prefix_length                RANGE 1-128
			                                          DEFAULT 64]
			 	[-intf_ipv6_addr_step                    IPV6
			                                          DEFAULT 0:0:0:1::0]
			 	[-ip_version                             ANY]
			x	[-loopback_bfd_registration              ANY]
			x	[-loopback_ip_addr                       ANY]
			x	[-loopback_ip_addr_step                  ANY]
			x	[-loopback_ip_prefix_length              ANY]
			x	[-loopback_ip_addr_count                 ANY]
			x	[-loopback_metric                        ANY]
			x	[-loopback_type                          ANY]
			x	[-loopback_routing_level                 ANY]
			x	[-loopback_l1_router_priority            ANY]
			x	[-loopback_l2_router_priority            ANY]
			x	[-loopback_te_metric                     ANY]
			x	[-loopback_te_admin_group                ANY]
			x	[-loopback_te_max_bw                     ANY]
			x	[-loopback_te_max_resv_bw                ANY]
			x	[-loopback_te_unresv_bw_priority0        ANY]
			x	[-loopback_te_unresv_bw_priority1        ANY]
			x	[-loopback_te_unresv_bw_priority2        ANY]
			x	[-loopback_te_unresv_bw_priority3        ANY]
			x	[-loopback_te_unresv_bw_priority4        ANY]
			x	[-loopback_te_unresv_bw_priority5        ANY]
			x	[-loopback_te_unresv_bw_priority6        ANY]
			x	[-loopback_te_unresv_bw_priority7        ANY]
			x	[-loopback_hello_password                ANY]
			 	[-mac_address_init                       MAC]
			x	[-mac_address_step                       MAC
			x                                         DEFAULT 0000.0000.0001]
			x	[-no_write                               ANY]
			x	[-reset                                  FLAG]
			x	[-type                                   ANY]
			x	[-vlan                                   CHOICES 0 1]
			 	[-vlan_id                                RANGE 0-4095]
			 	[-vlan_id_mode                           CHOICES fixed increment
			                                          DEFAULT increment]
			 	[-vlan_id_step                           RANGE 0-4096
			                                          DEFAULT 1]
			 	[-vlan_user_priority                     RANGE 0-7
			                                          DEFAULT 0]
			 	[-vpi                                    ANY]
			 	[-vci                                    ANY]
			 	[-vpi_step                               ANY]
			 	[-vci_step                               ANY]
			n	[-router_id_step                         ANY]
			n	[-vlan_cfi                               ANY]
			x	[-return_detailed_handles                CHOICES 0 1
			x                                         DEFAULT 0]
			 	[-multi_topology                         ANY]
		
		Arguments:
			 	-mode
			    		create - Creates the ISIS router on the Ixia interface.
			    		modify - Modifies the ISIS router on the Ixia interface.
			    		delete - Deletes the ISIS router on the Ixia interface.
			    		disable - The ISIS router will be disabled.
			    		enable - Enables the ISIS router on the Ixia interface.
			 	-handle
			 		ISIS session handle for using the modes delete, modify, enable and disable.
			 		When -handle is provided with the /globals value the arguments that configure global protocol
			 		setting accept both multivalue handles and simple values.
			 		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
			 		that configure global settings will only accept simple values. In this situation, these arguments will
			 		configure only the settings of the parent device group or the ports associated with the parent topology.
			x	-send_p2p_hellos_to_unicast_mac
			x		Send P2P Hellos To Unicast MAC
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-rate_control_interval
			x		Rate Control Interval (ms)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-no_of_lsps_or_mgroup_pdus_per_interval
			x		LSPs/MGROUP-PDUs per Interval
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-start_rate_scale_mode
			x		Indicates whether the control is specified per port or per device group
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		port -
			x   		device_group -
			x	-start_rate_enabled
			x		Enabled
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-start_rate_interval
			x		Time interval used to calculate the rate for triggering an action (rate = count/interval)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-start_rate
			x		Number of times an action is triggered per time interval
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-stop_rate_scale_mode
			x		Indicates whether the control is specified per port or per device group
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		port -
			x   		device_group -
			x	-stop_rate_enabled
			x		Enabled
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-stop_rate_interval
			x		Time interval used to calculate the rate for triggering an action (rate = count/interval)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-stop_rate
			x		Number of times an action is triggered per time interval
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-sr_draft_extension
			x		This specifies the segment routing draft extension
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		extension3 -
			x   		extension10 -
			x	-srms_preference_sub_tlv_type
			x		This specifies the type of SRMS Preference sub tlv, suggested value is 23.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srlb_sub_tlv_type
			x		This specifies the type of Segment Routing Local Block sub tlv, suggested value is 22.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_app_spec_link_attr_sub_tlv_type
			x		App Specific Link Attr Sub-TLV Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_fad_sub_tlv_type
			x		FAD Sub-TLV Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_eag_sub_tlv_type
			x		FAEAG Sub-TLV Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_fai_any_sub_tlv_type
			x		FAIAnyAG Sub-TLV Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_fai_all_sub_tlv_type
			x		FAIAllAG Sub-TLV Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_fadf_sub_tlv_type
			x		FADF Sub-TLV Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-if_active
			x		Flag.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-discard_lsp
			 		If 1, discards all LSPs coming from the neighbor which helps
			 		scalability.
			 	-system_id
			 		A system ID is typically 6-octet long.
			x	-system_id_step
			x		If -count > 1, this value is used to increment the system_id.
			 	-te_enable
			 		If true (1), enable traffic engineering extension. If this field is
			 		set to true (1) then wide_metrics field gets set to true (1)
			 		irrespective of the ip_version value. This behavior is for
			 		IxTclProtocol and IxTclNetwork
			 	-te_router_id
			 		The ID of the TE router, usually the lowest IP address on the router.
			x	-te_router_id_step
			x		The increment used for -te_router_id option.
			x	-enable_ipv6_te
			x		This enables the Traffic Engineering Profiles Isis IPv6
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_te_router_id
			x		The ID of the IPv6 TE router, usually the lowest IP address on the router.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_host_name
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-host_name
			x		Host Name
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-wide_metrics
			 		If true (1), enable wide style metrics. If te_enable is true then
			 		wide_metrics also gets set to true (1) irrespective of the
			 		ip_version value and cannot be modified to false. This is the
			 		behavior in IxTclProtocol and IxTclNetwork.
			 		(DEFAULT 0)
			x	-protocol_name
			x		Protocol name
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-active
			x		Flag.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-intf_metric
			 		The cost metric associated with the route.Valid range is 0-16777215.
			x	-enable_configured_hold_time
			x		Enable Configured Hold Time
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-configured_hold_time
			x		Configured Hold Time
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_mt_metric
			x		IPv6 MT Metric
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-intf_type
			x		Indicates the type of network attached to the interface: broadcast or
			x		ptop.
			x		Valid choices are:
			x   		broadcast -
			x   		ptop -
			x	-enable3_way_handshake
			x		Enable 3-way Handshake
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-extended_local_circuit_id
			x		Extended Local Circuit Id
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			n	-level_type
			x	-routing_level
			x   		Selects the supported routing level.
			x   		Valid choices are:
			x       		L1 - L1 only
			x       		L2 - L2 only
			x       		L1L2 - L1 and L2
			 	-l1_router_priority
			    		The session routers priority number for L1 DR role.
			 	-l2_router_priority
			    		The session routers priority number for L2 DR role.
			 	-hello_interval
			    		The frequency of transmitting L1/L2 Hello PDUs.
			x	-hello_interval_level1
			x   		The frequency of transmitting L1 Hello PDUs.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-level1_dead_interval
			x   		Level 1 Dead Interval (sec)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-hello_interval_level2
			x   		The frequency of transmitting L2 Hello PDUs.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-level2_dead_interval
			x   		Level 2 Dead Interval (sec)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-bfd_registration
			x   		Enable or disable BFD registration.
			x	-suppress_hello
			x   		Hello suppression
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_mt_ipv6
			x   		If true (1), it enables multi-topology (MT) support. If ip_version
			x   		is set to 4_6, this field (if not provided by user) gets enabled
			x   		(set to true (1)) by default.
			x   		(DEFAULT 0)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-hello_padding
			x   		Enable Hello Padding
			x	-max_area_addresses
			x   		Maximum Area Addresses
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-area_id
			    		The area address to be used for the ISIS router. A valid value for this parameter
			    		is represented by a list of octets written in hexadecimal.
			    		Example: "3F 22 11", "23", "44 55 FA"
			x	-area_id_step
			x   		The step value used for incrementing the -area_id option.A valid value for this parameter
			x   		is represented by a list of octets written in hexadecimal.
			x   		Example: "3F 22 11", "23", "44 55 FA"
			 	-graceful_restart
			    		If true (1), enable Graceful Restart (NSF) feature on the session
			    		router.
			 	-graceful_restart_mode
			        		normal - (default) The router operates as a normal router.
			        		restarting - The router simulates a restarting router.It sends an
IIH containing a Restart TLV with the RR bit set to the neighbor routers.
			        		starting - The router simulates a starting router.It sends an IIH
containing a Restart TLV with SA bit set to the neighbor routers.
			        		helper - The router acts as the helper for the DUT that is restarting.It acknowledges the Restart TLV sent by the
DUT by sending an IIH containing a Restart TLV with the RA bit set
			x	-graceful_restart_version
			x   		Specify which draft to use: draft3 draft4.
			x   		Valid choices are:
			x       		draft3 -
			x       		draft4 -
			 	-graceful_restart_restart_time
			    		Theamount of time that the router will wait for restart completion.
			 	-attach_bit
			    		For L2 only.If 1, indicates that the AttachedFlag is set.
			    		This indicates that this ISIS router can use L2 routing to reach
			    		other areas.
			 	-partition_repair
			    		If 1, enables the optional partition repair option specified in
			    		ISO/IEC 10589 and RFC 1195 for Level 1 areas.
			 	-overloaded
			    		If 1, the LSP database overload bit is set, indicating that the LSP
			    		database on this router does not have enough memory to store a
			    		received LSP.
			x	-override_existence_check
			x   		If this option is enabled, the interface existence check is skipped but the list of interfaces is still created and maintained in order to keep track of existing interfaces if required. Using this option will speed up the interfaces' creation.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-override_tracking
			x   		If this option is enabled, the list of interfaces won't be created and maintained anymore, thus, speeding up the interfaces' creation even more. Also, it will enable -override_existence_check in case it wasn't already enabled because checking for interface existence becomes impossible if the the list of interfaces doesn't exist anymore.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-lsp_refresh_interval
			    		The rate at which LSPs are resent.Unit is in seconds.
			 	-lsp_life_time
			    		The maximum age in seconds for retaining a learned LSP.
			x	-psnp_interval
			x   		PSNP Interval (ms)
			x	-csnp_interval
			x   		CSNP Interval (ms)
			 	-max_packet_size
			    		The maximum IS-IS packet size that will be transmitted.Hello packets
			    		are also padded to the size.Valid range is 576-32832.
			x	-pdu_min_tx_interval
			x   		LSP/MGROUP-PDU Min Transmission Interval (ms)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-auto_adjust_mtu
			x   		Auto Adjust MTU
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-auto_adjust_area
			x   		Auto Adjust Area
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-auto_adjust_supported_protocols
			x   		Auto Adjust Supported Protocols
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ignore_receive_md5
			x   		Ignore Receive MD5
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-area_authentication_mode
			    		Specifies the area authentication mode.Choices are null, text and
			    		md5.
			    		Valid choices are:
			        		null -
			        		text -
			        		md5 -
			 	-area_password
			    		The password used in simple text authentication mode.This is used by
			    		L1 routing.
			 	-domain_authentication_mode
			    		Specifies the domain authentication mode.Choices are null, text and
			    		md5.
			    		Valid choices are:
			        		null -
			        		text -
			        		md5 -
			 	-domain_password
			    		The password used in simple text authentication mode.This is used by
			    		L2 routing.
			x	-auth_type
			x   		Authentication Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		none -
			x       		password -
			x       		md5 -
			 	-circuit_tranmit_password_md5_key
			    		area/domain password.
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-pdu_per_burst
			x   		Max LSPs/MGROUP-PDUs Per Burst
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pdu_burst_gap
			x   		Inter LSPs/MGROUP-PDUs Burst Gap (ms)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_sr
			x   		Enables SR to run on top of ISIS
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-router_id
			    		Router capability identifier
			x	-node_prefix
			x   		Used to uniquely identify the ISIS-L3 SR router
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-mask
			x   		Mask for the node prefix
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-d_bit
			x   		When the ISIS router capability TLV is leaked from level-2 to level-1, the D bit must be set, otherwise this bit must be clear
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-s_bit
			x   		If the S bit is set 1, the ISIS router capability TLV must be flooded across the entire routing domain, otherwise the TLV must not be leaked between levels
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-redistribution
			x   		It can have any of the two choices- UP or DOWN
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		up -
			x       		down -
			x	-r_flag
			x   		Readvertisement flag
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-n_flag
			x   		Node SID flag
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p_flag
			x   		PHP (penultimate hop popping) flag
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-e_flag
			x   		If the E-flag is set then any upstream neighbor of the Prefix- SID originator MUST replace the PrefixSID with a Prefix-SID having an Explicit-NULL value
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-v_flag
			x   		Value flag
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-l_flag
			x   		L flag of ISIS-L3 router
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_flag
			x   		If set, then the router is capable of outgoing IPv4 encapsulation on all interfaces
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_flag
			x   		If set, then the router is capable of outgoing IPv6 encapsulation on all interfaces
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-configure_sid_index_label
			x   		If enabled, then the nodal SID will not be taken from the SRGB range, rather it will be the value of SID index label
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-sid_index_label
			x   		This is the value which will be used to set the nodal SID of the ISIS-L3 SR enabled router if configure sid index label option has been enabled
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-algorithm
			x   		This specifies the algorithm e.g. SPF
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srgb_range_count
			x   		How many ranges the user wants to create in the SRGB range. Max is 5
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-start_sid_label
			x   		Start SID in one SRGB range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-sid_count
			x   		Total count of SIDs in that SRGB range
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_enable_adj_sid
			x   		Enables adjacent SID for SR enabled ISIS-L3 interface
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_adj_sid
			x   		Adjacent SID for SR enabled ISIS-L3 interface
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_override_f_flag
			x   		Override F flag option for SR enabled ISIS-L3 interface
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_f_flag
			x   		F flag for SR enabled ISIS-L3 interface
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_b_flag
			x   		B flag for SR enabled ISIS-L3 interface
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_v_flag
			x   		Value flag for SR enabled ISIS-L3 interface
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_l_flag
			x   		L flag for SR enabled ISIS-L3 interface
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_s_flag
			x   		S flag for SR enabled ISIS-L3 interface
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_p_flag
			x   		P flag for SR enabled ISIS-L3 interface
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_weight
			x   		Weight value of the adjacent link for SR enabled ISIS-L3 interface
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-sr_tunnel_active
			x   		Active/Inactive SR Tunnel
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-number_of_sr_tunnels
			x   		Number of ISIS SR Tunnels
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-sr_tunnel_description
			x   		ISIS SR Tunnel Description
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-using_head_end_node_prefix
			x   		ISIS SR Tunnel Using head end Node prefix
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-source_ipv4
			x   		ISIS SR Tunnel Source IPv4
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-source_ipv6
			x   		ISIS SR Tunnel Source IPv4
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-number_of_segments
			x   		ISIS SR Tunnel - Number of Segments
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_segment
			x   		ISIS SR Tunnel - Enable each segment
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-segment_type
			x   		ISIS SR Tunnel Segment type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		node - ISIS SR Tunnel Segment type - Node
			x       		link - ISIS SR Tunnel Segment type - Link
			x	-node_system_id
			x   		ISIS SR Tunnel Node System ID
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-neighbour_node_system_id
			x   		1
			x   		ISIS SR Tunnel Neighbour Node System ID
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_srh_flag_emulated_router
			x   		Router will advertise and process IPv6 SR related TLVs
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_enable_app_spec_srlg
			x   		Enables Application Specific SRLG on the ISIS link between two mentioned interfaces
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-no_of_app_spec_srlg
			x   		Number of Application Specific SRLG.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-app_spec_srlg_l_flag
			x   		If set to False, all link attributes will be advertised as sub-sub-tlv of sub tlv "Application Specific Link Attributes sub-TLV (Type 16) of TLV 22,23,141,222 and 223
			x   		If true, then all link attributes will be advertised as sub-TLV of TLV 22,23,141,222 and 223.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-app_spec_srlg_std_app_type
			x   		Standard Application Type for Application Specific SRLG
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-app_spec_srlg_usr_def_app_bm_len
			x   		User Defined Application BM Length for Application Specific SRLG
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-app_spec_srlg_usr_def_ap_bm
			x   		User Defined Application BM
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-app_spec_srlg_ipv4_interface_Addr
			x   		IPv4 Interface Address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-app_spec_srlg_ipv4_neighbor_Addr
			x   		IPv4 Neighbor Address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-app_spec_srlg_ipv6_interface_Addr
			x   		IPv6 Interface Address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-app_spec_srlg_ipv6_neighbor_Addr
			x   		IPv6 Neighbor Address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_enable_srlg
			x   		Enables SRLG on the ISIS link between two mentioned interfaces
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srlg_value
			x   		This is the SRLG Value for the link between two mentioned interfaces.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srlg_count
			x   		This field value shows how many SRLG Value columns would be there in the GUI.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-flex_algo_count
			x   		Flex Algorithm Count
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-flex_algo
			x   		Flex Algorithm
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_metric_type
			x   		Metric Type: 0-IGP Metric, 1:Min. Unidirectional link Delay, 2:TE Default Metric
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_calc_type
			x   		Metric Type: 0-IGP Metric, 1:Min. Unidirectional link Delay, 2:TE Default Metric
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_priority
			x   		Priority
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_enable_exclude_ag
			x   		If this is enabled, Flexible Algorithm Exclude Admin Group Sub-Sub TLV will be advertised with FAD sub-TLV.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_exclude_ag_ext_ag_len
			x   		Exculde AG- Ext Ag length
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_exclude_ag_ext_ag
			x   		Exculde AG- Ext Admin Group
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_enable_include_any_ag
			x   		If this is enabled, Flexible Algorithm Include-Any Admin Group Sub-Sub TLV will be advertised with FAD sub-TLV
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_include_any_ag_ext_ag_len
			x   		Include Any AG- Ext Ag length
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_include_any_ag_ext_ag
			x   		Include AG- Ext Admin Group
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_enable_include_all_ag
			x   		If this is enabled, Flexible Algorithm Include-All Admin Group Sub-Sub TLV will be advertised with FAD sub-TLV
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_include_all_ag_ext_ag_len
			x   		Include All AG- Ext Ag length
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_include_all_ag_ext_ag
			x   		Include AG- Ext Admin Group
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_enable_fadf_tlv
			x   		If enabled then following attributes will get enabled and ISIS Flexible Algorithm Definition Flags Sub-TLV or
			x   		FADF sub-sub-TLV will be advertised with FAD Sub-TLV
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_fadf_len
			x   		FADF Length
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_fadf_m_flag
			x   		M-Flag
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_fsdf_rsrvd
			x   		Reserved
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_dont_adv_in_sr_algo
			x   		Don't Adv. in SR Algorithm
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_adv_twice_excl_ag
			x   		Advertise Twice Exclude AG
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_adv_twice_incl_any_ag
			x   		Advertise Twice Include-Any AG
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fa_adv_twice_incl_all_ag
			x   		Advertise Twice Include-All AG
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-s_r_algorithm_count
			x   		SR Algorithm Count
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-isis_sr_algorithm
			x   		SR Algorithm
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-advertise_srlb
			x   		Enables advertisement of Segment Routing Local Block (SRLB)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srlb_flags
			x   		This specifies the value of the SRLB flags field
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srlb_descriptor_count
			x   		Count of the SRLB descriptor entries
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srlbDescriptor_startSidLabel
			x   		Start SID/Label
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-srlbDescriptor_sidCount
			x   		SID Count
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_link_protection
			x   		This enables the link protection on the ISIS link between two mentioned interfaces.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-extra_traffic
			x   		This is a Protection Scheme with value 0x01. It means that the link is protecting another link or links.The LSPs on a link of this type will be lost if any of the links it is protecting fail.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-unprotected
			x   		This is a Protection Scheme with value 0x02. It means that there is no other link protecting this link.The LSPs on a link of this type will be lost if the link fails.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-shared
			x   		This is a Protection Scheme with value 0x04. It means that there are one or more disjoint links of type Extra Traffic that are protecting this link.These Extra Traffic links are shared between one or more links of type Shared.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dedicated_one_to_one
			x   		This is a Protection Scheme with value 0x08. It means that there is one dedicated disjoint link of type Extra Traffic that is protecting this link.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dedicated_one_plus_one
			x   		This is a Protection Scheme with value 0x10. It means that a dedicated disjoint link is protecting this link.However, the protecting link is not advertised in the link state database and is therefore not available for the routing of LSPs.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enhanced
			x   		This is a Protection Scheme with value 0x20. It means that a protection scheme that is more reliable than Dedicated 1+1, e.g., 4 fiber BLSR/MS-SPRING, is being used to protect this link.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-reserved0x40
			x   		This is a Protection Scheme with value 0x40.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-reserved0x80
			x   		This is a Protection Scheme with value 0x80.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-no_of_te_profiles
			x   		Number of ISIS Traffic Engineering Profiles
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-traffic_engineering_name
			x   		Name of Isis Traffic Engineering Profile
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-te_admin_group
			    		Administrator Group
			 	-te_metric
			    		TE Metric Level
			 	-te_max_bw
			    		The maximum bandwidth to be advertised.
			 	-te_max_resv_bw
			    		The maximum reservable bandwidth to be advertised.
			 	-te_unresv_bw_priority0
			    		The unreserved bandwidth for priority 0 to be advertised.
			 	-te_unresv_bw_priority1
			    		The unreserved bandwidth for priority 1 to be advertised.
			 	-te_unresv_bw_priority2
			    		The unreserved bandwidth for priority 2 to be advertised.
			 	-te_unresv_bw_priority3
			    		The unreserved bandwidth for priority 3 to be advertised.
			 	-te_unresv_bw_priority4
			    		The unreserved bandwidth for priority 4 to be advertised.
			 	-te_unresv_bw_priority5
			    		The unreserved bandwidth for priority 5 to be advertised.
			 	-te_unresv_bw_priority6
			    		The unreserved bandwidth for priority 6 to be advertised.
			 	-te_unresv_bw_priority7
			    		The unreserved bandwidth for priority 7 to be advertised.
			x	-te_adv_ext_admin_group
			x   		Advertise Ext Admin Group
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-te_ext_admin_group_len
			    		Ext Admin Group Length
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-te_ext_admin_group
			x   		Ext Admin Group
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-te_adv_uni_dir_link_delay
			x   		Advertise Uni-Directional Link Delay
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-te_uni_dir_link_delay_a_bit
			x   		Uni-Directional Link Delay A-Bit
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-te_uni_dir_link_delay
			    		Uni-Directional Link Delay (us)
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-te_adv_min_max_unidir_link_delay
			x   		Advertise Min/Max Uni-Directional Link Delay
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-te_min_max_unidir_link_delay_a_bit
			x   		Min/Max Uni-Directional Link Delay A-Bit
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-te_uni_dir_min_link_delay
			    		Uni-Directional Min Link Delay (us)
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-te_uni_dir_max_link_delay
			    		Uni-Directional Max Link Delay (us)
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-te_adv_unidir_delay_variation
			x   		Advertise Uni-Directional Delay Variation
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-te_uni_dir_link_delay_variation
			    		Delay Variation(us)
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-te_adv_unidir_link_loss
			x   		Advertise Uni-Directional Link Loss
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-te_unidir_link_loss_a_bit
			x   		Min/Max Uni-Directional Link Delay A-Bit
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-te_uni_dir_link_loss
			    		Link Loss(%)
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-te_adv_unidir_residual_bw
			x   		Advertise Uni-Directional Residual BW
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-te_uni_dir_residual_bw
			    		Residual BW (B/sec)
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-te_adv_unidir_available_bw
			x   		Advertise Uni-Directional Available BW
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-te_uni_dir_available_bw
			    		Available BW (B/sec)
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-te_adv_unidir_utilized_bw
			x   		Advertise Uni-Directional Utilized BW
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-te_uni_dir_utilized_bw
			    		Utilized BW (B/sec)
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-te_mt_applicability_for_ipv6
			x   		Multi-Topology Applicability for IPv6
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		usesamete - Use Same TE for all MTs
			x       		specifymtid - Specify MTID
			 	-te_mt_id
			    		MTID
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-te_adv_app_spec_traffic
			x   		If this is set to True, link attributes will be advertised as sub-TLV of TLVs 22,23,141,222 and 223
			x   		If set to False, the link atrributes will be advertised as wither sub-sub-tlv of Application Specific
			x   		Link Attributes sub-TLV (Type 26) or sub-tlv of TLVs 22,23,141,222 and 223 depending upon the configuration of L flag
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-te_app_spec_std_app_type
			x   		Standard Application Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-te_app_spec_l_flag
			x   		If set to False, all link attributes will be advertised as sub-sub-tlv of sub tlv "Application Specific Link Attributes sub-TLV (Type 16) of TLV 22,23,141,222 and 223
			x   		If true, then all link attributes will be advertised as sub-TLV of TLV 22,23,141,222 and 223.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-te_app_spec_usr_def_app_bm_len
			x   		User Defined Application BM Length
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-te_app_spec_usr_def_ap_bm
			x   		User Defined Application BM
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-port_handle
			    		Ixia Interface where to act upon.
			    		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-atm_encapsulation
			x   		The encapsulation of the ATM protocol interface associated with the emulated router.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-count
			    		The number of ISIS routers to configure on the targeted Ixia
			    		interface.The range is 0-1000.
			x	-dce_capability_router_id
			x   		DCE ISIS router capability in IPv4 format. Parameter type is optional. This parameter is valid when -mode is create or modify.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dce_bcast_root_priority
			x   		DCE ISIS broadcast root priority. Each device announces a broadcast root-priority and the number of trees it expects all other nodes to compute if it does become the broadcast root. Once a node receives a new LSP, it runs an election algorithm, independently of the other nodes in the network, to determine the broadcast root. The node that announced the lowest broadcast priority becomes the root of the broadcast tree.If two devices advertise the same broadcast priority, the device with the lower system ID becomes the root of the broadcast tree. The elected broadcast-root decides on the multicast-roots to be used in the network domain and their roots. This announcement takes place in the roots identifier sub-TLV. The valid range is 0-65535. Parameter type is optional. This parameter is valid when -mode is create or modify.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dce_num_mcast_dst_trees
			x   		The number of multicast destination trees. The valid range is 0-65535. Parameter type is optional. This parameter is valid when -mode is create or modify.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dce_device_id
			x   		The DCE ISIS device id. The valid range is 0-65535. Parameter type is optional. This parameter is valid when -mode is create or modify.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dce_device_pri
			x   		The DCE ISIS device id. The valid range is 0-255.Parameter type is optional. This parameter is valid when -mode is create or modify.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dce_ftag_enable
			x   		Enable usage of forwarding tag. The valid range is 0-1. Parameter type is optional. This parameter is valid when -mode is create or modify.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dce_ftag
			x   		The DCE ISIS forwarding tag. The valid range is 0-65535. Parameter type is optional. This parameter is valid when -mode is create or modify.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-gateway_ip_addr
			    		The gateway IP address.
			 	-gateway_ip_addr_step
			    		The gateway IP address increment value.
			 	-gateway_ipv6_addr
			    		The gateway IPv6 address.
			 	-gateway_ipv6_addr_step
			    		The gateway IPv6 address increment value.
			 	-hello_password
			    		If true (1), enable circuit authentication in hello pkts.L1 uses area password, L2 uses domain password.
			    		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-interface_handle
			    		A list of protocol interface handles that will be associated with the ISIS router interfaces. This option should be used when interfaces were previously created with interface_config or other emulation_<protocol>_config command. When configuring multiple protocols that use the same protocol interfaces, using this parameter should speed up the configuration.When using this parameter, all other parameter for configuring protocol interfaces are ignored. This option is valid only when using IxTclNetwork API.
			    		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-intf_ip_addr
			    		The IP address of the Ixia Simulated ISIS router.If -count is > 1,
			    		this IP address will increment by value specified
			    		in -intf_ip_addr_step.
			x	-intf_ip_prefix_length
			x   		Defines the mask of the IP address used for the Ixia (-intf_ip_addr)
			x   		and the DUT interface.The range of the value is 1-32.
			 	-intf_ip_addr_step
			    		This value will be used for incrementing the IP address of Simulated
			    		ISIS router if -count is > 1.
			 	-intf_ipv6_addr
			    		The IPv6 address of the Ixia Simulated ISIS router.If -count
			    		is > 1, this IPv6 address will increment by the value specified
			    		in -intf_ipv6_addr_step.
			 	-intf_ipv6_prefix_length
			    		Defines the mask of the IPv6 address used for the Ixia
			    		(-intf_ipv6_addr) and the DUT interface.Valid range is 1-128.
			 	-intf_ipv6_addr_step
			    		This value will be used for incrementing the IPV6 address of Simulated
			    		ISIS router if -count is > 1.
			 	-ip_version
			    		Choices are 4, 6, and 4_6.When 4_6 is selected, wide_metrics is
			    		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-loopback_bfd_registration
			x   		Enable BFD registration for loopback interface.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_ip_addr
			x   		The starting ip address of the unconnected interfaces that are created along with the connected interface, when this option is present.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_ip_addr_step
			x   		The incrementing step for -loopback_ip_addr option.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_ip_prefix_length
			x   		The prefix length for the unconnected interface.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_ip_addr_count
			x   		The number of unconnected interfaces that should be created when the option -loopback_ip_addr is present.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_metric
			x   		The cost metric associated with the route. Valid range is 0-16777215.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_type
			x   		Indicates the type of network attached to the interface: broadcast or ptop.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_routing_level
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x       		L1 - L1 only
			x       		L2 - L2 only
			x       		L1L2 - L1 and L2
			x	-loopback_l1_router_priority
			x   		The session routers priority number for L1 DR role.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_l2_router_priority
			x   		The session routers priority number for L2 DR role.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_te_metric
			x   		The traffic engineering metric, used for both L1 and L2 routes.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_te_admin_group
			x   		The administrative group associated with the traffic engineering.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_te_max_bw
			x   		The maximum bandwidth to be advertised.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_te_max_resv_bw
			x   		The maximum reservable bandwidth to be advertised.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_te_unresv_bw_priority0
			x   		The unreserved bandwidth for priority 0 to be advertised.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_te_unresv_bw_priority1
			x   		The unreserved bandwidth for priority 1 to be advertised.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_te_unresv_bw_priority2
			x   		The unreserved bandwidth for priority 2 to be advertised.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_te_unresv_bw_priority3
			x   		The unreserved bandwidth for priority 3 to be advertised.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_te_unresv_bw_priority4
			x   		The unreserved bandwidth for priority 4 to be advertised.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_te_unresv_bw_priority5
			x   		The unreserved bandwidth for priority 5 to be advertised.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_te_unresv_bw_priority6
			x   		The unreserved bandwidth for priority 6 to be advertised.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_te_unresv_bw_priority7
			x   		The unreserved bandwidth for priority 7 to be advertised.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-loopback_hello_password
			x   		If true (1), enable circuit authentication in hello pkts.L1 uses area password, L2 uses domain password.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-mac_address_init
			    		This option defines the MAC address that will be configured on
			    		the Ixia interface.If is -count > 1, this MAC address will
			    		increment by default by step of 1, or you can specify another step by
			    		using mac_address_step option.
			x	-mac_address_step
			x   		This option defines the incrementing step for the MAC address that
			x   		will be configured on the Ixia interface. Valid only when
			x   		IxNetwork Tcl API is used.
			x	-no_write
			x   		If this option is present, the configuration is not written to the hardware. This option can be used to queue up multiple configurations before writing to the hardware.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-reset
			x   		If this option is selected, this will clear any ISIS-L3 router on
			x   		the targeted interface.
			x	-type
			x   		Selects the ISIS emulation type. This can either be Layer 3 ISIS routing or DCE ISIS emulation based on the draft-ward-l2isis-04. Valid options are: dce_isis_draft_ward_l2_isis_04 and isis_l3_routing. Parameter type is optional. This parameter is valid when -mode is create.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vlan
			x   		Enables vlan on the directly connected ISIS router interface.
			x   		Valid options are: 0 - disable, 1 - enable.
			x   		This option is valid only when -mode is create or -mode is modify
			x   		and -handle is an ISIS router handle.
			 	-vlan_id
			    		If VLAN is enabled on the Ixia interface, this option will configure
			    		the VLAN number.
			 	-vlan_id_mode
			    		If the user configures more than one interface on the Ixia with
			    		VLAN, he can choose to automatically increment the VLAN tag
			    		(increment)or leave it idle for each interface (fixed).
			    		Valid choices are:
			        		fixed -
			        		increment -
			 	-vlan_id_step
			    		If the -vlan_id_mode is increment, this will be the step value by
			    		which the VLAN tags are incremented.
			    		When vlan_id_step causes the vlan_id value to exceed it's maximum value the
			    		increment will be done modulo <number of possible vlan ids>.
			    		Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0
			    		vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			 	-vlan_user_priority
			    		VLAN user priority assigned to emulated router node.
			 	-vpi
			    		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vci
			    		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vpi_step
			    		The step value used for incrementing the -vpi option.When vpi_step causes the vpi value to exceed it's maximum value the increment will be done modulo <number of possible vpi ids>.Examples: vpi = 254; vpi_step = 2-> new vpi value = 0vpi = 255; vpi_step = 11 -> new vpi value = 10
			    		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vci_step
			    		The step value used for incrementing the -vci option.When vci_step causes the vci value to exceed it's maximum value the increment will be done modulo <number of possible vci ids>.Examples: vci = 65534; vci_step = 2-> new vci value = 0vci = 65535; vci_step = 11 -> new vci value = 10
			    		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-router_id_step
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-vlan_cfi
			x   	-return_detailed_handles
			x       		This argument determines if individual interface, session or router handles are returned by the current command.
			x       		This applies only to the command on which it is specified.
			x       		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x       		decrease the size of command results and speed up script execution.
			x       		The default is 0, meaning only protocol stack handles will be returned.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			    	-multi_topology
			        		If true (1), it enables multi-topology (MT) support. If ip_versionis set to 4_6, this field (if not provided by user) gets enabled (set to true (1)) by default.(DEFAULT 0)
			        		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
		
		Return Values:
		   A list containing the ethernet protocol stack handles that were added by the command (if any).
			x   key:ethernet_handle            value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		   A list containing the ipv4 protocol stack handles that were added by the command (if any).
			x   key:ipv4_handle                value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		   A list containing the ipv6 protocol stack handles that were added by the command (if any).
			x   key:ipv6_handle                value:A list containing the ipv6 protocol stack handles that were added by the command (if any).
		   A list containing the isis l3 protocol stack handles that were added by the command (if any).
			x   key:isis_l3_handle             value:A list containing the isis l3 protocol stack handles that were added by the command (if any).
		   A list containing the isis l3 router protocol stack handles that were added by the command (if any).
			x   key:isis_l3_router_handle      value:A list containing the isis l3 router protocol stack handles that were added by the command (if any).
		   A list containing the isis l3 te protocol stack handles that were added by the command (if any).
			x   key:isis_l3_te_handle          value:A list containing the isis l3 te protocol stack handles that were added by the command (if any).
		   A list containing the srgb range  rtr protocol stack handles that were added by the command (if any).
			x   key:srgb_range_handle_rtr      value:A list containing the srgb range  rtr protocol stack handles that were added by the command (if any).
		   A list containing the sr tunnel  rtr protocol stack handles that were added by the command (if any).
			x   key:sr_tunnel_handle_rtr       value:A list containing the sr tunnel  rtr protocol stack handles that were added by the command (if any).
		   A list containing the sr tunnel seg  rtr protocol stack handles that were added by the command (if any).
			x   key:sr_tunnel_seg_handle_rtr   value:A list containing the sr tunnel seg  rtr protocol stack handles that were added by the command (if any).
		   A list containing the srlg range  rtr protocol stack handles that were added by the command (if any).
			x   key:srlg_range_handle_rtr      value:A list containing the srlg range  rtr protocol stack handles that were added by the command (if any).
		   A list containing the sr algoList  rtr protocol stack handles that were added by the command (if any).
			x   key:sr_algoList_handle_rtr     value:A list containing the sr algoList  rtr protocol stack handles that were added by the command (if any).
		   A list containing the srlb descList  rtr protocol stack handles that were added by the command (if any).
			x   key:srlb_descList_handle_rtr   value:A list containing the srlb descList  rtr protocol stack handles that were added by the command (if any).
		   A list containing the flex algo r protocol stack handles that were added by the command (if any).
			x   key:flex_algo_handler          value:A list containing the flex algo r protocol stack handles that were added by the command (if any).
		   A list containing the app spec srlg r protocol stack handles that were added by the command (if any).
			x   key:app_spec_srlg_handler      value:A list containing the app spec srlg r protocol stack handles that were added by the command (if any).
		   A list containing the isis te profile protocol stack handles that were added by the command (if any).
			x   key:isis_te_profile_handle     value:A list containing the isis te profile protocol stack handles that were added by the command (if any).
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:interface_handle           value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:isis_handle                value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:isis_l3_te_handles         value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:srgb_range_handles_rtr     value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:sr_tunnel_handles_rtr      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:sr_tunnel_seg_handles_rtr  value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:srlg_range_handles_rtr     value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:sr_algoList_handle_rtr     value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:srlb_descList_handle_rtr   value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:flex_algo_handler          value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:app_spec_srlg_handler      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:isis_te__profile_handles   value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   $::SUCCESS | $::FAILURE
			    key:status                     value:$::SUCCESS | $::FAILURE
		   On status of failure, gives detailed information.
			    key:log                        value:On status of failure, gives detailed information.
		   list of router node handles Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			    key:handle                     value:list of router node handles Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   list of router node handles
			    key:handle                     value:list of router node handles
		
		Examples:
		   See files starting with ISIS_ in the Samples subdirectory.  Also see some of the L3VPN, MPLS, and MVPN sample files for further examples of ISIS usage. See the ISIS example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		   {status $::SUCCESS} {handle {router1 router2 router3 router4}}
		
		Notes:
		   This function does not support the following return values:
		   neighbor.<neighbor_handle>: area_id; system_id; pseudonode_num; intf_ip_addr; intf_ipv6_addr
		   link_local_ipv6_addr
		   link_local_ipv6_prefix_length
		   pseudonode_num
		   The following fields are used in creating a protocol interface.
		   If IxNetwork Tcl Api is used they are applicable only when mode = create.
		   ip_version
		   intf_ip_addr
		   intf_ip_prefix_length
		   intf_ip_addr_step
		   intf_ipv6_addr
		   intf_ipv6_prefix_length
		   intf_ipv6_addr_step
		   vlan
		   vlan_id
		   vlan_id_mode
		   vlan_idstep
		   vlan_user_priority
		   vpi
		   vci
		   vpi_step
		   vci_step
		   gateway_ip_addr      IP
		   gateway_ip_addr_step IP
		   mac_address_init
		   When -handle is provided with the /globals value the arguments that configure global protocol
		   setting accept both multivalue handles and simple values.
		   When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
		   that configure global settings will only accept simple values. In this situation, these arguments will
		   configure only the settings of the parent device group or the ports associated with the parent topology.
		   Notes:
		   Coded versus functional specification. If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  interface_handle, handle, isis_handle, isis_l3_te_handles, srgb_range_handles_rtr, sr_tunnel_handles_rtr, sr_tunnel_seg_handles_rtr, srlg_range_handles_rtr, sr_algoList_handle_rtr, srlb_descList_handle_rtr, flex_algo_handler, app_spec_srlg_handler, isis_te__profile_handles
		   Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_isis_config", kwargs)

	def emulation_isis_control(self, **kwargs):
		""" This procedure is used to start, stop, and restart the ISIS protocol.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_isis_control
			 	-mode                CHOICES start
			                      CHOICES stop
			                      CHOICES restart
			                      CHOICES abort
			                      CHOICES restart_down
			                      CHOICES stop_hello
			                      CHOICES resume_hello
			                      CHOICES age_out_routes
			                      CHOICES readvertise_routes
			                      CHOICES disconnect
			                      CHOICES reconnect
			x	[-age_out_percent    NUMERIC]
			 	[-port_handle        ANY]
			 	[-handle             ANY]
			n	[-advertise          ANY]
			n	[-flap_count         ANY]
			n	[-flap_down_time     ANY]
			n	[-flap_interval_time ANY]
			n	[-flap_routes        ANY]
			n	[-withdraw           ANY]
		
		Arguments:
			 	-mode
			    		start - Start the protocol.
			    		stop - Stop the protocol.
			    		restart - Restart the protocol.
			    		abort - Abort the protocol
			    		restart_down - Restart down the protocol
			    		stop_hello - Stop hello
			    		resume_hello - Resume hello
			    		age_out_routes - Age out routes
			    		readvertise_routes - Readvertise routes
			    		disconnect - Disconnent operation is being performed on either a From-Node or a To-Node under a simulated interface, which removes the neighborhood information
			    		reconnect - Disconnent operation is being performed on either a From-Node or a To-Node under a simulated interface, which brings back the neighborhood information
			x	-age_out_percent
			x		The percentage of addresses that will be aged out. This argument is ignored when mode is not age_out_routes and *must* be specified in such circumstances.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-port_handle
			 		The port where the IS-IS is to be controlled.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-handle
			 		ISIS session handle where the ISIS control action is applied.
			n	-advertise
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_count
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_down_time
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_interval_time
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_routes
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-withdraw
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		See files starting with ISIS_ in the Samples subdirectory.  Also see some of the L3VPN, MPLS, and MVPN sample files for further examples of ISIS usage. See the ISIS example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_isis_control", kwargs)

	def emulation_isis_info(self, **kwargs):
		""" This procedure retrieves ISIS statistics, learned routing information from ISIS routers.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_isis_info
			x	-mode         CHOICES stats
			x              CHOICES clear_stats
			x              CHOICES learned_info]
			 	[-port_handle REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-handle      ANY]
		
		Arguments:
			x	-mode
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		stats - Gather IS-IS statistics.
			x   		clear_stats - Clear IS-IS statistics.
			x   		learned_info - Get Learned Info
			 	-port_handle
			 		The port from which to extract ISISdata.
			 		One of the two parameters is required: port_handle/handle.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-handle
			x		ISIS session handle where the ISIS control action is applied. The
			x		session handle is an emulated IS-IS router object reference.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                                     value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                                                                        value:If status is failure, detailed information provided.
		The stats are aggregated per port no matter which optional parameter is provided: handle or port_handle. If multiple ports were provided, the stats' values are for the first port in the list. If multiple handles were provided, the stats' values are for the corresponding port of the first handles in the list. This is valid only for IxTclNetwork API (new API).
			 key:For -mode stats                                                            value:The stats are aggregated per port no matter which optional parameter is provided: handle or port_handle. If multiple ports were provided, the stats' values are for the first port in the list. If multiple handles were provided, the stats' values are for the corresponding port of the first handles in the list. This is valid only for IxTclNetwork API (new API).
		Ixia only; represents the port name
			 key:port_name                                                                  value:Ixia only; represents the port name
		Ixia only; represents the count of ISIS L1 Sessions Configured
			 key:l1_sessions_configured                                                     value:Ixia only; represents the count of ISIS L1 Sessions Configured
		Ixia only; represents the count of ISIS L1 Sessions Up
			 key:l1_sessions_up                                                             value:Ixia only; represents the count of ISIS L1 Sessions Up
		Ixia only; represents the count of ISIS Number of Full L1 Neighbors
			 key:full_l1_neighbors                                                          value:Ixia only; represents the count of ISIS Number of Full L1 Neighbors
		Ixia only; represents the count of ISIS L2 Sessions Configured
			 key:l2_sessions_configured                                                     value:Ixia only; represents the count of ISIS L2 Sessions Configured
		Ixia only; represents the count of ISIS L2 Sessions Up
			 key:l2_sessions_configured                                                     value:Ixia only; represents the count of ISIS L2 Sessions Up
		Ixia only; represents the count of ISIS Number of Full L2 Neighbors
			 key:full_l2_neighbors                                                          value:Ixia only; represents the count of ISIS Number of Full L2 Neighbors
		Ixia only; represents the count of ISIS Aggregated L1 Hellos Tx
			 key:aggregated_l1_hellos_tx                                                    value:Ixia only; represents the count of ISIS Aggregated L1 Hellos Tx
		Ixia only; represents the count of ISIS Aggregated L1 Point-to-Point Hellos Tx
			 key:aggregated_l1_p2p_hellos_tx                                                value:Ixia only; represents the count of ISIS Aggregated L1 Point-to-Point Hellos Tx
		Ixia only; represents the count of ISIS Aggregated L1 LSP Tx
			 key:aggregated_l1_lsp_tx                                                       value:Ixia only; represents the count of ISIS Aggregated L1 LSP Tx
		Ixia only; represents the count of ISIS Aggregated L1 CSNP Tx
			 key:aggregated_l1_csnp_tx                                                      value:Ixia only; represents the count of ISIS Aggregated L1 CSNP Tx
		Ixia only; represents the count of ISIS Aggregated L1 PSNP Tx
			 key:aggregated_l1_psnp_tx                                                      value:Ixia only; represents the count of ISIS Aggregated L1 PSNP Tx
		Ixia only; represents the count of ISIS Aggregated L1 Database Size
			 key:aggregated_l1_db_size                                                      value:Ixia only; represents the count of ISIS Aggregated L1 Database Size
		Ixia only; represents the count of ISIS Aggregated L2 Hellos Tx
			 key:aggregated_l2_hellos_tx                                                    value:Ixia only; represents the count of ISIS Aggregated L2 Hellos Tx
		Ixia only; represents the count of ISIS Aggregated L2 Point-to-Point Hellos Tx
			 key:aggregated_l2_p2p_hellos_tx                                                value:Ixia only; represents the count of ISIS Aggregated L2 Point-to-Point Hellos Tx
		Ixia only; represents the count of ISIS Aggregated L2 LSP Tx
			 key:aggregated_l2_lsp_tx                                                       value:Ixia only; represents the count of ISIS Aggregated L2 LSP Tx
		Ixia only; represents the count of ISIS Aggregated L2 CSNP Tx
			 key:aggregated_l2_csnp_tx                                                      value:Ixia only; represents the count of ISIS Aggregated L2 CSNP Tx
		Ixia only; represents the count of ISIS Aggregated L2 PSNP Tx
			 key:aggregated_l2_psnp_tx                                                      value:Ixia only; represents the count of ISIS Aggregated L2 PSNP Tx
		Ixia only; represents the count of ISIS Aggregated L2 Database Size
			 key:aggregated_l2_db_size                                                      value:Ixia only; represents the count of ISIS Aggregated L2 Database Size
		Ixia only; represents the count of ISIS Aggregated L1 Hellos Rx
			 key:aggregated_l1_hellos_rx                                                    value:Ixia only; represents the count of ISIS Aggregated L1 Hellos Rx
		Ixia only; represents the count of ISIS Aggregated L1 Point-to-Point Hellos Rx
			 key:aggregated_l1_p2p_hellos_rx                                                value:Ixia only; represents the count of ISIS Aggregated L1 Point-to-Point Hellos Rx
		Ixia only; represents the count of ISIS Aggregated L1 LSP Rx
			 key:aggregated_l1_lsp_rx                                                       value:Ixia only; represents the count of ISIS Aggregated L1 LSP Rx
		Ixia only; represents the count of ISIS Aggregated L1 CSNP Rx
			 key:aggregated_l1_csnp_rx                                                      value:Ixia only; represents the count of ISIS Aggregated L1 CSNP Rx
		Ixia only; represents the count of ISIS Aggregated L1 PSNP Rx
			 key:aggregated_l1_psnp_rx                                                      value:Ixia only; represents the count of ISIS Aggregated L1 PSNP Rx
		Ixia only; represents the count of ISIS Aggregated L2 Hellos Rx
			 key:aggregated_l2_hellos_rx                                                    value:Ixia only; represents the count of ISIS Aggregated L2 Hellos Rx
		Ixia only; represents the count of ISIS Aggregated L2 Point-to-Point Hellos Rx
			 key:aggregated_l2_p2p_hellos_rx                                                value:Ixia only; represents the count of ISIS Aggregated L2 Point-to-Point Hellos Rx
		Ixia only; represents the count of ISIS Aggregated L2 LSP Rx
			 key:aggregated_l2_lsp_rx                                                       value:Ixia only; represents the count of ISIS Aggregated L2 LSP Rx
		Ixia only; represents the count of ISIS Aggregated L2 CSNP Rx
			 key:aggregated_l2_csnp_rx                                                      value:Ixia only; represents the count of ISIS Aggregated L2 CSNP Rx
		Ixia only; represents the count of ISIS Aggregated L2 PSNP Rx
			 key:aggregated_l2_psnp_rx                                                      value:Ixia only; represents the count of ISIS Aggregated L2 PSNP Rx
		Ixia only; represents the count of ISIS Aggregated L1 Init Count
			 key:aggregated_l1_init_count                                                   value:Ixia only; represents the count of ISIS Aggregated L1 Init Count
		Ixia only; represents the count of ISIS Aggregated L1 Full Count
			 key:aggregated_l1_full_count                                                   value:Ixia only; represents the count of ISIS Aggregated L1 Full Count
		Ixia only; represents the count of ISIS Aggregated L2 Init Count
			 key:aggregated_l2_init_count                                                   value:Ixia only; represents the count of ISIS Aggregated L2 Init Count
		Ixia only; represents the count of ISIS Aggregated L2 Full Count
			 key:aggregated_l2_full_count                                                   value:Ixia only; represents the count of ISIS Aggregated L2 Full Count
		The stats are aggregated per port no matter which optional parameter is provided: handle or port_handle. This is valid only for IxTclNetwork API (new API).
			 key:For -mode stats                                                            value:The stats are aggregated per port no matter which optional parameter is provided: handle or port_handle. This is valid only for IxTclNetwork API (new API).
		Ixia only; represents the count of ISIS L1 Sessions Configured
			 key:<port_handle>.l1_sessions_configured                                       value:Ixia only; represents the count of ISIS L1 Sessions Configured
		Ixia only; represents the count of ISIS L1 Sessions Up
			 key:<port_handle>.l1_sessions_up                                               value:Ixia only; represents the count of ISIS L1 Sessions Up
		Ixia only; represents the count of ISIS Number of Full L1 Neighbors
			 key:<port_handle>.full_l1_neighbors                                            value:Ixia only; represents the count of ISIS Number of Full L1 Neighbors
		Ixia only; represents the count of ISIS L2 Sessions Configured
			 key:<port_handle>.l2_sessions_configured                                       value:Ixia only; represents the count of ISIS L2 Sessions Configured
		Ixia only; represents the count of ISIS L2 Sessions Up
			 key:<port_handle>.l2_sessions_up                                               value:Ixia only; represents the count of ISIS L2 Sessions Up
		Ixia only; represents the count of ISIS Number of Full L2 Neighbors
			 key:<port_handle>.full_l2_neighbors                                            value:Ixia only; represents the count of ISIS Number of Full L2 Neighbors
		Ixia only; represents the count of ISIS Aggregated L1 Hellos Tx
			 key:<port_handle>.aggregated_l1_hellos_tx                                      value:Ixia only; represents the count of ISIS Aggregated L1 Hellos Tx
		Ixia only; represents the count of ISIS Aggregated L1 Point-to-Point Hellos Tx
			 key:<port_handle>.aggregated_l1_p2p_hellos_tx                                  value:Ixia only; represents the count of ISIS Aggregated L1 Point-to-Point Hellos Tx
		Ixia only; represents the count of ISIS Aggregated L1 LSP Tx
			 key:<port_handle>.aggregated_l1_lsp_tx                                         value:Ixia only; represents the count of ISIS Aggregated L1 LSP Tx
		Ixia only; represents the count of ISIS Aggregated L1 CSNP Tx
			 key:<port_handle>.aggregated_l1_csnp_tx                                        value:Ixia only; represents the count of ISIS Aggregated L1 CSNP Tx
		Ixia only; represents the count of ISIS Aggregated L1 PSNP Tx
			 key:<port_handle>.aggregated_l1_psnp_tx                                        value:Ixia only; represents the count of ISIS Aggregated L1 PSNP Tx
		Ixia only; represents the count of ISIS Aggregated L1 Database Size
			 key:<port_handle>.aggregated_l1_db_size                                        value:Ixia only; represents the count of ISIS Aggregated L1 Database Size
		Ixia only; represents the count of ISIS Aggregated L2 Hellos Tx
			 key:<port_handle>.aggregated_l2_hellos_tx                                      value:Ixia only; represents the count of ISIS Aggregated L2 Hellos Tx
		Ixia only; represents the count of ISIS Aggregated L2 Point-to-Point Hellos Tx
			 key:<port_handle>.aggregated_l2_p2p_hellos_tx                                  value:Ixia only; represents the count of ISIS Aggregated L2 Point-to-Point Hellos Tx
		Ixia only; represents the count of ISIS Aggregated L2 LSP Tx
			 key:<port_handle>.aggregated_l2_lsp_tx                                         value:Ixia only; represents the count of ISIS Aggregated L2 LSP Tx
		Ixia only; represents the count of ISIS Aggregated L2 CSNP Tx
			 key:<port_handle>.aggregated_l2_csnp_tx                                        value:Ixia only; represents the count of ISIS Aggregated L2 CSNP Tx
		Ixia only; represents the count of ISIS Aggregated L2 PSNP Tx
			 key:<port_handle>.aggregated_l2_psnp_tx                                        value:Ixia only; represents the count of ISIS Aggregated L2 PSNP Tx
		Ixia only; represents the count of ISIS Aggregated L2 Database Size
			 key:<port_handle>.aggregated_l2_db_size                                        value:Ixia only; represents the count of ISIS Aggregated L2 Database Size
		Ixia only; represents the count of ISIS Aggregated L1 Hellos Rx
			 key:<port_handle>.aggregated_l1_hellos_rx                                      value:Ixia only; represents the count of ISIS Aggregated L1 Hellos Rx
		Ixia only; represents the count of ISIS Aggregated L1 Point-to-Point Hellos Rx
			 key:<port_handle>.aggregated_l1_p2p_hellos_rx                                  value:Ixia only; represents the count of ISIS Aggregated L1 Point-to-Point Hellos Rx
		Ixia only; represents the count of ISIS Aggregated L1 LSP Rx
			 key:<port_handle>.aggregated_l1_lsp_rx                                         value:Ixia only; represents the count of ISIS Aggregated L1 LSP Rx
		Ixia only; represents the count of ISIS Aggregated L1 CSNP Rx
			 key:<port_handle>.aggregated_l1_csnp_rx                                        value:Ixia only; represents the count of ISIS Aggregated L1 CSNP Rx
		Ixia only; represents the count of ISIS Aggregated L1 PSNP Rx
			 key:<port_handle>.aggregated_l1_psnp_rx                                        value:Ixia only; represents the count of ISIS Aggregated L1 PSNP Rx
		Ixia only; represents the count of ISIS Aggregated L2 Hellos Rx
			 key:<port_handle>.aggregated_l2_hellos_rx                                      value:Ixia only; represents the count of ISIS Aggregated L2 Hellos Rx
		Ixia only; represents the count of ISIS Aggregated L2 Point-to-Point Hellos Rx
			 key:<port_handle>.aggregated_l2_p2p_hellos_rx                                  value:Ixia only; represents the count of ISIS Aggregated L2 Point-to-Point Hellos Rx
		Ixia only; represents the count of ISIS Aggregated L2 LSP Rx
			 key:<port_handle>.aggregated_l2_lsp_rx                                         value:Ixia only; represents the count of ISIS Aggregated L2 LSP Rx
		Ixia only; represents the count of ISIS Aggregated L2 CSNP Rx
			 key:<port_handle>.aggregated_l2_csnp_rx                                        value:Ixia only; represents the count of ISIS Aggregated L2 CSNP Rx
		Ixia only; represents the count of ISIS Aggregated L2 PSNP Rx
			 key:<port_handle>.aggregated_l2_psnp_rx                                        value:Ixia only; represents the count of ISIS Aggregated L2 PSNP Rx
		Ixia only; represents the count of ISIS Aggregated L1 Init Count
			 key:<port_handle>.aggregated_l1_init_count                                     value:Ixia only; represents the count of ISIS Aggregated L1 Init Count
		Ixia only; represents the count of ISIS Aggregated L1 Full Count
			 key:<port_handle>.aggregated_l1_full_count                                     value:Ixia only; represents the count of ISIS Aggregated L1 Full Count
		Ixia only; represents the count of ISIS Aggregated L2 Init Count
			 key:<port_handle>.aggregated_l2_init_count                                     value:Ixia only; represents the count of ISIS Aggregated L2 Init Count
		Ixia only; represents the count of ISIS Aggregated L2 Full Count
			 key:<port_handle>.aggregated_l2_full_count                                     value:Ixia only; represents the count of ISIS Aggregated L2 Full Count
		The stats are aggregated per port no matter which optional parameter is provided: handle or port_handle. This is valid only for IxTclProtocol API (old API).
			 key:For -mode stats                                                            value:The stats are aggregated per port no matter which optional parameter is provided: handle or port_handle. This is valid only for IxTclProtocol API (old API).
		Ixia only; represents the count of ISIS L1 Sessions Configured
			 key:<port_handle>.l1_sessions_configured                                       value:Ixia only; represents the count of ISIS L1 Sessions Configured
		Ixia only; represents the count of ISIS L1 Sessions Up
			 key:<port_handle>.l1_sessions_up                                               value:Ixia only; represents the count of ISIS L1 Sessions Up
		Ixia only; represents the count of ISIS Number of Full L1 Neighbors
			 key:<port_handle>.full_l1_neighbors                                            value:Ixia only; represents the count of ISIS Number of Full L1 Neighbors
		Ixia only; represents the count of ISIS L2 Sessions Configured
			 key:<port_handle>.l2_sessions_configured                                       value:Ixia only; represents the count of ISIS L2 Sessions Configured
		Ixia only; represents the count of ISIS L2 Sessions Up
			 key:<port_handle>.l2_sessions_up                                               value:Ixia only; represents the count of ISIS L2 Sessions Up
		Ixia only; represents the count of ISIS Number of Full L2 Neighbors
			 key:<port_handle>.full_l2_neighbors                                            value:Ixia only; represents the count of ISIS Number of Full L2 Neighbors
		Ixia only; valid only with IxOS 5.30 an greater.
			 key:<port_handle>.rbridges_learned                                             value:Ixia only; valid only with IxOS 5.30 an greater.
		Ixia only; valid only with IxOS 5.30 an greater.
			 key:<port_handle>.mac_group_recors_learned                                     value:Ixia only; valid only with IxOS 5.30 an greater.
		Ixia only; valid only with IxOS 5.30 an greater.
			 key:<port_handle>.ipv4_group_records_learned                                   value:Ixia only; valid only with IxOS 5.30 an greater.
		Ixia only; valid only with IxOS 5.30 an greater.
			 key:<port_handle>.ipv6_group_records_learned                                   value:Ixia only; valid only with IxOS 5.30 an greater.
		Ixia only; valid only with IxOS 5.30 an greater.
			 key:<port_handle>.l1_db_size                                                   value:Ixia only; valid only with IxOS 5.30 an greater.
		Ixia only; valid only with IxOS 5.30 an greater.
			 key:<port_handle>.l2_db_size                                                   value:Ixia only; valid only with IxOS 5.30 an greater.
		The stats are retrieved per ISIS session handle no matter which optional parameter is provided: handle or port_handle. Valid only for IxTclProtocol (old API).
			 key:For -mode learned_info                                                     value:The stats are retrieved per ISIS session handle no matter which optional parameter is provided: handle or port_handle. Valid only for IxTclProtocol (old API).
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.rbridges.<index>.this              value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.rbridges.<index>.system_id         value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.rbridges.<index>.ftag              value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.rbridges.<index>.role              value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.rbridges.<index>.priority          value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.rbridges.<index>.age               value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.rbridges.<index>.seq_number        value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.rbridges.<index>.device_id         value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.rbridges.<index>.graph_id          value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.rbridges.<index>.secondary_ftag    value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.ipv4.<index>.lsp_id                value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.ipv4.<index>.sequence_number       value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.ipv4.<index>.group_address         value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.ipv4.<index>.source_address        value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.ipv4.<index>.age                   value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.ipv6.<index>.lsp_id                value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.ipv6.<index>.sequence_number       value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.ipv6.<index>.mcast_group_address   value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.ipv6.<index>.ucast_source_address  value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.ipv6.<index>.age                   value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.mac.<index>.lsp_id                 value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.mac.<index>.sequence_number        value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.mac.<index>.mcast_group_address    value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.mac.<index>.ucast_source_address   value:Ixia only;
		Ixia only;
			 key:<handle>.dce_isis_draft_ward_l2_isis_04.mac.<index>.age                    value:Ixia only;
		The stats are retrieved per ISIS session handle no matter which optional parameter is provided: handle or port_handle. Valid for both IxTclProtocol (old API) and IxTclNetwork (new API).
			 key:For -mode learned_info                                                     value:The stats are retrieved per ISIS session handle no matter which optional parameter is provided: handle or port_handle. Valid for both IxTclProtocol (old API) and IxTclNetwork (new API).
		Ixia only;
			 key:<handle>.isis_l3_routing.ipv4.<index>.lsp_id                               value:Ixia only;
		Ixia only;
			 key:<handle>.isis_l3_routing.ipv4.<index>.sequence_number                      value:Ixia only;
		Ixia only;
			 key:<handle>.isis_l3_routing.ipv4.<index>.prefix                               value:Ixia only;
		Ixia only;
			 key:<handle>.isis_l3_routing.ipv4.<index>.metric                               value:Ixia only;
		Ixia only;
			 key:<handle>.isis_l3_routing.ipv4.<index>.age                                  value:Ixia only;
		Ixia only;
			 key:<handle>.isis_l3_routing.ipv6.<index>.lsp_id                               value:Ixia only;
		Ixia only;
			 key:<handle>.isis_l3_routing.ipv6.<index>.sequence_number                      value:Ixia only;
		Ixia only;
			 key:<handle>.isis_l3_routing.ipv6.<index>.prefix                               value:Ixia only;
		Ixia only;
			 key:<handle>.isis_l3_routing.ipv6.<index>.metric                               value:Ixia only;
		Ixia only;
			 key:<handle>.isis_l3_routing.ipv6.<index>.age                                  value:Ixia only;
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_isis_info", kwargs)

	def emulation_isis_network_group_config(self, **kwargs):
		""" This procedure creates or modifies or deletes ISIS route(s) to a particular simulated ISIS router Ixia Interface. The user can configure the properties of the ISIS routes.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_isis_network_group_config
			 	-handle                                            ANY]
			 	-mode                                              CHOICES create modify delete]
			 	[-type                                             CHOICES grid
			                                                    CHOICES mesh
			                                                    CHOICES custom
			                                                    CHOICES ring
			                                                    CHOICES hub-and-spoke
			                                                    CHOICES tree
			                                                    CHOICES ipv4-prefix
			                                                    CHOICES ipv6-prefix
			                                                    CHOICES fat-tree
			                                                    CHOICES linear]
			x	[-protocol_name                                    ALPHA]
			x	[-multiplier                                       NUMERIC]
			x	[-connected_to_handle                              ANY]
			x	[-return_detailed_handles                          CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-enable_device                                    CHOICES 0 1]
			 	[-grid_row                                         NUMERIC]
			 	[-grid_col                                         NUMERIC]
			x	[-grid_include_emulated_device                     CHOICES 0 1]
			x	[-grid_link_multiplier                             NUMERIC]
			x	[-mesh_number_of_nodes                             NUMERIC]
			x	[-mesh_include_emulated_device                     CHOICES 0 1]
			x	[-mesh_link_multiplier                             NUMERIC]
			x	[-ring_number_of_nodes                             NUMERIC]
			x	[-ring_include_emulated_device                     CHOICES 0 1]
			x	[-ring_link_multiplier                             NUMERIC]
			x	[-hub_spoke_number_of_first_level                  NUMERIC]
			x	[-hub_spoke_number_of_second_level                 NUMERIC]
			x	[-hub_spoke_enable_level_2                         CHOICES 0 1]
			x	[-hub_spoke_link_multiplier                        NUMERIC]
			x	[-tree_number_of_nodes                             NUMERIC]
			x	[-tree_include_emulated_device                     CHOICES 0 1]
			x	[-tree_use_tree_depth                              CHOICES 0 1]
			x	[-tree_depth                                       NUMERIC]
			x	[-tree_max_children_per_node                       NUMERIC]
			x	[-tree_link_multiplier                             NUMERIC]
			x	[-custom_link_multiplier                           NUMERIC]
			x	[-custom_from_node_index                           NUMERIC]
			x	[-custom_to_node_index                             NUMERIC]
			x	[-fat_tree_link_multiplier                         NUMERIC]
			x	[-fat_tree_level_count                             NUMERIC]
			x	[-fat_tree_node_count                              NUMERIC]
			x	[-linear_nodes                                     NUMERIC]
			x	[-linear_link_multiplier                           NUMERIC]
			x	[-sim_topo_active                                  CHOICES 0 1]
			x	[-sim_topo_enable_host_name                        CHOICES 0 1]
			x	[-sim_topo_host_name                               REGEXP ^[0-9,a-f,A-F]+$]
			x	[-sim_topo_ipv4_node_route_count                   NUMERIC]
			x	[-sim_topo_ipv6_node_route_count                   NUMERIC]
			x	[-grid_router_route_step                           NUMERIC]
			x	[-grid_node_step                                   NUMERIC]
			x	[-grid_ipv6_router_route_step                      NUMERIC]
			x	[-grid_ipv6_node_step                              NUMERIC]
			 	[-router_system_id                                 HEX8WITHSPACES]
			x	[-node_active                                      CHOICES 0 1]
			 	[-router_te                                        CHOICES 0 1]
			 	[-router_id                                        IPV4]
			x	[-enable_wide_metric                               CHOICES 0 1]
			x	[-enable_mt_ipv6                                   CHOICES 0 1]
			x	[-ipv6_mt_metric                                   NUMERIC]
			x	[-pseudo_node_enable_sr                            CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_rtrcap_id                            IPV4
			x                                                   DEFAULT 1.1.1.1]
			x	[-pseudo_node_d_bit                                CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_s_bit                                CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_ipv4_flag                            CHOICES 0 1
			x                                                   DEFAULT 1]
			x	[-pseudo_node_ipv6_flag                            CHOICES 0 1
			x                                                   DEFAULT 1]
			x	[-pseudo_node_node_prefix                          IPV4
			x                                                   DEFAULT 1.1.1.1]
			x	[-pseudo_node_mask                                 RANGE 1-32
			x                                                   DEFAULT 32]
			x	[-pseudo_node_redistribution                       CHOICES up down
			x                                                   DEFAULT up]
			x	[-pseudo_node_r_flag                               CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_n_flag                               CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_p_flag                               CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_e_flag                               CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_v_flag                               CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_l_flag                               CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_configure_sid_index_label            CHOICES 0 1
			x                                                   DEFAULT 1]
			x	[-pseudo_node_sid_index_label                      RANGE 0-1048575
			x                                                   DEFAULT 0]
			x	[-pseudo_node_srgb_range_count                     RANGE 1-5
			x                                                   DEFAULT 1]
			x	[-pseudo_node_start_sid_label                      RANGE 1-1048575
			x                                                   DEFAULT 16000]
			x	[-pseudo_node_sid_count                            RANGE 1-15000
			x                                                   DEFAULT 8000]
			x	[-ipv6_srh_flag_pseudo_router                      CHOICES 0 1]
			x	[-pseudo_node_sr_algo_count                        RANGE 1-5
			x                                                   DEFAULT 1]
			x	[-pseudo_node_isis_sr_algorithm                    NUMERIC]
			x	[-pseudo_node_algorithm                            RANGE 0-255
			x                                                   DEFAULT 0]
			x	[-advertise_srlb                                   CHOICES 0 1]
			x	[-srlb_flags                                       HEX]
			x	[-srlb_descriptor_count                            RANGE 1-5
			x                                                   DEFAULT 1]
			x	[-srlbDescriptor_startSidLabel                     RANGE 1-1048575
			x                                                   DEFAULT 16000]
			x	[-srlbDescriptor_sidCount                          RANGE 1-1048575
			x                                                   DEFAULT 8000]
			x	[-grid_router_active                               CHOICES 0 1
			x                                                   DEFAULT 0]
			 	[-grid_router_id                                   IPV4
			                                                    DEFAULT 201.1.0.0]
			 	[-grid_stub_per_router                             NUMERIC
			                                                    DEFAULT 1]
			 	[-grid_router_ip_pfx_len                           RANGE 1-32
			                                                    DEFAULT 16]
			 	[-grid_router_metric                               NUMERIC
			                                                    DEFAULT 0]
			 	[-grid_router_origin                               CHOICES internal external
			                                                    DEFAULT internal]
			 	[-grid_router_up_down_bit                          CHOICES 0 1
			                                                    DEFAULT 0]
			x	[-pseudo_node_route_ipv4_r_flag                    CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_route_ipv4_n_flag                    CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_route_ipv4_p_flag                    CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_route_ipv4_e_flag                    CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_route_ipv4_v_flag                    CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_route_ipv4_l_flag                    CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_route_ipv4_configure_sid_index_label CHOICES 0 1
			x                                                   DEFAULT 1]
			x	[-pseudo_node_route_ipv4_sid_index_label           RANGE 0-1048575
			x                                                   DEFAULT 1]
			x	[-grid_ipv6_router_active                          CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-grid_ipv6_router_id                              IPV6
			x                                                   DEFAULT 3000:0:1:1:0:0:0:0]
			x	[-grid_ipv6_stub_per_router                        NUMERIC
			x                                                   DEFAULT 1]
			x	[-grid_ipv6_router_ip_pfx_len                      RANGE 1-128
			x                                                   DEFAULT 64]
			x	[-grid_ipv6_router_metric                          NUMERIC
			x                                                   DEFAULT 0]
			x	[-grid_ipv6_router_origin                          CHOICES internal external
			x                                                   DEFAULT internal]
			x	[-grid_ipv6_router_up_down_bit                     CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_route_ipv6_r_flag                    CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_route_ipv6_n_flag                    CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_route_ipv6_p_flag                    CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_route_ipv6_e_flag                    CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_route_ipv6_v_flag                    CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_route_ipv6_l_flag                    CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_route_ipv6_configure_sid_index_label CHOICES 0 1
			x                                                   DEFAULT 1]
			x	[-pseudo_node_route_ipv6_sid_index_label           RANGE 0-1048575
			x                                                   DEFAULT 1]
			x	[-external_link_router_source                      NUMERIC]
			x	[-external_link_router_destination                 NUMERIC]
			x	[-external_link_network_group_handle               ANY]
			x	[-enable_ip                                        CHOICES 0 1]
			x	[-from_ip                                          IPV4]
			x	[-to_ip                                            IPV4]
			x	[-subnet_prefix_length                             NUMERIC]
			x	[-enable_ipv6                                      CHOICES 0 1]
			x	[-from_ipv6                                        IPV6]
			x	[-to_ipv6                                          IPV6]
			x	[-subnet_ipv6_prefix_length                        NUMERIC]
			x	[-link_type                                        CHOICES pttopt broadcast]
			x	[-si_enable_adj_sid                                CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-si_adj_sid                                       RANGE 1-1048575
			x                                                   DEFAULT 9001]
			x	[-si_override_f_flag                               CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-si_f_flag                                        CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-si_b_flag                                        CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-si_v_flag                                        CHOICES 0 1
			x                                                   DEFAULT 1]
			x	[-si_l_flag                                        CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-si_s_flag                                        CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-si_p_flag                                        CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-si_weight                                        RANGE 0-255
			x                                                   DEFAULT 0]
			x	[-enable_link_protection                           CHOICES 0 1]
			x	[-extra_traffic                                    CHOICES 0 1]
			x	[-unprotected                                      CHOICES 0 1]
			x	[-shared                                           CHOICES 0 1]
			x	[-dedicated_one_to_one                             CHOICES 0 1]
			x	[-dedicated_one_plus_one                           CHOICES 0 1]
			x	[-enhanced                                         CHOICES 0 1]
			x	[-reserved0x40                                     CHOICES 0 1]
			x	[-reserved0x80                                     CHOICES 0 1]
			x	[-pseudo_node_enable_srlg                          CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-pseudo_node_srlg_count                           RANGE 1-5
			x                                                   DEFAULT 1]
			x	[-pseudo_node_srlg_value                           NUMERIC]
			x	[-from_node_active                                 CHOICES 0 1]
			x	[-from_node_link_metric                            RANGE 0-16777215
			x                                                   DEFAULT 0]
			x	[-to_node_active                                   CHOICES 0 1]
			x	[-to_node_link_metric                              RANGE 0-16777215
			x                                                   DEFAULT 0]
			 	[-admin_group                                      HEX]
			x	[-metric_level                                     RANGE 0-16777215
			x                                                   DEFAULT 0]
			 	[-max_bw                                           REGEXP ^[0-9]+]
			 	[-max_resv_bw                                      REGEXP ^[0-9]+$]
			 	[-bw_priority0                                     REGEXP ^[0-9]+$]
			 	[-bw_priority1                                     REGEXP ^[0-9]+$]
			 	[-bw_priority2                                     REGEXP ^[0-9]+$]
			 	[-bw_priority3                                     REGEXP ^[0-9]+$]
			 	[-bw_priority4                                     REGEXP ^[0-9]+$]
			 	[-bw_priority5                                     REGEXP ^[0-9]+$]
			 	[-bw_priority6                                     REGEXP ^[0-9]+$]
			 	[-bw_priority7                                     REGEXP ^[0-9]+$]
			 	[-ipv4_prefix_network_address                      IPV4
			                                                    DEFAULT 0.0.0.0]
			x	[-ipv4_prefix_number_of_addresses                  NUMERIC
			x                                                   DEFAULT 1]
			 	[-ipv4_prefix_length                               RANGE 1-32
			                                                    DEFAULT 24]
			x	[-stub_router_active                               CHOICES 0 1]
			x	[-stub_router_origin                               CHOICES internal external]
			 	[-stub_up_down_bit                                 CHOICES 0 1]
			 	[-stub_metric                                      NUMERIC]
			x	[-routerange_ipv4_r_flag                           CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-routerange_ipv4_n_flag                           CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-routerange_ipv4_p_flag                           CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-routerange_ipv4_e_flag                           CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-routerange_ipv4_v_flag                           CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-routerange_ipv4_l_flag                           CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-routerange_ipv4_configure_sid_index_label        CHOICES 0 1
			x                                                   DEFAULT 1]
			x	[-routerange_ipv4_sid_index_label                  RANGE 0-1048575
			x                                                   DEFAULT 1]
			 	[-ipv6_prefix_network_address                      IPV6
			                                                    DEFAULT 3000::0]
			x	[-ipv6_prefix_number_of_addresses                  NUMERIC
			x                                                   DEFAULT 1]
			 	[-ipv6_prefix_length                               RANGE 1-128
			                                                    DEFAULT 64]
			x	[-external_router_active                           CHOICES 0 1]
			x	[-external_router_origin                           CHOICES internal external]
			 	[-external_up_down_bit                             CHOICES 0 1]
			 	[-external_metric                                  NUMERIC]
			x	[-routerange_ipv6_r_flag                           CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-routerange_ipv6_n_flag                           CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-routerange_ipv6_p_flag                           CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-routerange_ipv6_e_flag                           CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-routerange_ipv6_v_flag                           CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-routerange_ipv6_l_flag                           CHOICES 0 1
			x                                                   DEFAULT 0]
			x	[-routerange_ipv6_configure_sid_index_label        CHOICES 0 1
			x                                                   DEFAULT 1]
			x	[-routerange_ipv6_sid_index_label                  RANGE 0-1048575
			x                                                   DEFAULT 1]
			x	[-from_ip_step                                     IPV4]
			x	[-to_ip_step                                       IPV4]
			x	[-from_ipv6_step                                   IPV6]
			x	[-to_ipv6_step                                     IPV6]
		
		Arguments:
			 	-handle
			 		This option represents the handle the user *must* pass to the
			 		"emulation_isis_network_group_config" procedure. This option
			 		specifies on which ISIS router to configure the ISIS topology.
			 		The ISIS router handle(s) are returned by the procedure
			 		"emulation_isis_config" when configuring ISIS routers on the
			 		Ixia interface.
			 	-mode
			 		Mode of the procedure call.Valid choices are: create modify delete.
			    		create -
			    		modify -
			    		delete -
			 	-type
			 		The type of topology route to create.
			 		Valid choices are:
			    		grid -
			    		mesh -
			    		custom -
			    		ring -
			    		hub-and-spoke -
			    		tree -
			    		ipv4-prefix -
			    		ipv6-prefix -
			    		fat-tree-
			    		linear -
			x	-protocol_name
			x	-multiplier
			x	-connected_to_handle
			x		Scenario element this connector is connecting to
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			x	-enable_device
			x		enables/disables device.
			 	-grid_row
			 		Define number of rows in a grid.
			 	-grid_col
			 		Define number of columns in a grid.
			x	-grid_include_emulated_device
			x	-grid_link_multiplier
			x	-mesh_number_of_nodes
			x	-mesh_include_emulated_device
			x	-mesh_link_multiplier
			x	-ring_number_of_nodes
			x	-ring_include_emulated_device
			x	-ring_link_multiplier
			x	-hub_spoke_number_of_first_level
			x	-hub_spoke_number_of_second_level
			x	-hub_spoke_enable_level_2
			x	-hub_spoke_link_multiplier
			x	-tree_number_of_nodes
			x	-tree_include_emulated_device
			x	-tree_use_tree_depth
			x	-tree_depth
			x	-tree_max_children_per_node
			x	-tree_link_multiplier
			x	-custom_link_multiplier
			x		number of links between two nodes
			x	-custom_from_node_index
			x	-custom_to_node_index
			x	-fat_tree_link_multiplier
			x		number of links between two nodes
			x	-fat_tree_level_count
			x		Number of Levels
			x	-fat_tree_node_count
			x		Number of Nodes Per Level
			x	-linear_nodes
			x		number of nodes
			x	-linear_link_multiplier
			x		number of links between two nodes
			x	-sim_topo_active
			x		Active Simulated Topology Config
			x	-sim_topo_enable_host_name
			x		Active Simulated Topology Config
			x	-sim_topo_host_name
			x		Simulated Topology Host Name
			x	-sim_topo_ipv4_node_route_count
			x		Simulated Topology Ipv4 Node Route Count
			x	-sim_topo_ipv6_node_route_count
			x		Simulated Topology Ipv6 Node Route Count
			x	-grid_router_route_step
			x		The step for the route in the grid node route entry.
			x	-grid_node_step
			x		grid ipv4 Node route step
			x	-grid_ipv6_router_route_step
			x		The step for the route in the grid node route entry.
			x	-grid_ipv6_node_step
			x		grid ipv4 Node route step
			 	-router_system_id
			 		This is typically 6-octet long hex characters.
			x	-node_active
			x		Flag.
			 	-router_te
			 		If true (1), enable traffic engineering.
			 	-router_id
			 		This is used for traffic engineering.
			x	-enable_wide_metric
			x	-enable_mt_ipv6
			x	-ipv6_mt_metric
			x	-pseudo_node_enable_sr
			x		This will enable segment routing on an ISIS pseudo node (simulated router)
			x	-pseudo_node_rtrcap_id
			x		Router capability identifier for SR enabled ISIS pseudo node
			x	-pseudo_node_d_bit
			x		D bit for SR enabled ISIS pseudo node
			x	-pseudo_node_s_bit
			x		S bit for SR enabled ISIS pseudo node
			x	-pseudo_node_ipv4_flag
			x		I flag for SR enabled ISIS pseudo node
			x	-pseudo_node_ipv6_flag
			x		V flag for SR enabled ISIS pseudo node
			x	-pseudo_node_node_prefix
			x		It uniquely identifies the SR enabled ISIS pseudo node
			x	-pseudo_node_mask
			x		Mask for node prefix corresponding to SR enabled ISIS pseudo node
			x	-pseudo_node_redistribution
			x		Possible choices are UP or DOWN for SR enabled ISIS pseudo node
			x		Valid choices are:
			x   		up -
			x   		down -
			x	-pseudo_node_r_flag
			x		Readvertisement flag for SR enabled ISIS pseudo node
			x	-pseudo_node_n_flag
			x		Node SID flag for SR enabled ISIS pseudo node
			x	-pseudo_node_p_flag
			x		PHP (penultimate hop popping) flag for SR enabled ISIS pseudo node
			x	-pseudo_node_e_flag
			x		E flag for SR enabled ISIS pseudo node
			x	-pseudo_node_v_flag
			x		Value flag for SR enabled ISIS pseudo node
			x	-pseudo_node_l_flag
			x		L flag for SR enabled ISIS pseudo node
			x	-pseudo_node_configure_sid_index_label
			x		If enabled, then the nodal SID for SR enabled ISIS pseudo node will not be taken from the SRGB range, rather it will be the value of SID index label
			x	-pseudo_node_sid_index_label
			x		This is the value which will be used to set the nodal SID of the SR enabled ISIS pseudo node if configure sid index label option has been enabled
			x	-pseudo_node_srgb_range_count
			x		How many ranges the user wants to create in the SRGB range of SR enabled ISIS pseudo node. Max is 5
			x	-pseudo_node_start_sid_label
			x		Start SID in one SRGB range for SR enabled ISIS pseudo node
			x	-pseudo_node_sid_count
			x		Total count of SIDs in that SRGB range for SR enabled ISIS pseudo node
			x	-ipv6_srh_flag_pseudo_router
			x		Router will advertise and process IPv6 SR related TLVs
			x	-pseudo_node_sr_algo_count
			x		SR Algorithm Count
			x	-pseudo_node_isis_sr_algorithm
			x		SR Algorithm
			x	-pseudo_node_algorithm
			x		It specifies Algorithm value corresponding to a pseudo node and it can be like SPF
			x	-advertise_srlb
			x		Enables advertisement of Segment Routing Local Block (SRLB)
			x	-srlb_flags
			x		This specifies the value of the SRLB flags field
			x	-srlb_descriptor_count
			x		Count of the SRLB descriptor entries
			x	-srlbDescriptor_startSidLabel
			x		Start SID/Label
			x	-srlbDescriptor_sidCount
			x		SID Count
			x	-grid_router_active
			x		If set, then the IPv4 pseudo node routes will get advertised
			 	-grid_router_id
			 		IPv4 type network prefix address corresponding to the pseudo node route.
			 	-grid_stub_per_router
			 		Number of IPv4 network addresses (pseudo node routes).
			 	-grid_router_ip_pfx_len
			 		IPv4 prefix length for the corresponding IPv4 network address (pseudo node routes).
			 	-grid_router_metric
			 		Route metric corresponding to the IPv4 pseudo node routes
			 	-grid_router_origin
			 		The origin of the routes advertised by the grid nodes.Choices are internal and external (or Choices are internal or external).
			 	-grid_router_up_down_bit
			 		This is the up down bit associated with the routes advertised by the
			 		grid nodes.If 1, the route will be distributed down.If 0, the
			 		route will be redistributed up.
			 		Valid choices are:
			    		0 - 0 up
			    		1 - 1 down
			x	-pseudo_node_route_ipv4_r_flag
			x		R flag corresponding to IPv4 pseudo node route
			x	-pseudo_node_route_ipv4_n_flag
			x		N flag corresponding to IPv4 pseudo node route
			x	-pseudo_node_route_ipv4_p_flag
			x		P flag corresponding to IPv4 pseudo node route
			x	-pseudo_node_route_ipv4_e_flag
			x		E flag corresponding to IPv4 pseudo node route
			x	-pseudo_node_route_ipv4_v_flag
			x		V flag corresponding to IPv4 pseudo node route
			x	-pseudo_node_route_ipv4_l_flag
			x		L flag corresponding to IPv4 pseudo node route
			x	-pseudo_node_route_ipv4_configure_sid_index_label
			x		If set, then all the pseudo node routes (IPv4 type) will take SID/ index from SID index label field and not from the SRGB range being configured under ISIS pseudo node, otherwise SID/ indexes will be assigned to them from the configured SRGB range
			x	-pseudo_node_route_ipv4_sid_index_label
			x		If pseudo node route IPv4 configure SID index label has been enabled, then the IPv4 prefixes corresponding to the pseudo node routes will be assigned with the SID/ index from the SID index label field depending on the configured V flag
			x	-grid_ipv6_router_active
			x		If set, then the IPv6 pseudo node routes will get advertised
			x	-grid_ipv6_router_id
			x		IPv6 type network prefix address corresponding to the pseudo node route.
			x	-grid_ipv6_stub_per_router
			x		Number of IPv6 network addresses (pseudo node routes)
			x	-grid_ipv6_router_ip_pfx_len
			x		IPv6 prefix length for the corresponding IPv6 network address (pseudo node routes)
			x	-grid_ipv6_router_metric
			x		Route metric corresponding to the IPv6 pseudo node routes
			x	-grid_ipv6_router_origin
			x		The origin of the routes advertised by the grid nodes.Choices are internal and external.
			x	-grid_ipv6_router_up_down_bit
			x		This is the up down bit associated with the routes advertised by the
			x		grid nodes.If 1, the route will be distributed down.If 0, the
			x		route will be redistributed up.
			x		Valid choices are:
			x   		0 - 0 up
			x   		1 - 1 down
			x	-pseudo_node_route_ipv6_r_flag
			x		R flag corresponding to IPv6 pseudo node route
			x	-pseudo_node_route_ipv6_n_flag
			x		N flag corresponding to IPv6 pseudo node route
			x	-pseudo_node_route_ipv6_p_flag
			x		P flag corresponding to IPv6 pseudo node route
			x	-pseudo_node_route_ipv6_e_flag
			x		E flag corresponding to IPv6 pseudo node route
			x	-pseudo_node_route_ipv6_v_flag
			x		V flag corresponding to IPv6 pseudo node route
			x	-pseudo_node_route_ipv6_l_flag
			x		L flag corresponding to IPv6 pseudo node route
			x	-pseudo_node_route_ipv6_configure_sid_index_label
			x		If set, then all the pseudo node routes (IPv6 type) will take SID/ index from SID index label field and not from the SRGB range being configured under ISIS pseudo node, otherwise SID/ indexes will be assigned to them from the configured SRGB range.
			x	-pseudo_node_route_ipv6_sid_index_label
			x		If pseudo node route IPv6 configure SID index label has been enabled, then the IPv6 prefixes pseudo node routes will be assigned with the SID/ index from the SID index label field depending on the configured V flag.
			x	-external_link_router_source
			x		Index of the originating node as defined in fromNetworkTopology
			x	-external_link_router_destination
			x		Index of the target node as defined in toNetworkTopology
			x	-external_link_network_group_handle
			x		Network Topology this link is pointing to
			x	-enable_ip
			x		Enable IPv4
			x	-from_ip
			x	-to_ip
			x	-subnet_prefix_length
			x	-enable_ipv6
			x		Enable IPv6
			x	-from_ipv6
			x	-to_ipv6
			x	-subnet_ipv6_prefix_length
			x	-link_type
			x		Link Type
			x		Valid choices are:
			x   		pttopt -
			x   		broadcast -
			x	-si_enable_adj_sid
			x		Enables adjacent SID for SR enabled ISIS pseudo interface
			x	-si_adj_sid
			x		Adjacent SID for SR enabled ISIS pseudo interface
			x	-si_override_f_flag
			x		Override F flag option for SR enabled ISIS pseudo interface
			x	-si_f_flag
			x		F flag for SR enabled ISIS pseudo interface
			x	-si_b_flag
			x		B flag for SR enabled ISIS pseudo interface
			x	-si_v_flag
			x		Value flag for SR enabled ISIS pseudo interface
			x	-si_l_flag
			x		L flag for SR enabled ISIS pseudo interface
			x	-si_s_flag
			x		S flag for SR enabled ISIS pseudo interface
			x	-si_p_flag
			x		P flag for SR enabled ISIS pseudo interface
			x	-si_weight
			x		Weight value of the adjacent link for SR enabled ISIS pseudo interface
			x	-enable_link_protection
			x		This enables the link protection on the ISIS link between two mentioned interfaces.
			x	-extra_traffic
			x		This is a Protection Scheme with value 0x01. It means that the link is protecting another link or links.The LSPs on a link of this type will be lost if any of the links it is protecting fail.
			x	-unprotected
			x		This is a Protection Scheme with value 0x02. It means that there is no other link protecting this link.The LSPs on a link of this type will be lost if the link fails.
			x	-shared
			x		This is a Protection Scheme with value 0x04. It means that there are one or more disjoint links of type Extra Traffic that are protecting this link.These Extra Traffic links are shared between one or more links of type Shared.
			x	-dedicated_one_to_one
			x		This is a Protection Scheme with value 0x08. It means that there is one dedicated disjoint link of type Extra Traffic that is protecting this link.
			x	-dedicated_one_plus_one
			x		This is a Protection Scheme with value 0x10. It means that a dedicated disjoint link is protecting this link.However, the protecting link is not advertised in the link state database and is therefore not available for the routing of LSPs.
			x	-enhanced
			x		This is a Protection Scheme with value 0x20. It means that a protection scheme that is more reliable than Dedicated 1+1, e.g., 4 fiber BLSR/MS-SPRING, is being used to protect this link.
			x	-reserved0x40
			x		This is a Protection Scheme with value 0x40.
			x	-reserved0x80
			x		This is a Protection Scheme with value 0x80.
			x	-pseudo_node_enable_srlg
			x		This enables the SRLG on the ISIS link between two mentioned interfaces.
			x	-pseudo_node_srlg_count
			x		This field value shows how many SRLG Value columns would be there in the GUI.
			x	-pseudo_node_srlg_value
			x		This is the SRLG Value for the link between two mentioned interfaces.
			x	-from_node_active
			x		Flag
			x		Active Simulated Interface Config for From-Node
			x	-from_node_link_metric
			x		Link Metric From-Node
			x	-to_node_active
			x		Flag
			x		Active Simulated Interface Config for To-Node
			x	-to_node_link_metric
			x		Link Metric To-Node
			 	-admin_group
			 		The administrative group associated with the link, expressed as the
			 		decimal equivalent of 32-bit number. in 4-byte hex format.
			x	-metric_level
			x		The metric associated with the interface that the TE data is advertised
			x		on.
			 	-max_bw
			 		Maximum bandwidth that can be used on this link expressed as octets
			 		per second.
			 	-max_resv_bw
			 		Maximum bandwidth that may be reserved on this link.This may be
			 		greater than the actual max to allow a link to be oversubscribed.
			 		It is expressed as octets per second.
			 	-bw_priority0
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 0 priority level.This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 0.The value must be less than the linke_te_max_resv_bw
			 		option.
			 	-bw_priority1
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 1 priority level.This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 1.The value must be less than the linke_te_max_resv_bw
			 		option.
			 	-bw_priority2
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 1 priority level.This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 1.The value must be less than the linke_te_max_resv_bw
			 		option.
			 	-bw_priority3
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 1 priority level.This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 1.The value must be less than the linke_te_max_resv_bw
			 		option.
			 	-bw_priority4
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 1 priority level.This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 1.The value must be less than the linke_te_max_resv_bw
			 		option.
			 	-bw_priority5
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 1 priority level.This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 1.The value must be less than the linke_te_max_resv_bw
			 		option.
			 	-bw_priority6
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 1 priority level.This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 1.The value must be less than the linke_te_max_resv_bw
			 		option.
			 	-bw_priority7
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 1 priority level.This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 1.The value must be less than the linke_te_max_resv_bw
			 		option.
			 	-ipv4_prefix_network_address
			 		The IP address of the first stub network route to be advertised.
			x	-ipv4_prefix_number_of_addresses
			x		For IxTclProtocol it sets the number of routes in a L3 Route Range.
			x		This paramter will be ignored if the -stub_router is also given.
			x		For IxTclNetwork it sets the the number of router in a L3 Route Range
			x		and will be advertised for stub network.
			 	-ipv4_prefix_length
			 		The number of bits in the prefixes to be advertised.
			x	-stub_router_active
			x	-stub_router_origin
			x		The origin of the routes advertised by the grid nodes.Choices are
			x		internal and external.
			 	-stub_up_down_bit
			 		If 1, the route will be distributed down.If 0, the route will be
			 		distributed up.
			 		Valid choices are:
			    		0 - 0 up
			    		1 - 1 down
			 	-stub_metric
			 		The cost metric associated with the stub network route.
			x	-routerange_ipv4_r_flag
			x		R flag for ISIS IPv4 route range (prefix pool)
			x	-routerange_ipv4_n_flag
			x		N flag for ISIS IPv4 route range (prefix pool)
			x	-routerange_ipv4_p_flag
			x		P flag for ISIS IPv4 route range (prefix pool)
			x	-routerange_ipv4_e_flag
			x		E flag for ISIS IPv4 route range (prefix pool)
			x	-routerange_ipv4_v_flag
			x		V flag (Value flag) for ISIS IPv4 route range (prefix pool)
			x	-routerange_ipv4_l_flag
			x		L flag for ISIS IPv4 route range (prefix pool)
			x	-routerange_ipv4_configure_sid_index_label
			x		If set, then all the prefixes in that prefix pool (IPv4 type) will take SID/ index from SID index label field and not from the SRGB range being configured under ISIS-L3 router, otherwise SID/ indexes will be assigned to the prefixes from the configured SRGB range
			x	-routerange_ipv4_sid_index_label
			x		If IPv4 configure SID index label has been enabled, then the IPv4 prefixes in the prefix pool will be assigned with the SID/ index from the SID index label field depending on the configured V flag
			 	-ipv6_prefix_network_address
			 		The IPv6 address of the first external network route to be advertised.
			x	-ipv6_prefix_number_of_addresses
			x		For IxTclProtocol it sets the number of routes in a L3 Route Range.
			x		This paramter will be ignored if the -external_router is also given.
			x		For IxTclNetwork it sets the the number of router in a L3 Route Range
			x		and will be advertised for external network.
			 	-ipv6_prefix_length
			 		The number of bits in the prefixes to be advertised in a IPV6 external
			 		network.
			x	-external_router_active
			x	-external_router_origin
			x		The origin of the routes advertised by the grid nodes.Choices are
			x		internal and external.
			 	-external_up_down_bit
			 		If 1, the route will be distributed down.If 0, the route will be
			 		distributed up.
			 		Valid choices are:
			    		0 - 0 up
			    		1 - 1 down
			 	-external_metric
			 		The cost metric associated with the external network route.
			x	-routerange_ipv6_r_flag
			x		R flag for ISIS IPv6 route range (prefix pool)
			x	-routerange_ipv6_n_flag
			x		N flag for ISIS IPv6 route range (prefix pool)
			x	-routerange_ipv6_p_flag
			x		P flag for ISIS IPv6 route range (prefix pool)
			x	-routerange_ipv6_e_flag
			x		E flag for ISIS IPv6 route range (prefix pool)
			x	-routerange_ipv6_v_flag
			x		V flag (Value flag) for ISIS IPv6 route range (prefix pool)
			x	-routerange_ipv6_l_flag
			x		L flag for ISIS IPv6 route range (prefix pool)
			x	-routerange_ipv6_configure_sid_index_label
			x		If set, then all the prefixes in that prefix pool (IPv6 type) will take SID/ index from SID index label field and not from the SRGB range being configured under ISIS-L3 router, otherwise SID/ indexes will be assigned to the prefixes from the configured SRGB range
			x	-routerange_ipv6_sid_index_label
			x		If IPv6 configure SID index label has been enabled, then the IPv6 prefixes in the prefix pool will be assigned with the SID/ index from the SID index label field depending on the configured V flag
			x	-from_ip_step
			x	-to_ip_step
			x	-from_ipv6_step
			x	-to_ipv6_step
		
		Return Values:
		A list containing the network group protocol stack handles that were added by the command (if any).
			xkey:network_group_handle                    value:A list containing the network group protocol stack handles that were added by the command (if any).
		A list containing the simulated topology protocol stack handles that were added by the command (if any).
			xkey:simulated_topology_handle               value:A list containing the simulated topology protocol stack handles that were added by the command (if any).
		A list containing the simulated interface ipv4 protocol stack handles that were added by the command (if any).
			xkey:simulated_interface_ipv4_handle         value:A list containing the simulated interface ipv4 protocol stack handles that were added by the command (if any).
		A list containing the simulated interface ipv6 protocol stack handles that were added by the command (if any).
			xkey:simulated_interface_ipv6_handle         value:A list containing the simulated interface ipv6 protocol stack handles that were added by the command (if any).
		A list containing the to node protocol stack handles that were added by the command (if any).
			xkey:to_node_handle                          value:A list containing the to node protocol stack handles that were added by the command (if any).
		A list containing the from node protocol stack handles that were added by the command (if any).
			xkey:from_node_handle                        value:A list containing the from node protocol stack handles that were added by the command (if any).
		A list containing the pseudo node srlg range protocol stack handles that were added by the command (if any).
			xkey:pseudo_node_srlg_range_handle           value:A list containing the pseudo node srlg range protocol stack handles that were added by the command (if any).
		A list containing the simulated rbridge protocol stack handles that were added by the command (if any).
			xkey:simulated_rbridge_handle                value:A list containing the simulated rbridge protocol stack handles that were added by the command (if any).
		A list containing the pseudo node protocol stack handles that were added by the command (if any).
			xkey:pseudo_node_handle                      value:A list containing the pseudo node protocol stack handles that were added by the command (if any).
		A list containing the pseudo node srgb range protocol stack handles that were added by the command (if any).
			xkey:pseudo_node_srgb_range_handle           value:A list containing the pseudo node srgb range protocol stack handles that were added by the command (if any).
		A list containing the pseudo node ipv4 route protocol stack handles that were added by the command (if any).
			xkey:pseudo_node_ipv4_route_handle           value:A list containing the pseudo node ipv4 route protocol stack handles that were added by the command (if any).
		A list containing the pseudo node ipv6 route protocol stack handles that were added by the command (if any).
			xkey:pseudo_node_ipv6_route_handle           value:A list containing the pseudo node ipv6 route protocol stack handles that were added by the command (if any).
		A list containing the pseudo node sr algoList protocol stack handles that were added by the command (if any).
			xkey:pseudo_node_sr_algoList_handle          value:A list containing the pseudo node sr algoList protocol stack handles that were added by the command (if any).
		A list containing the pseudo node srlb descriptorList protocol stack handles that were added by the command (if any).
			xkey:pseudo_node_srlb_descriptorList_handle  value:A list containing the pseudo node srlb descriptorList protocol stack handles that were added by the command (if any).
		A list containing the ipv4 prefix interface protocol stack handles that were added by the command (if any).
			xkey:ipv4_prefix_interface_handle            value:A list containing the ipv4 prefix interface protocol stack handles that were added by the command (if any).
		A list containing the ipv6 prefix interface protocol stack handles that were added by the command (if any).
			xkey:ipv6_prefix_interface_handle            value:A list containing the ipv6 prefix interface protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:simulated_topology_handles              value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:simulated_interface_ipv4_handles        value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:simulated_interface_ipv6_handles        value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:to_node_handles                         value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:from_node_handle                        value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:pseudo_node_srlg_range_handles          value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:simulated_rbridge_handles               value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:pseudo_node_handles                     value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:pseudo_node_srgb_range_handles          value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:pseudo_node_ipv4_route_handles          value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:pseudo_node_ipv6_route_handles          value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:pseudo_node_sr_algoList_handles         value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:pseudo_node_srlb_descriptorList_handle  value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:ipv4_prefix_interface_handles           value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:ipv6_prefix_interface_handles           value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  simulated_topology_handles, simulated_interface_ipv4_handles, simulated_interface_ipv6_handles, to_node_handles, from_node_handle, pseudo_node_srlg_range_handles, simulated_rbridge_handles, pseudo_node_handles, pseudo_node_srgb_range_handles, pseudo_node_ipv4_route_handles, pseudo_node_ipv6_route_handles, pseudo_node_sr_algoList_handles, pseudo_node_srlb_descriptorList_handle, ipv4_prefix_interface_handles, ipv6_prefix_interface_handles
		
		See Also:
		
		"""
		return self._run_keyword("emulation_isis_network_group_config", kwargs)

	def emulation_isis_topology_route_config(self, **kwargs):
		""" This procedure creates or modifies or deletes routes from an emulated IS-IS router of Ixia Interface. This function also configures the properties of the IS-IS routes.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_isis_topology_route_config
			 	[-elem_handle                          ANY]
			 	[-external_count                       ANY]
			x	[-external_route_count                 ANY]
			 	[-external_ip_pfx_len                  ANY]
			 	[-external_ip_start                    ANY]
			 	[-external_ip_step                     ANY]
			 	[-external_ipv6_pfx_len                ANY]
			 	[-external_ipv6_start                  ANY]
			 	[-external_ipv6_step                   ANY]
			 	[-external_metric                      ANY]
			 	[-external_up_down_bit                 ANY]
			 	[-grid_col                             ANY]
			 	[-grid_connect                         ANY]
			x	[-grid_outside_link                    ANY]
			x	[-grid_ol_connection_row               ANY]
			x	[-grid_ol_connection_col               ANY]
			x	[-grid_ol_linked_rid                   ANY]
			x	[-grid_ol_ip_and_prefix                ANY]
			x	[-grid_ol_admin_group                  ANY]
			x	[-grid_ol_metric                       ANY]
			x	[-grid_ol_max_bw                       ANY]
			x	[-grid_ol_max_resv_bw                  ANY]
			x	[-grid_ol_unresv_bw_priority0          ANY]
			x	[-grid_ol_unresv_bw_priority1          ANY]
			x	[-grid_ol_unresv_bw_priority2          ANY]
			x	[-grid_ol_unresv_bw_priority3          ANY]
			x	[-grid_ol_unresv_bw_priority4          ANY]
			x	[-grid_ol_unresv_bw_priority5          ANY]
			x	[-grid_ol_unresv_bw_priority6          ANY]
			x	[-grid_ol_unresv_bw_priority7          ANY]
			 	[-grid_ip_step                         ANY]
			 	[-grid_ipv6_pfx_len                    ANY]
			 	[-grid_ipv6_start                      ANY]
			 	[-grid_ipv6_step                       ANY]
			 	[-grid_link_type                       ANY]
			 	[-grid_router_id                       ANY]
			 	[-grid_router_id_step                  ANY]
			 	[-grid_router_ip_pfx_len               ANY]
			 	[-grid_row                             ANY]
			 	[-grid_start_system_id                 ANY]
			 	[-grid_start_te_ip                     ANY]
			 	[-grid_stub_per_router                 ANY]
			 	[-grid_te                              ANY]
			 	[-grid_te_max_resv_bw                  ANY]
			 	[-handle                               ANY]
			 	[-ip_version                           ANY]
			n	[-link_enable                          ANY]
			 	[-link_ip_addr                         ANY]
			 	[-link_ip_prefix_length                ANY]
			 	[-link_ipv6_addr                       ANY]
			 	[-link_ipv6_prefix_length              ANY]
			 	[-link_multi_topology                  ANY]
			 	[-link_narrow_metric                   ANY]
			 	[-link_te                              ANY]
			 	[-link_te_admin_group                  ANY]
			 	[-link_te_max_bw                       ANY]
			 	[-link_te_max_resv_bw                  ANY]
			 	[-link_te_unresv_bw_priority0          ANY]
			 	[-link_te_unresv_bw_priority1          ANY]
			 	[-link_te_unresv_bw_priority2          ANY]
			 	[-link_te_unresv_bw_priority3          ANY]
			 	[-link_te_unresv_bw_priority4          ANY]
			 	[-link_te_unresv_bw_priority5          ANY]
			 	[-link_te_unresv_bw_priority6          ANY]
			 	[-link_te_unresv_bw_priority7          ANY]
			 	[-link_wide_metric                     ANY]
			 	-mode                                  ANY
			 	[-router_area_id                       ANY]
			 	[-router_id                            ANY]
			 	[-router_system_id                     ANY]
			 	[-router_te                            ANY]
			 	[-stub_count                           ANY]
			x	[-stub_route_count                     ANY]
			 	[-stub_ip_pfx_len                      ANY]
			 	[-stub_ip_start                        ANY]
			 	[-stub_ip_step                         ANY]
			 	[-stub_ipv6_pfx_len                    ANY]
			 	[-stub_ipv6_start                      ANY]
			 	[-stub_ipv6_step                       ANY]
			 	[-stub_metric                          ANY]
			 	[-stub_up_down_bit                     ANY]
			 	[-type                                 ANY]
			x	[-dce_bcast_root_pri                   ANY]
			x	[-dce_bcast_root_pri_step              ANY]
			x	[-dce_connection_column                ANY]
			x	[-dce_connection_row                   ANY]
			x	[-dce_device_id                        ANY]
			x	[-dce_device_id_step                   ANY]
			x	[-dce_device_pri                       ANY]
			x	[-dce_ftag                             ANY]
			x	[-dce_ftag_enable                      ANY]
			x	[-dce_include_groups                   ANY]
			x	[-dce_intra_grp_ucast_step             ANY]
			x	[-dce_inter_grp_ucast_step             ANY]
			x	[-dce_linked_router_id                 ANY]
			x	[-dce_local_entry_point_column         ANY]
			x	[-dce_local_entry_point_row            ANY]
			x	[-dce_local_link_metric                ANY]
			x	[-dce_local_num_columns                ANY]
			x	[-dce_local_num_rows                   ANY]
			x	[-dce_mcast_addr_count                 ANY]
			x	[-dce_mcast_addr_node_step             ANY]
			x	[-dce_mcast_addr_step                  ANY]
			x	[-dce_mcast_start_addr                 ANY]
			x	[-dce_num_mcast_destination_trees      ANY]
			x	[-dce_src_grp_mapping                  ANY]
			x	[-dce_system_id                        ANY]
			x	[-dce_system_id_step                   ANY]
			x	[-dce_ucast_addr_node_step             ANY]
			x	[-dce_ucast_sources_per_mcast_addr     ANY]
			x	[-dce_ucast_src_addr                   ANY]
			x	[-dce_vlan_id                          ANY]
			x	[-grid_interface_metric                ANY]
			x	[-grid_ip_pfx_len                      ANY]
			x	[-grid_router_count                    ANY]
			x	[-grid_router_ip_version               ANY]
			x	[-grid_router_metric                   ANY]
			x	[-grid_router_origin                   ANY]
			x	[-grid_router_route_step               ANY]
			x	[-grid_router_up_down_bit              ANY]
			x	[-grid_system_id_step                  ANY]
			x	[-grid_te_admin                        ANY]
			x	[-grid_te_ip_step                      ANY]
			x	[-grid_te_max_bw                       ANY]
			x	[-grid_te_metric                       ANY]
			x	[-grid_te_override_admin               ANY]
			x	[-grid_te_override_enable              ANY]
			x	[-grid_te_override_max_bw              ANY]
			x	[-grid_te_override_max_resv_bw         ANY]
			x	[-grid_te_override_metric              ANY]
			x	[-grid_te_override_unresv_bw_priority0 ANY]
			x	[-grid_te_override_unresv_bw_priority1 ANY]
			x	[-grid_te_override_unresv_bw_priority2 ANY]
			x	[-grid_te_override_unresv_bw_priority3 ANY]
			x	[-grid_te_override_unresv_bw_priority4 ANY]
			x	[-grid_te_override_unresv_bw_priority5 ANY]
			x	[-grid_te_override_unresv_bw_priority6 ANY]
			x	[-grid_te_override_unresv_bw_priority7 ANY]
			x	[-grid_te_path_admin                   ANY]
			x	[-grid_te_path_count                   ANY]
			x	[-grid_te_path_start_row               ANY]
			x	[-grid_te_path_start_col               ANY]
			x	[-grid_te_path_end_row                 ANY]
			x	[-grid_te_path_end_col                 ANY]
			x	[-grid_te_path_row_step                ANY]
			x	[-grid_te_path_col_step                ANY]
			x	[-grid_te_path_bidir                   ANY]
			x	[-grid_te_path_max_bw                  ANY]
			x	[-grid_te_path_max_resv_bw             ANY]
			x	[-grid_te_path_metric                  ANY]
			x	[-grid_te_path_unresv_bw_priority0     ANY]
			x	[-grid_te_path_unresv_bw_priority1     ANY]
			x	[-grid_te_path_unresv_bw_priority2     ANY]
			x	[-grid_te_path_unresv_bw_priority3     ANY]
			x	[-grid_te_path_unresv_bw_priority4     ANY]
			x	[-grid_te_path_unresv_bw_priority5     ANY]
			x	[-grid_te_path_unresv_bw_priority6     ANY]
			x	[-grid_te_path_unresv_bw_priority7     ANY]
			x	[-grid_te_unresv_bw_priority0          ANY]
			x	[-grid_te_unresv_bw_priority1          ANY]
			x	[-grid_te_unresv_bw_priority2          ANY]
			x	[-grid_te_unresv_bw_priority3          ANY]
			x	[-grid_te_unresv_bw_priority4          ANY]
			x	[-grid_te_unresv_bw_priority5          ANY]
			x	[-grid_te_unresv_bw_priority6          ANY]
			x	[-grid_te_unresv_bw_priority7          ANY]
			x	[-grid_user_wide_metric                ANY]
			x	[-link_te_metric                       ANY]
			x	[-no_write                             ANY]
			n	[-external_connect                     ANY]
			n	[-external_metric_type                 ANY]
			n	[-grid_connect_session                 ANY]
			n	[-grid_disconnect                      ANY]
			n	[-link_external                        ANY]
			n	[-link_te_remote_ip_addr               ANY]
			n	[-link_te_remote_ipv6_addr             ANY]
			n	[-link_up_down_bit                     ANY]
			n	[-router_attached_bit                  ANY]
			n	[-router_connect                       ANY]
			n	[-router_disconnect                    ANY]
			n	[-router_host_name                     ANY]
			n	[-router_overload_bit                  ANY]
			n	[-router_pseudonode_num                ANY]
			n	[-router_routing_level                 ANY]
			n	[-stub_connect                         ANY]
			n	[-stub_ip_step                         ANY]
		
		Arguments:
			 	-elem_handle
			 		This option specifies on which topology element to configure the route options. The user must pass in this option if the -mode is modify or delete. The value must be provided with an extra set of braces.
			 	-external_count
			 		For IxTclProtocol it sets the number of routes in a L3 Route Range.The -external_route_count parameter will be ignored if they are both given.For IxTclNetwork it sets the number of L3 Route Ranges that are createdand will be advertised for external network.
			x	-external_route_count
			x		For IxTclProtocol it sets the number of routes in a L3 Route Range.This paramter will be ignored if the -external_router is also given.For IxTclNetwork it sets the the number of router in a L3 Route Rangeand will be advertised for external network.
			 	-external_ip_pfx_len
			 		The number of bits in the prefixes to be advertised.
			 	-external_ip_start
			 		The IP address of the first external network route to be advertised.
			 	-external_ip_step
			 		The IPv4 incrementing step for the external network route to be advertised.
			 	-external_ipv6_pfx_len
			 		The number of bits in the prefixes to be advertised in a IPV6 external network.
			 	-external_ipv6_start
			 		The IPv6 address of the first external network route to be advertised.
			 	-external_ipv6_step
			 		The IPv6 incrementing step for the external network route to be advertised.
			 	-external_metric
			 		The cost metric associated with the external network route.
			 	-external_up_down_bit
			 		If 1, the route will be distributed down.If 0, the route will be distributed up.
			 	-grid_col
			 		Define number of columns in a grid.
			 	-grid_connect
			 		The session router is connected to a router in the grid at a particular row column location.This option specifies the row column location.
			x	-grid_outside_link
			x		If true (1), enable outside link on the network range. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_connection_row
			x		Define the connection row of the outside link. A list of values can beprovided for multiple outside links. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_connection_col
			x		Define the connection column of the outside link. A list of values can be provided for multiple outside links. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_linked_rid
			x		Define the linked router ID of the outside link. A list of values can be provided for multiple outside links. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_ip_and_prefix
			x		Define the combination of IP and prefix of the outside link. A list of comma separated values can be provided for multiple outside links. The comma separated values contains the multiple IP Address supported per link. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_admin_group
			x		Define the administrator group ID of the outside link. A list of values can be provided for multiple outside links. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_metric
			x		Define the metric of the outside link. A list of values can be provided for multiple outside links. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_max_bw
			x		Define the maximum bandwidth of the outside link. A list of values can be provided for multiple outside links. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_max_resv_bw
			x		Define the maximum reservable bandwidht of the outside link. A list of values can be provided for multiple outside links. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_unresv_bw_priority0
			x		Define the unreserved priority 0 bandwidth of the outside link. A list of values can be provided for multiple outside links. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_unresv_bw_priority1
			x		Define the unreserved priority 1 bandwidth of the outside link. A list of values can be provided for multiple outside links. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_unresv_bw_priority2
			x		Define the unreserved priority 2 bandwidth of the outside link. A list of values can be provided for multiple outside links. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_unresv_bw_priority3
			x		Define the unreserved priority 3 bandwidth of the outside link. A list of values can be provided for multiple outside links. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_unresv_bw_priority4
			x		Define the unreserved priority 4 bandwidth of the outside link. A list of values can be provided for multiple outside links. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_unresv_bw_priority5
			x		Define the unreserved priority 5 bandwidth of the outside link. A list of values can be provided for multiple outside links. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_unresv_bw_priority6
			x		Define the unreserved priority 6 bandwidth of the outside link. A list of values can be provided for multiple outside links. This paramater is supported with IxTclNetwork only.
			x	-grid_ol_unresv_bw_priority7
			x		Define the unreserved priority 7 bandwidth of the outside link. A list of values can be provided for multiple outside links. This paramater is supported with IxTclNetwork only.
			 	-grid_ip_step
			 		The step between assigned networks in a grid.
			 	-grid_ipv6_pfx_len
			 		The number of bits in the network mask of IPV6 address used in a grid.
			 	-grid_ipv6_start
			 		The IPV6 address of the first router in a grid.
			 	-grid_ipv6_step
			 		The step between assigned networks in a grid.
			 	-grid_link_type
			 		Type of links connecting routers in a grid.Choices are: broadcast ptop.
			 	-grid_router_id
			 		The IP address of the routes to be advertised per router in a grid.
			 	-grid_router_id_step
			 		The increment to be applied to the network part of grid_router_id between per node uses.
			 	-grid_router_ip_pfx_len
			 		The number of bits in the prefixes to be advertised by the grid nodes.
			 	-grid_row
			 		Define number of rows in a grid.
			 	-grid_start_system_id
			 		This is the router ID of the first router in the grid (at row = 0, column = 0).It is specified as a string of 12 hex characters.Range: 000000000000-FFFFFFFFFFF.Routers are assigned individual router IDs by adding the value of the grid_system_id_step each element in the grid, in a row first manner.
			 	-grid_start_te_ip
			 		If grid_te is true, then this is the TE router ID of the first router in the grid (at row=0, column=0), in IPv4 format.Routers are assigned individual TE router IDs by adding the value of the grid_te_ip_step value to each element in the grid, in a row first manner.
			 	-grid_stub_per_router
			 		Define number of stub numbers per router in a grid.
			 	-grid_te
			 		If true (1), enable traffic engineering on the router grid.
			 	-grid_te_max_resv_bw
			 		The maximum reservable bandwidth to be advertised for all nodes in an ISIS grid.
			 	-handle
			 		This option represents the handle the user *must* pass to the "emulation_isis_topology_route_config" procedure. This option specifies on which ISIS router to configure the ISIS topology. The ISIS router handle(s) are returned by the procedure"emulation_isis_config" when configuring ISIS routers on the Ixia interface.
			 	-ip_version
			 		and 4_6.Note that the IP version of topology element cannot be changed after it is created.
			n	-link_enable
			n		If true (1), enable the link.
			 	-link_ip_addr
			 		IP address of the link between the session router and the topology
			 	-link_ip_prefix_length
			 		IP prefix length of the link between the session router and the topology router (router behind the session router).
			 	-link_ipv6_addr
			 		IPV6 address of the link between the session router and the topology router (router behind the session router).
			 	-link_ipv6_prefix_length
			 		IPV6 prefix length of the link between the session router and the topology router (router behind the session router).
			 	-link_multi_topology
			 		Enable multi-topology (MT) support. (always set to 1)
			 	-link_narrow_metric
			 		This value is used for link metric if the wide metric is set to false in the router.
			 	-link_te
			 		If true (1), enable the traffic engineering on the link.
			 	-link_te_admin_group
			 		The administrative group associated with the link, expressed as the decimal equivalent of 32-bit number. in 4-byte hex format.
			 	-link_te_max_bw
			 		Maximum bandwidth that can be used on this link expressed as octets per second.
			 	-link_te_max_resv_bw
			 		Maximum bandwidth that may be reserved on this link.This may be greater than the actual max to allow a link to be oversubscribed. It is expressed as octets per second.
			 	-link_te_unresv_bw_priority0
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth, in bytes per second, not yet reserved at the 0 priority level.This value corresponds to the bandwidth that can be reserved with a setup priority of 0.The value must be less than the linke_te_max_resv_bw option.
			 	-link_te_unresv_bw_priority1
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth, in bytes per second, not yet reserved at the 1 priority level.This value corresponds to the bandwidth that can be reserved with a setup priority of 1.The value must be less than the linke_te_max_resv_bw option.
			 	-link_te_unresv_bw_priority2
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth, in bytes per second, not yet reserved at the 2 priority level.This value corresponds to the bandwidth that can be reserved with a setup priority of 2.The value must be less than the linke_te_max_resv_bw option.
			 	-link_te_unresv_bw_priority3
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth, in bytes per second, not yet reserved at the 3 priority level.This value corresponds to the bandwidth that can be reserved with a setup priority of 3.The value must be less than the linke_te_max_resv_bw option.
			 	-link_te_unresv_bw_priority4
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth, in bytes per second, not yet reserved at the 4 priority level.This value corresponds to the bandwidth that can be reserved with a setup priority of 4.The value must be less than the linke_te_max_resv_bw option.
			 	-link_te_unresv_bw_priority5
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth, in bytes per second, not yet reserved at the 5 priority level.This value corresponds to the bandwidth that can be reserved with a setup priority of 5.The value must be less than the linke_te_max_resv_bw option.
			 	-link_te_unresv_bw_priority6
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth, in bytes per second, not yet reserved at the 6 priority level.This value corresponds to the bandwidth that can be reserved with a setup priority of 6.The value must be less than the linke_te_max_resv_bw option.
			 	-link_te_unresv_bw_priority7
			 		If "-line_te" is 1, then this value indicates the amount of bandwidth, in bytes per second, not yet reserved at the 7 priority level.This value corresponds to the bandwidth that can be reserved with a setup priority of 7.The value must be less than the linke_te_max_resv_bw option.
			 	-link_wide_metric
			 		This value is used for link metric if the wide metric is set to true in the router.
			 	-mode
			 	-router_area_id
			 		The list of area addresses to use.An address is a hex string of up to 4 bytes.This option cannot be modified with modify mode.
			 	-router_id
			 		This is used for traffic engineering.
			 	-router_system_id
			 		This is typically 6-octet long hex characters.
			 	-router_te
			 		If true (1), enable traffic engineering.
			 	-stub_count
			 		For IxTclProtocol it sets the number of routes in a L3 Route Range.The -stub_route_count parameter will be ignored if they are both given.For IxTclNetwork it sets the number of L3 Route Ranges that are createdand will be advertised for stub network.
			x	-stub_route_count
			x		For IxTclProtocol it sets the number of routes in a L3 Route Range.This paramter will be ignored if the -stub_router is also given.For IxTclNetwork it sets the the number of router in a L3 Route Rangeand will be advertised for stub network.
			 	-stub_ip_pfx_len
			 		The number of bits in the prefixes to be advertised.
			 	-stub_ip_start
			 		The IP address of the first stub network route to be advertised.
			 	-stub_ip_step
			 		The IPv4 incrementing step for the stub network route to be advertised.
			 	-stub_ipv6_pfx_len
			 		The number of bits in the prefixes to be advertised in a IPV6 stub network.
			 	-stub_ipv6_start
			 		The IPV6 address of the first stub network route to be advertised.
			 	-stub_ipv6_step
			 		The IPv6 incrementing step for the stub network route to be advertised.
			 	-stub_metric
			 		The cost metric associated with the stub network route.
			 	-stub_up_down_bit
			 		If 1, the route will be distributed down.If 0, the route will be distributed up.
			 	-type
			 		router- Individual ISIS router.grid- A rectangular grid of ISIS routers.stub- A stub network with a number of reachable network prefixes.external - An external network with a number of reachable network prefixes.dce_network_range- A rectangular grid of DCE ISIS devices.dce_mcast_mac_range- A multicast MAC range for a DCE ISIS device.dce_mcast_ipv4_group_range - A multicast IPv4 range for a DCE ISIS device.dce_mcast_ipv6_group_range - A multicast IPv6 range for a DCE ISIS device.dce_node_mac_group- A MAC group for a DCE ISIS grid.dce_node_ipv4_group- A IPv4 group for a DCE ISIS grid.dce_node_ipv6_group- A IPv6 group for a DCE ISIS grid.dce_outside_link- A Outside Link for a DCE ISIS grid.
			x	-dce_bcast_root_pri
			x		Broadcast root priority. This is valid for -type dce_network_range.
			x	-dce_bcast_root_pri_step
			x		Broadcast root priority step. This is valid for -type dce_network_range.
			x	-dce_connection_column
			x		This is valid for -type dce_outside_link.
			x	-dce_connection_row
			x		This is valid for -type dce_outside_link.
			x	-dce_device_id
			x		This is valid for -type dce_network_range.
			x	-dce_device_id_step
			x		This is valid for -type dce_network_range.
			x	-dce_device_pri
			x		This is valid for -type dce_network_range.
			x	-dce_ftag
			x		This is valid for -type dce_network_range.
			x	-dce_ftag_enable
			x		This is valid for -type dce_network_range.
			x	-dce_include_groups
			x		This is valid for -type dce_node_mac_group,dce_node_ipv4_group,dce_node_ipv6_group.
			x	-dce_intra_grp_ucast_step
			x		This is valid for -type dce_node_mac_group,dce_node_ipv4_group,dce_node_ipv6_group, dce_mcast_mac_range, dce_mcast_ipv4_group_range, dce_mcast_ipv6_group_range.
			x	-dce_inter_grp_ucast_step
			x		This is valid for -type dce_node_mac_group,dce_node_ipv4_group,dce_node_ipv6_group, dce_mcast_mac_range, dce_mcast_ipv4_group_range, dce_mcast_ipv6_group_range.
			x	-dce_linked_router_id
			x		This is valid for -type dce_outside_link.
			x	-dce_local_entry_point_column
			x		This is valid for -type dce_network_range.
			x	-dce_local_entry_point_row
			x		This is valid for -type dce_network_range.
			x	-dce_local_link_metric
			x		This is valid for -type dce_network_range.
			x	-dce_local_num_columns
			x		This is valid for -type dce_network_range.
			x	-dce_local_num_rows
			x		This is valid for -type dce_network_range.
			x	-dce_mcast_addr_count
			x		This is valid for -type dce_node_mac_group,dce_node_ipv4_group,dce_node_ipv6_group, dce_mcast_mac_range, dce_mcast_ipv4_group_range, dce_mcast_ipv6_group_range.
			x	-dce_mcast_addr_node_step
			x		This is valid for -type dce_node_mac_group,dce_node_ipv4_group,dce_node_ipv6_group.
			x	-dce_mcast_addr_step
			x		This is valid for -type dce_node_mac_group,dce_node_ipv4_group,dce_node_ipv6_group, dce_mcast_mac_range, dce_mcast_ipv4_group_range, dce_mcast_ipv6_group_range.
			x	-dce_mcast_start_addr
			x		This is valid for -type dce_node_mac_group,dce_node_ipv4_group,dce_node_ipv6_group, dce_mcast_mac_range, dce_mcast_ipv4_group_range, dce_mcast_ipv6_group_range.
			x	-dce_num_mcast_destination_trees
			x		This is valid for -type dce_network_range.
			x	-dce_src_grp_mapping
			x		This is valid for -type dce_node_mac_group,dce_node_ipv4_group,dce_node_ipv6_group, dce_mcast_mac_range, dce_mcast_ipv4_group_range, dce_mcast_ipv6_group_range.
			x	-dce_system_id
			x		This is valid for -type dce_network_range.
			x	-dce_system_id_step
			x		This is valid for -type dce_network_range.
			x	-dce_ucast_addr_node_step
			x		This is valid for -type dce_node_mac_group,dce_node_ipv4_group,dce_node_ipv6_group.
			x	-dce_ucast_sources_per_mcast_addr
			x		This is valid for -type dce_node_mac_group,dce_node_ipv4_group,dce_node_ipv6_group, dce_mcast_mac_range, dce_mcast_ipv4_group_range, dce_mcast_ipv6_group_range.
			x	-dce_ucast_src_addr
			x		This is valid for -type dce_node_mac_group,dce_node_ipv4_group,dce_node_ipv6_group, dce_mcast_mac_range, dce_mcast_ipv4_group_range, dce_mcast_ipv6_group_range.
			x	-dce_vlan_id
			x		This is valid for -type dce_node_mac_group,dce_node_ipv4_group,dce_node_ipv6_group, dce_mcast_mac_range, dce_mcast_ipv4_group_range, dce_mcast_ipv6_group_range.
			x	-grid_interface_metric
			x		The metric for the interface connected to the grid.
			x	-grid_ip_pfx_len
			x		The number of bits in the network mask of IP address used in a grid.
			x	-grid_router_count
			x		The number of grid node route entries.
			x	-grid_router_ip_version
			x		The IP version of of grid node route entry.
			x	-grid_router_metric
			x		The cost metric associated with the route advertised by the grid nodes.
			x	-grid_router_origin
			x		The origin of the routes advertised by the grid nodes.Choices are stub and external.
			x	-grid_router_route_step
			x		The step for the route in the grid node route entry.
			x	-grid_router_up_down_bit
			x		This is the up down bit associated with the routes advertised by the grid nodes.If 1, the route will be distributed down.If 0, the route will be redistributed up.
			x	-grid_system_id_step
			x		The value used to increment grid_start_system_id by as each router is assigned a unique system ID.
			x	-grid_te_admin
			x		The administrative group associated with the node in a grid, expressed as the decimal equivalent of 32-bit number.
			x	-grid_te_ip_step
			x		The value used to increment teRouterId by as each router is assigned a unique TE router ID.
			x	-grid_te_max_bw
			x		The maximum bandwidth to be advertised for all nodes in an ISIS grid.
			x	-grid_te_metric
			x		The metric associated with the interface that the TE data is advertised on.
			x	-grid_te_override_admin
			x		The override administrative group associated with the node in a grid, expressed as the decimal equivalent of 32-bit number.
			x	-grid_te_override_enable
			x		Enable override the TE parameters.
			x	-grid_te_override_max_bw
			x		The override maximum bandwidth to be advertised for all nodes in an ISIS grid.
			x	-grid_te_override_max_resv_bw
			x		The override maximum reservable bandwidth to be advertised for all nodes in an ISIS grid.
			x	-grid_te_override_metric
			x		The override metric associated with the interface that the TE data is advertised on.
			x	-grid_te_override_unresv_bw_priority0
			x		The override unreserved bandwidth for priority0 to be advertised for nodes in a ISIS grid.
			x	-grid_te_override_unresv_bw_priority1
			x		The override unreserved bandwidth for priority1 to be advertised for nodes in a ISIS grid.
			x	-grid_te_override_unresv_bw_priority2
			x		The override unreserved bandwidth for priority2 to be advertised for nodes in a ISIS grid.
			x	-grid_te_override_unresv_bw_priority3
			x		The override unreserved bandwidth for priority3 to be advertised for nodes in a ISIS grid.
			x	-grid_te_override_unresv_bw_priority4
			x		The override unreserved bandwidth for priority4 to be advertised for nodes in a ISIS grid.
			x	-grid_te_override_unresv_bw_priority5
			x		The override unreserved bandwidth for priority5 to be advertised for nodes in a ISIS grid.
			x	-grid_te_override_unresv_bw_priority6
			x		The override unreserved bandwidth for priority6 to be advertised for nodes in a ISIS grid.
			x	-grid_te_override_unresv_bw_priority7
			x		The override unreserved bandwidth for priority7 to be advertised for nodes in a ISIS grid.
			x	-grid_te_path_admin
			x		The path administrative group associated with the node in a grid, expressed as the decimal equivalent of 32-bit number.
			x	-grid_te_path_count
			x		The number of te paths. The rest of the grid_te_path_... parameters need to provide a list of values with tehe length equal to the value of grid_te_path_count.
			x	-grid_te_path_start_row
			x		The path start row for the ISIS grid.
			x	-grid_te_path_start_col
			x		The path start column for the ISIS grid.
			x	-grid_te_path_end_row
			x		The path end row for the ISIS grid.
			x	-grid_te_path_end_col
			x		The path end column for the ISIS grid.
			x	-grid_te_path_row_step
			x		The path row step for the ISIS grid.
			x	-grid_te_path_col_step
			x		The path column step for the ISIS grid.
			x	-grid_te_path_bidir
			x		The path bidirectional flag for the ISIS grid.
			x	-grid_te_path_max_bw
			x		The path maximum bandwidth to be advertised for all nodes in an ISIS grid.
			x	-grid_te_path_max_resv_bw
			x		The path maximum reservable bandwidth to be advertised for all nodes in an ISIS grid.
			x	-grid_te_path_metric
			x		The path metric associated with the interface that the TE data is advertised on.
			x	-grid_te_path_unresv_bw_priority0
			x		The path unreserved bandwidth for priority0 to be advertised for nodes in a ISIS grid.
			x	-grid_te_path_unresv_bw_priority1
			x		The path unreserved bandwidth for priority1 to be advertised for nodes in a ISIS grid.
			x	-grid_te_path_unresv_bw_priority2
			x		The path unreserved bandwidth for priority2 to be advertised for nodes in a ISIS grid.
			x	-grid_te_path_unresv_bw_priority3
			x		The path unreserved bandwidth for priority3 to be advertised for nodes in a ISIS grid.
			x	-grid_te_path_unresv_bw_priority4
			x		The path unreserved bandwidth for priority4 to be advertised for nodes in a ISIS grid.
			x	-grid_te_path_unresv_bw_priority5
			x		The path unreserved bandwidth for priority5 to be advertised for nodes in a ISIS grid.
			x	-grid_te_path_unresv_bw_priority6
			x		The path unreserved bandwidth for priority6 to be advertised for nodes in a ISIS grid.
			x	-grid_te_path_unresv_bw_priority7
			x		The path unreserved bandwidth for priority7 to be advertised for nodes in a ISIS grid.
			x	-grid_te_unresv_bw_priority0
			x		The unreserved bandwidth for priority0 to be advertised for nodes in a ISIS grid.
			x	-grid_te_unresv_bw_priority1
			x		The unreserved bandwidth for priority1 to be advertised for nodes in a ISIS grid.
			x	-grid_te_unresv_bw_priority2
			x		The unreserved bandwidth for priority2 to be advertised for nodes in a ISIS grid.
			x	-grid_te_unresv_bw_priority3
			x		The unreserved bandwidth for priority3 to be advertised for nodes in a ISIS grid.
			x	-grid_te_unresv_bw_priority4
			x		The unreserved bandwidth for priority4 to be advertised for nodes in a ISIS grid.
			x	-grid_te_unresv_bw_priority5
			x		The unreserved bandwidth for priority5 to be advertised for nodes in a ISIS grid.
			x	-grid_te_unresv_bw_priority6
			x		The unreserved bandwidth for priority6 to be advertised for nodes in a ISIS grid.
			x	-grid_te_unresv_bw_priority7
			x		The unreserved bandwidth for priority7 to be advertised for nodes in a ISIS grid.
			x	-grid_user_wide_metric
			x		Enables the use of wide metrics for interface metric. Its value can be set to 0 only if the -grid_te parameter is set to 0.
			x	-link_te_metric
			x		The metric associated with the interface that the TE data is advertised on.
			x	-no_write
			x		If this option is present, the configuration is not written to the hardware. This option can be used to queue up multiple configurations before writing to the hardware.
			n	-external_connect
			n	-external_metric_type
			n	-grid_connect_session
			n	-grid_disconnect
			n	-link_external
			n	-link_te_remote_ip_addr
			n	-link_te_remote_ipv6_addr
			n	-link_up_down_bit
			n	-router_attached_bit
			n	-router_connect
			n	-router_disconnect
			n	-router_host_name
			n	-router_overload_bit
			n	-router_pseudonode_num
			n	-router_routing_level
			n	-stub_connect
			n	-stub_ip_step
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                 value: $::SUCCESS | $::FAILURE
		On failure, gives detailed information.
			 key:log                    value: On failure, gives detailed information.
		ISIS topology element handle
			 key:elem_handle            value: ISIS topology element handle
		4 | 6 | 4_6
			 key:version                value: 4 | 6 | 4_6
		number of stub network prefixes
			 key:stub.num_networks      value: number of stub network prefixes
		number of external network prefixes
			 key:external.num_networks  value: number of external network prefixes
		
		Examples:
		See files starting with ISIS_ in the Samples subdirectory.  Also see some of the L3VPN, MPLS, and MVPN sample files for further examples of ISIS usage. See the ISIS example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		1)  The stub and external networks cannot be defined inside a grid.  They can added behind a session router.
		2)  In modify mode, if IP address related options are modified, such as, stub_ip_start, stub_ip_pfx_len, stub_ip_step, then all the related options need to be specified; otherwise the default settings will be applied.
		3)  This function does not support the following return values:key:router.connected_handles <connected_elem_handles>key:router.$row.$col <router_handle>
		4)  DCE ISIS is only supported using old API (IxTclProtocol API).
		
		See Also:
		
		"""
		return self._run_keyword("emulation_isis_topology_route_config", kwargs)

	def emulation_lacp_control(self, **kwargs):
		""" Control Operation on the LACP/Static LAG Protocol    The following operations are done:     1. Restart     2. Send Marker Request    3. Start    4. Start PDU    5. Stop    6. Stop PDU
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_lacp_control
			 	-mode          CHOICES restart
			                CHOICES send_marker_req
			                CHOICES start
			                CHOICES restart_down
			                CHOICES start_pdu
			                CHOICES stop
			                CHOICES stop_pdu
			                CHOICES abort]
			 	[-port_handle  REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle       ANY]
			 	[-session_type CHOICES lacp staticLag
			                DEFAULT lacp]
		
		Arguments:
			 	-mode
			 		What is being done to the protocol.Valid choices are:
			 		restart - Restart the protocol.
			 		start- Start the protocol.
			 		stop- Stop the protocol.
			 		start_pdu- start_pdu the protocol.
			 		stop_pdu- stop_pdu the protocol.
			 		send_marker_req- send_marker_req the protocol.
			 		Valid choices are:
			    		restart - Restart the protocol.
			    		send_marker_req - send marker req.
			    		start - Start the protocol.
			    		restart_down - restart the down sessions
			    		start_pdu - Start PDU.
			    		stop - Stop the protocol.
			    		stop_pdu - Stop PDU.
			    		abort - Abort.
			 	-port_handle
			 		The port on which to perform action.
			 	-handle
			 	-session_type
			 		The LACP to be emulated. CHOICES: lacp staticLag.
			 		Valid choices are:
			    		lacp -
			    		staticLag -
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		On status of failure, gives detailed information.
			 key:log     value:On status of failure, gives detailed information.
		
		Examples:
		See files starting with LACP_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_lacp_control", kwargs)

	def emulation_lacp_info(self, **kwargs):
		""" Retrieves information about the LACP protocol     The following operations are done:     aggregate_stats learned_info clear_stats configuration
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_lacp_info
			 	-mode          CHOICES aggregate_stats
			                CHOICES global_learned_info
			                CHOICES per_port
			                CHOICES per_device_group
			                CHOICES per_lag_statistics
			                CHOICES clear_stats
			                CHOICES configuration]
			 	[-session_type CHOICES lacp staticLag
			                DEFAULT lacp]
			 	[-handle       ANY]
			 	[-port_handle  REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
		
		Arguments:
			 	-mode
			    		aggregate_stats -
			    		global_learned_info -
			    		per_device_group -
			    		per_port -
			    		per_lag_statistics -
			    		clear_stats -
			    		configuration -
			 	-session_type
			 		The LACP to be emulated. CHOICES: lacp static_lag.
			 		Valid choices are:
			    		lacp - LACP
			    		staticLag - "Static Lag"
			 	-handle
			 	-port_handle
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                      value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                                         value:On status of failure, gives detailed information.
			 key:Aggregate stats:                                            value:
			 key:<port_handle>.aggregate.port_name                           value:
			 key:<port_handle>.aggregate.sessions_up                         value:
			 key:<port_handle>.aggregate.sessions_flap                       value:
			 key:<port_handle>.aggregate.sessions_not_started                value:
			 key:<port_handle>.aggregate.sessions_down                       value:
			 key:<port_handle>.aggregate.link_state                          value:
			 key:<port_handle>.aggregate.lag_id                              value:
			 key:<port_handle>.aggregate.total_lag_member_ports              value:
			 key:<port_handle>.aggregate.lag_member_ports_up                 value:
			 key:<port_handle>.aggregate.lacpdu_tx                           value:
			 key:<port_handle>.aggregate.lacpdu_rx                           value:
			 key:<port_handle>.aggregate.lacpu_malformed_rx                  value:
			 key:<port_handle>.aggregate.marker_pdu_tx                       value:
			 key:<port_handle>.aggregate.marker_pdu_rx                       value:
			 key:<port_handle>.aggregate.marker_res_pdu_tx                   value:
			 key:<port_handle>.aggregate.marker_res_pdu_rx                   value:
			 key:<port_handle>.aggregate.marker_res_timeout_count            value:
			 key:<port_handle>.aggregate.lacpdu_tx_rate_violation_count      value:
			 key:<port_handle>.aggregate.marker_pdu_tx_rate_violation_count  value:
			 key:<port_handle>.aggregate.lag_id                              value:
			 key:lag_id                                                      value:
			 key:actor_system_id                                             value:
			 key:actor_system_priority                                       value:
			 key:actor_port_number                                           value:
			 key:administrative_key                                          value:
			 key:actor_operationalkey                                        value:
			 key:actor_lacp_activity                                         value:
			 key:actor_lacp_activity                                         value:
			 key:actor_lacpdu_timeout                                        value:
			 key:actor_aggregration_enabled                                  value:
			 key:actor_synchronized_flag                                     value:
			 key:actor_synchronized_flag                                     value:
			 key:actor_collecting_flag                                       value:
			 key:actor_defaulted_flag                                        value:
			 key:actor_expired_flag                                          value:
			 key:link_aggregration_status                                    value:
			 key:partner_system_id                                           value:
			 key:partner_system_priority                                     value:
			 key:partner_port_number                                         value:
			 key:partner_port_priority                                       value:
			 key:partner_operational_key                                     value:
			 key:partner_lacp_activity                                       value:
			 key:partner_lacpdu_timeout                                      value:
			 key:partner_aggregration                                        value:
			 key:partner_synchronized_flag                                   value:
			 key:partner_collecting_flag                                     value:
			 key:partner_distributing_flag                                   value:
			 key:partner_defaulted_flag                                      value:
			 key:partner_expired_flag                                        value:
			 key:collectors_max_delay                                        value:
			 key:other_lag_member_count                                      value:
			 key:details                                                     value:
		MAC
			 key:<port_handle>.actor_system_id                               value: MAC
		integer
			 key:<port_handle>.actor_system_pri                              value: integer
		integer
			 key:<port_handle>.actor_port_num                                value: integer
		integer
			 key:<port_handle>.actor_op_key                                  value: integer
		integer
			 key:<port_handle>.actor_port_pri                                value: integer
		1 - Active | 0 - Passive
			 key:<port_handle>.actor_lacp_activity                           value: 1 - Active | 0 - Passive
		Long | Short
			 key:<port_handle>.actor_lacp_timeout                            value: Long | Short
		1 - Aggregateable | 0 - Individual
			 key:<port_handle>.actor_aggregation                             value: 1 - Aggregateable | 0 - Individual
		1 - IN SYNC | 0 - OUT OF SYNC
			 key:<port_handle>.actor_sync_flag                               value: 1 - IN SYNC | 0 - OUT OF SYNC
		0 | 1
			 key:<port_handle>.actor_collecting_flag                         value: 0 | 1
		0 | 1
			 key:<port_handle>.actor_distributing_flag                       value: 0 | 1
		0 | 1
			 key:<port_handle>.actor_defaulted_flag                          value: 0 | 1
		0 | 1
			 key:<port_handle>.actor_expired_flag                            value: 0 | 1
		1 - Aggregated | 0 - Not Aggregated
			 key:<port_handle>.actor_link_aggregation_status                 value: 1 - Aggregated | 0 - Not Aggregated
		MAC
			 key:<port_handle>.partner_system_id                             value: MAC
		integer
			 key:<port_handle>.partner_system_pri                            value: integer
		integer
			 key:<port_handle>.partner_port_num                              value: integer
		integer
			 key:<port_handle>.partner_op_key                                value: integer
		integer
			 key:<port_handle>.partner_port_pri                              value: integer
		1 - Active | 0 - Passive
			 key:<port_handle>.partner_lacp_activity                         value: 1 - Active | 0 - Passive
		Long | Short
			 key:<port_handle>.partner_lacp_timeout                          value: Long | Short
		1 - Aggregateable | 0 - Individual
			 key:<port_handle>.partner_aggregation                           value: 1 - Aggregateable | 0 - Individual
		1 - IN SYNC | 0 - OUT OF SYNC
			 key:<port_handle>.partner_sync_flag                             value: 1 - IN SYNC | 0 - OUT OF SYNC
		0 | 1
			 key:<port_handle>.partner_collecting_flag                       value: 0 | 1
		0 | 1
			 key:<port_handle>.partner_distributing_flag                     value: 0 | 1
		0 | 1
			 key:<port_handle>.partner_defaulted_flag                        value: 0 | 1
		0 | 1
			 key:<port_handle>.partner_expired_flag                          value: 0 | 1
		integer
			 key:<port_handle>.partner_collectors_max_delay                  value: integer
		0 | 1
			 key:<port_handle>.aggregate.link_state                          value: 0 | 1
		integer
			 key:<port_handle>.aggregate.lacpdu_rx                           value: integer
		integer
			 key:<port_handle>.aggregate.lacpdu_tx                           value: integer
		integer
			 key:<port_handle>.aggregate.lacpu_malformed_rx                  value: integer
		integer
			 key:<port_handle>.aggregate.marker_pdu_rx                       value: integer
		integer
			 key:<port_handle>.aggregate.marker_pdu_tx                       value: integer
		integer
			 key:<port_handle>.aggregate.marker_res_pdu_rx                   value: integer
		integer
			 key:<port_handle>.aggregate.marker_res_pdu_tx                   value: integer
		integer
			 key:<port_handle>.aggregate.marker_res_timeout_count            value: integer
		integer
			 key:<port_handle>.aggregate.lacpdu_tx_rate_violation_count      value: integer
		integer
			 key:<port_handle>.aggregate.marker_pdu_tx_rate_violation_count  value: integer
		port handles
			 key:lag.<lag_id>.ports                                          value: port handles
		MAC
			 key:lag.<lag_id>.actor_system_id                                value: MAC
		integer
			 key:lag.<lag_id>.actor_system_pri                               value: integer
		integer
			 key:lag.<lag_id>.actor_key                                      value: integer
		link handle
			 key:lag.<lag_id>.<port_handle>.active_link                      value: link handle
		link handles
			 key:lag.<lag_id>.<port_handle>.links                            value: link handles
		
		Examples:
		See files starting with LACP_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_lacp_info", kwargs)

	def emulation_lacp_link_config(self, **kwargs):
		""" This procedure will configure LACP/Static LAG
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_lacp_link_config
			 	-mode                               CHOICES create
			                                     CHOICES delete
			                                     CHOICES modify
			                                     CHOICES enable
			                                     CHOICES disable]
			 	[-port_handle                       REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle                            ANY]
			x	[-active                            CHOICES 0 1]
			 	[-session_type                      CHOICES lacp staticLag
			                                     DEFAULT lacp]
			x	[-lag_id                            RANGE 1-65535
			x                                    DEFAULT 1]
			 	[-count                             NUMERIC
			                                     DEFAULT 1]
			x	[-reset                             ANY]
			 	[-actor_key                         RANGE 0-65535
			                                     DEFAULT 1]
			 	[-actor_port_num                    RANGE 0-65535
			                                     DEFAULT 1]
			 	[-actor_key_step                    RANGE 0-65535
			                                     DEFAULT 1]
			 	[-actor_port_num_step               RANGE 0-65535
			                                     DEFAULT 1]
			 	[-actor_port_pri                    RANGE 0-65535
			                                     DEFAULT 1]
			 	[-actor_port_pri_step               RANGE 0-65535
			                                     DEFAULT 1]
			 	[-lag_count                         RANGE 0-65535
			                                     DEFAULT 1]
			 	[-actor_system_id                   HEX8WITHSPACES]
			x	[-administrative_key                RANGE 1-65535
			x                                    DEFAULT 1]
			 	[-actor_system_id_step              HEX8WITHSPACES
			                                     DEFAULT 0000.0000.0001]
			 	[-auto_pick_port_mac                ANY]
			x	[-collecting_flag                   CHOICES 0 1
			x                                    DEFAULT 1]
			x	[-distributing_flag                 CHOICES 0 1
			x                                    DEFAULT 1]
			x	[-collector_max_delay               RANGE 0-65535
			x                                    DEFAULT 0]
			x	[-inter_marker_pdu_delay            RANGE 1-255
			x                                    DEFAULT 6]
			x	[-lacp_activity                     CHOICES active passive
			x                                    DEFAULT active]
			x	[-lacp_timeout                      RANGE 0-65535
			x                                    DEFAULT 0]
			x	[-lacpdu_periodic_time_interval     RANGE 0-65535
			x                                    DEFAULT 0]
			x	[-marker_req_mode                   CHOICES fixed random
			x                                    DEFAULT fixed]
			x	[-marker_res_wait_time              RANGE 1-255
			x                                    DEFAULT 5]
			x	[-send_marker_req_on_lag_change     CHOICES 0 1
			x                                    DEFAULT 1]
			x	[-inter_marker_pdu_delay_random_min RANGE 1-255
			x                                    DEFAULT 1]
			x	[-inter_marker_pdu_delay_random_max RANGE 1-255
			x                                    DEFAULT 6]
			x	[-send_periodic_marker_req          CHOICES 0 1
			x                                    DEFAULT 0]
			x	[-support_responding_to_marker      CHOICES 0 1
			x                                    DEFAULT 1]
			x	[-sync_flag                         CHOICES 0 1
			x                                    DEFAULT 1]
			x	[-aggregation_flag                  CHOICES 0 1
			x                                    DEFAULT 1]
			 	[-actor_system_pri                  ANY]
			 	[-actor_system_pri_step             ANY]
			 	[-no_write                          ANY]
			 	[-port_mac                          ANY]
			 	[-port_mac_step                     ANY]
		
		Arguments:
			 	-mode
			    		create -
			    		delete -
			    		modity -
			    		enable -
			    		disable -
			 	-port_handle
			 	-handle
			 		LACP and StaticLag protocol Handle
			x	-active
			x		Flag.
			 	-session_type
			 		The LACP to be emulated. CHOICES: lacp staticLag.
			 		Valid choices are:
			    		lacp -
			    		staticLag -
			x	-lag_id
			x		lag_id. RANGE 1-65535
			 	-count
			 		Defines the number of LACP to create.
			x	-reset
			x		Clears any LACP configuration on the targeted port before
			x		configuring further.
			 	-actor_key
			 		Actor Key. RANGE 0-65535
			 	-actor_port_num
			 		Actor Port Number. RANGE 0-65535
			 	-actor_key_step
			 		Actor Key Step. RANGE 0-65535
			 	-actor_port_num_step
			 		Actor Port Num step. RANGE 0-65535
			 	-actor_port_pri
			 		Actor Port Priority. RANGE 0-65535
			 	-actor_port_pri_step
			 		Actor Port Priority step. RANGE 0-65535
			 	-lag_count
			 		lag_count
			 	-actor_system_id
			 		actor system id
			x	-administrative_key
			x		administrative key
			 	-actor_system_id_step
			 		actor_system_id_step
			 	-auto_pick_port_mac
			x	-collecting_flag
			x   		collecting flag
			x	-distributing_flag
			x   		distributing Flag
			x	-collector_max_delay
			x   		collector maximum delay
			x	-inter_marker_pdu_delay
			x   		inter marker pdu delay
			x	-lacp_activity
			x   		lacp activity
			x   		Valid choices are:
			x       		active - (default) Active.
			x       		passive - passive
			x	-lacp_timeout
			x   		lacp timeout
			x	-lacpdu_periodic_time_interval
			x   		lacpdu periodic time interval
			x	-marker_req_mode
			x   		marker req mode
			x   		Valid choices are:
			x       		fixed - (default) fixed.
			x       		random - random
			x	-marker_res_wait_time
			x   		marker res wait time
			x	-send_marker_req_on_lag_change
			x   		send marker req on lag change
			x	-inter_marker_pdu_delay_random_min
			x   		inter marker pdu delay random min
			x	-inter_marker_pdu_delay_random_max
			x   		inter marker pdu delay random max
			x	-send_periodic_marker_req
			x   		send periodic marker req
			x	-support_responding_to_marker
			x   		support responding to marker
			x	-sync_flag
			x   		sync flag
			x	-aggregation_flag
			x   		aggregation flag
			 	-actor_system_pri
			    	-actor_system_pri_step
			        	-no_write
			            	-port_mac
			                	-port_mac_step
		               
		               Return Values:
		                   A list containing the ethernet protocol stack handles that were added by the command (if any).
			x                   key:ethernet_handle   value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		                   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x                   key:handle            value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		                   $::SUCCESS | $::FAILURE
			                    key:status            value:$::SUCCESS | $::FAILURE
		                   When status is $::FAILURE, contains more information
			                    key:log               value:When status is $::FAILURE, contains more information
		                   Handle of lacp configured
			                    key:lacp_handle       value:Handle of lacp configured
		                   Handle of lacp configured
			                    key:staticLag_handle  value:Handle of lacp configured
		                   On status of failure, gives detailed information.
			                    key:log               value:On status of failure, gives detailed information.
		                   On mode create, list of LACP link handles
			                    key:handle            value:On mode create, list of LACP link handles
		               
		               Examples:
		                   See files starting with LACP_ in the Samples subdirectory.
		               
		               Sample Input:
		               
		               Sample Output:
		               
		               Notes:
		                   If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		                   1) This protocol is available only when using IxTclProtocol API.
		               
		               See Also:
		               
		"""
		return self._run_keyword("emulation_lacp_link_config", kwargs)

	def emulation_lag_config(self, **kwargs):
		""" This procedure will configure LAG Ports, LACP and Static LAG
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_lag_config
			 	-mode                                    CHOICES create delete modify]
			 	[-port_handle                            REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle                                 ANY]
			x	[-lag_handle                             ANY]
			x	[-ethernet_handle                        ANY]
			x	[-active                                 CHOICES 0 1]
			x	[-lag_name                               ALPHA]
			 	[-protocol_type                          CHOICES lag_port_lacp
			                                          CHOICES lag_port_staticlag
			                                          DEFAULT lag_port_lacp]
			x	[-lag_id                                 RANGE 1-65535
			x                                         DEFAULT 1]
			x	[-reset                                  ANY]
			 	[-lacp_actor_key                         RANGE 0-65535
			                                          DEFAULT 1]
			 	[-lacp_actor_port_num                    RANGE 0-65535
			                                          DEFAULT 1]
			 	[-lacp_actor_key_step                    RANGE 0-65535
			                                          DEFAULT 1]
			 	[-lacp_actor_port_num_step               RANGE 0-65535
			                                          DEFAULT 1]
			 	[-lacp_actor_port_priority               RANGE 0-65535
			                                          DEFAULT 1]
			 	[-lacp_actor_system_id                   HEX8WITHSPACES]
			 	[-lacp_actor_system_id_step              HEX8WITHSPACES
			                                          DEFAULT 0000.0000.0001]
			x	[-lacp_administrative_key                RANGE 1-65535
			x                                         DEFAULT 1]
			 	[-actor_system_id_step                   HEX8WITHSPACES
			                                          DEFAULT 0000.0000.0001]
			x	[-lacp_collecting_flag                   CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-lacp_distributing_flag                 CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-lacp_collector_max_delay               RANGE 0-65535
			x                                         DEFAULT 0]
			x	[-lacp_inter_marker_pdu_delay            RANGE 1-255
			x                                         DEFAULT 6]
			x	[-lacp_activity                          CHOICES active passive
			x                                         DEFAULT active]
			x	[-lacp_timeout                           RANGE 0-65535
			x                                         DEFAULT 0]
			x	[-lacp_du_periodic_time_interval         RANGE 0-65535
			x                                         DEFAULT 0]
			x	[-lacp_marker_req_mode                   CHOICES fixed random
			x                                         DEFAULT fixed]
			x	[-lacp_marker_res_wait_time              RANGE 1-255
			x                                         DEFAULT 5]
			x	[-lacp_send_marker_req_on_lag_change     CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-lacp_inter_marker_pdu_delay_random_min RANGE 1-255
			x                                         DEFAULT 1]
			x	[-lacp_inter_marker_pdu_delay_random_max RANGE 1-255
			x                                         DEFAULT 6]
			x	[-lacp_send_periodic_marker_req          CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-lacp_support_responding_to_marker      CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-lacp_sync_flag                         CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-lacp_aggregation_flag                  CHOICES 0 1
			x                                         DEFAULT 1]
			x	[-lacp_actor_system_priority             NUMERIC
			x                                         DEFAULT 1]
			x	[-mtu                                    RANGE 68-9216
			x                                         DEFAULT 1500]
			 	[-src_mac_addr                           MAC]
			x	[-src_mac_addr_step                      MAC
			x                                         DEFAULT 0000.0000.0001]
			 	[-vlan                                   CHOICES 0 1]
			x	[-vlan_id                                REGEXP ^[0-9]{1,4}(,[0-9]{1,4}){0,5}$
			x                                         RANGE 0-4096]
			x	[-vlan_id_step                           REGEXP ^[0-9]{1,4}(,[0-9]{1,4}){0,5}$
			x                                         RANGE 0-4096
			x                                         DEFAULT 1]
			x	[-vlan_id_count                          REGEXP ^[0-9]{1,4}(,[0-9]{1,4}){0,5}$
			x                                         RANGE 1-4094
			x                                         DEFAULT 4094]
			x	[-vlan_tpid                              CHOICES 0x8100
			x                                         CHOICES 0x88a8
			x                                         CHOICES 0x88A8
			x                                         CHOICES 0x9100
			x                                         CHOICES 0x9200
			x                                         CHOICES 0x9300
			x                                         DEFAULT 0x8100]
			x	[-vlan_user_priority                     REGEXP ^[0-7](,[0-7]){0,5}$
			x                                         RANGE 0-7
			x                                         DEFAULT 0]
			x	[-vlan_user_priority_step                REGEXP ^[0-7](,[0-7]){0,5}$
			x                                         RANGE 0-7
			x                                         DEFAULT 1]
			x	[-notify_mac_move                        CHOICES 0 1]
		
		Arguments:
			 	-mode
			    		create -
			    		delete -
			    		modity -
			 	-port_handle
			 	-handle
			 		LAG, LACP and StaticLag protocol Handle
			x	-lag_handle
			x		Handle for the LAG that the user wants to modify or delete. This argument does not support lists.
			x	-ethernet_handle
			x		Handle for the ethernet of LAG that the user wants to modify. This argument does not support lists.
			x	-active
			x		Flag.
			x	-lag_name
			x		Name of the LAG port configured in HLAPI.
			 	-protocol_type
			 		The LACP to be emulated. CHOICES: lag_port_lacp lag_port_staticlag.
			 		Valid choices are:
			    		lag_port_lacp -
			    		lag_port_staticlag -
			x	-lag_id
			x		lag_id. RANGE 1-65535
			x	-reset
			x		Clears any LACP configuration on the targeted port before
			x		configuring further.
			 	-lacp_actor_key
			 		The operational Key value assigned to the port by the Actor on the fly.RANGE 0-65535
			 	-lacp_actor_port_num
			 		The port number assigned to the port by the Actor (the System sending the PDU). RANGE 0-65535
			 	-lacp_actor_key_step
			 		This argument specifies the step value of actor Key. RANGE 0-65535
			 	-lacp_actor_port_num_step
			 		This argument specifies the step value of actor port number. RANGE 0-65535
			 	-lacp_actor_port_priority
			 		This argument specifies the port priority of the link Actor. RANGE 0-65535
			 	-lacp_actor_system_id
			 		This argument specifies the system identifier for the link Actor.
			 	-lacp_actor_system_id_step
			 		Step value of the system identifier for the link Actor.
			x	-lacp_administrative_key
			x		Lacp administrative key
			 	-actor_system_id_step
			 		actor_system_id_step
			x	-lacp_collecting_flag
			x		If selected, the actor port state Collecting is set to true based on Tx and Rx state machines. Otherwise, the flag in LACPDU remains reset for all packets sent.
			x	-lacp_distributing_flag
			x		If selected, the actor port state Distributing is set to true based on Tx and Rx state machines. Otherwise, the flag in LACPDU remains reset for all packets sent.
			x	-lacp_collector_max_delay
			x		The maximum time in microseconds that the Frame Collector may delay the delivery of a frame received from an Aggregator to its MAC client. RANGE 0-65535
			x	-lacp_inter_marker_pdu_delay
			x		Indicates the fixed inter marker PDU interval. It is enable only when Marker Request Mode is set as Fixed. RANGE 1-255
			x	-lacp_activity
			x		Sets the value of LACPs Actor activity, either passive or active.
			x		Valid choices are:
			x   		active - (default) Active.
			x   		passive - passive
			x	-lacp_timeout
			x		This timer is used to detect whether received protocol information has expired. RANGE 0-65535
			x	-lacp_du_periodic_time_interval
			x		This field defines how frequently LACPDUs are sent to the link partner. RANGE 0-65535
			x	-lacp_marker_req_mode
			x		Sets the marker request mode for the Actor link, either random or fixed.
			x		Valid choices are:
			x   		fixed - (default) fixed.
			x   		random - random
			x	-lacp_marker_res_wait_time
			x		The number of seconds to wait for Marker Response after sending a Marker Request. After this time, the Marker Response Timeout Count is incremented. If a marker response does arrive for the request after this timeout, it is not considered as a legitimate response. RANGE 1-255
			x	-lacp_send_marker_req_on_lag_change
			x		If selected, this argument causes LACP to send a Marker PDU in the following situations:
			x		- System Priority has been modified
			x		- System Id has been modified
			x		- Actor Key has been modified
			x		Port Number/Port Priority has been modified while we are in Individual mode.
			x	-lacp_inter_marker_pdu_delay_random_min
			x		Indicates random inter marker PDU interval range start value. RANGE 1-255
			x	-lacp_inter_marker_pdu_delay_random_max
			x		Indicates random inter marker PDU interval range end value. RANGE 1-255
			x	-lacp_send_periodic_marker_req
			x		send periodic marker req
			x	-lacp_support_responding_to_marker
			x		support responding to marker
			x	-lacp_sync_flag
			x		If selected, the actor port state is set to True based on Tx and Rx state machines. Otherwise, the flag in LACPDU remains reset for all packets sent.
			x	-lacp_aggregation_flag
			x		If selected, sets the port status to allow aggregation.
			x	-lacp_actor_system_priority
			x		If selected, sets the port status to allow aggregation.
			x	-mtu
			x		This option configure Maximum Trasmision Unit for created interfaces.
			x		This parameter can be an interfaces - one MTU value for each interface
			x		to be created.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			 	-src_mac_addr
			 		MAC address of the port.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid formats are:
			 		{00 00 00 00 00 00}, 00:00:00:00:00:00, 0000.0000.0000,
			 		00.00.00.00.00.00, {0000 0000 0000}
			x	-src_mac_addr_step
			x		The incrementing step for the MAC address of the connected interface,
			x		when connected_count is greater than 1.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This is valid for the new API.
			 	-vlan
			 		Whether to enable VLAN on the traffic generation tool interfaces.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid options are:
			 		1 - Enable
			 		0 - Disable (DEFAULT)
			x	-vlan_id
			x		VLAN ID of each interface where VLAN is enabled. This parameter
			x		accepts a list of numbers separated by ',' - the vlan id for each
			x		encapsulation 802.1q. This is how stacked vlan is configured.
			x		Each value should be between 0 and 4095, inclusive, for l23_config_type protocol_interfaces.
			x		Each value should be between 0 and 4094, inclusive, for l23_config_type static_endpoint.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x	-vlan_id_step
			x		The incrementing step for the VLAN ID of the interface, when
			x		connected_count is greater than 1.
			x		The vlan_id will be incremented modulo 4096, when the maximum value
			x		is reached, the counting starts again from 0.
			x		The vlan_id will be incremented modulo 4094 (by default), when the maximum value
			x		is reached, the counting starts again from 0, for l23_config_type static_endpoint,
			x		but the number of unique values can be modified by using vlan_id_count.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x	-vlan_id_count
			x		The number of unique outer VLAN IDs that will be created. This parameter
			x		accepts a list of numbers separated by ',' - the vlan id count for each
			x		encapsulation 802.1q. This is how stacked vlan is configured.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when l23_config_type is static_endpoint (new API).
			x	-vlan_tpid
			x		Tag Protocol Identifier / TPID (hex). The EtherType that identifies
			x		the protocol header that follows the VLAN header (tag).
			x		Available TPIDs: 0x8100 (the default), 0x88a8, 0x9100, 0x9200.
			x		If the VLAN Count is greater than 1 (for stacked VLANs),
			x		this field also accepts comma-separated values so that different TPID
			x		values can be assigned to different VLANs. For example, to assign TPID
			x		0x8100, 0x9100, 0x9200, and 0x9200 to the first four created VLANs,
			x		enter: 0x8100,0x9100,0x9200,0x9200.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when l23_config_type is protocol_interface.
			x		Valid choices are:
			x   		0x8100 -
			x   		0x88a8 -
			x   		0x88A8 -
			x   		0x9100 -
			x   		0x9200 -
			x   		0x9300 -
			x	-vlan_user_priority
			x		If VLAN is enabled on the interface, the priority of the VLAN. For each interface,
			x		the user priority list should be given as a list of integers separated by commas.
			x		This parameter accepts a list of user priority for each 802.1 encapsulation used.
			x		Valid choices for each element in the list are between 0 and 7, inclusive.
			x		This option takes a list of values when -port_handle is a list of port handles.
			x		For example, if we have 2 interfaces with 3 vlans each, the user priority could be: [list 1,2,7 1,3,4]
			x	-vlan_user_priority_step
			x		The incrementing step for the VLAN user priority of the interface, when
			x		connected_count is greater than 1. The vlan_user_priority will be
			x		incremented modulo 8, when the maximum value is reached, the counting
			x		starts again from 0.
			x		This option is valid only when l23_config_type is static_endpoint.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x	-notify_mac_move
			x		Flag to determine if MAC move notifications should be sent
		
		Return Values:
		A list containing the protocol stack protocol stack handles that were added by the command (if any).
			xkey:protocol_stack_handle      value:A list containing the protocol stack protocol stack handles that were added by the command (if any).
		A list containing the ethernet protocol stack handles that were added by the command (if any).
			xkey:ethernet_handle            value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:handle                     value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		$::SUCCESS | $::FAILURE
			 key:status                     value:$::SUCCESS | $::FAILURE
		When status is $::FAILURE, contains more information
			 key:log                        value:When status is $::FAILURE, contains more information
		Handle of lag configured
			 key:lag_handle                 value:Handle of lag configured
		Handle of Lag port lacp configured
			 key:lag_port_lacp_handle       value:Handle of Lag port lacp configured
		Handle of Lag port StaticLag configured
			 key:lag_port_staticLag_handle  value:Handle of Lag port StaticLag configured
		When status is $::FAILURE, contains more information.
			 key:log                        value:When status is $::FAILURE, contains more information.
		Handle of Lag port lacp configured
			 key:lag_handle                 value:Handle of Lag port lacp configured
		
		Examples:
		See files starting with LAG_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		1) This protocol is available only when using IxTclProtocol API.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_lag_config", kwargs)

	def emulation_ldp_config(self, **kwargs):
		""" This procedure configures LDP simulated routers and the router interfaces.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ldp_config
			 	[-handle                                        ANY]
			 	[-mode                                          CHOICES create
			                                                 CHOICES delete
			                                                 CHOICES disable
			                                                 CHOICES enable
			                                                 CHOICES modify]
			 	[-port_handle                                   ANY]
			 	[-label_adv                                     CHOICES unsolicited on_demand
			                                                 DEFAULT unsolicited]
			 	[-peer_discovery                                ANY]
			 	[-count                                         NUMERIC
			                                                 DEFAULT 1]
			n	[-interface_handle                              ANY]
			x	[-interface_mode                                ANY]
			 	[-intf_ip_addr                                  IPV4
			                                                 DEFAULT 0.0.0.0]
			 	[-intf_prefix_length                            RANGE 1-32
			                                                 DEFAULT 24]
			 	[-intf_ip_addr_step                             IPV4
			                                                 DEFAULT 0.0.1.0]
			x	[-loopback_ip_addr                              IPV4]
			x	[-loopback_ip_addr_step                         IPV4
			x                                                DEFAULT 0.0.1.0]
			 	[-intf_ipv6_addr                                IPV6
			                                                 DEFAULT 0:0:0:1::0]
			 	[-intf_ipv6_prefix_length                       RANGE 1-64
			                                                 DEFAULT 64]
			 	[-intf_ipv6_addr_step                           IPV6
			                                                 DEFAULT 0:0:0:1::0]
			x	[-loopback_ipv6_addr                            IPV6]
			x	[-loopback_ipv6_addr_step                       IPV6
			x                                                DEFAULT 0:0:0:1::0]
			 	[-lsr_id                                        IPV4]
			 	[-label_space                                   RANGE 0-65535]
			 	[-lsr_id_step                                   IPV4
			                                                 DEFAULT 0.0.1.0]
			 	[-mac_address_init                              MAC]
			x	[-mac_address_step                              MAC
			x                                                DEFAULT 0000.0000.0001]
			 	[-remote_ip_addr                                IPV4]
			 	[-remote_ip_addr_target                         IPV6]
			 	[-remote_ip_addr_step                           IPV4]
			 	[-remote_ip_addr_step_target                    IPV6]
			 	[-hello_interval                                RANGE 0-65535]
			 	[-hello_hold_time                               RANGE 0-65535]
			 	[-keepalive_interval                            RANGE 0-65535]
			 	[-keepalive_holdtime                            RANGE 0-65535]
			 	[-discard_self_adv_fecs                         CHOICES 0 1]
			x	[-vlan                                          CHOICES 0 1
			x                                                DEFAULT 0]
			 	[-vlan_id                                       RANGE 0-4095]
			 	[-vlan_id_mode                                  CHOICES fixed increment
			                                                 DEFAULT increment]
			 	[-vlan_id_step                                  RANGE 0-4096
			                                                 DEFAULT 1]
			 	[-vlan_user_priority                            RANGE 0-7
			                                                 DEFAULT 0]
			 	[-vpi                                           ANY]
			 	[-vci                                           ANY]
			 	[-vpi_step                                      ANY]
			 	[-vci_step                                      ANY]
			x	[-atm_encapsulation                             ANY]
			x	[-auth_mode                                     CHOICES null md5
			x                                                DEFAULT null]
			x	[-auth_key                                      ANY]
			x	[-bfd_registration                              CHOICES 0 1
			x                                                DEFAULT 0]
			x	[-bfd_registration_mode                         CHOICES single_hop multi_hop
			x                                                DEFAULT multi_hop]
			 	[-atm_range_max_vpi                             ANY]
			 	[-atm_range_min_vpi                             ANY]
			 	[-atm_range_max_vci                             ANY]
			 	[-atm_range_min_vci                             ANY]
			 	[-atm_vc_dir                                    ANY]
			x	[-enable_explicit_include_ip_fec                ANY]
			x	[-enable_l2vpn_vc_fecs                          ANY]
			x	[-enable_remote_connect                         ANY]
			x	[-enable_vc_group_matching                      ANY]
			x	[-gateway_ip_addr                               IPV4]
			x	[-gateway_ip_addr_step                          IPV4
			x                                                DEFAULT 0.0.1.0]
			x	[-gateway_ipv6_addr                             IPV6]
			x	[-gateway_ipv6_addr_step                        IPV6
			x                                                DEFAULT 0:0:0:1::0]
			x	[-graceful_restart_enable                       CHOICES 0 1]
			x	[-no_write                                      ANY]
			x	[-reconnect_time                                RANGE 0-300000]
			x	[-recovery_time                                 RANGE 0-300000]
			x	[-reset                                         FLAG]
			x	[-targeted_hello_hold_time                      RANGE 0-65535]
			x	[-targeted_hello_interval                       RANGE 0-65535]
			x	[-override_existence_check                      ANY]
			x	[-override_tracking                             ANY]
			n	[-cfi                                           ANY]
			n	[-config_seq_no                                 ANY]
			n	[-egress_label_mode                             ANY]
			n	[-label_start                                   ANY]
			n	[-label_step                                    ANY]
			n	[-label_type                                    ANY]
			n	[-loop_detection                                ANY]
			n	[-max_lsps                                      ANY]
			n	[-max_pdu_length                                ANY]
			n	[-message_aggregation                           ANY]
			n	[-mtu                                           ANY]
			n	[-path_vector_limit                             ANY]
			n	[-timeout                                       ANY]
			n	[-transport_ip_addr                             ANY]
			n	[-user_priofity                                 ANY]
			n	[-vlan_cfi                                      ANY]
			x	[-peer_count                                    NUMERIC]
			x	[-interface_name                                ALPHA]
			x	[-interface_multiplier                          NUMERIC]
			x	[-interface_active                              CHOICES 0 1]
			x	[-target_name                                   ALPHA]
			x	[-target_multiplier                             NUMERIC]
			x	[-target_auth_key                               ANY]
			x	[-initiate_targeted_hello                       CHOICES 0 1]
			x	[-target_auth_mode                              CHOICES null md5]
			x	[-target_active                                 CHOICES 0 1]
			x	[-router_name                                   ALPHA]
			x	[-router_multiplier                             NUMERIC]
			x	[-router_active                                 CHOICES 0 1]
			x	[-targeted_peer_name                            ALPHA]
			x	[-start_rate_scale_mode                         CHOICES port device_group
			x                                                DEFAULT port]
			x	[-start_rate_enabled                            CHOICES 0 1]
			x	[-start_rate                                    NUMERIC]
			x	[-start_rate_interval                           NUMERIC]
			x	[-stop_rate_scale_mode                          CHOICES port device_group
			x                                                DEFAULT port]
			x	[-stop_rate_enabled                             CHOICES 0 1]
			x	[-stop_rate                                     NUMERIC]
			x	[-stop_rate_interval                            NUMERIC]
			x	[-lpb_interface_name                            ALPHA]
			x	[-lpb_interface_active                          CHOICES 0 1]
			x	[-root_ranges_count_v4                          NUMERIC]
			x	[-leaf_ranges_count_v4                          NUMERIC]
			x	[-root_ranges_count_v6                          NUMERIC]
			x	[-leaf_ranges_count_v6                          NUMERIC]
			x	[-ipv6_peer_count                               NUMERIC]
			x	[-ldp_version                                   CHOICES version1 version2]
			x	[-session_preference                            CHOICES any ipv4 ipv6]
			x	[-include_sac                                   ANY]
			x	[-enable_ipv4_fec                               ANY]
			x	[-enable_ipv6_fec                               ANY]
			x	[-enable_fec128                                 ANY]
			x	[-enable_fec129                                 ANY]
			x	[-ignore_received_sac                           ANY]
			x	[-enable_p2mp_capability                        ANY]
			x	[-enable_bfd_mpls_learned_lsp                   ANY]
			x	[-enable_lsp_ping_learned_lsp                   ANY]
			x	[-lsp_type                                      CHOICES p2MP]
			x	[-root_address                                  ANY]
			x	[-root_address_count                            ANY]
			x	[-root_address_step                             ANY]
			x	[-lsp_count_per_root                            ANY]
			x	[-label_value_start                             ANY]
			x	[-label_value_step                              ANY]
			x	[-continuous_increment_opaque_value_across_root ANY]
			x	[-number_of_tlvs                                NUMERIC]
			x	[-group_address_v4                              ANY]
			x	[-group_address_v6                              ANY]
			x	[-group_count_per_lsp                           ANY]
			x	[-group_count_per_lsp_root                      ANY]
			x	[-source_address_v4                             ANY]
			x	[-source_address_v6                             ANY]
			x	[-source_count_per_lsp                          ANY]
			x	[-filter_on_group_address                       ANY]
			x	[-start_group_address_v4                        ANY]
			x	[-start_group_address_v6                        ANY]
			x	[-active_leafrange                              ANY]
			x	[-name                                          ALPHA]
			x	[-active                                        ANY]
			x	[-type                                          ANY]
			x	[-tlv_length                                    ANY]
			x	[-value                                         ANY]
			x	[-increment                                     ANY]
		
		Arguments:
			 	-handle
			 		An LDP handle returned from this procedure and now being used when
			 		the -mode is anything but create.
			 		When -handle is provided with the /globals value the arguments that configure global protocol
			 		setting accept both multivalue handles and simple values.
			 		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
			 		that configure global settings will only accept simple values. In this situation, these arguments will
			 		configure only the settings of the parent device group or the ports associated with the parent topology.
			 	-mode
			 		The mode that is being performed. All but create require the use of
			 		the -handle option.
			 		Valid choices are:
			    		create - Create a new LDP router
			    		delete - Delete the given LDP router
			    		disable - Disable the given LDP router
			    		enable - Enable the given LDP router
			    		modify - Modify an existing LDP router
			 	-port_handle
			 		The port which on which the LDP configuration will take place.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-label_adv
			 		The mode by which the simulated router advertises its FEC ranges.
			 		Valid choices are:
			    		unsolicited - (default) The router distributes FEC ranges whenever it has a new one.
			    		on_demand - The router only distributes FEC ranges when requested by a peer.
			 	-peer_discovery
			 		link- (default) The basic mode which does not attempt to contact targeted peers.targeted - Attempts to contact targeted peers.targeted_martini - Attempts to contact targeted peers.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-count
			 		Defines the number of LDP interfaces to create.
			n	-interface_handle
			x	-interface_mode
			    	-intf_ip_addr
			        		Interface IP address of the LDP session router. Mandatory when -mode is create.
			        		When using IxTclNetwork (new API) this parameter can be omitted if -interface_handle is used.
			        		For IxTclProtocol (old API), when -mode is modify and one of the layer
			        		2-3 parameters (-intf_ip_addr, -gateway_ip_addr, -loopback_ip_addr, etc)
			        		needs to be modified, the emulation_ldp_config command must be provided
			        		with the entire list of layer 2-3 parameters. Otherwise they will be
			        		set to their default values.
			    	-intf_prefix_length
			        		Prefix length on the interface.
			    	-intf_ip_addr_step
			        		Define interface IP address for multiple sessions.
			        		Valid only for -mode create.
			x   	-loopback_ip_addr
			x       		The IP address of the unconnected protocol interface that will be
			x       		created behind the intf_ip_addr interface. The loopback(unconnected)
			x       		interface is the one that will be used for LDP emulation. This type
			x       		of interface is needed when creating extended Martini sessions.
			x   	-loopback_ip_addr_step
			x       		Valid only for -mode create.
			x       		The incrementing step for the loopback_ip_addr parameter.
			    	-intf_ipv6_addr
			        		Interface IP address of the LDP session router. Mandatory when -mode is create.
			        		When using IxTclNetwork (new API) this parameter can be omitted if -interface_handle is used.
			        		For IxTclProtocol (old API), when -mode is modify and one of the layer
			        		2-3 parameters (-intf_ip_addr, -gateway_ip_addr, -loopback_ip_addr, etc)
			        		needs to be modified, the emulation_ldp_config command must be provided
			        		with the entire list of layer 2-3 parameters. Otherwise they will be
			        		set to their default values.
			        		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			    	-intf_ipv6_prefix_length
			        		Prefix length on the interface.
			        		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			    	-intf_ipv6_addr_step
			        		Define interface IP address for multiple sessions.
			        		Valid only for -mode create.
			        		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x   	-loopback_ipv6_addr
			x       		The IP address of the unconnected protocol interface that will be
			x       		created behind the intf_ip_addr interface. The loopback(unconnected)
			x       		interface is the one that will be used for LDP emulation. This type
			x       		of interface is needed when creating extended Martini sessions.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-loopback_ipv6_addr_step
			x       		Valid only for -mode create.
			x       		The incrementing step for the loopback_ip_addr parameter.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			    	-lsr_id
			        		The ID of the router to be emulated.
			    	-label_space
			        		The label space identifier for the interface.
			    	-lsr_id_step
			        		Used to define the lsr_id step for multiple interface creations.
			        		Valid only for -mode create.
			    	-mac_address_init
			        		MAC address to be used for the first session.
			x   	-mac_address_step
			x       		Valid only for -mode create.
			x       		The incrementing step for the MAC address configured on the directly
			x       		connected interfaces. Valid only when IxNetwork Tcl API is used.
			    	-remote_ip_addr
			        		The IPv4 address of a targeted peer.
			    	-remote_ip_addr_target
			        		The IPv6 address of a targeted peer.
			        		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			    	-remote_ip_addr_step
			        		When creating multiple sessions and using the -remote_ip_addr, tells
			        		how to increment between sessions.
			        		Valid only for -mode create.
			    	-remote_ip_addr_step_target
			        		When creating multiple sessions and using the -remote_ip_addr, tells
			        		how to increment between sessions.
			        		Valid only for -mode create.
			        		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			    	-hello_interval
			        		The amount of time, expressed in seconds, between transmitted
			        		HELLO messages.
			    	-hello_hold_time
			        		The amount of time, expressed in seconds, that an LDP adjacency
			        		will be maintained in the absence of a HELLO message.
			    	-keepalive_interval
			        		The amount of time, expressed in seconds, between keep-alive messages
			        		sent from simulated routers to their adjacency in the absence of
			        		other PDUs sent to the adjacency.
			    	-keepalive_holdtime
			        		The amount of time, expressed in seconds, that an LDP adjacency
			        		will be maintained in the absence of a PDU received from the adjacency.
			    	-discard_self_adv_fecs
			        		Discard learned labels from the DUT that match any of the enabled
			        		configured IPv4 FEC ranges.This flag is only set when LDP is
			        		started.If it is to be changed later, LDP should be stopped,
			        		the value changed and then restart LDP.
			x   	-vlan
			x       		Enables vlan on the directly connected LDP router interface.
			x       		Valid options are: 0 - disable, 1 - enable.
			x       		This option is valid only when -mode is create or -mode is modify
			x       		and -handle is a LDP router handle.
			x       		This option is available only when IxNetwork tcl API is used.
			    	-vlan_id
			        		VLAN ID for protocol interface.
			    	-vlan_id_mode
			        		For multiple neighbor configuration, configures the VLAN ID mode.
			        		Valid choices are:
			            		fixed - VLAN ID mode is fixed.
			            		increment - (default) VLAN ID mode to increment.
			    	-vlan_id_step
			        		Valid only for -mode create.
			        		Defines the step for the VLAN ID when the VLAN ID mode is increment.
			        		When vlan_id_step causes the vlan_id value to exceed its maximum value the
			        		increment will be done modulo <number of possible vlan ids>.
			        		Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0
			        		vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			    	-vlan_user_priority
			        		VLAN user priority assigned to protocol interface.
			    	-vpi
			        		VPI for emulated router node
			        		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			    	-vci
			        		VCI for emulated router node
			        		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			    	-vpi_step
			        		Valid only for -mode create. Step value to apply to VPI fieldWhen vpi_step causes the vpi value to exceed its maximum value the increment will be done modulo <number of possible vpi ids>.Examples: vpi = 254; vpi_step = 2-> new vpi value = 0vpi = 255; vpi_step = 11 -> new vpi value = 10
			        		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			    	-vci_step
			        		Valid only for -mode create. Step value to apply to VCI field.When vci_step causes the vci value to exceed its maximum value the increment will be done modulo <number of possible vci ids>.Examples: vci = 65534; vci_step = 2-> new vci value = 0vci = 65535; vci_step = 11 -> new vci value = 10
			        		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x   	-atm_encapsulation
			x       		The encapsulation of the ATM protocol interface associated with the emulated router.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-auth_mode
			x       		Select the type of cryptographic authentication to be used for this targeted peer.
			x       		Valid choices are:
			x           		null - no authentication (the default)
			x           		md5 - an encrypted Message Digest 5 (MD5 key is used)
			x   	-auth_key
			x       		Active only when "md5" is selected in the Authentication Type field.
			x       		(String) Enter a value to be used as a "secret" MD5 key for authentication.
			x       		The maximum length allowed is 255 characters.
			x       		One MD5 key can be configured per interface.
			x   	-bfd_registration
			x       		Enable or disable BFD registration.
			x   	-bfd_registration_mode
			x       		Set BFD registration mode to single hop or multi hop.
			x       		Valid choices are:
			x           		single_hop - In this case, routes are directly connected.
			x           		multi_hop - In this case, routes are more than one hop away of each other.
			    	-atm_range_max_vpi
			        		The maximum VPI value in the ATM label range.
			        		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			    	-atm_range_min_vpi
			        		The minimum VPI value in the ATM label range.
			        		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			    	-atm_range_max_vci
			        		The maximum VCI value in the ATM label range.
			        		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			    	-atm_range_min_vci
			        		The minimum VCI value in the ATM label range.
			        		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			    	-atm_vc_dir
			        		The ATM directional virtual circuit (VC) capability of this LSR. bi_dir- (default) In a label mapping for a defined VPI, a defined VCI can be used for both directions on the link.uni_dir - In a label mapping for a defined VPI, a defined VCI can be used for only one direction on the link.
			        		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x   	-enable_explicit_include_ip_fec
			x       		Enables the use of the explicit include IP FEC list which filters received labels.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-enable_l2vpn_vc_fecs
			x       		Enables the use of Layer 2 Virtual Circuit FECs for this router.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-enable_remote_connect
			x       		Enables LDP routers not part of the local multicast network to connect to the simulated router.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-enable_vc_group_matching
			x       		This option enables the matching of received Martini labels by group ID as well as VCID.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-gateway_ip_addr
			x       		Gives the gateway IP address for the protocol interface that will
			x       		be created for use by the simulated routers.
			x   	-gateway_ip_addr_step
			x       		Valid only for -mode create.
			x       		Gives the step for the gateway IP address.
			x   	-gateway_ipv6_addr
			x       		Gives the gateway IP address for the protocol interface that will
			x       		be created for use by the simulated routers.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-gateway_ipv6_addr_step
			x       		Valid only for -mode create.
			x       		Gives the step for the gateway IP address.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-graceful_restart_enable
			x       		Will enable graceful restart (HA) on the LDP neighbor.
			x   	-no_write
			x       	-reconnect_time
			x           		(in milliseconds) This Fault Tolerant (FT) Reconnect Timer value is
			x           		advertised in the FT Session TLV in the Initialization message sent by
			x           		a neighbor LSR. It is a request sent by an LSR to its neighbor(s) - in
			x           		the event that the receiving neighbor detects that the LDP session has
			x           		failed, the receiver should maintain MPLS forwarding state and wait
			x           		for the sender to perform a restart of the control plane and LDP
			x           		protocol. If the value = 0, the sender is indicating that it will not
			x           		preserve its MPLS forwarding state across the restart.
			x           		If -graceful_restart_enable is set.
			x       	-recovery_time
			x           		If -graceful_restart_enable is set; (in milliseconds)
			x           		The restarting LSR is advertising the amount of time that it will
			x           		retain its MPLS forwarding state. This time period begins when it
			x           		sends the restart Initialization message, with the FT session TLV,
			x           		to the neighbor LSRs (to re-establish the LDP session). This timer
			x           		allows the neighbors some time to resync the LSPs in an orderly
			x           		manner. If the value = 0, it means that the restarting LSR was not
			x           		able to preserve the MPLS forwarding state.
			x       	-reset
			x           		If set, then all existing simulated routers will be removed
			x           		before creating a new one.
			x       	-targeted_hello_hold_time
			x           		The amount of time, expressed in seconds, that an LDP adjacency will
			x           		be maintained for a targeted peer in the absence of a HELLO message.
			x       	-targeted_hello_interval
			x           		The amount of time, expressed in seconds, between transmitted HELLO
			x           		messages to targeted peers.
			x       	-override_existence_check
			x           		If this option is enabled, the interface existence check is skipped but the list of interfaces is still created and maintained in order to keep track of existing interfaces if required. Using this option will speed up the interfaces' creation.
			x           		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x       	-override_tracking
			x           		If this option is enabled, the list of interfaces won't be created and maintained anymore, thus, speeding up the interfaces' creation even more. Also, it will enable -override_existence_check in case it wasn't already enabled because checking for interface existence becomes impossible if the the list of interfaces doesn't exist anymore.
			x           		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			n       	-cfi
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-config_seq_no
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-egress_label_mode
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-label_start
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-label_step
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-label_type
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-loop_detection
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-max_lsps
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-max_pdu_length
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-message_aggregation
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-mtu
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-path_vector_limit
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-timeout
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-transport_ip_addr
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-user_priofity
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n       	-vlan_cfi
			x           	-peer_count
			x               		Peer Count(multiplier)
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-interface_name
			x               		NOT DEFINED
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-interface_multiplier
			x               		number of layer instances per parent instance (multiplier)
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-interface_active
			x               		Flag.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-target_name
			x               		NOT DEFINED
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-target_multiplier
			x               		number of this object per parent object
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-target_auth_key
			x               		MD5Key
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-initiate_targeted_hello
			x               		Initiate Targeted Hello
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-target_auth_mode
			x               		The Authentication mode which will be used.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x               		Valid choices are:
			x                   		null -
			x                   		md5 - Configure the MD5 authentication signature.
			x           	-target_active
			x               		Enable or Disable LDP Targeted Peer
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-router_name
			x               		NOT DEFINED
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-router_multiplier
			x               		number of layer instances per parent instance (multiplier)
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-router_active
			x               		Enable or Disable LDP Router
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-targeted_peer_name
			x               		Targted Peer Name.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-start_rate_scale_mode
			x               		Indicates whether the control is specified per port or per device group
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x               		Valid choices are:
			x                   		port - The control is specified per port.
			x                   		device_group - The control is specified per device group.
			x           	-start_rate_enabled
			x               		Enabled
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-start_rate
			x               		Number of times an action is triggered per time interval
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-start_rate_interval
			x               		Time interval used to calculate the rate for triggering an action (rate = count/interval)
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-stop_rate_scale_mode
			x               		Indicates whether the control is specified per port or per device group
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x               		Valid choices are:
			x                   		port - The control is specified per port.
			x                   		device_group - The control is specified per device group.
			x           	-stop_rate_enabled
			x               		Enabled
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-stop_rate
			x               		Number of times an action is triggered per time interval
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-stop_rate_interval
			x               		Time interval used to calculate the rate for triggering an action (rate = count/interval)
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-lpb_interface_name
			x               		Name of NGPF element
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-lpb_interface_active
			x               		Enable or Disable LDP Interface
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-root_ranges_count_v4
			x               		The number of Root Ranges configured for this LDP router
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-leaf_ranges_count_v4
			x               		The number of Leaf Ranges configured for this LDP router
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-root_ranges_count_v6
			x               		The number of Root Ranges configured for this LDP router
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-leaf_ranges_count_v6
			x               		The number of Leaf Ranges configured for this LDP router
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-ipv6_peer_count
			x               		The number of Ipv6 peers
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-ldp_version
			x               		Version of LDP. When RFC 5036 is chosen, LDP version is version 1. When draft-pdutta-mpls-ldp-adj-capability-00 is chosen, LDP version is version 2
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x               		Valid choices are:
			x                   		version1 - In this case the LDP version chosen will be of RFC 5036.
			x                   		version2 - In this case, the LDO version chosen will be of draft-pdutta-mpls-ldp-adj-capability-00.
			x           	-session_preference
			x               		The transport connection preference of the LDP router that is conveyed in Dual-stack capability TLV included in LDP Hello message.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x               		Valid choices are:
			x                   		any - Use either ipv4 or ipv6 transport connection preference.
			x                   		ipv4 - Use Ipv4 as the Transport connection preference.
			x                   		ipv6 - Use Ipv6 as the Transport connection preference.
			x           	-include_sac
			x               		Select to include 'State Advertisement Control Capability' TLV in Initialization message and Capability message
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-enable_ipv4_fec
			x               		If selected, IPv4-Prefix LSP app type is enabled in SAC TLV.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-enable_ipv6_fec
			x               		If selected, IPv6-Prefix LSP app type is enabled in SAC TLV.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-enable_fec128
			x               		If selected, FEC128 P2P-PW app type is enabled in SAC TLV.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-enable_fec129
			x               		If selected, FEC129 P2P-PW app type is enabled in SAC TLV.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-ignore_received_sac
			x               		If selected, LDP Router ignores SAC TLV it receives.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-enable_p2mp_capability
			x               		If selected, LDP Router is P2MP capable.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-enable_bfd_mpls_learned_lsp
			x               		If selected, BFD MPLS is enabled.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-enable_lsp_ping_learned_lsp
			x               		If selected, LSP Ping is enabled for learned LSPs.
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-lsp_type
			x               		LSP Type
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x               		Valid choices are:
			x                   		p2MP - Enable point-to-multipoint LSP.
			x           	-root_address
			x               		Root Address
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-root_address_count
			x               		Root Address Count
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-root_address_step
			x               		Root Address Step
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-lsp_count_per_root
			x               		LSP Count Per Root
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-label_value_start
			x               		Label Value Start
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-label_value_step
			x               		Label Value Step
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-continuous_increment_opaque_value_across_root
			x               		Continuous Increment Opaque Value Across Root
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-number_of_tlvs
			x               		Number Of TLVs
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-group_address_v4
			x               		IPv4 Group Address
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-group_address_v6
			x               		IPv6 Group Address
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-group_count_per_lsp
			x               		Group Count per LSP
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-group_count_per_lsp_root
			x               		Group Count per LSP
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-source_address_v4
			x               		IPv4 Source Address
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-source_address_v6
			x               		IPv6 Source Address
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-source_count_per_lsp
			x               		Source Count Per LSP
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-filter_on_group_address
			x               		If selected, all the LSPs will belong to the same set of groups
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-start_group_address_v4
			x               		Start Group Address(V4)
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-start_group_address_v6
			x               		Start Group Address(V6)
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-active_leafrange
			x               		Activate/Deactivate Configuration
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-name
			x               		Name of NGPF element, guaranteed to be unique in Scenario
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-active
			x               		If selected, Then the TLV is enabled
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-type
			x               		Type
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-tlv_length
			x               		Length
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-value
			x               		Value
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-increment
			x               		Increment Step
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		       
		       Return Values:
		           A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
			x           key:ipv4_loopback_handle              value:A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
		           A list containing the ipv6 loopback protocol stack handles that were added by the command (if any).
			x           key:ipv6_loopback_handle              value:A list containing the ipv6 loopback protocol stack handles that were added by the command (if any).
		           A list containing the ipv4 protocol stack handles that were added by the command (if any).
			x           key:ipv4_handle                       value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		           A list containing the ipv6 protocol stack handles that were added by the command (if any).
			x           key:ipv6_handle                       value:A list containing the ipv6 protocol stack handles that were added by the command (if any).
		           A list containing the ethernet protocol stack handles that were added by the command (if any).
			x           key:ethernet_handle                   value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		           A list containing the ldp basic router protocol stack handles that were added by the command (if any).
			x           key:ldp_basic_router_handle           value:A list containing the ldp basic router protocol stack handles that were added by the command (if any).
		           A list containing the ldp connected interface protocol stack handles that were added by the command (if any).
			x           key:ldp_connected_interface_handle    value:A list containing the ldp connected interface protocol stack handles that were added by the command (if any).
		           A list containing the ldp targeted router protocol stack handles that were added by the command (if any).
			x           key:ldp_targeted_router_handle        value:A list containing the ldp targeted router protocol stack handles that were added by the command (if any).
		           A list containing the leaf ranges protocol stack handles that were added by the command (if any).
			x           key:leaf_ranges                       value:A list containing the leaf ranges protocol stack handles that were added by the command (if any).
		           A list containing the root ranges protocol stack handles that were added by the command (if any).
			x           key:root_ranges                       value:A list containing the root ranges protocol stack handles that were added by the command (if any).
		           A list containing the ldpv6 basic router protocol stack handles that were added by the command (if any).
			x           key:ldpv6_basic_router_handle         value:A list containing the ldpv6 basic router protocol stack handles that were added by the command (if any).
		           A list containing the ldpv6 connected interface protocol stack handles that were added by the command (if any).
			x           key:ldpv6_connected_interface_handle  value:A list containing the ldpv6 connected interface protocol stack handles that were added by the command (if any).
		           A list containing the ldpv6 targeted router protocol stack handles that were added by the command (if any).
			x           key:ldpv6_targeted_router_handle      value:A list containing the ldpv6 targeted router protocol stack handles that were added by the command (if any).
		           $::SUCCESS | $::FAILURE
			            key:status                            value:$::SUCCESS | $::FAILURE
		           If status is failure, detailed information provided.
			            key:log                               value:If status is failure, detailed information provided.
		           List of LDP routers created Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			            key:handle                            value:List of LDP routers created Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		           List of LDP routers created
			            key:handle                            value:List of LDP routers created
		       
		       Examples:
		           See files starting with LDP_ in the Samples subdirectory.  Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the LDP usage.
		           See the LDP example in Appendix A, "Example APIs," for one specific example usage.
		           See files starting with LDP_ in the Samples subdirectory.  Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the LDP usage.
		           See the LDP example in Appendix A, "Example APIs," for one specific example usage.
		       
		       Sample Input:
		       
		       Sample Output:
		       
		       Notes:
		           Coded versus functional specification.
		           If one wants to modify the ineterface to which the protocol interface is
		           connected, one has to specify the correct MAC address of that interface.
		           If this requirement is not fulfilled, the interface is not guaranteed to
		           be correctly determined because more interfaces can have the exact same
		           configuration.
		           When -handle is provided with the /globals value the arguments that configure global protocol
		           setting accept both multivalue handles and simple values.
		           When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
		           that configure global settings will only accept simple values. In this situation, these arguments will
		           configure only the settings of the parent device group or the ports associated with the parent topology.
		           If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		           Coded versus functional specification.
		           If one wants to modify the ineterface to which the protocol interface is connected, one has to specify the correct MAC address of that interface. If this requirement is not fulfilled, the interface is not guaranteed to be correctly determined because more interfaces can have the exact same configuration.
		       
		       See Also:
		       
		"""
		return self._run_keyword("emulation_ldp_config", kwargs)

	def emulation_ldp_control(self, **kwargs):
		""" Stop, start or restart the protocol.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ldp_control
			 	-mode                CHOICES restart
			                      CHOICES start
			                      CHOICES stop
			                      CHOICES restartDown
			                      CHOICES abort
			                      CHOICES gracefullyRestart
			                      CHOICES resumebasichello
			                      CHOICES stopbasichello
			                      CHOICES resumekeepalive
			                      CHOICES stopkeepalive
			                      CHOICES activateLeafRange
			                      CHOICES deactivateLeafRange
			 	[-port_handle        ANY]
			x	[-delay              NUMERIC]
			 	-handle              ANY]
			n	[-advertise          ANY]
			n	[-flap_count         ANY]
			n	[-flap_down_time     ANY]
			n	[-flap_interval_time ANY]
			n	[-flap_routes        ANY]
			n	[-withdraw           ANY]
		
		Arguments:
			 	-mode
			 		Operation that is been executed on the protocol. Valid choices are:
			 		restart - Restart the protocol.
			 		start- Start the protocol.
			 		stop- Stop the protocol.
			 		restart_down - Restarts the down sessions.
			 		abort- Aborts the protocol.
			 		resume_hello - Resumes hello message for the given LDP connected interface.
			 		stop_hello - Stops hello message for the given LDP connected Interface.
			 		resume_keepalive - Resumes Keepalive message for the given LDP connected interface.
			 		stop_keepalive- Stop Keepalive message for the given LDP connected interface.
			 		activate_LeafRange - Activate Multicast Leaf Range.
			 		deactivate_LeafRange - Stop Multicast Leaf Range.
			 		Valid choices are:
			    		restart - Restart the LDP protocol/session.
			    		start - Start the LDP protocol/session.
			    		stop - Stop the LDP protocol/session.
			    		restart_down - Restart the down sessions.
			    		abort - Aborts the protcol.
			    		gracefullyRestart - Aborts the protcol.
			    		resumebasichello - Resumes hello message for the given LDP connected interface.
			    		stopbasichello - Stops hello message for the given LDP connected Interface.
			    		resumekeepalive - Resumes Keepalive message for the given LDP connected Interface.
			    		stopkeepalive - Stops Keepalive message for the given LDP connected Interface.
			    		activateLeafRange - Activate Multicast Leaf Range.
			    		deactivateLeafRange - Deactivate Multicast Leaf Range.
			 	-port_handle
			 		The port where the LDP is to be controlled.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-delay
			x		The percentage of addresses that will be aged out. This argument is ignored when mode is not age_out_routes and *must* be specified in such circumstances.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-handle
			 		The LDP session handle to act upon.
			n	-advertise
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_count
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_down_time
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_interval_time
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_routes
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-withdraw
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		See files starting with LDP_ in the Samples subdirectory.  Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the LDP usage.
		See the LDP example in Appendix A, "Example APIs," for one specific example usage.
		See files starting with LDP_ in the Samples subdirectory.  Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the LDP usage.
		See the LDP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_ldp_control", kwargs)

	def emulation_ldp_info(self, **kwargs):
		""" Retrieves information about the LDP protocol.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ldp_info
			 	-mode    CHOICES stats
			          CHOICES clear_stats
			          CHOICES settings
			          CHOICES neighbors
			          CHOICES lsp_labels
			          CHOICES stats_per_device_group
			          CHOICES session]
			 	-handle  ANY]
		
		Arguments:
			 	-mode
			 		Operation that is been executed on the protocol. Valid options are:
			 		stats
			 		clear_stats
			 		settings
			 		neighbors
			 		lsp_labels
			 		stats_per_device_group
			 		session
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		stats -
			    		clear_stats -
			    		settings -
			    		neighbors -
			    		lsp_labels -
			    		stats_per_device_group -
			    		session -
			 	-handle
			 		The LDP session handle to act upon.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                        value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                           value:If status is failure, detailed information provided.
		Ixia only
			xkey:port_name                     value:Ixia only
		Ixia only
			xkey:basic_sessions                value:Ixia only
		Ixia only
			xkey:targeted_sessions_running     value:Ixia only
		Ixia only
			xkey:targeted_sessions_configured  value:Ixia only
		Cisco only
			nkey:routing_protocol              value:Cisco only
		Cisco only
			nkey:ip_address                    value:Cisco only
		Cisco only
			nkey:elapsed_time                  value:Cisco only
		Cisco only
			nkey:linked_hellos_tx              value:Cisco only
		Cisco only
			nkey:linked_hellos_rx              value:Cisco only
		Cisco only
			nkey:targeted_hellos_tx            value:Cisco only
		Cisco only
			nkey:targeted_hellos_rx            value:Cisco only
		Cisco only
			nkey:total_setup_time              value:Cisco only
		Cisco only
			nkey:min_setup_time                value:Cisco only
		Cisco only
			nkey:max_setup_time                value:Cisco only
		Cisco only
			nkey:num_lsps_setup                value:Cisco only
		No further support planned
			 key:req_rx                        value:No further support planned
		No further support planned
			 key:req_tx                        value:No further support planned
		No further support planned
			 key:map_rx                        value:No further support planned
		No further support planned
			 key:map_tx                        value:No further support planned
		No further support planned
			 key:release_rx                    value:No further support planned
		No further support planned
			 key:release_tx                    value:No further support planned
		No further support planned
			 key:withdraw_rx                   value:No further support planned
		No further support planned
			 key:withdraw_tx                   value:No further support planned
		No further support planned
			 key:abort_rx                      value:No further support planned
		No further support planned
			 key:abort_tx                      value:No further support planned
		No further support planned
			 key:notif_rx                      value:No further support planned
		No further support planned
			 key:notif_tx                      value:No further support planned
		No further support planned; Cisco only
			nkey:max_peers                     value:No further support planned; Cisco only
		No further support planned; Cisco only
			nkey:max_lsps                      value:No further support planned; Cisco only
		No further support planned; Cisco only
			nkey:peer_count                    value:No further support planned; Cisco only
		No further support planned
			 key:intf_ip_addr      a.b.c.d     value:No further support planned
		No further support planned; Cisco only
			nkey:transport_address a.b.c.d     value:No further support planned; Cisco only
		No further support planned
			 key:targeted_hello                value:No further support planned
		No further support planned
			 key:label_adv                     value:No further support planned
		No further support planned
			 key:hello_hold_time               value:No further support planned
		No further support planned
			 key:hello_interval                value:No further support planned
		No further support planned
			 key:keepalive_interval            value:No further support planned
		No further support planned
			 key:keepalive_holdtime            value:No further support planned
		No further support planned
			 key:label_space                   value:No further support planned
		No further support planned
			 key:vpi                           value:No further support planned
		No further support planned
			 key:vci                           value:No further support planned
		No further support planned
			 key:atm_range_min_vci             value:No further support planned
		No further support planned
			 key:atm_range_max_vci             value:No further support planned
		No further support planned
			 key:atm_range_min_vpi             value:No further support planned
		No further support planned
			 key:atm_range_max_vpi             value:No further support planned
		No further support planned; Cisco only
			nkey:vc_direction                  value:No further support planned; Cisco only
		No further support planned; Cisco only
			nkey:atm_merge_capability          value:No further support planned; Cisco only
		No further support planned; Cisco only
			nkey:fr_merge_capability           value:No further support planned; Cisco only
		No further support planned; Cisco only
			nkey:path_vector_limit             value:No further support planned; Cisco only
		No further support planned; Cisco only
			nkey:max_pdu_length                value:No further support planned; Cisco only
		No further support planned; Cisco only
			nkey:loop_detection                value:No further support planned; Cisco only
		No further support planned
			 key:ip_address  a.b.c.d           value:No further support planned
		No further support planned
			 key:hold_time                     value:No further support planned
		No further support planned
			 key:keepalive                     value:No further support planned
		No further support planned; Cisco only
			nkey:label_type                    value:No further support planned; Cisco only
		No further support planned; Cisco only
			nkey:config_seq_no                 value:No further support planned; Cisco only
		No further support planned; Cisco only
			nkey:max_lsps                      value:No further support planned; Cisco only
		No further support planned; Cisco only
			nkey:max_peers                     value:No further support planned; Cisco only
		No further support planned; Cisco only
			nkey:atm_label_range               value:No further support planned; Cisco only
		No further support planned; Cisco only
			nkey:fr_label_range                value:No further support planned; Cisco only
		Cisco only; disabled|nonexist|hello_adj|init|openrec|opensent|operational
			nkey:session_state                 value:Cisco only; disabled|nonexist|hello_adj|init|openrec|opensent|operational
		Cisco only; number of opened LSPs
			nkey:num_incoming_ingress_lsps     value:Cisco only; number of opened LSPs
		Cisco only; number of opened LSPs
			nkey:num_incoming_egress_lsps      value:Cisco only; number of opened LSPs
		Cisco only
			nkey:lsp_pool_handle.<handle>.     value:Cisco only
		Cisco only; {ingress|egress}
			nkey:type                          value:Cisco only; {ingress|egress}
		Cisco only; <number of opened LSPs>
			nkey:num_opened_lsps               value:Cisco only; <number of opened LSPs>
		Ixia only; list of neighbors of the selected LSR
			xkey:neighbors                     value:Ixia only; list of neighbors of the selected LSR
		list of values like: <pool_handle>, incoming_egress
			 key:source                        value:list of values like: <pool_handle>, incoming_egress
		Ixia only; list of ipv4_prefix|host_addr...
			 key:fec_type                      value:Ixia only; list of ipv4_prefix|host_addr...
		Ixia only; list of FEC IP prefix (only for link or targeted sessions)
			 key:prefix                        value:Ixia only; list of FEC IP prefix (only for link or targeted sessions)
		Ixia only; list of FEC prefix length (only for link or targeted sessions)
			 key:prefix_length                 value:Ixia only; list of FEC prefix length (only for link or targeted sessions)
		Ixia only; list of MPLS label (for IPv4 labels)
			 key:label                         value:Ixia only; list of MPLS label (for IPv4 labels)
		Ixia only; list of values learned | assigned
			xkey:type                          value:Ixia only; list of values learned | assigned
		Ixia only; list of Group IDs (only for martini labels)
			xkey:group_id                      value:Ixia only; list of Group IDs (only for martini labels)
		Ixia only; list of VC IDs (only for martini labels)
			xkey:vc_id                         value:Ixia only; list of VC IDs (only for martini labels)
		Ixia only; list of VC types like: frameRelay, ATMAAL5, ATMXCell, etc.
			xkey:vc_type                       value:Ixia only; list of VC types like: frameRelay, ATMAAL5, ATMXCell, etc.
		Ixia only; list of VCI (only for ATM labels)
			xkey:vci                           value:Ixia only; list of VCI (only for ATM labels)
		Ixia only; list of VPI (only for ATM labels)
			xkey:vpi                           value:Ixia only; list of VPI (only for ATM labels)
		Ixia only; list of state (only for ATM assigned labels)
			xkey:state                         value:Ixia only; list of state (only for ATM assigned labels)
		Routing Protocol
			 key:routing_protocol              value:Routing Protocol
		Ip Address
			 key:ip_address                    value:Ip Address
		Elapsed Time
			 key:elapsed_time                  value:Elapsed Time
		Linked Hellos Tx
			 key:linked_hellos_tx              value:Linked Hellos Tx
		Linked Hellos Rx
			 key:linked_hellos_rx              value:Linked Hellos Rx
		Targeted Hellos Tx
			 key:targeted_hellos_tx            value:Targeted Hellos Tx
		Targeted Hellos Rx
			 key:targeted_hellos_rx            value:Targeted Hellos Rx
		Total Setup Time
			 key:total_setup_time              value:Total Setup Time
		Min Setup Time
			 key:min_setup_time                value:Min Setup Time
		Max Setup Time
			 key:max_setup_time                value:Max Setup Time
		Num Lsps Setup
			 key:num_lsps_setup                value:Num Lsps Setup
		No further support planned
			 key:max_peers                     value:No further support planned
		No further support planned
			 key:max_lsps                      value:No further support planned
		No further support planned
			 key:peer_count                    value:No further support planned
		No further support planned
			 key:transport_address a.b.c.d     value:No further support planned
		No further support planned
			 key:vc_direction                  value:No further support planned
		No further support planned
			 key:atm_merge_capability          value:No further support planned
		No further support planned
			 key:fr_merge_capability           value:No further support planned
		No further support planned
			 key:path_vector_limit             value:No further support planned
		No further support planned
			 key:max_pdu_length                value:No further support planned
		No further support planned
			 key:loop_detection                value:No further support planned
		No further support planned
			 key:label_type                    value:No further support planned
		No further support planned
			 key:config_seq_no                 value:No further support planned
		No further support planned
			 key:atm_label_range               value:No further support planned
		No further support planned
			 key:fr_label_range                value:No further support planned
		disabled|nonexist|hello_adj|init|openrec|opensent|operational
			 key:session_state                 value:disabled|nonexist|hello_adj|init|openrec|opensent|operational
		number of opened LSPs
			 key:num_incoming_ingress_lsps     value:number of opened LSPs
		number of opened LSPs
			 key:num_incoming_egress_lsps      value:number of opened LSPs
		Lsp Pool Handle
			 key:lsp_pool_handle.<handle>.     value:Lsp Pool Handle
		{ingress|egress}
			 key:type                          value:{ingress|egress}
		<number of opened LSPs>
			 key:num_opened_lsps               value:<number of opened LSPs>
		
		Examples:
		See files starting with LDP_ in the Samples subdirectory.  Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the LDP usage.
		See the LDP example in Appendix A, "Example APIs," for one specific example usage.
		See files starting with LDP_ in the Samples subdirectory.  Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the LDP usage.
		See the LDP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_ldp_info", kwargs)

	def emulation_ldp_route_config(self, **kwargs):
		""" This procedure creates
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ldp_route_config
			 	-mode                                CHOICES create modify delete
			 	-handle                              ANY]
			x	[-return_detailed_handles            CHOICES 0 1
			x                                     DEFAULT 0]
			 	[-egress_label_mode                  CHOICES nextlabel fixed
			                                      DEFAULT nextlabel]
			 	[-fec_ip_prefix_start                IPV4
			                                      DEFAULT 0.0.0.0]
			x	[-fec_ip_prefix_step                 IPV4
			x                                     DEFAULT 0.0.0.1]
			x	[-fec_ip_prefix_length               RANGE 1-32
			x                                     DEFAULT 24]
			 	[-fec_host_addr                      ANY]
			 	[-fec_host_prefix_length             ANY]
			 	[-fec_type                           CHOICES ipv4_prefix
			                                      CHOICES host_addr
			                                      CHOICES vc
			                                      CHOICES network_topology
			                                      DEFAULT ipv4_prefix]
			x	[-network_topology_type              CHOICES grid
			x                                     CHOICES mesh
			x                                     CHOICES custom
			x                                     CHOICES ring
			x                                     CHOICES hub-and-spoke
			x                                     CHOICES tree
			x                                     CHOICES ipv4-prefix
			x                                     CHOICES fat-tree
			x                                     CHOICES linear]
			x	[-fec_vc_atm_enable                  CHOICES 0 1
			x                                     DEFAULT 1]
			x	[-fec_vc_atm_max_cells               RANGE 1-65535
			x                                     DEFAULT 1]
			 	[-fec_vc_cbit                        CHOICES 0 1
			                                      DEFAULT 1]
			x	[-fec_vc_ce_ip_addr                  ANY]
			x	[-fec_vc_ce_ip_addr_inner_step       ANY]
			x	[-fec_vc_ce_ip_addr_outer_step       ANY]
			x	[-fec_vc_cem_option                  RANGE 0-65535
			x                                     DEFAULT 0]
			x	[-fec_vc_cem_option_enable           CHOICES 0 1
			x                                     DEFAULT 0]
			x	[-fec_vc_cem_payload                 RANGE 48-1023
			x                                     DEFAULT 48]
			x	[-fec_vc_cem_payload_enable          CHOICES 0 1
			x                                     DEFAULT 1]
			x	[-fec_vc_count                       NUMERIC
			x                                     DEFAULT 1]
			x	[-fec_vc_fec_type                    CHOICES generalized_id_fec_vpls
			x                                     CHOICES pw_id_fec
			x                                     DEFAULT generalized_id_fec_vpls]
			 	[-fec_vc_group_id                    NUMERIC]
			x	[-fec_vc_group_count                 ANY]
			 	[-fec_vc_id_start                    RANGE 0-2147483647
			                                      DEFAULT 1]
			 	[-fec_vc_id_step                     RANGE 0-2147483647
			                                      DEFAULT 1]
			x	[-fec_vc_id_count                    ANY]
			 	[-fec_vc_intf_mtu_enable             ANY]
			 	[-fec_vc_intf_mtu                    RANGE 0-65535
			                                      REGEXP ^[0-9]+$
			                                      DEFAULT 0]
			 	[-fec_vc_intf_desc                   ANY]
			x	[-fec_vc_intf_desc_enable            CHOICES 0 1]
			x	[-fec_vc_name                        ALPHA]
			x	[-fec_vc_active                      CHOICES 0 1]
			x	[-fec_vc_ip_range_addr_count         ANY]
			x	[-fec_vc_ip_range_addr_start         ANY]
			x	[-fec_vc_ip_range_addr_inner_step    ANY]
			x	[-fec_vc_ip_range_addr_outer_step    ANY]
			x	[-fec_vc_ip_range_enable             ANY]
			x	[-fec_vc_ip_range_prefix_len         ANY]
			x	[-fec_vc_label_mode                  ANY]
			x	[-fec_vc_label_value_start           RANGE 0-1046400
			x                                     DEFAULT 16]
			x	[-fec_vc_label_value_step            RANGE 0-1046400
			x                                     DEFAULT 0]
			x	[-fec_vc_mac_range_count             NUMERIC
			x                                     DEFAULT 1]
			x	[-fec_vc_mac_range_enable            CHOICES 0 1
			x                                     DEFAULT 0]
			x	[-fec_vc_mac_range_first_vlan_id     RANGE 0-4095
			x                                     DEFAULT 100]
			x	[-fec_vc_mac_range_repeat_mac        ANY]
			x	[-fec_vc_mac_range_same_vlan         ANY]
			x	[-fec_vc_mac_range_start             MAC
			x                                     DEFAULT 0000.0000.0000]
			x	[-fec_vc_mac_range_vlan_enable       ANY]
			x	[-fec_vc_peer_address                IP
			x                                     DEFAULT 0.0.0.0]
			 	[-fec_vc_type                        CHOICES atm_aal5_vcc
			                                      CHOICES atm_cell
			                                      CHOICES atm_vcc_1_1
			                                      CHOICES atm_vcc_n_1
			                                      CHOICES atm_vpc_1_1
			                                      CHOICES atm_vpc_n_1
			                                      CHOICES cem
			                                      CHOICES eth
			                                      CHOICES eth_vlan
			                                      CHOICES eth_vpls
			                                      CHOICES fr_dlci
			                                      CHOICES hdlc
			                                      CHOICES ppp
			                                      CHOICES satop_e1
			                                      CHOICES satop_e3
			                                      CHOICES satop_t1
			                                      CHOICES satop_t3
			                                      CHOICES cesopsn_basic
			                                      CHOICES cesopsn_cas
			                                      CHOICES fr_dlci_rfc4619
			                                      DEFAULT eth_vlan]
			 	[-hop_count_tlv_enable               ANY]
			 	[-hop_count_value                    ANY]
			 	[-label_msg_type                     ANY]
			x	[-label_value_start                  RANGE 0-1048575
			x                                     DEFAULT 16]
			x	[-label_value_start_step             RANGE 0-1048575
			x                                     DEFAULT 1]
			 	[-lsp_handle                         ANY]
			x	[-next_hop_peer_ip                   ANY]
			 	[-num_lsps                           RANGE 1-34048
			                                      DEFAULT 1]
			x	[-num_routes                         ANY]
			x	[-packing_enable                     CHOICES 0 1
			x                                     DEFAULT 0]
			x	[-provisioning_model                 CHOICES bgp_auto_discovery
			x                                     CHOICES manual_configuration]
			x	[-stale_timer_enable                 ANY]
			x	[-stale_request_time                 ANY]
			x	[-no_write                           ANY]
			x	[-auto_peer_id                       CHOICES 0 1]
			x	[-fec_vc_pw_status_enable            CHOICES 0 1]
			x	[-fec_vc_pw_status_code              CHOICES clear_fault_code
			x                                     CHOICES pw_not_forwarding_code
			x                                     CHOICES ac_rx_fault_code
			x                                     CHOICES ac_tx_fault_code
			x                                     CHOICES pw_rx_fault_code
			x                                     CHOICES pw_tx_fault_code]
			x	[-fec_vc_pw_status_send_notification CHOICES 0 1]
			x	[-fec_vc_down_start                  NUMERIC]
			x	[-fec_vc_down_interval               NUMERIC]
			x	[-fec_vc_up_interval                 NUMERIC]
			x	[-fec_vc_repeat_count                NUMERIC]
			x	[-fec_vc_type_vpls_id                CHOICES id_as_number id_ip_address]
			x	[-fec_vc_ip_address_vpls_id          ANY]
			x	[-fec_vc_as_number_vpls_id           ANY]
			x	[-fec_vc_assigned_number_vpls_id     ANY]
			x	[-fec_vc_source_aii_type             CHOICES as_ip number]
			x	[-fec_vc_source_aii_as_ip            IPV4]
			x	[-fec_vc_source_aii_as_number        ANY]
			x	[-fec_vc_target_aii_type             CHOICES as_ip number]
			x	[-fec_vc_target_aii_as_ip            IPV4]
			x	[-fec_vc_target_aii_as_number        NUMERIC]
			x	[-fec_vc_include_tdm_payload         ANY]
			x	[-fec_vc_tdm_data_size               NUMERIC]
			x	[-fec_vc_include_tdm_bitrate         ANY]
			x	[-fec_vc_tdm_bitrate                 ANY]
			x	[-fec_vc_include_rtp_header          ANY]
			x	[-fec_vc_include_tdm_option          ANY]
			x	[-fec_vc_timestamp_mode              CHOICES absolute differential]
			x	[-fec_vc_payload_type                ANY]
			x	[-fec_vc_frequency                   ANY]
			x	[-fec_vc_include_ssrc                ANY]
			x	[-fec_vc_ssrc                        ANY]
			x	[-fec_vc_cas                         CHOICES e1_trunk
			x                                     CHOICES t1_esf_trunk
			x                                     CHOICES t1_sf_trunk]
			x	[-fec_vc_sp                          CHOICES hexval1
			x                                     CHOICES hexval2
			x                                     CHOICES hexval3
			x                                     CHOICES hexval4]
			x	[-fec_vc_enable_cccv_negotiation     ANY]
			x	[-fec_vc_pw_ach_cc                   ANY]
			x	[-fec_vc_router_alert_cc             ANY]
			x	[-fec_vc_lsp_ping_cv                 ANY]
			x	[-fec_vc_bfd_udp_cv                  ANY]
			x	[-fec_vc_bfd_pw_cv                   ANY]
			x	[-fec_active                         CHOICES 0 1]
			x	[-fec_name                           ALPHA]
			x	[-topology_config_active             CHOICES 0 1]
			x	[-topology_router_active             CHOICES 0 1]
			x	[-topology_router_label_value        ANY]
			x	[-topology_router_id                 ANY]
			 	[-grid_col                           RANGE 2-10000
			                                      DEFAULT 2]
			 	[-grid_row                           RANGE 2-10000
			                                      DEFAULT 2]
			x	[-grid_include_emulated_device       CHOICES 0 1]
			x	[-grid_link_multiplier               NUMERIC]
			x	[-mesh_number_of_nodes               NUMERIC]
			x	[-mesh_include_emulated_device       CHOICES 0 1]
			x	[-mesh_link_multiplier               NUMERIC]
			x	[-ring_number_of_nodes               NUMERIC]
			x	[-ring_include_emulated_device       CHOICES 0 1]
			x	[-ring_link_multiplier               NUMERIC]
			x	[-hub_spoke_number_of_first_level    NUMERIC]
			x	[-hub_spoke_number_of_second_level   NUMERIC]
			x	[-hub_spoke_enable_level_2           CHOICES 0 1]
			x	[-hub_spoke_link_multiplier          NUMERIC]
			x	[-tree_number_of_nodes               NUMERIC]
			x	[-tree_include_emulated_device       CHOICES 0 1]
			x	[-tree_use_tree_depth                CHOICES 0 1]
			x	[-tree_depth                         NUMERIC]
			x	[-tree_max_children_per_node         NUMERIC]
			x	[-tree_link_multiplier               NUMERIC]
			x	[-custom_link_multiplier             NUMERIC]
			x	[-custom_from_node_index             NUMERIC]
			x	[-custom_to_node_index               NUMERIC]
			x	[-fat_tree_link_multiplier           NUMERIC]
			x	[-fat_tree_level_count               NUMERIC]
			x	[-fat_tree_node_count                NUMERIC]
			x	[-linear_nodes                       NUMERIC]
			x	[-linear_link_multiplier             NUMERIC]
			x	[-external_link_router_source        NUMERIC]
			x	[-external_link_router_destination   NUMERIC]
			x	[-external_link_network_group_handle ANY]
			x	[-connected_to_handle                ANY]
			n	[-fec_host_step                      ANY]
			n	[-path_vector_tlv                    ANY]
			n	[-path_vector_tlv_lsr                ANY]
			x	[-name                               ANY]
		
		Arguments:
			 	-mode
			 		Mode that is being performed.All but create require the use of
			 		the -handle option.Valid choices are:
			 		create- Create a new LDP interface
			 		modify- Modify an existing LDP interface
			 		delete- Delete the given LDP interface
			 		Valid choices are:
			    		create - Create the specified LSP or FEC Pools/Ranges.
			    		modify - Modify the given LSP.
			    		delete - Delete the specified LSP.
			 	-handle
			 		The LDP handle.
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-egress_label_mode
			 		This argument can be used to specify whether or not the same label
			 		will be used for all the FECs in the FEC range. It has any meaning
			 		only when the fec_type option is set to host_addr.
			 		Valid choices are:
			    		nextlabel - Next available label is assigned for each LSP.
			    		fixed - The same label (increment from previous FEC range) is assigned for all LSPs in this FEC range.
			 	-fec_ip_prefix_start
			 		The first network address in the range of advertising FECs, when
			 		fec_type is ipv4_prefix.
			x	-fec_ip_prefix_step
			x		Provides step increment for fec_ip_prefix_start for adv Fec Range.
			x	-fec_ip_prefix_length
			x		The number of bits in the mask applied to the network address. The
			x		masked bits in the First Network address form the address prefix.
			x		Valid when fec_type is ipv4_prefix.
			 	-fec_host_addr
			 		The first network address in the range of Requesting FECs, when fec_type is host_addr.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-fec_host_prefix_length
			 		The number of bits in the mask applied to the network address. The masked bits in the First Network address form the address prefix.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-fec_type
			 		Note: this option cannot be modified with modify mode.
			 		Valid choices are:
			 		ipv4_prefix - configure FECs to be advertised by the
			 		simulated router
			 		host_addr - configure FECs to be requested of upstream peers, to be
			 		used in download on demand advertising mode.
			 		vc - configure parameters for VC range associated with an LDP L2 VPN
			 		interface.
			 		Valid choices are:
			    		ipv4_prefix - Configure FECs to be advertised by the simulated router.
			    		host_addr - Configure FECs to be requested of upstream peers, to be used in download on demand advertising mode.
			    		vc - Configure parameters for VC range associated with an LDP L2 VPN interface.
			    		network_topology - Configure parameters for configuring a network topology.
			x	-network_topology_type
			x		The type of topology route to create.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		grid - This option configures a grid type network topology in network group.
			x   		mesh - This option configures a mesh type network topology in network group.
			x   		custom - This option configures a custom type network topology in network group.
			x   		ring - This option configures a ring type network topology in network group.
			x   		hub-and-spoke - This option configures a hub and spoke type network topology in network group.
			x   		tree - This option configures a tree type network topology in network group.
			x   		fat-tree - This option configures a fat tree type network topology in network group.
			x   		linear - This option configures a linear type network topology in network group.
			x	-fec_vc_atm_enable
			x		If checked, indicates that ATM Transparent Cell Transport mode is
			x		being used. Multiple ATM cells may be grouped into a single MPLS frame
			x		for transmission from one ATM port connected to another ATM port.
			x		Valid only when -mode is create/modify and -fec_vc_type is atm_cell or
			x		atm_vcc_1_1 or atm_vpc_1_1 or atm_vcc_n_1 or atm_vpc_n_1 and fec_type is vc.
			x		Valid only when using IxTclNetwork.
			x	-fec_vc_atm_max_cells
			x		The Maximum number of ATM Cells which may be concatenated and sent in
			x		a single MPLS frame. This parameter is part of the FEC element.
			x		Valid only when -mode is create/modify and -fec_vc_type is atm_cell or
			x		atm_vcc_1_1 or atm_vpc_1_1 or atm_vcc_n_1 or atm_vpc_n_1 and fec_type is vc.
			x		Valid only when using IxTclNetwork.
			 	-fec_vc_cbit
			 		If checked, sets the C-Bit (flag). It is the highest order bit in the
			 		VC Type field. If the bit is set, it indicates the presence of a
			 		control word on this VC.
			 		Valid when fec_type is vc. This parameter is always 1, when fec_vc_type is cem, fr_dlci or fr_dlci_rfc4619.
			x	-fec_vc_ce_ip_addr
			x		The customer edge device IP address. Valid only when -mode is create or modify and -fec_vc_type is eth_vpls and fec_type is vc. Valid only when using IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-fec_vc_ce_ip_addr_inner_step
			x		The value used to increment the CE IP address for the same VC Range. Valid only when -mode is create or modify and -fec_vc_type is eth_vpls and -fec_type is vc. Valid only when using IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-fec_vc_ce_ip_addr_outer_step
			x		The value used to increment the CE IP address when creating multiple VC Ranges.Valid only when -mode is create or modify and -fec_vc_type is eth_vpls and fec_type is vc. Valid only when using IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-fec_vc_cem_option
			x		The value of the CEM option.
			x		Valid only when -mode is create/modify and -fec_vc_type is cem and fec_type is vc.
			x		Valid only when using IxTclNetwork.
			x	-fec_vc_cem_option_enable
			x		If checked, indicates that the CEM option is present.
			x		Valid only when -mode is create or modify and -fec_vc_type is cem and fec_type is vc.
			x		Valid only when using IxTclNetwork.
			x	-fec_vc_cem_payload
			x		The length of the CEM payload (in bytes).
			x		Valid only when -mode is create or modify and -fec_vc_type is cem and fec_type is vc.
			x		Valid only when using IxTclNetwork.
			x	-fec_vc_cem_payload_enable
			x		If checked, indicates that there is a CEM payload.
			x		Valid only when -mode is create or modify and -fec_vc_type is cem and fec_type is vc.
			x		Valid only when using IxTclNetwork.
			x	-fec_vc_count
			x		This option can be used to set the number of pseudowires to be
			x		configured on each LDP VC range.
			x		Valid only when using IxTclNetwork API and fec_type is vc.
			x	-fec_vc_fec_type
			x		Configure the FEC type Valid only when using IxTclNetwork API and fec_type is vc.
			x		Valid choices are:
			x		generalized_id_fec_vpls- Generalized Id FEC 0x81 VPLS
			x		pw_id_fec- PW Id FEC 0x80
			x		Valid choices are:
			x   		generalized_id_fec_vpls - Denotes the Generalized Id FEC 0x81 VPLS.
			x   		pw_id_fec - Denotes the PW Id FEC 0x80.
			 	-fec_vc_group_id
			 		A user-defined 32-bit value used to identify a group of VCs.
			 		Valid when fec_type is vc.
			x	-fec_vc_group_count
			x		The number of VCs in the group.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-fec_vc_id_start
			 		The 32-bit VC connection identifier. Used with the VC type to identify
			 		a specific VC.
			 		Valid when fec_type is vc.
			 	-fec_vc_id_step
			 		The increment step to be added to the VCID to create the next VCID in
			 		a group of VCIDs.
			 		Valid when fec_type is vc.
			x	-fec_vc_id_count
			x		(In octets) The 8-bit VC information Length field. It indicates the length of the (2-octet) VC ID field plus combined length of all of the parameters in the VC FEC element.Valid only when -mode is create or modify and fec_type is vc.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-fec_vc_intf_mtu_enable
			 		If checked, indicates that an Interface MTU parameter is present, applies to, and is required for, the following VC types:Type 0x0001 - fr_dlci Type 0x0002 - atm_aal5_vcc Type 0x0004 - eth_vlanType 0x0005 - ethType 0x0007 - pppValid when fec_type is vc.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-fec_vc_intf_mtu
			 		(in octets) The 2-octet value for the maximum Transmission Unit (MTU).
			 		Valid when fec_type is vc.
			 	-fec_vc_intf_desc
			 		An optional user-defined Interface Description. It may be used with
			 		ALL VC types. Valid length is 0 to 80 octets.
			 		Valid when fec_type is vc.
			x	-fec_vc_intf_desc_enable
			x		Enable or Disable "Description Enabled".
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_name
			x		Name of the LDP L2VPN element.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_active
			x		Activates the FEC VC/LSP items.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_ip_range_addr_count
			x		The number of emulated LDP hosts to be created on this port. Valid only when -mode is create or modify and -fec_vc_type is eth_vpls and fec_type is vc. Valid only when using IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-fec_vc_ip_range_addr_start
			x		The IP address that starts the L2 VC IP range. Valid only when -mode is create or modify and -fec_vc_type is eth_vpls and fec_type is vc. Valid only when using IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-fec_vc_ip_range_addr_inner_step
			x		The value to be added for creating each additional L2 VC IP route range. This is the incrementing step when fec_vc_ip_range_addr_count is greater than 1. This parameter is used for incrementing between multiple hosts for the same VC IP range. Valid only when -mode is create or modify and -fec_vc_type is eth_vpls and fec_type is vc. Valid only when using IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-fec_vc_ip_range_addr_outer_step
			x		The value to be added for creating each additional L2 VC IP route range. This is the incrementing step when fec_vc_count is greater than 1. This parameter is used for incrementing between the start address for different VC IP ranges. Valid only when -mode is create or modify and -fec_vc_type is eth_vpls and fec_type is vc. Valid only when using IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-fec_vc_ip_range_enable
			x		If checked, this L2 VC IP range will be enabled.Valid only when -mode is create or modify and -fec_vc_type is eth_vpls and fec_type is vc. Valid only when using IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-fec_vc_ip_range_prefix_len
			x		The number of bits in the mask applied to the network address. The masked bits in the First Network address form the address prefix. Valid only when -mode is create or modify and -fec_vc_type is eth_vpls and fec_type is vc. Valid only when using IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-fec_vc_label_mode
			x		Valid only when -mode is create or modify and fec_type is vc. Choose one of:fixed_label - use the same label value for all packets.increment_label - use incrementing label values for consecutive packets. The increment step is 1.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-fec_vc_label_value_start
			x		The first label in the range of labels.
			x		Valid when fec_type is vc.
			x	-fec_vc_label_value_step
			x		The incrementing step for the fec_vc_label_value_start.
			x		Valid when fec_type is vc and fec_vc_count is greater than 1.
			x		Valid only when using IxTclNetwork.
			x	-fec_vc_mac_range_count
			x		If fec_vc_mac_range_vlan_enable is 1, this it the number of MAC
			x		address/VLAN combinations that will be created. If
			x		fec_vc_mac_range_vlan_enable is 0, this is the number of MAC addresses
			x		that will be created.
			x		Valid only when -mode is create or modify and -fec_vc_type is eth or
			x		eth_vlan and fec_type is vc.
			x		Valid only when using IxTclNetwork.
			x	-fec_vc_mac_range_enable
			x		If checked, the MAC range corresponding to the layer2 VC range
			x		will be enabled.
			x		Valid only when -mode is create or modify and -fec_vc_type is eth or
			x		eth_vlan and fec_type is vc.
			x		Valid only when using IxTclNetwork.
			x	-fec_vc_mac_range_first_vlan_id
			x		The VLAN ID for the first VLAN in the MAC/VLAN range.
			x		Valid only when -mode is create or modify and -fec_vc_type is eth or
			x		eth_vlan and fec_type is vc.
			x		Valid only when using IxTclNetwork.
			x	-fec_vc_mac_range_repeat_mac
			x		If checked, and the fec_vc_mac_range_count is greater than 1, the same address value will be repeated for all MAC addresses. If unchecked, and the fec_vc_mac_range_count is greater than 1, the address values will be incremented across the MAC addresses. Valid only when -mode is create or modify and -fec_vc_type is eth or eth_vlan and fec_type is vc. Valid only when using IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-fec_vc_mac_range_same_vlan
			x		If checked, all MAC addresses in the range will be associated with the same VLAN ID. If unchecked, all MAC addresses in the range will be associated with different VLAN IDs, where the VLAN IDs will be automatically incremented. Valid only when -mode is create or modify and -fec_vc_type is eth or eth_vlan and fec_type is vc. Valid only when using IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-fec_vc_mac_range_start
			x		The first MAC address in the MAC range.
			x		Valid only when -mode is create or modify and -fec_vc_type is eth or
			x		eth_vlan and fec_type is vc.
			x		Valid only when using IxTclNetwork.
			x	-fec_vc_mac_range_vlan_enable
			x		If checked, MAC/VLAN range will be enabled. Valid only when -mode is create or modify and -fec_vc_type is eth or eth_vlan and fec_type is vc. Valid only when using IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-fec_vc_peer_address
			x		The 32-bit IP address of the LDP Peer.
			x		Valid only when -mode is create or modify and fec_type is vc.
			 	-fec_vc_type
			 		The 15-bit VC Type used in the VC FEC element. It depends on the Layer
			 		2 protocol used on the interface. Valid when fec_type is vc.
			 		Valid choices are:
			 		atm_aal5_vcc - ATM AAL5 VCC transport (VC Type 0x0002)
			 		atm_cell - ATM Transparent cell transport (VC Type 0x0003)
			 		atm_vcc_1_1 - ATM VCC cell transport (VC Type 0x0009)
			 		atm_vcc_n_1 - ATM VCC cell transport (VC Type 0x0009)
			 		atm_vpc_1_1 - ATM VPC cell transport (VC Type 0x000A)
			 		atm_vpc_n_1 - ATM VPC cell transport (VC Type 0x000A)
			 		cem - Circuit Emulation Service over MPLS (CEM), for encapsulation of TDM signal (VC Type 0x8008)
			 		eth - untagged Ethernet frames (VC Type 0x0005)
			 		eth_vlan - VLAN-tagged Ethernet frames (VC Type 0x0004)
			 		eth_vpls - Internet Protocol packets (VC Type 0x000B)
			 		fr_dlci - Frame Relay DLCI (VC Type 0x0001)
			 		hdlc - HDLC frames (VC Type 0x0006)
			 		ppp - Point-to-Point Protocol frames (VC Type 0x0007)
			 		satop_e1 - Satop-E1
			 		satop_e3 - Satop-E3
			 		satop_t1 - Satop-T1
			 		satop_t3 - Satop-T3
			 		cesopsn_basic - CESoPSN-Basic
			 		cesopsn_cas - CESoPSN-CAS
			 		fr_dlci_rfc4619 - RFC 4619 Frame Relay DLCI (VC Type 0x0019)
			 		Valid choices are:
			    		atm_aal5_vcc - ATM AAL5 VCC transport (VC Type 0x0002).
			    		atm_cell - ATM Transparent cell transport (VC Type 0x0003).
			    		atm_vcc_1_1 - ATM VCC cell transport (VC Type 0x0009).
			    		atm_vcc_n_1 - ATM VCC cell transport (VC Type 0x0009).
			    		atm_vpc_1_1 - ATM VPC cell transport (VC Type 0x000A).
			    		atm_vpc_n_1 - ATM VPC cell transport (VC Type 0x000A).
			    		cem - Circuit Emulation Service over MPLS (CEM), for encapsulation of TDM signal (VC Type 0x8008).
			    		eth - Untagged Ethernet frames (VC Type 0x0005).
			    		eth_vlan - VLAN-tagged Ethernet frames (VC Type 0x0004).
			    		eth_vpls - Internet Protocol packets (VC Type 0x000B).
			    		fr_dlci - Frame Relay DLCI (VC Type 0x0001).
			    		hdlc - HDLC frames (VC Type 0x0006).
			    		ppp - Point-to-Point Protocol frames (VC Type 0x0007).
			    		satop_e1 - Satop-E1
			    		satop_e3 - Satop-E3
			    		satop_t1 - Satop-T1
			    		satop_t3 - Satop-T3
			    		cesopsn_basic - CESoPSN-Basic
			    		cesopsn_cas - CESoPSN-CAS
			    		fr_dlci_rfc4619 - RFC 4619 Frame Relay DLCI (VC Type 0x0019).
			 	-hop_count_tlv_enable
			 		If checked, the setup messages used to create an LSP will contain a Hop Count TLV. This TLV tracks the number of LSP hops during the LSP setup process. This TLV is optional except in the case of ATM links, which require this TLV.Valid for fec_type host_addr.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-hop_count_value
			 		The number of hops along the path of the LSP.Valid for fec_type host_addr.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-label_msg_type
			 		This argument is kept only for backwards compatibility when using the 5.30 IxTclNetwork API. To specify the FEC type to be created, use the fec_type option.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-label_value_start
			x		The first label in the range of labels.
			x		Valid when fec_type is ipv4_prefix.
			x	-label_value_start_step
			x		Specifies the step increment for Label Value start.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-lsp_handle
			 		This option specifies on which lsp element to configure the
			 		lsp pools/fec range options. The user must pass in this option
			 		if the "type" is modify or delete.lsp_handle is returned by
			 		this procedure when "type" is create.
			x	-next_hop_peer_ip
			x		The IPv4 address of the LDP Peer that is the next hop router on this path. (0.0.0.0 indicates that requests will be sent to all of this router's peers that are in Downstream on Demand mode.)Valid for fec_type host_addr.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-num_lsps
			 		The number of network addresses to be included in the range. The
			 		maximum number of valid possible addresses depends on the values for
			 		the first network and the network mask.
			 		Valid for fec_type ipv4_prefix.
			x	-num_routes
			x		The number of routes in the Requested FEC Range. Valid when fec_type is host_addr.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-packing_enable
			x		For L2 VC FEC ranges and in Unsolicited Label Distribution Mode ONLY.
			x		If checked, L2 VC FEC ranges will be aggregated within a single LDP
			x		PDU to conserve bandwidth and processing.
			x	-provisioning_model
			x		This option denotes the Provisioning Model.
			x		Valid choices are:
			x		bgp_auto_discovery - bgp Auto Discovery
			x		manual_configuration - manual configuration
			x		(DEFAULT=bgp_auto_discovery)
			x		Valid choices are:
			x   		bgp_auto_discovery - Bgp Auto Discovery Provisioning Model.
			x   		manual_configuration - Manual configuration Provisioning Model.
			x	-stale_timer_enable
			x		If checked, the Stale Request Timer is enabled.Valid when fec_type is host_addr.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-stale_request_time
			x		The Stale Request Timer value. When the Ixia-emulated LDP peer sends Label Request messages to the DUT, this timer is set. If no response is received from the DUT within the specified time, the Ixia peer considers the requests timed out and "Stale", and deletes the records of the previously sent messages.Valid when fec_type is host_addr.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-no_write
			x	-auto_peer_id
			x   		Enable PW Status
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_pw_status_enable
			x   		Enable or Disable PW Status
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_pw_status_code
			x   		PW Status Code to be sent when to transition to down state if PW Status Send Notification is enabled
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		clear_fault_code - 0x00000000 - Pseudowire forwarding (clear all failures).
			x       		pw_not_forwarding_code - 0x00000001 - Pseudowire Not Forwarding.
			x       		ac_rx_fault_code - 0x00000002 - Local Attachment Circuit (ingress) Receive Fault.
			x       		ac_tx_fault_code - 0x00000004 - Local Attachment Circuit (egress) Transmit Fault.
			x       		pw_rx_fault_code - 0x00000008 - Local PSN-facing PW (ingress) Receive Fault.
			x       		pw_tx_fault_code - 0x00000010 - Local PSN-facing PW (egress) Transmit Fault.
			x	-fec_vc_pw_status_send_notification
			x   		Enable or Disable "PW Status Send Notification". If selected, this enables the use of PW Status TLV in notification messages to notify the PW status
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_down_start
			x   		The duration in time after session becomes up and a notification message being sent to make the session down
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_down_interval
			x   		Time interval for which the PW status will remain down
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_up_interval
			x   		Time Interval for which the PW status will remain in Up state before transitioning again to Down state.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_repeat_count
			x   		The number of times to repeat the Up/Down status of the PW. '0' means keep toggling the Up/Down state indefinitely.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_type_vpls_id
			x   		The VPLS Id format
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		id_as_number - The id will ba AS Number.
			x       		id_ip_address - The id will be IP Address.
			x	-fec_vc_ip_address_vpls_id
			x   		VPLS ID IP Address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_as_number_vpls_id
			x   		VPLS ID AS Number
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_assigned_number_vpls_id
			x   		VPLS ID Assigned Number
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_source_aii_type
			x   		Source AII Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		as_ip - Specifies the source type as ip address.
			x       		number - Specifies the source type as number.
			x	-fec_vc_source_aii_as_ip
			x   		Source AII as IP
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_source_aii_as_number
			x   		Source AII as Number
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_target_aii_type
			x   		Target AII Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		as_ip - Specifies the target type as ip address.
			x       		number - Specifies the target type as number.
			x	-fec_vc_target_aii_as_ip
			x   		Target AII as IP
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_target_aii_as_number
			x   		Target AII as Number
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_include_tdm_payload
			x   		If selected, indicates that TDM Payload is present
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_tdm_data_size
			x   		The total size of the TDM data
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_include_tdm_bitrate
			x   		If selected, indicates that TDM Bitrate is present
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_tdm_bitrate
			x   		The value of the TDM Bitrate
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_include_rtp_header
			x   		If selected, indicates that RTP Header is present
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_include_tdm_option
			x   		Include TDM Option
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_timestamp_mode
			x   		Timestamp Mode
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		absolute - Provide timestamp as an absolute value.
			x       		differential - Provide timestamp as a differential value.
			x	-fec_vc_payload_type
			x   		Configures the Pay Load Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_frequency
			x   		Configures the frequency of the payload type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_include_ssrc
			x   		Enable or Disable "Include SSRC"
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_ssrc
			x   		SSRC
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_cas
			x   		TDS Timestamp Mode
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		e1_trunk -
			x       		t1_esf_trunk -
			x       		t1_sf_trunk -
			x	-fec_vc_sp
			x   		SP
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		hexval1 -
			x       		hexval2 -
			x       		hexval3 -
			x       		hexval4 -
			x	-fec_vc_enable_cccv_negotiation
			x   		Enable or Disable CCCV Negotiation
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_pw_ach_cc
			x   		PW-ACH CC
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_router_alert_cc
			x   		Router Alert CC
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_lsp_ping_cv
			x   		LSP Ping CV
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_bfd_udp_cv
			x   		BFD IP/UDP CV
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_vc_bfd_pw_cv
			x   		BFD PW-ACH CV
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_active
			x   		Enable/Activate the FEC Property Range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fec_name
			x   		Valid Name for the FEC Property Range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-topology_config_active
			x   		This is to activate the ldp Simulated Topology Config object of the NetworkTopology in Network Group.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-topology_router_active
			x   		This attribute activates the pseudo Ldp router of network Topology.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-topology_router_label_value
			x   		This attribute set the Label Value of the LDP Topology Router of Network Toplogy
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-topology_router_id
			x   		The router id of the LDP Topology router of Network topology.4 Byte Router Id in dotted decimal format.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-grid_col
			    		Defines number of columns in a grid.
			    		This option is valid only when -type is grid, otherwise it
			    		is ignored. This option is available with IxTclNetwork and IxTclProtocol API.
			    		(DEFAULT = 2)
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-grid_row
			    		Defines number of rows in a grid.
			    		This option is valid only when -type is grid, otherwise it
			    		is ignored.
			    		This option is available with IxTclNetwork and IxTclProtocol API.
			    		(DEFAULT = 2)
			    		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-grid_include_emulated_device
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-grid_link_multiplier
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-mesh_number_of_nodes
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-mesh_include_emulated_device
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-mesh_link_multiplier
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ring_number_of_nodes
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ring_include_emulated_device
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ring_link_multiplier
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-hub_spoke_number_of_first_level
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-hub_spoke_number_of_second_level
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-hub_spoke_enable_level_2
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-hub_spoke_link_multiplier
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-tree_number_of_nodes
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-tree_include_emulated_device
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-tree_use_tree_depth
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-tree_depth
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-tree_max_children_per_node
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-tree_link_multiplier
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-custom_link_multiplier
			x   		number of links between two nodes
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-custom_from_node_index
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-custom_to_node_index
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fat_tree_link_multiplier
			x   		number of links between two nodes
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fat_tree_level_count
			x   		Number of Levels
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fat_tree_node_count
			x   		Number of Nodes Per Level
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-linear_nodes
			x   		number of nodes
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-linear_link_multiplier
			x   		number of links between two nodes
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-external_link_router_source
			x   		Index of the originating node as defined in fromNetworkTopology
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-external_link_router_destination
			x   		Index of the target node as defined in toNetworkTopology
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-external_link_network_group_handle
			x   		Network Topology this link is pointing to
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-connected_to_handle
			x   		Scenario element this connector is connecting to
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			n	-fec_host_step
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-path_vector_tlv
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-path_vector_tlv_lsr
			x   	-name
			x       		Name of NGPF element, guaranteed to be unique in Scenario
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		   A list containing the network group protocol stack handles that were added by the command (if any).
			x   key:network_group_handle      value:A list containing the network group protocol stack handles that were added by the command (if any).
		   A list containing the fecproperty protocol stack handles that were added by the command (if any).
			x   key:fecproperty_handle        value:A list containing the fecproperty protocol stack handles that were added by the command (if any).
		   A list containing the ipv6 fecproperty protocol stack handles that were added by the command (if any).
			x   key:ipv6_fecproperty_handle   value:A list containing the ipv6 fecproperty protocol stack handles that were added by the command (if any).
		   A list containing the ldppwvpls protocol stack handles that were added by the command (if any).
			x   key:ldppwvpls_handle          value:A list containing the ldppwvpls protocol stack handles that were added by the command (if any).
		   A list containing the ldpotherpws protocol stack handles that were added by the command (if any).
			x   key:ldpotherpws_handle        value:A list containing the ldpotherpws protocol stack handles that were added by the command (if any).
		   A list containing the ldpvplsbgpad protocol stack handles that were added by the command (if any).
			x   key:ldpvplsbgpad_handle       value:A list containing the ldpvplsbgpad protocol stack handles that were added by the command (if any).
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:fecproperty_handles       value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:ipv6_fecproperty_handles  value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:ldppwvpls_handles         value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:ldpotherpws_handles       value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:ldpvplsbgpad_handles      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   $::SUCCESS | $::FAILURE
			    key:status                    value:$::SUCCESS | $::FAILURE
		   LDP lsp pool handle
			    key:lsp_handle                value:LDP lsp pool handle
		   If status is failure, detailed information provided.
			    key:log                       value:If status is failure, detailed information provided.
		   The LDP router L2Interface
			    key:lsp_intf                  value: The LDP router L2Interface
		   The LDP router L2Interface
			    key:lsp_handle                value: The LDP router L2Interface
		   List of LDP router L2Interface VcRanges
			    key:lsp_vc_range_handles      value: List of LDP router L2Interface VcRanges
		   List of LDP router interface VcRange IpRanges
			    key:lsp_vc_ip_range_handles   value: List of LDP router interface VcRange IpRanges 
		   List of LDP router interface VcRange MacRanges
			    key:lsp_vc_mac_range_handles  value: List of LDP router interface VcRange MacRanges     
		
		Examples:
		   See files starting with LDP_ in the Samples subdirectory.  Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the LDP usage.
		   See the LDP example in Appendix A, "Example APIs," for one specific example usage.
		   See files starting with LDP_ in the Samples subdirectory.  Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the LDP usage.
		   See the LDP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		   Coded versus functional specification.
		   If fec_type option is ipv4_prefix, the label_msg_type option must be
		   mapping; if fec_type option is host_addr, the the label_msg_type option
		   must be request.
		   For "modify" mode, the fec_type option and label_msg_type option will not
		   be updated for the lsp.
		   When using the new IxTclNetwork API 5.30, the label_msg_type option
		   is silently ignored. Only the fec_type option is used. If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  fecproperty_handles, ipv6_fecproperty_handles, ldppwvpls_handles, ldpotherpws_handles, ldpvplsbgpad_handles
		   Coded versus functional specification.
		   If fec_type option is ipv4_prefix, the label_msg_type option must be mapping; if fec_type option is host_addr, the the label_msg_type option must be request.
		   For "modify" mode, the fec_type option and label_msg_type option will not be updated for the lsp.
		   When using the new IxTclNetwork API 5.30, the label_msg_type option is silently ignored. Only the fec_type option is used.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_ldp_route_config", kwargs)

	def emulation_mld_config(self, **kwargs):
		""" Configures MLD sessions.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_mld_config
			 	-mode                                  CHOICES create
			                                        CHOICES modify
			                                        CHOICES delete
			                                        CHOICES disable
			                                        CHOICES enable
			                                        CHOICES enable_all
			                                        CHOICES disable_all
			x	[-atm_encapsulation                    ANY]
			x	[-count                                RANGE 1-4000
			x                                       DEFAULT 1]
			x	[-enable_packing                       ANY]
			 	[-filter_mode                          CHOICES include exclude
			                                        DEFAULT include]
			 	[-general_query                        CHOICES 0 1
			                                        DEFAULT 1]
			 	[-group_query                          CHOICES 0 1
			                                        DEFAULT 1]
			 	[-handle                               ANY]
			x	[-interface_handle                     ANY]
			x	[-return_detailed_handles              CHOICES 0 1
			x                                       DEFAULT 0]
			x	[-active                               CHOICES 0 1]
			x	[-active_flag                          CHOICES 0 1
			x                                       DEFAULT 0]
			 	[-intf_ip_addr                         IPV6]
			 	[-intf_ip_addr_step                    IPV6
			                                        DEFAULT 0::1]
			 	[-intf_prefix_len                      RANGE 1-128
			                                        DEFAULT 64]
			 	[-ip_router_alert                      CHOICES 0 1
			                                        DEFAULT 1]
			x	[-mac_address_init                     MAC
			x                                       DEFAULT 0011.0100.0001]
			x	[-mac_address_step                     MAC
			x                                       DEFAULT 0000.0000.0001]
			 	[-max_groups_per_pkts                  ANY]
			 	[-max_response_control                 CHOICES 0 1
			                                        DEFAULT 0]
			 	[-max_response_time                    RANGE 0-999999]
			 	[-max_sources_per_group                ANY]
			x	[-mldv2_report_type                    ANY]
			 	[-mld_version                          CHOICES v1 v2
			                                        DEFAULT v2]
			 	[-msg_count_per_interval               NUMERIC
			                                        DEFAULT 0]
			 	[-msg_interval                         NUMERIC
			                                        DEFAULT 0]
			 	[-neighbor_intf_ip_addr                IPV6
			                                        DEFAULT 0::0]
			 	[-neighbor_intf_ip_addr_step           IPV6
			                                        DEFAULT 0::0]
			x	[-no_write                             ANY]
			x	[-override_existence_check             CHOICES 0 1
			x                                       DEFAULT 0]
			x	[-override_tracking                    CHOICES 0 1
			x                                       DEFAULT 0]
			 	[-port_handle                          REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-reset                                FLAG]
			n	[-robustness                           ANY]
			 	[-suppress_report                      ANY]
			 	[-unsolicited_report_interval          NUMERIC
			                                        DEFAULT 120]
			x	[-vci                                  ANY]
			x	[-vci_step                             ANY]
			x	[-vlan                                 CHOICES 0 1
			x                                       CHOICES 0 1
			x                                       DEFAULT 0]
			n	[-vlan_cfi                             ANY]
			 	[-vlan_id                              REGEXP ^[0-9]{1,4}(,[0-9]{1,4}){0,5}$
			                                        RANGE 0-4095]
			 	[-vlan_id_mode                         CHOICES fixed increment
			                                        DEFAULT increment]
			 	[-vlan_id_step                         REGEXP ^[0-9]{1,4}(,[0-9]{1,4}){0,5}$
			                                        RANGE 0-4095
			                                        DEFAULT 1]
			 	[-vlan_user_priority                   RANGE 0-7
			                                        REGEXP ^[0-7](,[0-7]){0,5}$
			                                        DEFAULT 0]
			x	[-vpi                                  ANY]
			x	[-vpi_step                             ANY]
			x	[-name                                 ALPHA]
			x	[-unsolicited_response_mode            ANY
			x                                       DEFAULT 0]
			x	[-join_leave_multiplier                NUMERIC
			x                                       DEFAULT 1]
			x	[-enable_iptv                          CHOICES 0 1]
			x	[-iptv_name                            ALPHA]
			x	[-stb_leave_join_delay                 NUMERIC]
			x	[-join_latency_threshold               NUMERIC]
			x	[-leave_latency_threshold              NUMERIC]
			x	[-zap_behavior                         CHOICES zaponly zapandview onetime]
			x	[-zap_direction                        CHOICES up down random]
			x	[-zap_interval                         NUMERIC]
			x	[-num_channel_changes_before_view      NUMERIC]
			x	[-view_duration                        ANY]
			x	[-global_settings_enable               CHOICES 0 1]
			x	[-no_of_reports_per_second             ANY]
			x	[-interval_in_ms                       NUMERIC]
			x	[-inter_stb_start_delay                NUMERIC
			x                                       DEFAULT 0]
			x	[-zap_interval_type                    CHOICES leavetoleave multicasttoleave]
			x	[-log_failure_timestamps               CHOICES 0 1]
			x	[-enable_general_query_response        ANY]
			x	[-enable_group_specific_query_response ANY]
			x	[-combined_leave_join                  CHOICES 0 1]
		
		Arguments:
			 	-mode
			 		This option defines the action to be taken.
			 		Valid choices are:
			    		create - Creates an MLD session,requires the use of -handle.
			    		modify - Modifies an MLD session, requires the use of -handle.
			    		delete - Deletes an MLD session, requires the use of -handle.
			    		disable - Disables an MLD session, requires the use of -handle.
			    		enable - Enables an MLD session, requires the use of -handle.
			    		enable_all - Enables all MLD sessions on port,requires the use of -handle.
			    		disable_all - Disables all MLD sessions on port,requires the use of -handle.
			x	-atm_encapsulation
			x		The encapsulation of the ATM protocol interface associated with the emulated router. Valid only for IxTclNetwork API.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-count
			x		Number of sessions to create on the interface.
			x	-enable_packing
			x		If checked, multiple Sources can be included in each Record, and multiple Records can be included in each Frame, for more efficient transmission. This option is available only for MLDv2.This option is valid only for IxTclNetwork API.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-filter_mode
			 		Configure MLDv2 Include Filter Mode.
			 		Valid choices are:
			    		include - The specified source(s) is (are) of interest
			    		exclude - The specified source(s) is (are) not of interest
			 	-general_query
			 		If 1, respond to general queries received on the interface.
			 	-group_query
			 		If 1, respond to group specific queries received on the interface.
			 	-handle
			 		This parameter is mandatory for all modes, when using NGPF (it specifies the stack on which to add the mld host).
			 		For NGPF Backwards Compatibility for legacy HLT syntax support, if -mode is create, delete, modify, enable or disable this option is required
			 		to specify the existing MLD session.
			x	-interface_handle
			x		This parameter is used only for NGPF Backwards Compatibility for legacy HLT sytax (only when -port_handle is given).
			x		A handle or list of the handles that are returned from the interface_config call. These provide a direct link to an already existing interface and supercede the use of the intf_ip_addr value.
			x		Starting with IxNetwork 5.50 this parameter accepts handles returned by pppox_config procedure in the following format: |,-, ... The PPPoX ranges are separated from the Interface Index identifiers with the (|) character. The Interface Index identifiers are separated with comas (,). A range of Interface Index identifiers can be defined using the dash (-) character.
			x		Ranges along with the Interface Index identifiers are grouped together in TCL Lists. The lists can contain mixed items, protocol interface handles returned by interface_config and handles returned by pppox_config along with the interface index. 
			x		Example:count 10 (10 MLD routers). 3 pppox range handles returned by ::::pppox_config. Each pppox range has 20 sessions (interfaces). If we pass -interface_handle in the following format: [list $pppox_r1|1,5 $pppox_r2|1-3 $pppox_r3|1,3,5-9,13] The interfaces will be distributed to the routers in the following manner:
			x		
			x		
			x		- MLD Router 1: $pppox_r1 -> interface 1
			x		- MLD Router 2: $pppox_r1 -> interface 5
			x		- MLD Router 3: $pppox_r2 -> interface 1
			x		- MLD Router 4: $pppox_r2 -> interface 2
			x		- MLD Router 5: $pppox_r2 -> interface 3
			x		- MLD Router 6: $pppox_r3 -> interface 1
			x		- MLD Router 7: $pppox_r3 -> interface 3
			x		- MLD Router 8: $pppox_r3 -> interface 5
			x		- MLD Router 9: $pppox_r3 -> interface 6
			x		- MLD Router 10: $pppox_r3 -> interface 7
			x		- MLD Router 11: $pppox_r3 -> interface 8
			x		- MLD Router 12: $pppox_r3 -> interface 9
			x		- MLD Router 13: $pppox_r3 -> interface 1
			x		- 3Valid for mode create
			x		
			x		
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-active
			x		Enable/disable mld host
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-active_flag
			x		This argument is used for Enable/Disable the mld host item with it's corresponding item handle.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-intf_ip_addr
			 		IP address of the test interface / emulated mld Host.
			 	-intf_ip_addr_step
			 		Used to increment IP address.
			 	-intf_prefix_len
			 		Address prefix length.
			 	-ip_router_alert
			 		If 1, enable IP Router Alert Option.
			x	-mac_address_init
			x		MAC address to be set on the interface.
			x	-mac_address_step
			x		The incrementing step for the MAC address to be set on the interface.
			x		This option is valid only when IxTclNetwork API is used.
			 	-max_groups_per_pkts
			 		The maximum number of group records that can go into one MLDv2 membership report packet. If the number of groups to be advertised exceeds this number, then the groups are split up into multiple membership report packets. If set to 0, groups are packed into Membership Report packets until the MTU size is reached.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-max_response_control
			 		If 1, use -max_response_time to overwrite the value obtained from
			 		the received Query message.
			 	-max_response_time
			 		Set the maximum response time (in 1/10 seconds) on receipt of a query.
			 		If set to 0, immediately respond to received Query message.
			 	-max_sources_per_group
			 		The maximum number of sources that can go into one MLDv2 membership group record. Valid only with IxTclNetwork API.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-mldv2_report_type
			x		The type of MLD report. This parameter is valid only for IxTclNetwork API.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		143 - as per RFC 3810
			x   		206 - custom defined
			 	-mld_version
			 		Indicates the MLD protocol version to be used.
			 		Valid choices are:
			    		v1 - MLD v1
			    		v2 - MLD v2
			 	-msg_count_per_interval
			 		The number of multicast MLD groups to be advertised during each time period.
			 		A value of 0 disables this feature and transmits all groups
			 		immediately for all updates. Valid only with IxTclNetwork API.
			 		Used for MLDv2 only.
			 	-msg_interval
			 		The interval (in ms) used for throttling updates. Use the value 0 to
			 		send messages as fast as possible.
			 	-neighbor_intf_ip_addr
			 		Neighbor's interface IP address.
			 	-neighbor_intf_ip_addr_step
			 		Neighbor's interface IP address increment step for creating multiple
			 		sessions. Default is 0, i.e. same IP address for all sessions.
			x	-no_write
			x	-override_existence_check
			x   		If this option is enabled, the interface existence check is skipped but
			x   		the list of interfaces is still created and maintained in order to keep
			x   		track of existing interfaces if required. Using this option will speed
			x   		up the interfaces' creation. Valid only for IxTclNetwork API.
			x	-override_tracking
			x   		If this option is enabled, the list of interfaces wont be created and
			x   		maintained anymore, thus, speeding up the interfaces' creation even
			x   		more. Also, it will enable -override_existence_check in case it wasnt
			x   		already enabled because checking for interface existence becomes
			x   		impossible if the the list of interfaces doesnt exist anymore.
			x   		Valid only for IxTclNetwork API.
			 	-port_handle
			    		This option is required to specify the port where to take the action.
			x	-reset
			x   		Resets the MLD Host configuration on port.
			n	-robustness
			n   		The number of times to send a State Change Report. MLDv2 only.
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-suppress_report
			    		If 1, suppress the transmission of a listener report that duplicates one received on the interface.
			    		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-unsolicited_report_interval
			    		The interval (in seconds) to wait before re-sending the host's
			    		initial report of membership in a group. If 0, do not send unsolicited
			    		report.
			x	-vci
			x   		VCI for emulated router node. Valid only for IxTclNetwork API.
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vci_step
			x   		The step value used for incrementing the -vci option. When vci_step causes the vci value to exceed it's maximum value the increment will be done modulo number of possible vci ids. Valid only for IxTclNetwork API. Examples: 
			x   		
			x   		
			x   		-  vci = 65534; vci_step = 2-> new vci value = 0
			x   		-  vci = 65535; vci_step = 11 -> new vci value = 10
			x   		
			x   		
			x   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vlan
			x   		Enables vlan on the directly connected MLD router interface.
			x   		Valid options are: 0 (disable) / 1 (enable).
			x   		This option is valid only when -mode is create or -mode is modify
			x   		and -handle is a MLD router handle.
			x   		This option is available only when IxNetwork tcl API is used.
			x   		Valid choices are:
			x       		0 - Disables the vlan configuration
			x       		1 - Enables the vlan configuration
			n	-vlan_cfi
			    	-vlan_id
			        		VLAN ID for emulated router node.
			    	-vlan_id_mode
			        		For multiple neighbor configuration, configures the VLAN ID mode to
			        		be fixed or increment.
			        		Valid choices are:
			            		fixed - Same vlan id across interfaces
			            		increment - Increment vlan ids across interfaces
			    	-vlan_id_step
			        		When -vlan_id_mode isset to increment, this defines the step for
			        		every VLAN.
			        		When vlan_id_step causes the vlan_id value to exceed it's maximum value the
			        		increment will be done modulo number of possible vlan ids. Examples:
			        		
			        		
			        		- vlan_id = 4094; vlan_id_step = 2;-> new vlan_id value = 0
			        		- vlan_id = 4095; vlan_id_step = 11; -> new vlan_id value = 10
			        		
			        		
			    	-vlan_user_priority
			        		VLAN user priority assigned to emulated router node.
			x   	-vpi
			x       		VPI for emulated router node. Valid only for IxTclNetwork API.
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-vpi_step
			x       		The step value used for incrementing the -vpi option. When vpi_step causes the vpi value to exceed it's maximum value the increment will bedone modulo number of possible vpi ids. Valid only for IxTclNetwork API. Examples:
			x       		
			x       		
			x       		- vpi = 254; vpi_step = 2-> new vpi value = 0
			x       		- vpi = 255; vpi_step = 11 -> new vpi value = 10
			x       		
			x       		
			x       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x   	-name
			x       		The name of the protocol stack.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-unsolicited_response_mode
			x       		Unsolicited Response Mode.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-join_leave_multiplier
			x       		No. of Join/Leave messages to send per operation
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_iptv
			x       		Enable IPTV
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-iptv_name
			x       		Name of NGPF element, guaranteed to be unique in Scenario
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-stb_leave_join_delay
			x       		Time in milliseconds between sending a Leave for the current channel and Join for the next channel.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-join_latency_threshold
			x       		The maximum time that is allowed for a multicast stream to arrive for channel for which a Join has been sent.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-leave_latency_threshold
			x       		The maximum time allowed for a multicast stream to stop for a channel for which a Leave has been sent.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-zap_behavior
			x       		Use Zap Only to change channels without viewing the channel or Zap and View to change traffic and receive traffic for the last channel.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		zaponly - Enables channel change without viewing the channel
			x           		zapandview - Change and receive traffic for the last channel
			x           		onetime - Enabled a single channel change
			x   	-zap_direction
			x       		Specifies the direction of changing channels.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		up - Switching is done starting from the first multicast group to the last one in ascending order.
			x           		down - Switching is done starting from the first multicast group, then in descending order from the last group.
			x           		random - Switching between multicast groups is done randomly.
			x   	-zap_interval
			x       		Interval in milliseconds between channel changes based on the selected type.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-num_channel_changes_before_view
			x       		Number of channels to change before stopping on a channel and watching it for View Duration.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-view_duration
			x       		Specifies the time in milliseconds to view the last channel.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-global_settings_enable
			x       		Enable Global Settings for MLD protocol.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-no_of_reports_per_second
			x       		No. of Reports per Second
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-interval_in_ms
			x       		Time interval used to calculate the rate for triggering an action (rate = count/interval)
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-inter_stb_start_delay
			x       		Time in milliseconds between Join messages from clients within the same range.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-zap_interval_type
			x       		Specifies the wait interval type before changing the channels.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		Valid choices are:
			x           		leavetoleave - The interval is considered from sending the Join message to sending the Leave message for a multicast group.
			x           		multicasttoleave - The interval is considered from the time the multicast traffic for a group is received until the Leave message is sent for that group.
			x   	-log_failure_timestamps
			x       		If enabled, the timestamps for Join and Leave failures are saved to a log file.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_general_query_response
			x       		If enabled, General Query Response is send.
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-enable_group_specific_query_response
			x       		If enabled, Group Specific Response is sent
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   	-combined_leave_join
			x       		If enabled, Leave for current group and join for next group gets merged in a single multicast packet
			x       		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		   A list containing the mld host protocol stack handles that were added by the command (if any).
			x   key:mld_host_handle       value:A list containing the mld host protocol stack handles that were added by the command (if any).
		   A list containing the ethernet protocol stack handles that were added by the command (if any).
			x   key:ethernet_handle       value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		   A list containing the ipv6 protocol stack handles that were added by the command (if any).
			x   key:ipv6_handle           value:A list containing the ipv6 protocol stack handles that were added by the command (if any).
		   A list containing the dhcpv6 client protocol stack handles that were added by the command (if any).
			x   key:dhcpv6_client_handle  value:A list containing the dhcpv6 client protocol stack handles that were added by the command (if any).
		   A list containing the pppox client protocol stack handles that were added by the command (if any).
			x   key:pppox_client_handle   value:A list containing the pppox client protocol stack handles that were added by the command (if any).
		   A list containing the pppox server protocol stack handles that were added by the command (if any).
			x   key:pppox_server_handle   value:A list containing the pppox server protocol stack handles that were added by the command (if any).
		   A list containing the mld host iptv protocol stack handles that were added by the command (if any).
			x   key:mld_host_iptv_handle  value:A list containing the mld host iptv protocol stack handles that were added by the command (if any).
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:interface_handle      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x   key:mld_iptv_handles      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   $::SUCCESS | $::FAILURE
			    key:status                value:$::SUCCESS | $::FAILURE
		   If status is failure, contains more information
			    key:log                   value:If status is failure, contains more information
		   List of session handles Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			    key:handle                value:List of session handles Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		   List of session handles
			    key:handle                value:List of session handles
		
		Examples:
		   See files starting with MLD_ in the Samples subdirectory.See the MLD example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		   1) MLD implementation using IxTclNetwork is NOT SUPPORTED in HLTAPI 3.30. If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle, interface_handle, mld_iptv_handles
		   1) MLD implementation using IxTclNetwork is NOT SUPPORTED in HLTAPI 3.30.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_mld_config", kwargs)

	def emulation_mld_control(self, **kwargs):
		""" Controls MLD sessions.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_mld_control
			 	-mode                   CHOICES start
			                         CHOICES stop
			                         CHOICES restart
			                         CHOICES join
			                         CHOICES leave
			                         CHOICES rejoin
			                         CHOICES releave
			                         CHOICES mld_send_specific_query
			                         CHOICES mld_resume_periodic_gen_query
			                         CHOICES mld_stop_periodic_gen_query
			 	[-handle                ANY]
			 	[-port_handle           REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-group_member_handle   ANY]
			 	[-source_member_handle  ANY]
			x	[-start_group_address   IPV6
			x                        DEFAULT ff03:0:0:0:0:0:0:1]
			x	[-group_count           NUMERIC
			x                        DEFAULT 1]
			x	[-start_source_address  IPV6
			x                        DEFAULT aaaa:0:0:0:0:0:0:0]
			x	[-source_count          NUMERIC
			x                        DEFAULT 0]
			x	[-source_increment_step NUMERIC
			x                        DEFAULT 1]
		
		Arguments:
			 	-mode
			 		This option defines the action to be taken.
			 		Valid choices are:
			    		start - Starts the MLD host,requires the use of -handle.
			    		stop - Stops the MLD host,requires the use of -handle.
			    		restart - Restarts the MLD host,requires the use of -handle.
			    		join - If -group_member_handle is provided join specified
group pool(s).
If -handle is provided, enable all groups on this session.
If -port_handle is provided, enable all groups
on all sessions for that port.
			    		leave - If -group_member_handle is provided leave specified
group pool(s).
If -handle is provided, disable all groups on this session.
If -port_handle is provided, disable all groups
on all sessions for that port.
			    		rejoin - Sends another Join message to the Querier.
			    		releave - Sends another Leave message to the Querier.
			    		mld_send_specific_query - MLD Send Specific Query
			    		mld_resume_periodic_gen_query - MLD Resume Periodic Gen Query
			    		mld_stop_periodic_gen_query - MLD Stop Periodic Gen Query
			 	-handle
			 		If -mode is join or leave, all group pools belonging to the MLD
			 		session specified with this option will join or leave.
			 		Example :-
			 		::ixiangpf::emulation_mld_control -handle $device1handle -mode [start or stop]
			 	-port_handle
			 		This option is required to specify the port where to take the action.
			 	-group_member_handle
			 		If -mode is join or leave this option specifies the group pools
			 		to join or leave.
			 	-source_member_handle
			 		If -mode is join or leave this option specifies the source pools
			 		to join or leave. If -port_handle is provided along with -source_member_handle and -mode join/leave, the specified source will be enabled/disabled.
			 		If -source_member_handle is provided only with -mode join/leave, the source will execute join/leave.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-start_group_address
			x		Start group address for the mld host on which the action defined by the mode parameter will be applied
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-group_count
			x		Group count for the mld host on which the action defined by the mode parameter will be applied
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-start_source_address
			x		Start source address for the mld host address on which the action defined by the mode parameter will be applied
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-source_count
			x		Source count for the mld host on which the action defined by the mode parameter will be applied
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-source_increment_step
			x		Source Increment Step for the mld host on which the action defined by the mode parameter will be applied
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information
			 key:log     value:When status is failure, contains more information
		
		Examples:
		See files starting with MLD_ in the Samples subdirectory.See the MLD example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) MLD implementation using IxTclNetwork is NOT SUPPORTED in HLTAPI 3.20.
		1) MLD implementation using IxTclNetwork is NOT SUPPORTED in HLTAPI 3.20.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_mld_control", kwargs)

	def emulation_mld_group_config(self, **kwargs):
		""" Configures multicast groups added to an MLD session.  This procedure utilizes the common emulation_multicast_group_config and emulation_multicast_source_config procedures.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_mld_group_config
			 	-mode                     CHOICES create
			                           CHOICES delete
			                           CHOICES modify
			                           CHOICES clear_all
			                           CHOICES enable
			                           CHOICES disable
			x	[-return_detailed_handles CHOICES 0 1
			x                          DEFAULT 0]
			x	[-g_enable_packing        ANY]
			x	[-g_filter_mode           CHOICES include exclude]
			x	[-g_max_groups_per_pkts   ANY]
			x	[-g_max_sources_per_group ANY]
			 	[-group_pool_handle       ANY]
			 	[-handle                  ANY]
			x	[-no_of_grp_ranges        NUMERIC
			x                          DEFAULT 1]
			x	[-no_of_src_ranges        NUMERIC]
			x	[-no_write                ANY]
			x	[-reset                   FLAG]
			 	[-session_handle          ANY]
			 	[-source_pool_handle      ANY]
			x	[-filter_mode             CHOICES include exclude
			x                          DEFAULT include]
		
		Arguments:
			 	-mode
			 		This option defines the action to be taken.
			 		Valid choices are:
			    		create - When this mode is used, you must provide -session_handle. The
parameter -group_pool_handle is also mandatory.
			    		delete - Parameter -handle must be provided. In this case, -handle can represent
one or multiple Group Ranges.
			    		modify - Parameter -handle must be provided. When using this mode, -handle can represent
one or multiple Group Ranges.
			    		clear_all - When this mode is used, you must provide -session_handle.
			    		enable - When this mode is used, you must provide -handle.
			    		disable - When this mode is used, you must provide -handle.
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-g_enable_packing
			x		If checked, multiple Sources can be included in each Record, and multiple Records can be included in each Frame, for more efficient transmission. This option is available only for MLDv2. This is valid only for IxTclNetwork API. If this parameter is not provided, the enable_packing that was set at host level will be used instead.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-g_filter_mode
			x		Cofigure MLDv2 Include Filter Mode. This is valid only for IxTclNetwork API.
			x		If this parameter is not provided, the filter_mode that was set at host level will be used instead.
			x		Valid choices are:
			x   		include - The specified source(s) is (are) of interest
			x   		exclude - The specified source(s) is (are) not of interest
			x	-g_max_groups_per_pkts
			x		The total number of Group Records to be added to each frame/message. This option is available only for MLDv2. This is valid only for IxTclNetwork API. If this parameter is not provided, the max_groups_per_pkts that was set at host level will be used instead.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-g_max_sources_per_group
			x		The total number of Source addresses to be added to each Group Record. This option is available only for MLDv2. This is valid only for IxTclNetwork API. If this parameter is not provided, the max_sources_per_group that was set at host level will be used instead.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-group_pool_handle
			 		Groups to be linked to the session in create mode. The group pool
			 		must be added beforehand through procedure
			 		emulation_multicast_group_config.
			 	-handle
			 		Group membership handle that associates group pools with an MLD
			 		session. If modify mode, membership handle must be used to identify the multicast group pools.
			x	-no_of_grp_ranges
			x		Number of MLD multicast groups in group pool.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-no_of_src_ranges
			x		Number of MLD unicast sources in source pool.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-no_write
			x	-reset
			x   		If the -mode is create and this option exists, then any existing group ranges (for the specified -session_handle mld host) will
			x   		be deleted before creating new ones. This option is available
			x   		only for IxNetwork Tcl API.
			 	-session_handle
			    		MLD Host handle on which to configure the MLD group ranges.
			 	-source_pool_handle
			    		Associate source pool(s) with group(s). Specify one or more source pool
			    		handle(s) for (S,G) entries. None for (*,G) entries. The source pool(s)
			    		must be added beforehand through procedure
			    		emulation_multicast_source_config.
			x	-filter_mode
			x   		Configure MLDv2 Include Filter Mode.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		include - The specified source(s) is (are) of interest
			x       		exclude - The specified source(s) is (are) not of interest
		
		Return Values:
		A list containing the mld source protocol stack handles that were added by the command (if any).
			xkey:mld_source_handle   value:A list containing the mld source protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE
			 key:status              value:$::SUCCESS | $::FAILURE
		When status is failure, contains more info
			 key:log                 value:When status is failure, contains more info
		The group member handle Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:handle              value:The group member handle Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		The group pool handle
			 key:mld_group_handle    value:The group pool handle
		Source pool handles list Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:source_handle       value:Source pool handles list Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		The group member handle
			 key:handle              value:The group member handle
		The group pool handle
			 key:group_pool_handle   value:The group pool handle
		Source pool handles list
			 key:source_pool_handle  value:Source pool handles list
		
		Examples:
		See files starting with MLD_ in the Samples subdirectory.See the MLD example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		{status $::SUCCESS} {mld_groups {routeRange1 routeRange2}}
		
		Notes:
		1) Not yet coded to functional specification.
		2) MLD implementation using IxTclNetwork is NOT SUPPORTED in HLTAPI 3.20.
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle, source_handle
		1) Not yet coded to functional specification.2) MLD implementation using IxTclNetwork is NOT SUPPORTED in HLTAPI 3.20.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_mld_group_config", kwargs)

	def emulation_mld_info(self, **kwargs):
		""" This procedure gathers MLD statistics.     This procedure is only supported for IxTclNetwork.      It is not supported by IxNetwork-FT.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_mld_info
			x	-mode         CHOICES stats
			x              CHOICES aggregate
			x              CHOICES stats_per_device_group
			x              CHOICES stats_per_session
			x              CHOICES clear_stats
			x              CHOICES learned_info]
			 	[-port_handle REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			n	[-timeout     ANY]
			x	[-handle      ANY]
			x	[-type        CHOICES host querier both
			x              DEFAULT host]
		
		Arguments:
			x	-mode
			x		The statistics that should be retrieved for MLD host and querier.
			x		Valid choices are:
			x   		stats - Gather MLD aggregated statistics.
			x   		aggregate - Gather MLD aggregated statistics.
			x   		stats_per_device_group - Gather MLD statistics per Device Group.
			x   		stats_per_session - Gather MLD statistics per Session.
			x   		clear_stats - Clear MLD statistics.
			x   		learned_info - Get Learned Info
			 	-port_handle
			 		This option is required to specify the port where to take the action.
			n	-timeout
			x	-handle
			x   		 MLD session handle for which statistics are gathered. The
			x   		handle is an emulated MLD router object reference.
			x   		Example :
			x   		
			x   		
			x   		
			x   		- ::ixiangpf::emulation_mld_info -mode stats -handle $devicehandle -type [both or host or querier]
			x   		- ::ixiangpf::emulation_mld_info -mode learned_info -handle $mldQuerierHandle
			x   		
			x   		
			x	-type
			x   		The type of aggregated statistics to be gathered.
			x   		This option is available only when using the IxNetwork
			x   		(IxTclNetwork package) 6.30 or later. The option is NOT
			x   		supported by IxNetwork-FT (IxTclProtocol package).
			x   		Valid only for -mode stats.
			x   		Valid choices are:
			x       		host - statistics gathered from IxNetwork for the MLD sessions configured using emulation_mld_config.
			x       		querier - statistics gathered from IxNetwork for the MLD sessions configured using emulation_mld_querier_config.
			x       		both - both host and querier agregated statistics will be retrieved.
		
		Return Values:
		Sessions Total
			xkey:sessions_total                           value:Sessions Total
		Sessions Up
			xkey:sessions_up                              value:Sessions Up
		Sessions Down
			xkey:sessions_down                            value:Sessions Down
		Sessions Not Started
			xkey:sessions_not_started                     value:Sessions Not Started
		MLD Querier Total Frames Tx
			xkey:total_frames_tx                          value:MLD Querier Total Frames Tx
		MLD Querier Total Frames Rx
			xkey:total_frames_rx                          value:MLD Querier Total Frames Rx
		MLD Querier Invalid Packets Rx
			xkey:invalid_packets_rx                       value:MLD Querier Invalid Packets Rx
		MLDv1 General Query Tx
			xkey:v1_general_query_tx                      value:MLDv1 General Query Tx
		MLDv1 Group specific Query Tx
			xkey:v1_group_specific_query_tx               value:MLDv1 Group specific Query Tx
		MLDv1 Querier Membership Reports Rx
			xkey:v1_querier_membership_reports_rx         value:MLDv1 Querier Membership Reports Rx
		MLDv1 Done Rx
			xkey:v1_done_rx                               value:MLDv1 Done Rx
		MLDv2 General Query Tx
			xkey:v2_general_query_tx                      value:MLDv2 General Query Tx
		MLDv2 Group specific Query Tx
			xkey:v2_group_specific_query_tx               value:MLDv2 Group specific Query Tx
		MLDv2 Group and Source Specific Query Tx
			xkey:v2_group_and_source_specific_query_tx    value:MLDv2 Group and Source Specific Query Tx
		MLDv2 Querier Membership Reports Rx
			xkey:v2_querier_membership_reports_rx         value:MLDv2 Querier Membership Reports Rx
		MLDv1 General Query Count Rx
			xkey:v1_general_query_count_rx                value:MLDv1 General Query Count Rx
		MLDv2 General Query Count Rx
			xkey:v2_general_query_count_rx                value:MLDv2 General Query Count Rx
		MLDv1 Group Specific Query Count Rx
			xkey:v1_group_specific_query_count_rx         value:MLDv1 Group Specific Query Count Rx
		MLDv2 Group Specific Query Count Rx
			xkey:v2_group_specific_query_count_rx         value:MLDv2 Group Specific Query Count Rx
		Sessions Total
			xkey:sessions_total                           value:Sessions Total
		Sessions Up
			xkey:sessions_up                              value:Sessions Up
		Sessions Down
			xkey:sessions_down                            value:Sessions Down
		Sessions Not Started
			xkey:sessions_not_started                     value:Sessions Not Started
		Total Frames Tx
			xkey:total_frames_tx                          value:Total Frames Tx
		Total Frames Rx
			xkey:total_frames_rx                          value:Total Frames Rx
		Invalid Packets Rx
			xkey:invalid_packets_rx                       value:Invalid Packets Rx
		(S,G) Pairs Joined
			xkey:joined_groups                            value:(S,G) Pairs Joined
		v1 Membership Reports Tx
			xkey:v1_membership_reports_tx                 value:v1 Membership Reports Tx
		v1 Membership Reports Rx
			xkey:v1_membership_reports_rx                 value:v1 Membership Reports Rx
		v2 Membership Reports Tx
			xkey:v2_membership_reports_tx                 value:v2 Membership Reports Tx
		v2 Membership Reports Rx
			xkey:v2_membership_reports_rx                 value:v2 Membership Reports Rx
		v1 General Queries Tx
			xkey:v1_general_queries_tx                    value:v1 General Queries Tx
		v1 General Queries Rx
			xkey:v1_general_queries_rx                    value:v1 General Queries Rx
		v2 General Queries Tx
			xkey:v2_general_queries_tx                    value:v2 General Queries Tx
		v2 General Queries Rx
			xkey:v2_general_queries_rx                    value:v2 General Queries Rx
		v1 Group Specific Queries Tx
			xkey:v1_group_specific_queries_tx             value:v1 Group Specific Queries Tx
		v1 Group Specific Queries Rx
			xkey:v1_group_specific_queries_rx             value:v1 Group Specific Queries Rx
		v2 Group Specific Queries Tx
			xkey:v2_group_specific_queries_tx             value:v2 Group Specific Queries Tx
		v2 Group Specific Queries Rx
			xkey:v2_group_specific_queries_rx             value:v2 Group Specific Queries Rx
		v2 Group&Source Specific Queries Tx
			xkey:v2_group_and_source_specific_queries_tx  value:v2 Group&Source Specific Queries Tx
		v2 Group&Source Specific Queries Rx
			xkey:v2_group_and_source_specific_queries_rx  value:v2 Group&Source Specific Queries Rx
		v1 Done Tx
			xkey:v1_done_tx                               value:v1 Done Tx
		v1 Done Rx
			xkey:v1_done_rx                               value:v1 Done Rx
		v2 MODE_IS_INCLUDE Tx
			xkey:v2_mode_is_include_tx                    value:v2 MODE_IS_INCLUDE Tx
		v2 MODE_IS_INCLUDE Rx
			xkey:v2_mode_is_include_rx                    value:v2 MODE_IS_INCLUDE Rx
		v2 MODE_IS_EXCLUDE Tx
			xkey:v2_mode_is_exclude_tx                    value:v2 MODE_IS_EXCLUDE Tx
		v2 MODE_IS_EXCLUDE Rx
			xkey:v2_mode_is_exclude_rx                    value:v2 MODE_IS_EXCLUDE Rx
		v2 CHANGE_TO_INCLUDE_MODE Tx
			xkey:v2_change_to_include_tx                  value:v2 CHANGE_TO_INCLUDE_MODE Tx
		v2 CHANGE_TO_INCLUDE_MODE Rx
			xkey:v2_change_to_include_rx                  value:v2 CHANGE_TO_INCLUDE_MODE Rx
		v2 CHANGE_TO_EXCLUDE_MODE Tx
			xkey:v2_change_to_exclude_tx                  value:v2 CHANGE_TO_EXCLUDE_MODE Tx
		v2 CHANGE_TO_EXCLUDE_MODE Rx
			xkey:v2_change_to_exclude_rx                  value:v2 CHANGE_TO_EXCLUDE_MODE Rx
		v2 ALLOW_NEW_SOURCES Tx
			xkey:v2_allow_new_sources_tx                  value:v2 ALLOW_NEW_SOURCES Tx
		v2 ALLOW_NEW_SOURCES Rx
			xkey:v2_allow_new_sources_rx                  value:v2 ALLOW_NEW_SOURCES Rx
		v2 BLOCK_OLD_SOURCES Tx
			xkey:v2_block_old_sources_tx                  value:v2 BLOCK_OLD_SOURCES Tx
		v2 BLOCK_OLD_SOURCES Rx
			xkey:v2_block_old_sources_rx                  value:v2 BLOCK_OLD_SOURCES Rx
		
		Examples:
		
		Sample Input:
		.
		
		Sample Output:
		.
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_mld_info", kwargs)

	def emulation_mld_querier_config(self, **kwargs):
		""" Configures MLD Querier sessions.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_mld_querier_config
			 	-mode                               CHOICES create
			                                     CHOICES modify
			                                     CHOICES delete
			                                     CHOICES disable
			                                     CHOICES enable]
			x	-handle                             ANY]
			x	[-version                           CHOICES version1 version2
			x                                    DEFAULT version2]
			x	[-startup_query_count               ANY
			x                                    DEFAULT 2]
			x	[-general_query_interval            ANY
			x                                    DEFAULT 125]
			x	[-router_alert                      ANY
			x                                    DEFAULT 1]
			x	[-robustness_variable               ANY
			x                                    DEFAULT 2]
			x	[-general_query_response_interval   ANY
			x                                    DEFAULT 10000]
			x	[-specific_query_response_interval  ANY
			x                                    DEFAULT 1000]
			x	[-specific_query_transmission_count ANY
			x                                    DEFAULT 2]
			x	[-support_election                  ANY
			x                                    DEFAULT 1]
			x	[-support_older_version_host        ANY
			x                                    DEFAULT 1]
			x	[-support_older_version_querier     ANY
			x                                    DEFAULT 1]
			x	[-discard_learnt_info               ANY
			x                                    DEFAULT 1]
			x	[-active                            ANY
			x                                    DEFAULT 1]
			x	[-name                              ALPHA]
			x	[-count                             NUMERIC
			x                                    DEFAULT 1]
			x	[-intf_ip_addr                      IPV6]
			x	[-intf_ip_addr_step                 IPV6
			x                                    DEFAULT 0::1]
			x	[-intf_prefix_len                   RANGE 1-128
			x                                    DEFAULT 64]
			x	[-neighbor_intf_ip_addr             IP]
			x	[-neighbor_intf_ip_addr_step        IP
			x                                    DEFAULT 0::0]
			x	[-mac_address_init                  MAC]
			x	[-mac_address_step                  MAC
			x                                    DEFAULT 0000.0000.0001]
			x	[-vlan                              CHOICES 0 1
			x                                    DEFAULT 0]
			x	[-vlan_id                           RANGE 0-4095]
			x	[-vlan_id_mode                      CHOICES fixed increment
			x                                    DEFAULT increment]
			x	[-vlan_id_step                      RANGE 0-4096
			x                                    DEFAULT 1]
			x	[-vlan_user_priority                RANGE 0-7
			x                                    DEFAULT 0]
			x	[-enabled                           ANY]
			x	[-no_of_queries_per_unit_time       ANY]
			x	[-time_period                       ANY]
		
		Arguments:
			 	-mode
			 		This option defines the action to be taken.
			 		Valid choices are:
			    		create - Creates the MLD querier router on the Ixia interface. Requires the use of -handle.
			    		modify - Modifies the MLD querier router on the Ixia interface. Requires the use of -handle.
			    		delete - Deletes the MLD querier router on the Ixia interface. Requires the use of -handle.
			    		disable - The MLD querier router will be disabled. Requires the use of -handle.
			    		enable - Enables the MLD querier router on the Ixia interface. Requires the use of -handle.
			x	-handle
			x		If -mode is create, delete, modify, enable or disable this option is required
			x		to specify the existing MLD Querier session.
			x	-version
			x		MLD Querier Version
			x		Valid choices are:
			x   		version1 - Configures MLD Querier Version 1
			x   		version2 - Configures MLD Querier Version 2
			x	-startup_query_count
			x		The number of general query messages sent at startup.
			x	-general_query_interval
			x		General Query Interval in seconds
			x	-router_alert
			x		If true (1), enable IP Router Alert Option.
			x	-robustness_variable
			x		Defines the subnet vulnerability to lost packets. MLD can recover from robustness variable minus 1 lost MLD packets.
			x		The robustness variable should be set to a value of 2 or greater (7 being the maximum).
			x	-general_query_response_interval
			x		General Query Response Interval in milliseconds
			x	-specific_query_response_interval
			x		The maximum amount of time in seconds that the MLD Querier waits to receivea response to a Specific
			x		Query message. The default query response interval is 1000 milliseconds and must be less than the query interval.
			x		This parameter will be set (-mode create and -modify) only if discard_learned_info is not enabled.
			x	-specific_query_transmission_count
			x		Indicates the total number of specific Query messages sent every Specific Query Response Interval
			x		seconds before assuming that there is no interestedlistener for the particular group/source.
			x		This parameter will be set (-mode create and -modify) only if discard_learned_info is not enabled.
			x	-support_election
			x		Indicates whether or not the Querier participates in querier election. If disabled, then all incoming query messages are discarded.
			x	-support_older_version_host
			x		Indicates whether the Querier will comply to RFC 3376 Section 7.3.2 and RFC 3810 Section 8.3.2. If disabled, all membership reports with a version less than the current version are discarded.
			x	-support_older_version_querier
			x		Indicates whether the Querier downgrades to the lowest version of received query messages. If disabled, all query messages with a version less than the current version are discarded.
			x	-discard_learnt_info
			x		When -discard_learnt_info is 0, the emulated Querier maintains a complete record state for received
			x		reports and send queries (based on timer expiry for received groups and sources).
			x		If -discard_learnt_info is 1, the Querier does not maintain any database and only sends periodic general queries.
			x		The specific query group/source record information is not calculated based on any earlier received report, but is based only on the last received report.
			x	-active
			x		Specifies if the selected querier will be active or not.
			x	-name
			x		Name of the sppecified stack.
			x	-count
			x		Defines the number of sessions to create on the interface.
			x	-intf_ip_addr
			x		IP address of the test interface / emulated MLD Querier.
			x	-intf_ip_addr_step
			x		The IP address step between each session.
			x	-intf_prefix_len
			x		The netmask length value for the interface.
			x	-neighbor_intf_ip_addr
			x		IP address of the neighbor.
			x	-neighbor_intf_ip_addr_step
			x		The IP address step between each session.
			x	-mac_address_init
			x		The MAC address for the interface to be created.
			x	-mac_address_step
			x		The incrementing step for the MAC address of the interface to be
			x		created. Valid only when using IxNetwork Tcl API.
			x	-vlan
			x		Enables vlan on the directly connected MLD router interface.
			x		Valid options are: 0 - disable, 1 - enable.
			x		This option is valid only when -mode is create or -mode is modify
			x		and -handle is an MLD router handle.
			x		This option is available only when IxNetwork tcl API is used.
			x	-vlan_id
			x		VLAN ID for emulated router node. Valid for mode create and modify.
			x	-vlan_id_mode
			x		For multiple neighbor configuration, configures the VLAN ID mode to
			x		fixed or increment. Valid for mode create and modify.
			x		Valid choices are:
			x   		fixed - Same vlan id across interfaces
			x   		increment - Increment vlan ids across interfaces
			x	-vlan_id_step
			x		When -vlan_id_mode is set to increment, this defines the step for
			x		every VLAN. Valid for mode create.
			x		When vlan_id_step causes the vlan_id value to exceed it's maximum value the
			x		increment will be done modulo <number of possible vlan ids>.
			x		Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0
			x		vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			x	-vlan_user_priority
			x		VLAN user priority assigned to emulated router node. Valid for mode create and modfiy.
			x	-enabled
			x		Enable/Disable Rate Control
			x	-no_of_queries_per_unit_time
			x		No. of Queries (per Time Period)
			x	-time_period
			x		Time Period
		
		Return Values:
		A list containing the mld querier protocol stack handles that were added by the command (if any).
			xkey:mld_querier_handle    value:A list containing the mld querier protocol stack handles that were added by the command (if any).
		A list containing the ethernet protocol stack handles that were added by the command (if any).
			xkey:ethernet_handle       value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		A list containing the ipv6 protocol stack handles that were added by the command (if any).
			xkey:ipv6_handle           value:A list containing the ipv6 protocol stack handles that were added by the command (if any).
		A list containing the dhcpv6 client protocol stack handles that were added by the command (if any).
			xkey:dhcpv6_client_handle  value:A list containing the dhcpv6 client protocol stack handles that were added by the command (if any).
		A list containing the pppox client protocol stack handles that were added by the command (if any).
			xkey:pppox_client_handle   value:A list containing the pppox client protocol stack handles that were added by the command (if any).
		A list containing the pppox server protocol stack handles that were added by the command (if any).
			xkey:pppox_server_handle   value:A list containing the pppox server protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:interface_handle      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		$::SUCCESS | $::FAILURE
			 key:status                value:$::SUCCESS | $::FAILURE
		The handles for the MLD Querier created Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:mld_querier_handles   value:The handles for the MLD Querier created Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) MLD implementation using IxTclNetwork is NOT SUPPORTED in HLTAPI 3.30. If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  mld_querier_handles, interface_handle
		
		See Also:
		
		"""
		return self._run_keyword("emulation_mld_querier_config", kwargs)

	def emulation_mplstp_config(self, **kwargs):
		""" This command is used to create/modify/delete/enable/disable a MPLS-TP router or router interface. Each MPLS-TP router can have multiple MPLS-TP router interfaces. Each router interface is associated with a protocol interface.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_mplstp_config
			 	[-mode                          ANY]
			 	[-aps_channel_type              ANY]
			 	[-bfdcc_channel_type            ANY]
			 	[-delay_management_channel_type ANY]
			 	[-dut_mac_addr                  ANY]
			 	[-dut_mac_addr_step             ANY]
			 	[-fault_management_channel_type ANY]
			 	[-handle                        ANY]
			 	[-high_performance_mode_enable  ANY]
			 	[-interface_count               ANY]
			 	[-interface_handle              ANY]
			 	[-loss_measurement_channel_type ANY]
			 	[-no_write                      ANY]
			 	[-ondemand_cv_channel_type      ANY]
			 	[-port_handle                   ANY]
			 	[-pw_status_channel_type        ANY]
			 	[-router_count                  ANY]
			 	[-router_id                     ANY]
			 	[-router_id_step                ANY]
		
		Arguments:
			 	-mode
			 		Action to perform. This parameter is supported using the following APIs: IxN.create - Create new MPLS-TP routers or router interfaces or both. Param -port_handle is needed for creating routers (with possible multiple interfaces, see -interface_count). Param -router_handle is needed for creating interfaces on a specified router. modify- Modify MPLS-TP router or router interface specified with -router_handle or -interface_handle parameters. enable- Enable MPLS-TP router or router interface specified with -router_handle or -interface_handle parameters. disable - Disable MPLS-TP router or router interface specified with -router_handle or -interface_handle parameters. delete- Remove MPLS-TP router or router interface specified with -router_handle or -interface_handle parameters.
			 	-aps_channel_type
			 		Channel type for APS. APIs: IxN.
			 	-bfdcc_channel_type
			 		Channel type for BFDCC. APIs: IxN.
			 	-delay_management_channel_type
			 		Channel type for Delay management. APIs: IxN.
			 	-dut_mac_addr
			 		The DUT mac address linked to the connected interface. Must be a list if -interface_count > 1 or a single element if -dut_mac_addr_step is present. APIs: IxN.
			 	-dut_mac_addr_step
			 		Step for -dut_mac_addr to be added for each interface when -interface_count > 1. If this is specified, -dut_mac_addr cannot be a list. APIs: IxN.
			 	-fault_management_channel_type
			 		Channel type for Fault management. APIs: IxN.
			 	-handle
			 		The router handle to be configured with interfaces or modified. APIs: IxN.
			 	-high_performance_mode_enable
			 		If 1, enables high performance mode. APIs: IxN.
			 	-interface_count
			 		Number of interfaces to be created when using -router_handle or -router_count = 1. APIs: IxN.
			 	-interface_handle
			 		The interface handle used for modes modify/delete/enable/disable. APIs: IxN.
			 	-loss_measurement_channel_type
			 		Channel type for Loss measurement. APIs: IxN.
			 	-no_write
			 		If this option is present, the configuration is not written to the hardware. This option can be used to queue up multiple configurations before writing to the hardware. APIs: IxN.
			 	-ondemand_cv_channel_type
			 		Channel type for On demand CV. APIs: IxN.
			 	-port_handle
			 		Parameter -port_handle specifies the port to be configured with MPLS-TP. This param is only used when mode is "create" APIs: IxN.
			 	-pw_status_channel_type
			 		Channel type for PW status. APIs: IxN.
			 	-router_count
			 		Number of routers to create when using -port_handle. When router_count > 1, router interfaces must be added afterwards for each created router. APIs: IxN.
			 	-router_id
			 		The Router ID. Must be a list if -router_count > 1 or single element if -router_id_step is present. APIs: IxN.
			 	-router_id_step
			 		The step for Router ID. If this is specified, -router_id cannot be a list. APIs: IxN.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status             value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                value:On status of failure, gives detailed information.
		On mode create, list of router handles. On modes modify/enable/disable the router affected.
			 key:router_handles     value:On mode create, list of router handles. On modes modify/enable/disable the router affected.
		On mode create, list of router interface handles for a specific <router_handle> On modes modify/enable/disable the interface affected.
			 key:interface_handles  value:On mode create, list of router interface handles for a specific <router_handle> On modes modify/enable/disable the interface affected.
		
		Examples:
		See files starting with MPLSTP_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) This protocol is available only when using IxNetwork Tcl API.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_mplstp_config", kwargs)

	def emulation_mplstp_control(self, **kwargs):
		""" This command is used to control a MPLS-TP router.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_mplstp_control
			 	[-mode                                        ANY]
			 	[-alarm_ais_enable                            ANY]
			 	[-alarm_enable                                ANY]
			 	[-alarm_lck_enable                            ANY]
			 	[-alarm_periodicity                           ANY]
			 	[-alarm_set_ldi_enable                        ANY]
			 	[-alarm_trigger                               ANY]
			 	[-alarm_type                                  ANY]
			 	[-aps_trigger_enable                          ANY]
			 	[-aps_trigger_type                            ANY]
			 	[-cccv_pause_enable                           ANY]
			 	[-cccv_pause_trigger_option                   ANY]
			 	[-cccv_resume_enable                          ANY]
			 	[-cccv_resume_trigger_option                  ANY]
			 	[-dm_interval                                 ANY]
			 	[-dm_iterations                               ANY]
			 	[-dm_mode                                     ANY]
			 	[-dm_pad_len                                  ANY]
			 	[-dm_request_padded_reply                     ANY]
			 	[-dm_time_format                              ANY]
			 	[-dm_traffic_class                            ANY]
			 	[-dm_trigger_enable                           ANY]
			 	[-dm_type                                     ANY]
			 	[-handle                                      ANY]
			 	[-incoming_inner_label                        ANY]
			 	[-incoming_outer_label                        ANY]
			 	[-last_dm_response_timeout                    ANY]
			 	[-last_lm_response_timeout                    ANY]
			 	[-lm_counter_type                             ANY]
			 	[-lm_initial_rx_value                         ANY]
			 	[-lm_initial_tx_value                         ANY]
			 	[-lm_interval                                 ANY]
			 	[-lm_iterations                               ANY]
			 	[-lm_mode                                     ANY]
			 	[-lm_rx_step                                  ANY]
			 	[-lm_traffic_class                            ANY]
			 	[-lm_trigger_enable                           ANY]
			 	[-lm_tx_step                                  ANY]
			 	[-lm_type                                     ANY]
			 	[-lsp_ping_enable                             ANY]
			 	[-lsp_ping_encapsulation_type                 ANY]
			 	[-lsp_ping_fec_stack_validation_enable        ANY]
			 	[-lsp_ping_response_timeout                   ANY]
			 	[-lsp_ping_ttl_value                          ANY]
			 	[-lsp_trace_route_enable                      ANY]
			 	[-lsp_trace_route_encapsulation_type          ANY]
			 	[-lsp_trace_route_fec_stack_validation_enable ANY]
			 	[-lsp_trace_route_response_timeout            ANY]
			 	[-lsp_trace_route_ttl_limit                   ANY]
			 	[-outgoing_inner_label                        ANY]
			 	[-outgoing_outer_label                        ANY]
			 	[-port_handle                                 ANY]
			 	[-pw_status_clear_enable                      ANY]
			 	[-pw_status_clear_label_ttl                   ANY]
			 	[-pw_status_clear_transmit_interval           ANY]
			 	[-pw_status_code                              ANY]
			 	[-pw_status_fault_enable                      ANY]
			 	[-pw_status_fault_label_ttl                   ANY]
		
		Arguments:
			 	-mode
			 		Action to perform. This parameter is supported using the following APIs: IxN.start - Start the MPLS-TP protocol on specified -port_handle or a specific MPLS-TP router specified by -handle. stop - Stop the MPLS-TP protocol on specified -port_handle or a specific MPLS-TP router specified by -handle. restart - Restart the MPLS-TP protocol on specified -port_handle or a specific MPLS-TP router specified by -handle. trigger - Trigger the MPLS-TP protocol on specified -port_handle. A minimum of 1 trigger enable parameter must be set.
			 	-alarm_ais_enable
			 		If set to 1, the alarm AIS is enabled. APIs: IxN.
			 	-alarm_enable
			 		If set to 1, the alarm trigger type is enabled. APIs: IxN.
			 	-alarm_lck_enable
			 		If set to 1, the alarm LCK is enabled. APIs: IxN.
			 	-alarm_periodicity
			 		Configures the alarm trigger periodicity. APIs: IxN.
			 	-alarm_set_ldi_enable
			 		If set to 1, the alarm set LDI flag is enabled. APIs: IxN.
			 	-alarm_trigger
			 		Configures the alarm trigger type.
			 	-alarm_type
			 		Configures the alarm type. APIs: IxN.
			 	-aps_trigger_enable
			 		If set to 1, the APS trigger is enabled. APIs: IxN.
			 	-aps_trigger_type
			 		Configures the APS trigger action. APIs: IxN.
			 	-cccv_pause_enable
			 		If set to 1, the CCCV pause trigger is enabled. APIs: IxN.
			 	-cccv_pause_trigger_option
			 		Configures the CCCV pause trigger type.
			 	-cccv_resume_enable
			 		If set to 1, the CCCV resume trigger is enabled. APIs: IxN.
			 	-cccv_resume_trigger_option
			 		Configures the CCCV resume trigger type.
			 	-dm_interval
			 		Configures the DM interval. APIs: IxN.
			 	-dm_iterations
			 		Configures the number of DM iterations. APIs: IxN.
			 	-dm_mode
			 		Configures the DM mode.
			 	-dm_pad_len
			 		Configures the DM Pad length. APIs: IxN.
			 	-dm_request_padded_reply
			 		If set to 1, the DM request reply is padded. APIs: IxN.
			 	-dm_time_format
			 		Configures the DM time format.
			 	-dm_traffic_class
			 		Configures the DM traffic class. Ranges between 0 to 7. APIs: IxN.
			 	-dm_trigger_enable
			 		If set to 1, the DM trigger is enabled. APIs: IxN.
			 	-dm_type
			 		Configures the DM type.
			 	-handle
			 		An MPLS-TP router handle to be controlled. APIs: IxN.
			 	-incoming_inner_label
			 		The incoming inner label filter list. This has elements of form [element] or [start:step:count]. The latter will be expanded to the [element] form. All 4 label filter lists must have the same expanded list length. APIs: IxN.
			 	-incoming_outer_label
			 		The incoming outer label filter list. This has elements of form [element] or [start:step:count]. The latter will be expanded to the [element] form. All 4 label filter lists must have the same expanded list length. APIs: IxN.
			 	-last_dm_response_timeout
			 		Configures the Last DM response timeout. APIs: IxN.
			 	-last_lm_response_timeout
			 		Configures the Last LM response timeout. APIs: IxN.
			 	-lm_counter_type
			 		Configures the LM counter type.
			 	-lm_initial_rx_value
			 		Configures the LM initial RX value. APIs: IxN.
			 	-lm_initial_tx_value
			 		Configures the LM initial TX value. APIs: IxN.
			 	-lm_interval
			 		Configures the LM interval. APIs: IxN.
			 	-lm_iterations
			 		Configures the LM number of iterations. APIs: IxN.
			 	-lm_mode
			 		Configures the LM mode. APIs: IxN.
			 	-lm_rx_step
			 		Configures the LM RX Step. APIs: IxN.
			 	-lm_traffic_class
			 		Configures the LM traffic class. Ranges between 0 to 7. APIs: IxN.
			 	-lm_trigger_enable
			 		If set to 1, LM trigger is enabled. APIs: IxN.
			 	-lm_tx_step
			 		Configures the LM TX step. APIs: IxN.
			 	-lm_type
			 		Configures the LM type. APIs: IxN.
			 	-lsp_ping_enable
			 		If set to 1, the LSP Ping trigger is enabled. APIs: IxN.
			 	-lsp_ping_encapsulation_type
			 		Configures the LSP Ping encapsulation type. APIs: IxN.
			 	-lsp_ping_fec_stack_validation_enable
			 		If set to 1, the LSP Ping FEC stack validation is enabled. APIs: IxN.
			 	-lsp_ping_response_timeout
			 		Configures the LSP Ping response timeout. APIs: IxN.
			 	-lsp_ping_ttl_value
			 		Configures the LSP Ping TTL value. APIs: IxN.
			 	-lsp_trace_route_enable
			 		If set to 1, the LSP TraceRoute is enabled. APIs: IxN.
			 	-lsp_trace_route_encapsulation_type
			 		Configures the LSP TraceRoute encapsulation type. APIs: IxN.
			 	-lsp_trace_route_fec_stack_validation_enable
			 		If set to 1, the LSP TraceRoute FEC stack validation is enabled. APIs: IxN.
			 	-lsp_trace_route_response_timeout
			 		Configures the LSP TraceRoute response timeout. APIs: IxN.
			 	-lsp_trace_route_ttl_limit
			 		Configures the LSP TraceRoute TTL limit. APIs: IxN.
			 	-outgoing_inner_label
			 		The outgoing inner label filter list. This has elements of form [element] or [start:step:count]. The latter will be expanded to the [element] form. All 4 label filter lists must have the same expanded list length. APIs: IxN.
			 	-outgoing_outer_label
			 		The outgoing outer label filter list. This has elements of form [element] or [start:step:count]. The latter will be expanded to the [element] form. All 4 label filter lists must have the same expanded list length. APIs: IxN.
			 	-port_handle
			 		The port handle on whose MPLS-TP routers the action will be applied. APIs: IxN.
			 	-pw_status_clear_enable
			 		If set to 1, the PW status clear trigger is enabled. APIs: IxN.
			 	-pw_status_clear_label_ttl
			 		Configures the PW status clear trigger TTL value. APIs: IxN.
			 	-pw_status_clear_transmit_interval
			 		Configures the PW status clear trigger transmit interval. APIs: IxN.
			 	-pw_status_code
			 		Configures the PW status clear trigger status code. APIs: IxN.
			 	-pw_status_fault_enable
			 		If set to 1, the PW status fault trigger is enabled. APIs: IxN.
			 	-pw_status_fault_label_ttl
			 		Configures the PW status fault trigger TTL value. APIs: IxN.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log     value:On status of failure, gives detailed information.
		
		Examples:
		See files starting with MPLSTP_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) This protocol is available only when using IxNetwork Tcl API.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_mplstp_control", kwargs)

	def emulation_mplstp_info(self, **kwargs):
		""" This command is used to gather info/stats from MPLS-TP routers or LSP-PW ranges.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_mplstp_info
			 	[-mode   ANY]
			 	[-handle ANY]
		
		Arguments:
			 	-mode
			 		Action to perform. This parameter is supported using the following APIs: IxN. aggregate_stats - retrieve stats aggregated per port learned_info - retrieve all learned information by the MPLS-TP protocol general_learned_info - retrieve general learned information by the MPLS-TP protocol lm_learned_info - retrieve LM learned information by the MPLS-TP protocol dm_learned_info - retrieve DM learned information by the MPLS-TP protocol ping_learned_info - retrieve Ping learned information by the MPLS-TP protocol trace_route_learned_info - retrieve TraceRoute learned information by the MPLS-TP protocol clear_stats - clear stats
			 	-handle
			 		Either MPLS-TP router handle for the gathering of stats/info or a MPLS-TP router interface handle.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                   value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                      value:On status of failure, gives detailed information.
			 key:aggregate_stats                          value:
			 key:<port_handle>.aggregate.port_name        value:
			 key:<port_handle>.aggregate.cccv_configured  value:
			 key:<port_handle>.aggregate.cccv_up          value:
			 key:<port_handle>.aggregate.cccv_down        value:
			 key:<port_handle>.aggregate.cccv_flap_count  value:
			 key:<port_handle>.aggregate.cccv_tx          value:
			 key:<port_handle>.aggregate.cccv_rx          value:
			 key:<port_handle>.aggregate.aps_tx           value:
			 key:<port_handle>.aggregate.aps_rx           value:
			 key:<port_handle>.aggregate.mpls_echo_tx     value:
			 key:<port_handle>.aggregate.mpls_echo_rx     value:
			 key:<port_handle>.aggregate.lm_request_tx    value:
			 key:<port_handle>.aggregate.lm_request_rx    value:
			 key:<port_handle>.aggregate.lm_reply_tx      value:
			 key:<port_handle>.aggregate.lm_reply_rx      value:
			 key:<port_handle>.aggregate.dm_request_tx    value:
			 key:<port_handle>.aggregate.dm_request_rx    value:
			 key:<port_handle>.aggregate.dm_reply_tx      value:
			 key:<port_handle>.aggregate.dm_reply_rx      value:
			 key:<port_handle>.aggregate.alarm_tx         value:
			 key:<port_handle>.aggregate.alarm_rx         value:
			 key:<port_handle>.aggregate.pw_status_tx     value:
			 key:<port_handle>.aggregate.pw_status_rx     value:
			 key:learned_info                             value:
			 key:dm_learned_info                          value:
			 key:lm_learned_info                          value:
			 key:ping_learned_info                        value:
			 key:trace_route_learned_info                 value:
		
		Examples:
		See files starting with MPLSTP_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) This protocol is available only when using IxNetwork Tcl API.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_mplstp_info", kwargs)

	def emulation_mplstp_lsp_pw_config(self, **kwargs):
		""" This command is used to create/modify/delete/enable/disable a MPLS-TP LSP-PW ranges.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_mplstp_lsp_pw_config
			 	[-handle                            ANY]
			 	[-mode                              ANY]
			 	[-alarm_traffic_class               ANY]
			 	[-alarm_type                        ANY]
			 	[-aps_traffic_class                 ANY]
			 	[-aps_type                          ANY]
			 	[-cccv_interval                     ANY]
			 	[-cccv_traffic_class                ANY]
			 	[-cccv_type                         ANY]
			 	[-count                             ANY]
			 	[-description                       ANY]
			 	[-dest_ac_id                        ANY]
			 	[-dest_ac_id_step                   ANY]
			 	[-dest_global_id                    ANY]
			 	[-dest_lsp_number                   ANY]
			 	[-dest_lsp_number_step              ANY]
			 	[-dest_mep_id                       ANY]
			 	[-dest_mep_id_step                  ANY]
			 	[-dest_node_id                      ANY]
			 	[-dest_tunnel_number                ANY]
			 	[-dest_tunnel_number_step           ANY]
			 	[-dm_time_format                    ANY]
			 	[-dm_traffic_class                  ANY]
			 	[-dm_type                           ANY]
			 	[-ip_address                        ANY]
			 	[-ip_address_mask_len               ANY]
			 	[-ip_address_step                   ANY]
			 	[-ip_host_per_lsp                   ANY]
			 	[-ip_type                           ANY]
			 	[-lm_counter_type                   ANY]
			 	[-lm_initial_rx_value               ANY]
			 	[-lm_initial_tx_value               ANY]
			 	[-lm_rx_step                        ANY]
			 	[-lm_traffic_class                  ANY]
			 	[-lm_tx_step                        ANY]
			 	[-lm_type                           ANY]
			 	[-lsp_count                         ANY]
			 	[-lsp_incoming_label                ANY]
			 	[-lsp_incoming_label_step           ANY]
			 	[-lsp_outgoing_label                ANY]
			 	[-lsp_outgoing_label_step           ANY]
			 	[-mac_address                       ANY]
			 	[-mac_per_pw                        ANY]
			 	[-meg_id_integer_step               ANY]
			 	[-meg_id_prefix                     ANY]
			 	[-meg_level                         ANY]
			 	[-no_write                          ANY]
			 	[-on_demand_cv_traffic_class        ANY]
			 	[-peer_lsp_pw_range                 ANY]
			 	[-peer_nested_lsp_pw_range          ANY]
			 	[-protection_switching_type         ANY]
			 	[-pw_incoming_label                 ANY]
			 	[-pw_incoming_label_step            ANY]
			 	[-pw_incoming_label_step_across_lsp ANY]
			 	[-pw_outgoing_label                 ANY]
			 	[-pw_outgoing_label_step            ANY]
			 	[-pw_outgoing_label_step_across_lsp ANY]
			 	[-pw_per_lsp_count                  ANY]
			 	[-pw_status_fault_reply_interval    ANY]
			 	[-pw_status_traffic_class           ANY]
			 	[-range_role                        ANY]
			 	[-range_type                        ANY]
			 	[-repeat_mac                        ANY]
			 	[-skip_zero_vlan_id                 ANY]
			 	[-src_ac_id                         ANY]
			 	[-src_ac_id_step                    ANY]
			 	[-src_global_id                     ANY]
			 	[-src_lsp_number                    ANY]
			 	[-src_lsp_number_step               ANY]
			 	[-src_mep_id                        ANY]
			 	[-src_mep_id_step                   ANY]
			 	[-src_node_id                       ANY]
			 	[-src_tunnel_number                 ANY]
			 	[-src_tunnel_number_step            ANY]
			 	[-support_slow_start                ANY]
			 	[-vlan_count                        ANY]
			 	[-vlan_id                           ANY]
			 	[-vlan_increment_mode               ANY]
			 	[-vlan_priority                     ANY]
			 	[-vlan_tp_id                        ANY]
		
		Arguments:
			 	-handle
			 		When mode is create, this must be a MPLS-TP interface handle. For any other mode, this must be a LSP-PW range handle.APIs: IxN.
			 	-mode
			 		Action to perform. This parameter is supported using the following APIs: IxN.create - Create new MPLS-TP LSP-PW range. modify- Modify MPLS-TP LSP-PW range. enable- Enable MPLS-TP LSP-PW range. disable - Disable MPLS-TP LSP-PW range. delete- Remove MPLS-TP LSP-PW range. APIs: IxN.
			 	-alarm_traffic_class
			 		Configures the alarm traffic class. Ranges from class 0 to 7. APIs: IxN.
			 	-alarm_type
			 		Configures the alarm type.APIs: IxN.
			 	-aps_traffic_class
			 		Configures the APS traffic class. Ranges from class 0 to 7. APIs: IxN.
			 	-aps_type
			 		Configures the APS type.APIs: IxN.
			 	-cccv_interval
			 		Configures the CCCV interval. Measured in milliseconds. APIs: IxN.
			 	-cccv_traffic_class
			 		Configures CCCV traffic class. Ranges from class 0 to 7. APIs: IxN.
			 	-cccv_type
			 		Configures CCCV type.APIs: IxN.
			 	-count
			 		Number of LSP-PW ranges to be created. If greater than 1, all LSP-PW parameters must be lists of length "-count" APIs: IxN.
			 	-description
			 		Configures the LSP-PW description. APIs: IxN.
			 	-dest_ac_id
			 		Configures the destination AC ID. APIs: IxN.
			 	-dest_ac_id_step
			 		Configures the destination AC ID Step. APIs: IxN.
			 	-dest_global_id
			 		Configures the destination Global ID. APIs: IxN.
			 	-dest_lsp_number
			 		Configures the destination LSP number. APIs: IxN.
			 	-dest_lsp_number_step
			 		Configures the destination LSP number step. APIs: IxN.
			 	-dest_mep_id
			 		Configures the destination MEP ID. APIs: IxN.
			 	-dest_mep_id_step
			 		Configures the destination MEP ID Step. APIs: IxN.
			 	-dest_node_id
			 		Configures the destination Node ID. APIs: IxN.
			 	-dest_tunnel_number
			 		Configures the destination Tunnel number. APIs: IxN.
			 	-dest_tunnel_number_step
			 		Configures the destination Tunnel number step. APIs: IxN.
			 	-dm_time_format
			 		Configures the DM time format.APIs: IxN.
			 	-dm_traffic_class
			 		Configures the DM traffic class. Ranges from class 0 to 7. APIs: IxN.
			 	-dm_type
			 		Configures the DM type. APIs: IxN.
			 	-ip_address
			 		Configures the start IP address for LSP ranges. APIs: IxN.
			 	-ip_address_mask_len
			 		Configures the IP address mask length for LSP ranges. APIs: IxN.
			 	-ip_address_step
			 		Configures the IP address step for LSP ranges. APIs: IxN.
			 	-ip_host_per_lsp
			 		Configures how many IPs to have per LSP. APIs: IxN.
			 	-ip_type
			 		Configures the IP type. APIs: IxN.
			 	-lm_counter_type
			 		Configures the LM counter type. APIs: IxN.
			 	-lm_initial_rx_value
			 		Configures the LM initial RX value. APIs: IxN.
			 	-lm_initial_tx_value
			 		Configures the LM initial TX value. APIs: IxN.
			 	-lm_rx_step
			 		Configures the LM RX Step. APIs: IxN.
			 	-lm_traffic_class
			 		Configures the LM traffic class. Ranges from class 0 to 7. APIs: IxN.
			 	-lm_tx_step
			 		Configures the LM TX Step. APIs: IxN.
			 	-lm_type
			 		Configures the LM Type. APIs: IxN.
			 	-lsp_count
			 		Configures the number of LSPs per range. APIs: IxN.
			 	-lsp_incoming_label
			 		Configures the LSP incoming label. APIs: IxN.
			 	-lsp_incoming_label_step
			 		Configures the LSP incoming label step. APIs: IxN.
			 	-lsp_outgoing_label
			 		Configures the LSP outgoing label. APIs: IxN.
			 	-lsp_outgoing_label_step
			 		Configures the LSP outgoing label step. APIs: IxN.
			 	-mac_address
			 		Configures the starting MAC address for PW ranges. APIs: IxN.
			 	-mac_per_pw
			 		Configures the number of MACs per PW. APIs: IxN.
			 	-meg_id_integer_step
			 		Configures the MEG ID Integer Step. APIs: IxN.
			 	-meg_id_prefix
			 		Configures MEG ID Prefix. APIs: IxN. (DEFAULT = Ixia-0001)
			 	-meg_level
			 		Configured MEG level. APIs: IxN.
			 	-no_write
			 		If this option is present, the configuration is not written to the hardware. This option can be used to queue up multiple configurations before writing to the hardware. APIs: IxN.
			 	-on_demand_cv_traffic_class
			 		Configures the On-Demand CV traffic class. Ranges from class 0 to 7. APIs: IxN.
			 	-peer_lsp_pw_range
			 		Configures the LSP-PW range peer. Valid for role working. The peer range role must be protect. APIs: IxN.
			 	-peer_nested_lsp_pw_range
			 		Configures the nested LSP-PW range peer. Valid for range type nested.APIs: IxN.
			 	-protection_switching_type
			 		Configures the protection switch type. APIs: IxN. (DEFAULT one_to_one_bidir)
			 	-pw_incoming_label
			 		Configures the PW incoming label. APIs: IxN.
			 	-pw_incoming_label_step
			 		Configures the PW incoming label step. APIs: IxN.
			 	-pw_incoming_label_step_across_lsp
			 		Configures the PW incoming label step across LSPs. APIs: IxN.
			 	-pw_outgoing_label
			 		Configures the PW outgoing label. APIs: IxN.
			 	-pw_outgoing_label_step
			 		Configures the PW outgoing label step. APIs: IxN.
			 	-pw_outgoing_label_step_across_lsp
			 		Configures the PW outgoing label step across LSPs. APIs: IxN.
			 	-pw_per_lsp_count
			 		Configures the number of PWs per LSP. APIs: IxN.
			 	-pw_status_fault_reply_interval
			 		Configures the PW status fault reply interval. APIs: IxN.
			 	-pw_status_traffic_class
			 		Configures the PW status traffic class. Ranges from class 0 to 7. APIs: IxN.
			 	-range_role
			 		Configures the LSP-PW range role. APIs: IxN.
			 	-range_type
			 		Configures the range type. APIs: IxN.
			 	-repeat_mac
			 		If set to 1, the MAC address will be repeated for PW ranges. APIs: IxN.
			 	-skip_zero_vlan_id
			 		If set to 1, the 0 VLAN will be skipped for PW ranges. APIs: IxN.
			 	-src_ac_id
			 		configures the source AC ID. APIs: IxN.
			 	-src_ac_id_step
			 		Configures the source AC ID Step. APIs: IxN.
			 	-src_global_id
			 		Configures the source Global ID. APIs: IxN.
			 	-src_lsp_number
			 		Configures the source LSP Number. APIs: IxN.
			 	-src_lsp_number_step
			 		Configures the source LSP Number Step. APIs: IxN.
			 	-src_mep_id
			 		Configures the source MEP ID. APIs: IxN.
			 	-src_mep_id_step
			 		Configures the source MEP ID Step. APIs: IxN.
			 	-src_node_id
			 		Configures the source Node ID. APIs: IxN.
			 	-src_tunnel_number
			 		Configures the source Tunnel number. APIs: IxN.
			 	-src_tunnel_number_step
			 		Configures the source Tunnel number step. APIs: IxN.
			 	-support_slow_start
			 		If set to 1, the CCCV will support slow start. Valid for CCCV type bfdcc. APIs: IxN.
			 	-vlan_count
			 		Configures the number of MAC VLANs. APIs: IxN.
			 	-vlan_id
			 		Configures the MAC VLAN IDs.For vlan_count > 1, is a list of form "x,y,z"APIs: IxN.
			 	-vlan_increment_mode
			 		Configures the MAC VLAN IDs increment mode. APIs: IxN.
			 	-vlan_priority
			 		Configures the MAC VLANs priority. Ranges from class 0 to 7. For vlan_count > 1, is a list of form "x,y,z"APIs: IxN.
			 	-vlan_tp_id
			 		Configures the MAC VLANs tunneling protocol ID. For vlan_count > 1, is a list of form "x,y,z"APIs: IxN.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status             value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                value:On status of failure, gives detailed information.
		On mode create, the interface that was passed as -handle. On modes modify/enable/disable, the interface affected.
			 key:interface_handle   value:On mode create, the interface that was passed as -handle. On modes modify/enable/disable, the interface affected.
		On mode create, the a list of the created LSP-PW ranges. On modes modify/enable/disable, the range affected.
			 key:range_handle_list  value:On mode create, the a list of the created LSP-PW ranges. On modes modify/enable/disable, the range affected.
		
		Examples:
		See files starting with MPLSTP_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) This protocol is available only when using IxNetwork Tcl API.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_mplstp_lsp_pw_config", kwargs)

	def emulation_msrp_control(self, **kwargs):
		""" Control Operation on the MSRP Talker and Listener    The following operations are done:    1. Start    2. Stop    3. Restart    4. Restart Down    6. Abort
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_msrp_control
			 	-mode    CHOICES restart
			          CHOICES start
			          CHOICES restart_down
			          CHOICES stop
			          CHOICES abort]
			 	[-handle ANY]
		
		Arguments:
			 	-mode
			 		What is being done to the protocol.Valid choices are:
			 		restart - Restart the protocol.
			 		start- Start the protocol.
			 		stop- Stop the protocol.
			 		restart_down- Restart the down sessions.
			 		abort- Abort the protocol.
			 		Valid choices are:
			    		restart - Restart the protocol.
			    		start - Start the protocol.
			    		restart_down - restart the down sessions
			    		stop - Stop the protocol.
			    		abort - Abort.
			 	-handle
			 		MSRP Talker or msrp listener handle where the msrp control action is applied.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_msrp_control", kwargs)

	def emulation_msrp_info(self, **kwargs):
		""" Retrieves information about the MSRP Talker/Listener protocol.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_msrp_info
			x	-mode         CHOICES stats
			x              CHOICES clear_stats
			x              CHOICES learned_database
			x              CHOICES clear_learned_database]
			 	[-handle      ANY]
			 	[-port_handle REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
		
		Arguments:
			x	-mode
			x   		stats - Gather MSRP Talker/Listener statistics.
			x   		clear_stats - Clear MSRP Talker/Listener statistics.
			x   		learned_database - Get Talker/Listener Learned Database
			x   		clear_learned_database - Clear Talker/Listener Learned Database
			 	-handle
			 	-port_handle
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                       value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                                                          value:If status is failure, detailed information provided.
		Sessions Up
			xkey:sessions_up                                                  value:Sessions Up
		Sessions Down
			xkey:sessions_down                                                value:Sessions Down
		Sessions Total
			xkey:sessions_total                                               value:Sessions Total
			xkey:msrp_packet_tx                                               value:
		Sessions Not Started
			xkey:sessions_not_started                                         value:Sessions Not Started
			xkey:msrp_packet_tx                                               value:
			xkey:msrp_packet_rx                                               value:
			xkey:msrp_listener_tx                                             value:
			xkey:msrp_talker_advertisement_rx                                 value:
			xkey:msrp_talker_failed_rx                                        value:
			xkey:msrp_listener_ready_tx                                       value:
			xkey:msrp_listener_ready_failed_tx                                value:
			xkey:msrp_listener_asking_failed_tx                               value:
			xkey:msrp_domain_tx                                               value:
			xkey:msrp_domain_rx                                               value:
			xkey:mvrp_packet_tx                                               value:
			xkey:mvrp_packet_rx                                               value:
			xkey:msrp_listener_new_tx                                         value:
			xkey:msrp_talker_advertisement_new_rx                             value:
			xkey:msrp_talker_advertisement_mt_tx                              value:
			xkey:msrp_listener_mt_tx                                          value:
			xkey:msrp_listener_joinmt_tx                                      value:
			xkey:msrp_talker_advertisement_joinmt_rx                          value:
			xkey:msrp_listener_joinin_tx                                      value:
			xkey:msrp_talker_advertisement_joinin_rx                          value:
			xkey:msrp_listener_lv_tx                                          value:
			xkey:msrp_talker_advertisement_lv_rx                              value:
			xkey:msrp_listener_in_tx                                          value:
			xkey:msrp_talker_advertisement_in_rx                              value:
			xkey:msrp_malformed_packet_rx                                     value:
			xkey:msrp_malformed_domain_rx                                     value:
			xkey:msrp_malformed_talker_advertisement_rx                       value:
			xkey:msrp_malformed_talker_failed_rx                              value:
			xkey:msrp_talker_failed_new_rx                                    value:
			xkey:msrp_talker_failed_mt_rx                                     value:
			xkey:msrp_talker_failed_joinmt_rx                                 value:
			xkey:msrp_talker_failed_joinin_rx                                 value:
			xkey:msrp_talker_failed_lv_rx                                     value:
			xkey:msrp_talker_failed_in_rx                                     value:
			xkey:msrp_listener_rx                                             value:
			xkey:msrp_talker_advertisement_tx                                 value:
			xkey:msrp_listener_ready_rx                                       value:
			xkey:msrp_listener_ready_failed_rx                                value:
			xkey:msrp_listener_asking_failed_rx                               value:
			xkey:msrp_listener_new_rx                                         value:
			xkey:msrp_talker_advertisement_new_tx                             value:
			xkey:msrp_listener_mt_rx                                          value:
			xkey:msrp_listener_joinmt_rx                                      value:
			xkey:msrp_talker_advertisement_joinmt_tx                          value:
			xkey:msrp_listener_joinin_rx                                      value:
			xkey:msrp_talker_advertisement_joinin_tx                          value:
			xkey:msrp_listener_lv_rx                                          value:
			xkey:msrp_talker_advertisement_lv_tx                              value:
			xkey:msrp_listener_in_rx                                          value:
			xkey:msrp_talker_advertisement_in_tx                              value:
			xkey:msrp_malformed_listener_rx                                   value:
			xkey:mvrp_malformed_packet_rx                                     value:
			xkey:<handle>.talker_stream_database.attribute_type               value:
			xkey:<handle>.talker_stream_database.stream_id                    value:
			xkey:<handle>.talker_stream_database.destination_mac              value:
			xkey:<handle>.talker_stream_database.vlan_id                      value:
			xkey:<handle>.talker_stream_database.max_frame_size               value:
			xkey:<handle>.talker_stream_database.max_interval_frame           value:
			xkey:<handle>.talker_stream_database.priority                     value:
			xkey:<handle>.talker_stream_database.rank                         value:
			xkey:<handle>.talker_stream_database.latency                      value:
			xkey:<handle>.talker_stream_database.declaration_type             value:
			xkey:<handle>.talker_stream_database.applicant_state              value:
			xkey:<handle>.talker_stream_database.registrar_state              value:
			xkey:<handle>.talker_stream_database.source_mac                   value:
			xkey:<handle>.talker_stream_database.talker_advertise_tx          value:
			xkey:<handle>.talker_stream_database.talker_joint_mt_tx           value:
			xkey:<handle>.talker_stream_database.talker_joinin_tx             value:
			xkey:<handle>.talker_stream_database.talker_new_tx                value:
			xkey:<handle>.talker_stream_database.talker_mt_tx                 value:
			xkey:<handle>.talker_stream_database.talker_lv_tx                 value:
			xkey:<handle>.talker_stream_database.listener_advertise_rx        value:
			xkey:<handle>.talker_stream_database.listener_ready_rx            value:
			xkey:<handle>.talker_stream_database.listener_ready_failed_rx     value:
			xkey:<handle>.talker_stream_database.listener_asking_failed_rx    value:
			xkey:<handle>.talker_stream_database.listener_new_rx              value:
			xkey:<handle>.talker_stream_database.listener_joinmt_rx           value:
			xkey:<handle>.talker_stream_database.listener_joinin_rx           value:
			xkey:<handle>.talker_stream_database.listener_in_rx               value:
			xkey:<handle>.talker_stream_database.listener_lv_rx               value:
			xkey:<handle>.talker_stream_database.listener_mt_rx               value:
			xkey:<handle>.talker_domain_database.sr_class_id                  value:
			xkey:<handle>.talker_domain_database.sr_class_priority            value:
			xkey:<handle>.talker_domain_database.sr_class_vid                 value:
			xkey:<handle>.talker_domain_database.applicant_state              value:
			xkey:<handle>.talker_domain_database.registrar_state              value:
			xkey:<handle>.talker_domain_database.domain_tx                    value:
			xkey:<handle>.talker_domain_database.domain_rx                    value:
			xkey:<handle>.talker_domain_database.source_mac                   value:
			xkey:<handle>.talker_vlan_database.vlan_id                        value:
			xkey:<handle>.talker_vlan_database.applicant_state                value:
			xkey:<handle>.talker_vlan_database.registrar_state                value:
			xkey:<handle>.talker_vlan_database.source_mac                     value:
			xkey:<handle>.listener_stream_database.attribute_type             value:
			xkey:<handle>.listener_stream_database.stream_id                  value:
			xkey:<handle>.listener_stream_database.destination_mac            value:
			xkey:<handle>.listener_stream_database.vlan_id                    value:
			xkey:<handle>.listener_stream_database.max_frame_size             value:
			xkey:<handle>.listener_stream_database.max_interval_frame         value:
			xkey:<handle>.listener_stream_database.priority                   value:
			xkey:<handle>.listener_stream_database.rank                       value:
			xkey:<handle>.listener_stream_database.latency                    value:
			xkey:<handle>.listener_stream_database.declaration_type           value:
			xkey:<handle>.listener_stream_database.applicant_state            value:
			xkey:<handle>.listener_stream_database.registrar_state            value:
			xkey:<handle>.listener_stream_database.source_mac                 value:
			xkey:<handle>.listener_stream_database.error_code                 value:
			xkey:<handle>.listener_stream_database.bridge_id                  value:
			xkey:<handle>.listener_stream_database.talker_advertise_rx        value:
			xkey:<handle>.listener_stream_database.talker_failed_rx           value:
			xkey:<handle>.listener_stream_database.talker_joint_mt_rx         value:
			xkey:<handle>.listener_stream_database.talker_joinin_rx           value:
			xkey:<handle>.listener_stream_database.talker_in_rx               value:
			xkey:<handle>.listener_stream_database.talker_new_rx              value:
			xkey:<handle>.listener_stream_database.talker_mt_rx               value:
			xkey:<handle>.listener_stream_database.talker_lv_rx               value:
			xkey:<handle>.listener_stream_database.talker_failed_new_rx       value:
			xkey:<handle>.listener_stream_database.talker_failed_joinmt_rx    value:
			xkey:<handle>.listener_stream_database.talker_failed_joinin_rx    value:
			xkey:<handle>.listener_stream_database.talker_failed_in_rx        value:
			xkey:<handle>.listener_stream_database.talker_failed_lv_rx        value:
			xkey:<handle>.listener_stream_database.talker_failed_mt_rx        value:
			xkey:<handle>.listener_stream_database.listener_advertise_tx      value:
			xkey:<handle>.listener_stream_database.listener_ready_tx          value:
			xkey:<handle>.listener_stream_database.listener_ready_failed_tx   value:
			xkey:<handle>.listener_stream_database.listener_asking_failed_tx  value:
			xkey:<handle>.listener_stream_database.listener_new_tx            value:
			xkey:<handle>.listener_stream_database.listener_joinmt_tx         value:
			xkey:<handle>.listener_stream_database.listener_joinin_tx         value:
			xkey:<handle>.listener_stream_database.listener_in_tx             value:
			xkey:<handle>.listener_stream_database.listener_lv_tx             value:
			xkey:<handle>.listener_stream_database.listener_mt_tx             value:
			xkey:<handle>.listener_domain_database.sr_class_id                value:
			xkey:<handle>.listener_domain_database.sr_class_priority          value:
			xkey:<handle>.listener_domain_database.sr_class_vid               value:
			xkey:<handle>.listener_domain_database.sr_class_priority          value:
			xkey:<handle>.listener_domain_database.applicant_state            value:
			xkey:<handle>.listener_domain_database.registrar_state            value:
			xkey:<handle>.listener_domain_database.domain_tx                  value:
			xkey:<handle>.listener_domain_database.domain_rx                  value:
			xkey:<handle>.listener_domain_database.source_mac                 value:
			xkey:<handle>.listener_vlan_database.vlan_id                      value:
			xkey:<handle>.listener_vlan_database.applicant_state              value:
			xkey:<handle>.listener_vlan_database.registrar_state              value:
			xkey:<handle>.listener_vlan_database.source_mac                   value:
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_msrp_info", kwargs)

	def emulation_msrp_listener_config(self, **kwargs):
		""" This procedure will configure MSRP Listener
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_msrp_listener_config
			 	-mode                      CHOICES create
			                            CHOICES delete
			                            CHOICES modify
			                            CHOICES enable
			                            CHOICES disable]
			 	[-port_handle              REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle                   ANY]
			 	[-mac_address_init         MAC]
			x	[-mac_address_step         MAC
			x                           DEFAULT 0000.0000.0001]
			x	[-vlan                     CHOICES 0 1]
			 	[-vlan_id                  RANGE 0-4095]
			 	[-vlan_id_mode             CHOICES fixed increment
			                            DEFAULT increment]
			 	[-vlan_id_step             RANGE 0-4096
			                            DEFAULT 1]
			 	[-vlan_user_priority       RANGE 0-7
			                            DEFAULT 0]
			 	[-count                    ANY
			                            DEFAULT 1]
			x	[-reset                    FLAG]
			x	[-msrp_Listener_active     CHOICES 0 1]
			x	[-start_vlan_id            RANGE 1-4094
			x                           DEFAULT 2]
			x	[-vlan_count               RANGE 1-4094
			x                           DEFAULT 1]
			x	[-protocol_version         HEX]
			x	[-join_timer               RANGE 200-100000000
			x                           DEFAULT 200]
			x	[-leave_timer              RANGE 600-100000000
			x                           DEFAULT 600]
			x	[-leave_all_timer          RANGE 10000-100000000
			x                           DEFAULT 10000]
			x	[-declare_unsolicited_vlan CHOICES 0 1
			x                           DEFAULT 0]
			x	[-advertise_as             CHOICES joinmt new
			x                           DEFAULT new]
			x	[-subscribe_all            CHOICES 0 1
			x                           DEFAULT 0]
			x	[-domain_count             RANGE 1-2
			x                           DEFAULT 1]
			x	[-subscribed_stream_count  RANGE 1-65535
			x                           DEFAULT 1]
			x	[-sr_class_id              RANGE 0-255
			x                           DEFAULT 6]
			x	[-sr_class_priority_type   RANGE 0-7
			x                           DEFAULT 3]
			x	[-sr_class_vid             RANGE 1-4094
			x                           DEFAULT 2]
			x	[-domain_active            CHOICES 0 1]
			x	[-subscribed_stream_active CHOICES 0 1]
			x	[-stream_id                HEX]
		
		Arguments:
			 	-mode
			    		create -
			    		delete -
			    		modity -
			    		enable -
			    		disable -
			 	-port_handle
			 	-handle
			 		MSRP Listener protocol Handle
			 	-mac_address_init
			 		This option defines the MAC address that will be configured on
			 		the Ixia interface.If is -count > 1, this MAC address will
			 		increment by default by step of 1, or you can specify another step by
			 		using mac_address_step option.
			x	-mac_address_step
			x		This option defines the incrementing step for the MAC address that
			x		will be configured on the Ixia interface. Valid only when
			x		IxNetwork Tcl API is used.
			x	-vlan
			x		Enables vlan on the directly connected ISIS router interface.
			x		Valid options are: 0 - disable, 1 - enable.
			x		This option is valid only when -mode is create or -mode is modify
			x		and -handle is an ISIS router handle.
			 	-vlan_id
			 		If VLAN is enabled on the Ixia interface, this option will configure
			 		the VLAN number.
			 	-vlan_id_mode
			 		If the user configures more than one interface on the Ixia with
			 		VLAN, he can choose to automatically increment the VLAN tag
			 		(increment)or leave it idle for each interface (fixed).
			 		Valid choices are:
			    		fixed -
			    		increment -
			 	-vlan_id_step
			 		If the -vlan_id_mode is increment, this will be the step value by
			 		which the VLAN tags are incremented.
			 		When vlan_id_step causes the vlan_id value to exceed it's maximum value the
			 		increment will be done modulo <number of possible vlan ids>.
			 		Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0
			 		vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			 	-vlan_user_priority
			 		VLAN user priority assigned to emulated router node.
			 	-count
			 		The number of Talkers to configure on the targeted Ixia
			 		interface.The range is 0-1000.
			x	-reset
			x		If this option is selected, this will clear any MSRP Talker on
			x		the targeted interface.
			x	-msrp_Listener_active
			x		MSRP Active.
			x	-start_vlan_id
			x		2 byte VLAN ID This field will be editable when Eanble UnSol VLAN membership is enabled. Range is 1 through 4094
			x	-vlan_count
			x		2 bytes field. Default is 1. This field will be editable when Enable UnSol VLAN membership is enabled
			x		If true then all stream requests will be accepted and ready message will be sent.In this case withdraw/advertisement will be done from learned info trigger. If false then stream request will be accepted based on the srp stream IDs configured.
			x	-protocol_version
			x		Administrator Group
			x	-join_timer
			x		The Join Period Timer controls the interval, in milliseconds, between transmit opportunities that are applied to the Applicant state machine. Minimum is 200 ms and Maximum is 100000000 ms
			x	-leave_timer
			x		The leave timer controls the period of time, in milliseconds, that the Registrar state machine will wait in the LV state before transiting to the MT state. Default is 600 ms. Min is 600 ms and Max is 100000000 ms. The leave time should be at least twice the join time to allow re-registration after a leave or leave-all message, even if a message is lost.
			x	-leave_all_timer
			x		Controls the frequency, in milliseconds, with which the LeaveAll state machine generates Leave All PDUs. Default is 10000 ms. Minimum value is 10000 ms and Maximum value is 100000000 ms. To minimize the volume of re-joining traffic generated following a leaveall message, the leaveall time should be larger than the leave time.
			x	-declare_unsolicited_vlan
			x		This is used to advertise vlan membership prior to advertising listener advertisement. Required vlans information will be obtained from Start VLAN ID and VLAN Count fields.
			x	-advertise_as
			x		Advertise As
			x		Valid choices are:
			x   		joinmt - joinmt.
			x   		new - (default) new
			x	-subscribe_all
			x		subscribe All
			x	-domain_count
			x		Number of domains to be configured under a listener. Min value is 1 and max value is 2. Default value is 1.
			x	-subscribed_stream_count
			x		subscribed Stream Count
			x	-sr_class_id
			x		One byte field. It will be drop down list of {Class A(6), Class B(5)}. Default is Class A(6). Note: User will not see number. User will see only Class A/B.. RANGE 0-255
			x	-sr_class_priority_type
			x		one byte field. It will be drop down list of {Class A(3), Class B(2)}. Default is Class A(3). Note: User will not see number. User will see only Class A/B.. RANGE 0-7
			x	-sr_class_vid
			x		2 bytes field. Value will be in the range {1, 4094}. Default is 2
			x	-domain_active
			x		Domain Active.
			x	-subscribed_stream_active
			x		MSRP Subscribed Streams Active.
			x	-stream_id
			x		MSRP Stream ID
		
		Return Values:
		A list containing the ethernet protocol stack handles that were added by the command (if any).
			xkey:ethernet_handle                          value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:msrp_listener_handles                    value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:msrp_listener_domain_handles             value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:msrp_listener_subscribed_stream_handles  value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		$::SUCCESS | $::FAILURE
			 key:status                                   value:$::SUCCESS | $::FAILURE
		When status is $::FAILURE, contains more information
			 key:log                                      value:When status is $::FAILURE, contains more information
		Handle of MSRP Listener configured
			 key:msrp_listener_handle                     value:Handle of MSRP Listener configured
		Handle of MSRP Listener domain configured
			 key:msrp_listener_domain_handle              value:Handle of MSRP Listener domain configured
		Handle of MSRP Listener streams configured
			 key:msrp_listener_subscribed_stream_handle   value:Handle of MSRP Listener streams configured
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  msrp_listener_handles, msrp_listener_domain_handles, msrp_listener_subscribed_stream_handles
		
		See Also:
		
		"""
		return self._run_keyword("emulation_msrp_listener_config", kwargs)

	def emulation_msrp_talker_config(self, **kwargs):
		""" This procedure will configure MSRP Talker
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_msrp_talker_config
			 	-mode                        CHOICES create
			                              CHOICES delete
			                              CHOICES modify
			                              CHOICES enable
			                              CHOICES disable]
			 	[-port_handle                REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle                     ANY]
			 	[-mac_address_init           MAC]
			x	[-mac_address_step           MAC
			x                             DEFAULT 0000.0000.0001]
			x	[-vlan                       CHOICES 0 1]
			 	[-vlan_id                    RANGE 0-4095]
			 	[-vlan_id_mode               CHOICES fixed increment
			                              DEFAULT increment]
			 	[-vlan_id_step               RANGE 0-4096
			                              DEFAULT 1]
			 	[-vlan_user_priority         RANGE 0-7
			                              DEFAULT 0]
			 	[-count                      ANY
			                              DEFAULT 1]
			x	[-reset                      FLAG]
			x	[-msrp_talker_active         CHOICES 0 1]
			x	[-stream_active              CHOICES 0 1]
			x	[-source_mac                 MAC
			x                             DEFAULT 0011.0100.0001]
			x	[-unique_id                  RANGE 1-65535
			x                             DEFAULT 1]
			x	[-stream_name                REGEXP ^[0-9,a-f,A-F]+$]
			x	[-destination_mac            MAC
			x                             DEFAULT 91E0.F000.FE00]
			x	[-stream_vlan_id             RANGE 1-4094
			x                             DEFAULT 2]
			x	[-max_frame_size             RANGE 1-65535
			x                             DEFAULT 100]
			x	[-max_interval_frames        RANGE 1-65535
			x                             DEFAULT 1]
			x	[-per_frame_overhead         RANGE 0-65535
			x                             DEFAULT 42]
			x	[-class_measurement_interval RANGE 0-4294967295
			x                             DEFAULT 125]
			x	[-data_frame_priority        RANGE 0-7
			x                             DEFAULT 3]
			x	[-rank                       CHOICES emergency nonemergency
			x                             DEFAULT nonemergency]
			x	[-port_tc_max_latency        RANGE 1-4294967295
			x                             DEFAULT 20]
			x	[-protocol_version           HEX]
			x	[-join_timer                 RANGE 200-100000000
			x                             DEFAULT 200]
			x	[-leave_timer                RANGE 600-100000000
			x                             DEFAULT 600]
			x	[-leave_all_timer            RANGE 10000-100000000
			x                             DEFAULT 10000]
			x	[-advertise_vlan_membership  CHOICES 0 1
			x                             DEFAULT 1]
			x	[-advertise_as               CHOICES joinmt new
			x                             DEFAULT new]
			x	[-domain_count               RANGE 1-2
			x                             DEFAULT 1]
			x	[-stream_count               RANGE 0-1024000
			x                             DEFAULT 1]
			x	[-sr_class_id                RANGE 0-255
			x                             DEFAULT 6]
			x	[-sr_class_priority_type     RANGE 0-7
			x                             DEFAULT 3]
			x	[-sr_class_vid               RANGE 1-4094
			x                             DEFAULT 2]
			x	[-domain_active              CHOICES 0 1]
		
		Arguments:
			 	-mode
			    		create -
			    		delete -
			    		modity -
			    		enable -
			    		disable -
			 	-port_handle
			 	-handle
			 		Specifies the parent node/object handle on which the talker configuration should be configured.
			 		In case modesmodify/delete/disable/enablethis denotes the object node handle on which the action needs to be performed. The handle value syntax is dependent on the vendor.
			 	-mac_address_init
			 		This option defines the MAC address that will be configured on
			 		the Ixia interface.If is -count > 1, this MAC address will
			 		increment by default by step of 1, or you can specify another step by
			 		using mac_address_step option.
			x	-mac_address_step
			x		This option defines the incrementing step for the MAC address that
			x		will be configured on the Ixia interface. Valid only when
			x		IxNetwork Tcl API is used.
			x	-vlan
			x		Enables vlan on the directly connected ISIS router interface.
			x		Valid options are: 0 - disable, 1 - enable.
			x		This option is valid only when -mode is create or -mode is modify
			x		and -handle is an ISIS router handle.
			 	-vlan_id
			 		If VLAN is enabled on the Ixia interface, this option will configure
			 		the VLAN number.
			 	-vlan_id_mode
			 		If the user configures more than one interface on the Ixia with
			 		VLAN, he can choose to automatically increment the VLAN tag
			 		(increment)or leave it idle for each interface (fixed).
			 		Valid choices are:
			    		fixed -
			    		increment -
			 	-vlan_id_step
			 		If the -vlan_id_mode is increment, this will be the step value by
			 		which the VLAN tags are incremented.
			 		When vlan_id_step causes the vlan_id value to exceed it's maximum value the
			 		increment will be done modulo <number of possible vlan ids>.
			 		Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0
			 		vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			 	-vlan_user_priority
			 		VLAN user priority assigned to emulated router node.
			 	-count
			 		The number of Talkers to configure on the targeted Ixia
			 		interface.The range is 0-1000.
			x	-reset
			x		If this option is selected, this will clear any MSRP Talker on
			x		the targeted interface.
			x	-msrp_talker_active
			x		MSRP Active.
			x	-stream_active
			x		Stream Active.
			x	-source_mac
			x		This mac address is to be retrieved from own lower Ethernet layer by default. This field is editable by user for negative testing. This field is used for determining the Stream Id
			x	-unique_id
			x		2 bytes unsigned integer. Default value is 1. Min value is 1 and Max value is 65535. For each successive SRP stream ids this value has to be increased by 1 under a talker. This field is used for determining the Stream Id
			x	-stream_name
			x		A user editable name for each stream.
			x	-destination_mac
			x		Multicast/Unicast Destination MAC address. Multicast address Range is 91:E0:F0:00:FE:00 - 91:E0:F0:00:FE:FF. Default is 91:E0:F0:00:FE:00. Unicast address is any valid unicast mac address. Default is Multicast.
			x	-stream_vlan_id
			x		VLAN ID. Range is 1 through 4094. On exceeding the max value subsequent rows will remain on max value.
			x	-max_frame_size
			x		2 bytes unsigned integer. RANGE 1-65535
			x	-max_interval_frames
			x		2 bytes unsigned integer. Min is 1 and Max is 65535
			x	-per_frame_overhead
			x		per Frame Overhead. RANGE 0-65535
			x	-class_measurement_interval
			x		If value of SR Class is Class A then default value of Class Measurement Interval should be 125 micro Seconds. If value of SR Class is Class B then default value of Class Measurement Interval should be 250 us. If value of SR Class is No class associated then default value of Class Measurement Interval should be 0. (This will result to 0 bandwidth, and in a way asking user to key in value for class measurement interval so that bandwidth can be calculated when priorities are not mapped according to IEEE standard ). RANGE 0-4294967295
			x	-data_frame_priority
			x		Data Frame Priority. RANGE 0-7
			x	-rank
			x		Single bit field. Nonemergency traffic shall set this bit to a 1 and emergency traffic shall set it to zero. Default is 1.
			x		Valid choices are:
			x   		emergency - emergency.
			x   		nonemergency - (default) nonemergency
			x	-port_tc_max_latency
			x		Port Tc Max Latency (ns). Range 1-4294967295
			x	-protocol_version
			x		This one-octet field indicates the version supported by the applicant. Default value is 0x00. Maximum value is 0xFF
			x	-join_timer
			x		The Join Period Timer controls the interval, in milliseconds, between transmit opportunities that are applied to the Applicant state machine. Minimum is 200 ms and Maximum is 100000000 ms
			x	-leave_timer
			x		The leave timer controls the period of time, in milliseconds, that the Registrar state machine will wait in the LV state before transiting to the MT state. Default is 600 ms.
			x		Min is 600 ms and Max is 100000000 ms. The leave time should be at least twice the join time to allow re-registration after a leave or leave-all message, even if a message is lost.
			x	-leave_all_timer
			x		Controls the frequency, in milliseconds, with which the LeaveAll state machine generates Leave All PDUs. Default is 10000 ms. Minimum value is 10000 ms and Maximum value is 100000000 ms.
			x		To minimize the volume of re-joining traffic generated following a leaveall message, the leaveall time should be larger than the leave time.
			x	-advertise_vlan_membership
			x		This field denotes that talker will advertise the vlan membership information.
			x	-advertise_as
			x		Advertise As
			x		Valid choices are:
			x   		joinmt - joinmt.
			x   		new - (default) new
			x	-domain_count
			x		Number of domains to be configured under a talker. Min value is 1 and max value is 2.
			x	-stream_count
			x		Number of streams to be configured under a talker. The minimum value is always 1. Talker is always configured with at least 1 Stream. stream_count cannot be zero for a talker.
			x	-sr_class_id
			x		One byte field. It will be drop down list of {Class A(6), Class B(5)}. Default is Class A(6). Note: User will not see number. User will see only Class A/B. RANGE 0-255
			x	-sr_class_priority_type
			x		one byte field. It will be drop down list of {Class A(3), Class B(2)}. Default is Class A(3). Note: User will not see number. User will see only Class A/B.. RANGE 0-7
			x	-sr_class_vid
			x		SR Class VID. RANGE 1-4094
			x	-domain_active
			x		Domain Active.
		
		Return Values:
		A list containing the ethernet protocol stack handles that were added by the command (if any).
			xkey:ethernet_handle             value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:msrp_talker_handles         value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:msrp_stream_handles         value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:msrp_talker_domain_handles  value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		$::SUCCESS | $::FAILURE
			 key:status                      value:$::SUCCESS | $::FAILURE
		When status is $::FAILURE, contains more information
			 key:log                         value:When status is $::FAILURE, contains more information
		Handle of MSRP Talker configured
			 key:msrp_talker_handle          value:Handle of MSRP Talker configured
		Handle of MSRP Talker streams configured
			 key:msrp_stream_handle          value:Handle of MSRP Talker streams configured
		Handle of MSRP Talker Domain configured
			 key:msrp_talker_domain_handle   value:Handle of MSRP Talker Domain configured
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  msrp_talker_handles, msrp_stream_handles, msrp_talker_domain_handles
		
		See Also:
		
		"""
		return self._run_keyword("emulation_msrp_talker_config", kwargs)

	def emulation_multicast_group_config(self, **kwargs):
		""" Configures multicast groups to be used by all multicast emulation tools including PIM, IGMP, and MLD.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_multicast_group_config
			 	[-handle                ANY]
			 	-mode                   CHOICES create delete modify
			 	[-ip_addr_start         IP]
			 	[-ip_addr_step          IP
			                         DEFAULT 0.0.0.1]
			 	[-ip_prefix_len         ANY]
			 	[-num_groups            NUMERIC
			                         DEFAULT 1]
			x	[-active                CHOICES 0 1]
			n	[-multiplier            ANY]
			n	[-iptv_tracking_enabled ANY]
		
		Arguments:
			 	-handle
			 		If the -mode is delete or modify, then this option is required to
			 		specify the existing multicast group pool.
			 	-mode
			 		This option defines the action to be taken.
			 		Valid choices are:
			    		create - Creates a multicast group pool.
			    		delete - Deletes a multicast group pool. Requires the use of -handle.
			    		modify - Modifies a multicast group pool. Requires the use of -handle.
			 	-ip_addr_start
			 		First multicast group address in the group pool.
			 	-ip_addr_step
			 		Used to increment group address.
			 	-ip_prefix_len
			 		Defaults to 32 for IPv4 and 128 for IPv6. For MLD protocol this parameter is ignored.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-num_groups
			 		Number of multicast groups in group pool.
			x	-active
			x		The active state of an individual item from the group pool.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			n	-multiplier
			n	-iptv_tracking_enabled
		
		Return Values:
		   A list containing the multicast group protocol stack handles that were added by the command (if any).
			x   key:multicast_group_handle  value:A list containing the multicast group protocol stack handles that were added by the command (if any).
		   $::SUCCESS | $::FAILURE
			    key:status                  value:$::SUCCESS | $::FAILURE
		   When status is failure, contains more information
			    key:log                     value:When status is failure, contains more information
		   The handle for the multicast group pool created
			    key:handle                  value:The handle for the multicast group pool created
		
		Examples:
		   See the files starting with IGMPv1_, IGMPv2_, IGMPv3_, MLD_, MVPN_, and
		   PIM_ in the Samples subdirectory.
		   See the IGMP, MLD, MVPN, or PIM examples in Appendix A, "Example APIs," for
		   more specific example usage.
		   See the files starting with IGMPv1_, IGMPv2_, IGMPv3_, MLD_, MVPN_, and PIM_ in the Samples subdirectory. See the IGMP, MLD, MVPN, or PIM examples in Appendix A, "Example APIs," for more specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_multicast_group_config", kwargs)

	def emulation_multicast_source_config(self, **kwargs):
		""" Configures multicast sources to be used by all multicast emulation tools including PIM, IGMP, and MLD.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_multicast_source_config
			 	[-handle        ANY]
			 	-mode           CHOICES create delete modify
			 	[-ip_addr_start IP]
			 	[-ip_addr_step  IP
			                 DEFAULT 0.0.0.1]
			 	[-ip_prefix_len ANY]
			 	[-num_sources   NUMERIC
			                 DEFAULT 1]
			x	[-active        CHOICES 0 1]
			n	[-multiplier    ANY]
		
		Arguments:
			 	-handle
			 		If the -mode is delete or modify, then this option is required to
			 		specify the existing multicast source pool.
			 	-mode
			 		This option defines the action to be taken.
			 		Valid choices are:
			    		create - Creates a multicast group pool.
			    		delete - Deletes a multicast group pool, requires the use of -handle.
			    		modify - Modifies a multicast group pool, requires the use of -handle.
			 	-ip_addr_start
			 		First multicast source address in the group pool.
			 	-ip_addr_step
			 		Used to increment source address. For MLD protocol this
			 		parameter is ignored.
			 	-ip_prefix_len
			 		Defaults to 32 for IPv4 and 128 for IPv6. For MLD protocol this parameter is ignored.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-num_sources
			 		Number of multicast sources in source pool.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-active
			x		The active state of an individual item from the group pool.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			n	-multiplier
		
		Return Values:
		A list containing the multicast source protocol stack handles that were added by the command (if any).
			xkey:multicast_source_handle  value:A list containing the multicast source protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE
			 key:status                   value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information
			 key:log                      value:When status is failure, contains more information
		The handle for the multicast source pool created
			 key:handle                   value:The handle for the multicast source pool created
		
		Examples:
		See the files starting with IGMPv1_, IGMPv2_, IGMPv3_, MLD_, MVPN_, and
		PIM_ in the Samples subdirectory.
		See the IGMP, MLD, MVPN, or PIM examples in Appendix A, "Example APIs," for
		more specific example usage.
		See the files starting with IGMPv1_, IGMPv2_, IGMPv3_, MLD_, MVPN_, and PIM_ in the Samples subdirectory. See the IGMP, MLD, MVPN, or PIM examples in Appendix A, "Example APIs," for more specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_multicast_source_config", kwargs)

	def emulation_netconf_client_config(self, **kwargs):
		""" This procedure will add and configure Netconf Client to a particular Ixia Interface.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_netconf_client_config
			 	-mode                                   CHOICES create
			                                         CHOICES delete
			                                         CHOICES modify
			                                         CHOICES enable
			                                         CHOICES disable]
			 	[-port_handle                           REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle                                ANY]
			x	[-netconf_client_active                 ANY]
			x	[-netconf_client_name                   ALPHA]
			x	[-multiplier                            NUMERIC]
			x	[-server_ipv4_address                   ANY]
			x	[-server_ipv4_address_step              ANY]
			x	[-number_of_command_snippets_per_client NUMERIC]
			x	[-port_number                           ANY]
			x	[-fetch_schema_info                     ANY]
			x	[-schema_output_directory               ALPHA]
			x	[-send_close_on_stop                    ANY]
			x	[-do_not_validate_server_response       ANY]
			x	[-capabilities_base1_dot0               ANY]
			x	[-capabilities_base1_dot1               ANY]
			x	[-capabilities_writable_running         ANY]
			x	[-capabilities_candidate                ANY]
			x	[-capabilities_rollback_on_error        ANY]
			x	[-capabilities_startup                  ANY]
			x	[-capabilities_url                      ANY]
			x	[-capabilities_xpath                    ANY]
			x	[-capabilities_confirmed_commit         ANY]
			x	[-capabilities_validate                 ANY]
			x	[-capabilities_notification             ANY]
			x	[-capabilities_interleave               ANY]
			x	[-ssh_authentication_mechanism          CHOICES noauthentication
			x                                        CHOICES usernamepassword
			x                                        CHOICES keybased]
			x	[-user_name                             ALPHA]
			x	[-password                              ALPHA]
			x	[-private_key_directory                 ALPHA]
			x	[-private_key_file_name                 ALPHA]
			x	[-enable_passphrase                     ANY]
			x	[-passphrase                            ALPHA]
			x	[-output_directory                      ALPHA]
			x	[-decrypted_capture                     ANY]
			x	[-save_reply_x_m_l                      ANY]
			x	[-log_clean_up_option                   CHOICES clean notClean]
			x	[-log_file_age                          NUMERIC]
			x	[-command_snippets_data_active          ANY]
			x	[-command_snippet_directory             ALPHA]
			x	[-command_snippet_file                  ALPHA]
			x	[-transmission_behaviour                CHOICES dontsend
			x                                        CHOICES once
			x                                        CHOICES periodiccontinuous
			x                                        CHOICES periodicfixedcount]
			x	[-periodic_transmission_interval        ANY]
			x	[-transmission_count                    ANY]
		
		Arguments:
			 	-mode
			 		This option defines whether to Create/Modify/Delete/Enable/Disable Netconf Client.
			 		Valid choices are:
			    		create - Creates Netconf Client.
			    		delete - Deletes Netconf Client.
			    		modify - Modifies Netconf Client.
			    		enable - Enables Netconf Client.
			    		disable - Disables Netconf Client.
			 	-port_handle
			 		Port handle.
			 	-handle
			 		Specifies the parent node handle ( For ex : IP stack output of interface_config) on which the Netconf cleint is configured.
			 		The Netconf client handle(s) are returned by the procedure "emulation_netconf_client_config" when configuring Netconf client on the Ixia interface.
			 		For modify -mode, -handle can be Netconf Client's or Command Snippets' node handle.
			 		For delete -mode, -handle is Netconf Client's node handle.
			 		For enable/disable -mode, -handle can be Netconf Client's or Command Snippets' node handle or session(item) handle of these nodes.
			x	-netconf_client_active
			x		Activate/Deactivate Netconf Client Configuration.
			x	-netconf_client_name
			x		Name of NGPF element, guaranteed to be unique in Scenario
			x	-multiplier
			x		Number of layer instances per parent instance (multiplier)
			x	-server_ipv4_address
			x		Specify the IPv4 address of the DUT to which the Netconf Server should connect.
			x	-server_ipv4_address_step
			x		Step argument of Source IPv4 address
			x	-number_of_command_snippets_per_client
			x		Number of Command Snippets per client.Maximum 100 are allowed per client.
			x	-port_number
			x		The TCP Port Number the Netconf Server is listening on to which to connect.
			x	-fetch_schema_info
			x		Whether a get-schema operation will be performed after capability exchange
			x	-schema_output_directory
			x		Location of Directory in Client where the retrieved modules will be stored.
			x	-send_close_on_stop
			x		This specifies whether a close-session message will be sent on stopping this client.
			x	-do_not_validate_server_response
			x		If this option is enabled, the Netconf client will not parse server responses. Use this option to optimize memory usage in the client.
			x	-capabilities_base1_dot0
			x		Whether base1.0 support should be advertised in Capabilities.
			x	-capabilities_base1_dot1
			x		Whether base1.1 support should be advertised in Capabilities.
			x	-capabilities_writable_running
			x		Whether supports capability writable-running to directly modify running config.
			x	-capabilities_candidate
			x		Whether supports capability candidate to make changes into an intermediate candidate database. Normally this is preferred over writable-running.
			x	-capabilities_rollback_on_error
			x		Whether supports capability rollback to rollback partial changes make changes on detection of error during validate or commit.
			x	-capabilities_startup
			x		Whether supports capability startup to make changes in config persistent on device restart.
			x	-capabilities_url
			x		Whether supports capability url to specify netconf commands using url.
			x	-capabilities_xpath
			x		Whether supports capability xpath to specify netconf commands and filters using xpath extensions.
			x	-capabilities_confirmed_commit
			x		Whether supports capability confirmed-commit to specify ability to commit a group of commands or none as a batch.
			x	-capabilities_validate
			x		Whether supports capability validate to specify ability to validate a netconf command prior to commit.
			x	-capabilities_notification
			x		Whether supports capability notification to aynchronously handle notifications from Netconf server device connected to.
			x	-capabilities_interleave
			x		Whether supports capability interleave to interleave notifications and responses.
			x	-ssh_authentication_mechanism
			x		The authentication mechanism for connecting to Netconf Server.
			x		Valid choices are:
			x   		noauthentication - No authentication.
			x   		usernamepassword - Username/Password.
			x   		keybased - Key Based.
			x	-user_name
			x		Username for Username/Password mode and also used for Key-based Authentication as the username.
			x	-password
			x		Password for Username/Password mode.
			x	-private_key_directory
			x		File containing Private Key.(e.g. generated using ssh_keygen) . For multiple clients and assymetric key file names
			x		( which cannot be expressed easily as a pattern) please explore "File" option in Master Row Pattern Editor by putting the file names
			x		in a .csv and pulling those values into the column cells.
			x	-private_key_file_name
			x		File containing Private Key.(e.g. generated using ssh_keygen) . For multiple clients and assymetric key file names
			x		( which cannot be expressed easily as a pattern) please explore "File" option in Master Row Pattern Editor by putting the file names
			x		in a .csv and pulling those values into the column cells.
			x	-enable_passphrase
			x		If the Private Key was passphrase protected, this should be enabled to allow configuration of passphrase used.
			x	-passphrase
			x		The passphrase with which the Private Key was additionally protected during generation. For multiple clients and assymetric passphrases
			x		( which cannot be expressed easily as a pattern) please explore "File" option in Master Row Pattern Editor by putting the file names
			x		in a .csv and pulling those values into the column cells.
			x	-output_directory
			x		Location of Directory in Client where the decrypted capture, if enabled, and server replies, if enabled,will be stored.
			x	-decrypted_capture
			x		Whether SSH packets for this session will be captured and stored on client in decrypted form.
			x		Note that this is not linked to IxNetwork control or data capture which will capture the packets in encrypted format only.
			x		Also note that this option should be avoided if Continuous Tranmission mode is enabled for any of the Command Snippets which can lead
			x		to huge capture files being generated which could in turn affect Stop time since during Stop, the captures are transferred to the client.
			x		The Decrypted Capture can be viewed by either doing right-click on a client where this option is enabled and doing "Get Decrypted Capture"
			x		( allowed on 5 clients at a time ; each of the captures will be opened in a new Wireshark pop-up) OR by stopping the client and then directly
			x		opening it from the configured Output Directory from inside the current run folder/capture.
			x		This option can be enabled even when a session is already up in which case the capture will be started from that point of time.
			x	-save_reply_x_m_l
			x		If this is enabled, Hellos and replies to commands sent via Command Snippets or global command (such as 'get') by the Netconf Server will be stored in the Output Directory
			x		in current run folder/Replies. Any RPC errors recieved will be stored in a separate Error directory for convenience of debugging error scenarios.
			x		This option can be enabled even when a session is already up in which case the replies will be saved from that point of time.
			x	-log_clean_up_option
			x		Debug Log Clean Up
			x		Valid choices are:
			x   		clean - Clean Up on Start.
			x   		notClean - Don't Clean Up.
			x	-log_file_age
			x		This field determines how old logs to be deleted.
			x	-command_snippets_data_active
			x		Activate/Deactivate Command Snippets Data.
			x	-command_snippet_directory
			x		Directory containing XML based Netconf compliant command snippets.
			x	-command_snippet_file
			x		File containing XML based Netconf compliant command snippet. For multiple command snippets with assymetric file names
			x		( which cannot be expressed easily as a pattern) please explore "File" option in Master Row Pattern Editor by putting the file names
			x		in a .csv and pulling those values into the column cells.
			x	-transmission_behaviour
			x		Transmission behaviour for command snippet.
			x		Don't Send : This means that command will not be automatically executed. This choice should be
			x		used if user wants to control the order or/and timing of sending the command snippet to the DUT
			x		using Test Composer or Automation Script.
			x		Once: The command will be sent only once to the DUT every time session comes up with the DUT.
			x		Periodic - Continuous: The command will be sent every Transmission Interval for the full lifetime of the session.Capture should be enabled with care if this option is selected.
			x		Periodic - Fixed Count: The command will be sent Transmission Count number of times, every Periodic Transmission Interval.
			x		Valid choices are:
			x   		dontsend - Don't Send.
			x   		once - Once.
			x   		periodiccontinuous - Periodic - Continuous.
			x   		periodicfixedcount - Periodic - Fixed Count.
			x	-periodic_transmission_interval
			x		Minimum interval between scheduling of two transmits of the Command Snippet.
			x	-transmission_count
			x		Number of times to transmit the Command Snippet.
		
		Return Values:
		A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
			xkey:ipv4_loopback_handle          value:A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
		A list containing the ipv4 protocol stack handles that were added by the command (if any).
			xkey:ipv4_handle                   value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE
			 key:status                        value:$::SUCCESS | $::FAILURE
		When status is $::FAILURE, log shows the detailed information of failure.
			 key:log                           value:When status is $::FAILURE, log shows the detailed information of failure.
		Handle of Netconf Client configured
			 key:netconf_client_handle         value:Handle of Netconf Client configured
		Handle of Command Snippets Data configured
			 key:command_snippets_data_handle  value:Handle of Command Snippets Data configured
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_netconf_client_config", kwargs)

	def emulation_netconf_client_control(self, **kwargs):
		""" This procedure performs control actions like start, stop or restart on Netconf Client and does some right click actions.     The following operations are done:     1. Start     2. Stop     3. Restart     4. Restart Down     5. Abort     6. Get Decrypted Capture     7. Execute Command Get     8. Execute Command
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_netconf_client_control
			 	-mode    CHOICES restart
			          CHOICES start
			          CHOICES restart_down
			          CHOICES stop
			          CHOICES abort
			          CHOICES get_decrypted_capture
			          CHOICES execute_command_get
			          CHOICES execute_command]
			 	[-handle ANY]
		
		Arguments:
			 	-mode
			 		What is being done to the protocol.Valid choices are:
			 		restart- Restart the protocol.
			 		start- Start the protocol.
			 		stop- Stop the protocol.
			 		restart_down- Restart the down sessions.
			 		abort- Abort the protocol.
			 		get_decrypted_capture- This will fetch and open the decrypted capture for selected sessions.
			 		execute_command_get- Sends the configured command for the selected rows to the DUT if the selected client's Netconf session is up with the DUT. This action is performed in Netconf Client.
			 		execute_command- Sends the configured command for the selected rows to the DUT if the selected client's Netconf session is up with the DUT. This action is performed in Netconf Client's Command Snippets.
			 		Valid choices are:
			    		restart - Restart the protocol.
			    		start - Start the protocol.
			    		restart_down - restart the down sessions
			    		stop - Stop the protocol.
			    		abort - Abort.
			    		get_decrypted_capture - This will fetch and open the decrypted capture for selected sessions.
			    		execute_command_get - Sends the configured command for the selected rows to the DUT if the selected client's Netconf session is up with the DUT. This action is performed in Netconf Client.
			    		execute_command - Sends the configured command for the selected rows to the DUT if the selected client's Netconf session is up with the DUT. This action is performed in Netconf Client's Command Snippets.
			 	-handle
			 		This option represents the handle the user *must* pass to the
			 		"emulation_netconf_client_control" procedure. This option specifies
			 		on which Netconf session to control.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		For mode choices restart, start, restart_down, stop, abort, get_decrypted_capture and execute_command_get Netconf Client handle needs to be provided.
		For mode execute_command, node handle of Command Snippets needs to be provided.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_netconf_client_control", kwargs)

	def emulation_netconf_client_info(self, **kwargs):
		""" This procedure retrieves information about the Netconf Client sessions.     This procedure is also used to fetch stats, learned information and configured properties of Netconf Client, depending on the given mode and handle.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_netconf_client_info
			x	-mode         CHOICES per_port_stats
			x              CHOICES per_session_stats
			x              CHOICES per_device_group_stats
			x              CHOICES per_command_snippet_stats
			x              CHOICES clear_stats
			x              CHOICES get_learned_schema_info
			x              CHOICES clear_all_learned_schema_info]
			 	-handle       ANY]
			 	[-port_handle REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
		
		Arguments:
			x	-mode
			x		For fetching per_port_stats provide any Netconf Client handle, for per_session_stats, per_device_group_stats and per_command_snippet_stats provide a Netconf Client handle which is on the corresponding port.
			x		Valid choices are:
			x   		per_port_stats - Retrieves Netconf Client per port statistics.
			x   		per_session_stats - Retrieves Netconf Client per session statistics.
			x   		per_device_group_stats - Retrieves Netconf Client per device group statistics.
			x   		per_command_snippet_stats - Retrieves Netconf Client per Command Snippet statistics.
			x   		clear_stats - Clear Netconf Client statistics.
			x   		get_learned_schema_info - Get Learned Schema Info.
			x   		clear_all_learned_schema_info - Clear All Learned Schema Info.
			 	-handle
			 		The Netconf Client handle to act upon.
			 	-port_handle
			 		Port handle.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_netconf_client_info", kwargs)

	def emulation_netconf_server_config(self, **kwargs):
		""" This procedure will add and configure Netconf Server to a particular Ixia Interface.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_netconf_server_config
			 	-mode                               CHOICES create
			                                     CHOICES delete
			                                     CHOICES modify
			                                     CHOICES enable
			                                     CHOICES disable]
			 	[-port_handle                       REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle                            ANY]
			x	[-netconf_server_active             ANY]
			x	[-netconf_server_name               ALPHA]
			x	[-multiplier                        NUMERIC]
			x	[-client_ipv4_address               ANY]
			x	[-client_ipv4_address_step          ANY]
			x	[-port_number                       ANY]
			x	[-include_rx_timestamp_in_reply_msg ANY]
			x	[-capabilities_base1_dot0           ANY]
			x	[-capabilities_base1_dot1           ANY]
			x	[-capabilities_writable_running     ANY]
			x	[-capabilities_candidate            ANY]
			x	[-capabilities_rollback_on_error    ANY]
			x	[-capabilities_startup              ANY]
			x	[-capabilities_url                  ANY]
			x	[-capabilities_xpath                ANY]
			x	[-capabilities_confirmed_commit     ANY]
			x	[-capabilities_validate             ANY]
			x	[-capabilities_notification         ANY]
			x	[-capabilities_interleave           ANY]
			x	[-ssh_authentication_mechanism      CHOICES noauthentication
			x                                    CHOICES usernamepassword
			x                                    CHOICES keybased]
			x	[-user_name                         ALPHA]
			x	[-password                          ALPHA]
			x	[-public_key_directory              ALPHA]
			x	[-public_key_file_name              ALPHA]
			x	[-output_directory                  ALPHA]
			x	[-decrypted_capture                 ANY]
			x	[-error_percentage                  ANY]
			x	[-error_type                        CHOICES transport
			x                                    CHOICES rpc
			x                                    CHOICES protocol
			x                                    CHOICES application]
			x	[-error_tag                         CHOICES inuse
			x                                    CHOICES invalidvalue
			x                                    CHOICES toobig
			x                                    CHOICES missingattribute
			x                                    CHOICES badattribute
			x                                    CHOICES unknownattribute
			x                                    CHOICES missingelement
			x                                    CHOICES badelement
			x                                    CHOICES unknownelement
			x                                    CHOICES unknownnamespace
			x                                    CHOICES accessdenied
			x                                    CHOICES lockdenied
			x                                    CHOICES resourcedenied
			x                                    CHOICES rollbackfailed
			x                                    CHOICES dataexists
			x                                    CHOICES datamissing
			x                                    CHOICES operationnotsupported
			x                                    CHOICES operationfailed
			x                                    CHOICES partialoperation
			x                                    CHOICES malformedmessage]
			x	[-error_severity                    CHOICES error warning]
			x	[-include_error_info                ANY]
			x	[-error_info                        ALPHA]
			x	[-send_ok_response                  ANY]
			x	[-response_xml_directory            ALPHA]
			x	[-get_config_reply_xml              ALPHA]
		
		Arguments:
			 	-mode
			 		This option defines whether to Create/Modify/Delete/Enable/Disable Netconf Server.
			 		Valid choices are:
			    		create - Creates Netconf Server.
			    		delete - Deletes Netconf Server.
			    		modify - Modifies Netconf Server.
			    		enable - Enables Netconf Server.
			    		disable - Disables Netconf Server.
			 	-port_handle
			 		Port handle.
			 	-handle
			 		Specifies the parent node handle ( For ex : IP stack output of interface_config) on which the Netconf server is configured with create -mode.
			 		The Netconf server handle(s) are returned by the procedure "emulation_netconf_server_config" when configuring Netconf server on the Ixia interface.
			 		For modify/delete -mode, -handle can be Netconf Server's node handle.
			 		For enable/disable -mode, -handle can be Netconf Server's node handle or session(item) handle of the node.
			x	-netconf_server_active
			x		Activate/Deactivate Configuration
			x	-netconf_server_name
			x		Name of NGPF element, guaranteed to be unique in Scenario
			x	-multiplier
			x		Number of layer instances per parent instance (multiplier)
			x	-client_ipv4_address
			x		Specify the IPv4 address of the Netconf Client which will connect with this Server.
			x	-client_ipv4_address_step
			x		Step argument of Client IPv4 address
			x	-port_number
			x		The TCP Port Number the Netconf Server is listening on to which to connect.
			x	-include_rx_timestamp_in_reply_msg
			x		This specifies whether timestamp of received request messages will be included in the replies.
			x	-capabilities_base1_dot0
			x		Whether base1.0 support should be advertised in Capabilities.
			x	-capabilities_base1_dot1
			x		Whether base1.1 support should be advertised in Capabilities.
			x	-capabilities_writable_running
			x		Whether supports capability writable-running to directly modify running config.
			x	-capabilities_candidate
			x		Whether supports capability candidate to make changes into an intermediate candidate database. Normally this is preferred over writable-running.
			x	-capabilities_rollback_on_error
			x		Whether supports capability rollback to rollback partial changes make changes on detection of error during validate or commit.
			x	-capabilities_startup
			x		Whether supports capability startup to make changes in config persistent on device restart.
			x	-capabilities_url
			x		Whether supports capability url to specify netconf commands using url.
			x	-capabilities_xpath
			x		Whether supports capability xpath to specify netconf commands and filters using xpath extensions.
			x	-capabilities_confirmed_commit
			x		Whether supports capability confirmed-commit to specify ability to commit a group of commands or none as a batch.
			x	-capabilities_validate
			x		Whether supports capability validate to specify ability to validate a netconf command prior to commit.
			x	-capabilities_notification
			x		Whether supports capability notification to aynchronously send notifications to Netconf client.
			x	-capabilities_interleave
			x		Whether supports capability interleave to interleave notifications and responses.
			x	-ssh_authentication_mechanism
			x		The authentication mechanism for connecting to Netconf Client.
			x		Valid choices are:
			x   		noauthentication - No Authentication.
			x   		usernamepassword - Username/Password.
			x   		keybased - Key Based.
			x	-user_name
			x		Username for Username/Password mode and Username for Key-Based authentication mode if applicable.
			x	-password
			x		Password for Username/Password mode.
			x	-public_key_directory
			x		Directory containing public key file for this session
			x	-public_key_file_name
			x		File containing public key (e.g. generated using ssh_keygen). For multiple server rows and assymetric public key filenames
			x		( which cannot be expressed easily as a pattern) please explore "File" option in Master Row Pattern Editor by putting the file names
			x		in a .csv and pulling those values into the column cells.
			x	-output_directory
			x		Location of Directory in Client where the decrypted capture, if enabled, and server replies, if enabled,will be stored.
			x	-decrypted_capture
			x		Whether SSH packets for this session will be captured and stored on client in decrypted form.
			x		Note that this is not linked to IxNetwork control or data capture which will capture the packets in encrypted format only.
			x		The Decrypted Capture can be viewed by either doing right-click on a client where this option is enabled and doing "Get Decrypted Capture"
			x		( allowed on 5 clients at a time ; each of the captures will be opened in a new Wireshark pop-up) OR by stopping the client and then directly
			x		opening it from the configured Output Directory from inside the current run folder/capture.
			x		This option can be enabled even when a session is already up in which case the capture will be started from that point of time.
			x	-error_percentage
			x		The percentage of requests whose response will be errors.
			x	-error_type
			x		Defines the conceptual layer on which the error occurred.
			x		Valid choices are:
			x   		transport - Transport
			x   		rpc - RPC
			x   		protocol - Protocol
			x   		application - Application
			x	-error_tag
			x		Contains a string identifying the error condition.
			x		Valid choices are:
			x   		inuse - In Use
			x   		invalidvalue - Invalid Value
			x   		toobig - Too Big
			x   		missingattribute - Missing Attribute
			x   		badattribute - Bad Attribute
			x   		unknownattribute - Unknown Attribute
			x   		missingelement - Missing Element
			x   		badelement - Bad Element
			x   		unknownelement - Unknown Element
			x   		unknownnamespace - Unknown Namespace
			x   		accessdenied - Access Denied
			x   		lockdenied - Lock Denied
			x   		resourcedenied - Resource Denied
			x   		rollbackfailed - Rollback Failed
			x   		dataexists - Data Exists
			x   		datamissing - Data Missing
			x   		operationnotsupported - Operation Not Supported
			x   		operationfailed - Operation Failed
			x   		partialoperation - Partial Operation
			x   		malformedmessage - Malformed Message
			x	-error_severity
			x		Contains a string identifying the error severity, as determined by the device.
			x		Valid choices are:
			x   		error - Error
			x   		warning - Warning
			x	-include_error_info
			x		This specifies whether 'error-info' element should be included in rpc error messages.
			x	-error_info
			x		Contains protocol or data-model-specific error content.
			x	-send_ok_response
			x		This specifies whether <ok> element should be sent in <rpc-reply> in response to <get-config> requests. If this is unchecked, custom reply based on <get-config> response xml will be sent out.
			x	-response_xml_directory
			x		Directory where Reply XMLs for <get-config> operations are present.
			x	-get_config_reply_xml
			x		File containing the response to a <get-config> request.
		
		Return Values:
		A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
			xkey:ipv4_loopback_handle   value:A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
		A list containing the ipv4 protocol stack handles that were added by the command (if any).
			xkey:ipv4_handle            value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE
			 key:status                 value:$::SUCCESS | $::FAILURE
		When status is $::FAILURE, log shows the detailed information of failure.
			 key:log                    value:When status is $::FAILURE, log shows the detailed information of failure.
		Handle of Netconf Server configured
			 key:netconf_server_handle  value:Handle of Netconf Server configured
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_netconf_server_config", kwargs)

	def emulation_netconf_server_control(self, **kwargs):
		""" This procedure performs control actions like start, stop or restart on Netconf Server and does some right click actions.     The following operations are done:     1. Start     2. Stop     3. Restart     4. Restart Down     5. Abort
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_netconf_server_control
			 	-mode             CHOICES restart
			                   CHOICES start
			                   CHOICES restart_down
			                   CHOICES stop
			                   CHOICES abort
			                   CHOICES get_decrypted_capture
			                   CHOICES stop_rpc_reply_store_outstanding_requests
			                   CHOICES stop_rpc_reply_drop_outstanding_requests
			                   CHOICES resume_rpc_reply
			                   CHOICES send_rpc_reply_with_wrong_message_id
			                   CHOICES send_rpc_reply_with_wrong_character_count]
			 	[-handle          ANY]
			x	[-tcp_port_number ANY]
		
		Arguments:
			 	-mode
			 		What is being done to the protocol.Valid choices are:
			 		restart- Restart the protocol.
			 		start- Start the protocol.
			 		stop- Stop the protocol.
			 		restart_down- Restart the down sessions.
			 		abort- Abort the protocol.
			 		Valid choices are:
			    		restart - Restart the protocol.
			    		start - Start the protocol.
			    		restart_down - restart the down sessions
			    		stop - Stop the protocol.
			    		abort - Abort.
			    		get_decrypted_capture - This will fetch and open the decrypted capture for selected sessions.
			    		stop_rpc_reply_store_outstanding_requests - Stop sending replies to rpc requests. Store the outstanding requests so that when Resume RPC Reply is triggered,
responses will be sent for these requests.
			    		stop_rpc_reply_drop_outstanding_requests - Stop sending replies to rpc requests. Drop the outstanding requests so that when Resume RPC Reply is triggered,
responses will not be sent for these requests.
			    		resume_rpc_reply - Resume sending responses to RPC requests.
			    		send_rpc_reply_with_wrong_message_id - The response to the next RPC request will be sent with wrong message Id.
			    		send_rpc_reply_with_wrong_character_count - The response to the next RPC request will be sent with wrong character count.
			 	-handle
			 		This option represents the handle the user *must* pass to the
			 		"emulation_netconf_server_control" procedure. This option specifies
			 		on which Netconf session to control.
			x	-tcp_port_number
			x		The TCP Port number of the server connection for which the capture file is to be fetched. Enter 0 for the first server connection.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		For mode choices restart, start, restart_down, stop and abort Netconf Server handle needs to be provided.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_netconf_server_control", kwargs)

	def emulation_netconf_server_info(self, **kwargs):
		""" This procedure retrieves information about the Netconf Server sessions.     This procedure is also used to fetch stats, learned information and configured properties of Netconf Server, depending on the given mode and handle.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_netconf_server_info
			x	-mode         CHOICES per_port_stats
			x              CHOICES per_session_stats
			x              CHOICES per_device_group_stats
			x              CHOICES per_connection_stats
			x              CHOICES clear_stats]
			 	-handle       ANY]
			 	[-port_handle REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
		
		Arguments:
			x	-mode
			x		For fetching per_port_stats provide any Netconf Server handle, for per_session_stats and per_device_group_stats provide a Netconf Server handle which is on the corresponding port.
			x		Valid choices are:
			x   		per_port_stats - Retrieves Netconf Server per port statistics.
			x   		per_session_stats - Retrieves Netconf Server per session statistics.
			x   		per_device_group_stats - Retrieves Netconf Server per device group statistics.
			x   		per_connection_stats - Retrieves Netconf Server per connection statistics.
			x   		clear_stats - Clear Netconf Server statistics.
			 	-handle
			 		The Netconf Server handle to act upon.
			 	-port_handle
			 		Port handle.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_netconf_server_info", kwargs)

	def emulation_oam_config_msg(self, **kwargs):
		""" This procedure will configure OAM loopback and linktrace messages on MEPs.The MEPs that will be used to configure OAM messages on will can be determined in two ways
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_oam_config_msg
			 	-mode                           ANY
			 	-port_handle                    ANY
			 	[-count                         ANY]
			 	[-handle                        ANY]
			 	[-mac_local                     ANY]
			 	[-mac_local_incr_mode           ANY]
			 	[-mac_local_list                ANY]
			 	[-mac_local_repeat              ANY]
			 	[-mac_local_step                ANY]
			 	[-mac_remote                    ANY]
			 	[-mac_remote_incr_mode          ANY]
			 	[-mac_remote_list               ANY]
			 	[-mac_remote_repeat             ANY]
			 	[-mac_remote_step               ANY]
			 	[-md_level                      ANY]
			 	[-md_level_incr_mode            ANY]
			 	[-md_level_list                 ANY]
			 	[-md_level_repeat               ANY]
			 	[-md_level_step                 ANY]
			 	[-msg_timeout                   ANY]
			 	[-msg_type                      ANY]
			 	[-oam_standard                  ANY]
			 	[-renew_test_msgs               ANY]
			 	[-renew_period                  ANY]
			 	[-vlan_id                       ANY]
			 	[-vlan_id_repeat                ANY]
			 	[-vlan_id_outer_repeat          ANY]
			 	[-vlan_id_outer_step            ANY]
			 	[-vlan_id_step                  ANY]
			 	[-vlan_outer_id                 ANY]
			 	[-tlv_data_length               ANY]
			 	[-tlv_data_pattern              ANY]
			 	[-tlv_org_length                ANY]
			 	[-tlv_org_value                 ANY]
			 	[-tlv_sender_chassis_id         ANY]
			 	[-tlv_sender_chassis_id_length  ANY]
			 	[-tlv_sender_chassis_id_subtype ANY]
			 	[-ttl                           ANY]
			x	[-bridge_id                     ANY]
			x	[-handle_granularity            ANY]
			x	[-mep_id                        ANY]
			x	[-mep_id_incr_mode              ANY]
			x	[-mep_id_list                   ANY]
			x	[-mep_id_repeat                 ANY]
			x	[-mep_id_step                   ANY]
			x	[-short_ma_name_format          ANY]
			x	[-short_ma_name_length          ANY]
			x	[-short_ma_name_value           ANY]
			x	[-short_ma_name_repeat          ANY]
			x	[-short_ma_name_step            ANY]
			x	[-short_ma_name_wc_start        ANY]
			x	[-short_ma_name_wildcard        ANY]
			x	[-short_ma_name_incr_mode       ANY]
			x	[-short_ma_name_list            ANY]
			x	[-supress_warnings              ANY]
			x	[-vlan_id_incr_mode             ANY]
			x	[-vlan_id_list                  ANY]
			x	[-vlan_id_outer_incr_mode       ANY]
			x	[-vlan_id_outer_list            ANY]
			n	[-burst_delay                   ANY]
			n	[-burst_loop_count              ANY]
			n	[-dst_addr_type                 ANY]
			n	[-encap                         ANY]
			n	[-mac_dst                       ANY]
			n	[-mac_dst_incr_mode             ANY]
			n	[-mac_dst_list                  ANY]
			n	[-mac_dst_repeat                ANY]
			n	[-mac_dst_step                  ANY]
			n	[-pkts_per_burst                ANY]
			n	[-rate_pps                      ANY]
			n	[-sut_ip_address                ANY]
			n	[-tlv_org_oui                   ANY]
			n	[-tlv_org_subtype               ANY]
			n	[-tlv_sender_length             ANY]
			n	[-tlv_test_length               ANY]
			n	[-tlv_test_pattern              ANY]
			n	[-tlv_user_length               ANY]
			n	[-tlv_user_type                 ANY]
			n	[-tlv_user_value                ANY]
			n	[-trans_id                      ANY]
			n	[-trans_id_incr_mode            ANY]
			n	[-trans_id_list                 ANY]
			n	[-trans_id_repeat               ANY]
			n	[-trans_id_step                 ANY]
			n	[-transmit_mode                 ANY]
			n	[-vlan_ether_type               ANY]
			n	[-vlan_id_count                 ANY]
			n	[-vlan_id_outer_count           ANY]
		
		Arguments:
			 	-mode
			 		See description of -handle parameter for more details.
			 		Valid choices are:
			    		create- create messages
			    		modify-not supported
			    		reset-disables all messages and all TLVs.
			 	-port_handle
			 		Parameter -port_handle specifies the port on which to configure OAM messages. This parameter is supported using the following APIs: IxN.The messages will be configured on the MEPs from port -port_handle.
			 	-count
			 		Determines the number of messages to configure.Dependencies: -mep_id must not exist or -mep_id_incr_mode is not 'list'
			 	-handle
			 		Parameter handle can be a bridge handle returned by ::<namespace>::emulation_oam_config_topology or a port handle returned by ::<namespace>::connect. This parameter can be used when mode is 'reset'. If this parameter is a port handle, all messages and all TLVsfrom all the Maintenance Points from all the bridges on this port will be disabled. If this parameter is a bridge handle all messages and all TLVs from all the Maintenance Pointson this bridge will be disabled. If this parameter is not used on -mode 'reset', Maintenace Points will be filtered the same way as for -mode 'create' and the messages and TLVs on the filtered MPs will be disabled.
			 	-mac_local
			 		This parameter is used to select the MEPs to configure message on when -mep_id parameter is not specified.To configure messages on MEPs independent of their mac address identifier see the description for -mac_local_list parameter.If this parameter is not specified messages will be configured on MEPs independent of their mac_local address.
			 	-mac_local_incr_mode
			 		Used when -mep_id is not specified.
			 		Valid choices are:
			    		none - (DEFAULT) mac_local value will not be modified (all messages will be configured on the MEPs having the same mac address)
			    		increment - increment mac_local address MEP identifier a number of times equal to -count,
			    		decrement - decrement mac_local address MEP identifier a number of times
			    		list - Use the values specified with -mac_local_list as MEP identifiers.
			    		random - Generate a random mac_local address MEP identifier for every message.
			 	-mac_local_list
			 		Used when -mep_id is not specified.Dependencies: -mac_local_incr_mode list.This parameter must either be a list of MAC addresses or the keyword "all". When the keyword "all" is used -mac_local will not be used as identified for MEPs.
			 	-mac_local_repeat
			 		Used when -mep_id is not specified.Dependencies: -mac_local_incr_mode increment | decrement.The number of times to use the mac_local address MEP identifier before incrementing or decrementing
			 	-mac_local_step
			 		Used when -mep_id is not specified.Dependencies: -mac_local_incr_mode increment | decrement.The step to increment | decrement mac_local address MEP identifier.
			 	-mac_remote
			 		This parameter configures the destination of the OAM messages. To send to all destinations see the description for -mac_remote_list parameter.If this parameter is not specified, messages will be sent to all destinations.
			 	-mac_remote_incr_mode
			    		none - (DEFAULT) mac_remote value will not be modified (all messages will be configured with -mac_remote destination address)
			    		increment - increment mac_remote address a number of times equal to -count.
			    		decrement - decrement mac_remote address
			    		list - Use the values specified with -mac_remote_list as OAM message destinations.
			    		random - Generate a random mac_local address OAM message destination for every message.
			 	-mac_remote_list
			 		Dependencies: -mac_remote_incr_mode list.This parameter must either be a list of MAC addresses or the keyword "all". When the keyword "all" is used -mac_remote will not be used as OAM Message destination address and the message will be sent to all destinations.
			 	-mac_remote_repeat
			 		Dependencies: -mac_remote_incr_mode increment | decrement.The number of times to use the mac_remote OAM message destination address before incrementing or decrementing
			 	-mac_remote_step
			 		Dependencies: -mac_remote_incr_mode increment | decrement.The step to increment | decrement mac_remote OAM message destination address.
			 	-md_level
			 		Used when -mep_id is not specified.This parameter is used to select the MEPs to configure message on. MEPs will filtered by the Mainenance Domain level value that they belong to.To configure messages on MEPs independent of their Maintenance domain level see the description for -md_level_list parameter.
			 	-md_level_incr_mode
			 		Used when -mep_id is not specified.
			 		Valid choices are:
			    		none - (DEFAULT) md_level value will not be modified (all messages will be configured on MEPs from the same level)
			    		increment - increment md_level address MEP identifier a number of times equal to -count,
			    		decrement - decrement md_level address MEP identifier a number of times
			    		list - Use the values specified with -md_level_list as MEP identifiers.
			    		random - Generate a random md_level MEP identifier for every message.
			 	-md_level_list
			 		Used when -mep_id is not specified.Dependencies: -md_level_incr_mode list.This parameter must either be a list of MD levels or the keyword "all". When the keyword "all" is used -md_level will not be used as identified for MEPs.
			 	-md_level_repeat
			 		Used when -mep_id is not specified.Dependencies: -md_level_incr_mode increment | decrement.The number of times to use the md_level MEP identifier before incrementing or decrementing.
			 	-md_level_step
			 		Used when -mep_id is not specified.Dependencies: -md_level_incr_mode increment | decrement.The step to increment | decrement md_level MEP identifier.
			 	-msg_timeout
			 		Define the timeout duration before messages are deemed lost (in milliseconds).The timeout will be rounded to the closest equivalent measured in seconds. This value should be less than -renew_period. If a greater value than -renew_period is configured it will be forced to be equal to -renew_period.
			 	-msg_type
			 		loopback - (DEFAULT) configure loopback messageslinktrace - configure linktrace messagestest - not supported
			 	-oam_standard
			 		Used when -mep_id is not specified. Filter MEPs that will be used to configure OAM messages on by their oam standard.
			 		Valid choices are:
			    		1ag - (DEFAULT) IEEE standard
			    		itut_y1731 - ITU-T standard
			 	-renew_test_msgs
			 		Flag to indicate that messages should be sent periodically.
			 	-renew_period
			 		Define the timeout duration before resending messages (in milliseconds). The value will be rounded to the closest equivalent measured in seconds. This value should be greater than -msg_timeout. If a smaller value than -msg_timeout is configured, the value of -msg_timeout will be forced to be equal to -renew_timer.
			 	-vlan_id
			 		Used when -mep_id is not specified. Filter MEPs to configure messages on by their vlan value. To configure messages on MEPs independent of their vlan id value configure this parameter with the keyword "all".
			 	-vlan_id_repeat
			 		Used when -mep_id is not specified. Number of times to use vlan_id before incrementing.
			 	-vlan_id_outer_repeat
			 		Used when -mep_id is not specified. Number of times to use outer_vlan_id before incrementing.
			 	-vlan_id_outer_step
			 		Used when -mep_id is not specified.Amount to increment vlan_outer_id with.
			 	-vlan_id_step
			 		Used when -mep_id is not specified.Amount to increment vlan_id with.
			 	-vlan_outer_id
			 		Used when -mep_id is not specified.Filter MEPs to configure messages on by their outer vlan value.To configure messages on MEPs independent of their outer vlan id value configure this parameter with the keyword "all".
			 	-tlv_data_length
			 		Define the Data TLV length value.Dependencies: -msg_type loopback
			 	-tlv_data_pattern
			 		Define the Data TLV Data pattern.Dependencies: -msg_type loopback
			 	-tlv_org_length
			 		Define the Organization-Specific TLV length.
			 	-tlv_org_value
			 		Define the Organization-Specific TLV value.
			 	-tlv_sender_chassis_id
			 		Define the Sender ID TLV Chassis ID.
			 	-tlv_sender_chassis_id_length
			 		Define the Sender ID TLV Chassis ID Length.
			 	-tlv_sender_chassis_id_subtype
			 		Define the Sender ID TLV Chassis ID Subtype.0 - (DEFAULT) chassisComponent1 - interfaceAlias2 - interfaceName3 - locallyAssigned4 - macAddress5 - networkAddress6 - portComponent
			 	-ttl
			 		Define the Time-to-live value for the emulated messages.
			x	-bridge_id
			x		This parameter is used to select the MEPs to configure message on. MEPs will filtered by the bridge that they belong to.To configure messages on MEPs independent of their Bridge Id, do not specify this parameter.
			x	-handle_granularity
			x		Defines how message handles will be returned. Message handles can be used with ::<namespace>::emulation_oam_config_msg to retrieve per session message statistics for a specific message or a group of messages.One MEP can be configured with a maximum of two messages: one linktrace and one loopback. Notes: A message can be refered by only one message handle no matter what the type of the message handle is (per_message or per_group). If seperate calls to emulation_oam_config_msg procedure configure messages on MEPs that already have those messages configured, the last call will overwrite the former message handle with the new message handle and print a warning informing the user about this.
			x		Valid choices are:
			x   		per_message - one handle for each message created. The number of message
			x   		x - one handle for each message created. The number of message
			x   		per_group - one handle for all the messages created withing the current procedure call. Based
			x	-mep_id
			x		When this parameter is used, MEPs that will be used to configure OAM Messages on will be filtered based on -port_handle, -bridge_id and -mep_id. To configure OAM messages independant of the Mep ID see description for mep_id_list parameter.
			x	-mep_id_incr_mode
			x   		none - (DEFAULT) mep_id value will not be modified (all messages will be configured on the MEPs having the same mep id)
			x   		increment - increment MEP ID.
			x   		list - use mep_id_list. Parameter count will not be used in this case.
			x	-mep_id_list
			x		This parameter must either be a list of MEP Ids or the keyword "all". When the keyword "all" is used -mep_id will not be used as identified for MEPs.Note: -count parameter will not be used in this case.
			x	-mep_id_repeat
			x		Number of times to use -mep_id before incrementing.
			x	-mep_id_step
			x		Dependencies: -mep_id_incr_mode increment.Amount to increment -mep_id with.
			x	-short_ma_name_format
			x		Used when -mep_id is not specified. Filter MEPs to configure messages on by their short ma name.Configures Short MA Name format.
			x		Valid choices are:
			x   		primary_vid - short_ma_name must be a number from 0 to 4095.
			x   		char_str - short_ma_name must be valid string
			x   		integer - (DEFAULT) short_ma_name must be a number from 0 to 65535
			x   		rfc_2685_vpn_id - short_ma_name must be formatted <number1>-<number2>
			x   		x - short_ma_name must be formatted <number1>-<number2>
			x	-short_ma_name_length
			x		Used when -mep_id is not specified. Filter MEPs to configure messages on by their short ma name.Define the length for -short_ma_name
			x	-short_ma_name_value
			x		Used when -mep_id is not specified. Filter MEPs to configure messages on by their short ma name.Define the value of the short_ma_name depending on -short_ma_name_format.
			x	-short_ma_name_repeat
			x		Used when -mep_id is not specified. Filter MEPs to configure messages on by their short ma name.Configure the number of times to use the same Bridge ID before incrementing short_ma_name_valueor before incrementing -short_ma_name_wc_start.
			x	-short_ma_name_step
			x		Used when -mep_id is not specified. Filter MEPs to configure messages on by their short ma name.This is the step that will be used to increment the short_ma_name_value or the parameter -short_ma_name_wc_start if -short_ma_name_wildcard is 1.
			x	-short_ma_name_wc_start
			x		Used when -mep_id is not specified. Filter MEPs to configure messages on by their short ma name.When short_ma_name_format is 'char_str' this is the starting value for the wildcard substitution.
			x	-short_ma_name_wildcard
			x		Used when -mep_id is not specified. Filter MEPs to configure messages on by their short ma name.Enable or disable using wildcard substitution for short_ma_name_value. Wildcard character will be '?'
			x		Valid choices are:
			x   		0 - (DEFAULT ) Disable
			x   		1 - Enable
			x	-short_ma_name_incr_mode
			x		Used when -mep_id is not specified. Filter MEPs to configure messages on by their short ma name.
			x		Valid choices are:
			x   		none - (DEFAULT) use the same value
			x   		increment - short_ma_name_value will be incremented using short_ma_name_step and
			x   		x - short_ma_name_value will be incremented using short_ma_name_step and
			x   		list - uses short_ma_name_list parameter.
			x	-short_ma_name_list
			x		Used when -mep_id is not specified. Filter MEPs to configure messages on by their short ma name.List of short_ma_name values. If this parameter has the value "all" then MEPs are selected regardless of their short ma name value. Parameter short_ma_name_format must have the length 1 or the length equal to short_ma_name_list.
			x	-supress_warnings
			x		Disables printing warning messages.
			x	-vlan_id_incr_mode
			x		Used when -mep_id is not specified. Determine how vlans will be selected to filter the MEPs on which OAM messages
			x		Valid choices are:
			x   		increment - (DEFAULT) vlans will be incremented using vlan_id_step and vlan_id_repeat
			x   		list - vlans are selected from the vlan_id_list list of vlans.
			x	-vlan_id_list
			x		Used when -mep_id is not specified. List of vlan values to use when -vlan_id_incr_mode is "list". if the length of the list is smaller than the value specified with -count, the last value in the list will be duplicated to match. If this parameter has the value "all" then MEPs are selected regardless of their vlan id value.
			x	-vlan_id_outer_incr_mode
			x		Used when -mep_id is not specified. Determine how outer vlans will be selected to filter the MEPs on which OAM messages
			x		Valid choices are:
			x   		increment - (DEFAULT) outer vlans will be incremented using vlan_id_outer_step and vlan_id_outer_repeat
			x   		list - outer vlans are selected from the vlan_id_outer_list list of vlans.
			x	-vlan_id_outer_list
			x		Used when -mep_id is not specified. List of outer vlan values to use when -vlan_id_outer_incr_mode is "list". if the length of the list is smaller than the value specified with -count, the last value in the list will be duplicated to match. If this parameter has the value "all" then MEPs are selected regardless of their outer vlan id value.
			n	-burst_delay
			n	-burst_loop_count
			n	-dst_addr_type
			n	-encap
			n	-mac_dst
			n	-mac_dst_incr_mode
			n	-mac_dst_list
			n	-mac_dst_repeat
			n	-mac_dst_step
			n	-pkts_per_burst
			n	-rate_pps
			n	-sut_ip_address
			n	-tlv_org_oui
			n	-tlv_org_subtype
			n	-tlv_sender_length
			n	-tlv_test_length
			n	-tlv_test_pattern
			n	-tlv_user_length
			n	-tlv_user_type
			n	-tlv_user_value
			n	-trans_id
			n	-trans_id_incr_mode
			n	-trans_id_list
			n	-trans_id_repeat
			n	-trans_id_step
			n	-transmit_mode
			n	-vlan_ether_type
			n	-vlan_id_count
			n	-vlan_id_outer_count
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information.
			 key:log     value:When status is failure, contains more information.
		message of message group handle to be used in emulation_oam_info
			 key:handle  value:message of message group handle to be used in emulation_oam_info
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1. If all filter parameter are specified as lists, parameter -count will be ignored and the number of messages to be configured will be set by the length of the shortest list parameter. If all filter parameters are configured as 'all', the count parameter will be forced to value 1.
		2. If a filter parameter is not specified at all it will behave as an 'include all' filter.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_oam_config_msg", kwargs)

	def emulation_oam_config_topology(self, **kwargs):
		""" This procedure will configure an OAM topology consisting of
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_oam_config_topology
			 	-mode                                       ANY
			 	[-continuity_check                          ANY]
			 	[-continuity_check_interval                 ANY]
			 	[-count                                     ANY]
			 	[-domain_level                              ANY]
			 	[-encap                                     ANY]
			 	[-fault_alarm_interval                      ANY]
			 	[-fault_alarm_signal                        ANY]
			 	[-handle                                    ANY]
			 	[-mac_local                                 ANY]
			 	[-mac_local_incr_mode                       ANY]
			 	[-mac_local_list                            ANY]
			 	[-mac_local_repeat                          ANY]
			 	[-mac_local_step                            ANY]
			 	[-md_integer                                ANY]
			 	[-md_level                                  ANY]
			 	[-md_mac                                    ANY]
			 	[-md_name                                   ANY]
			 	[-md_name_format                            ANY]
			 	[-md_name_length                            ANY]
			 	[-mep_count                                 ANY]
			 	[-mep_id                                    ANY]
			 	[-mep_id_incr_mode                          ANY]
			 	[-mep_id_list                               ANY]
			 	[-mep_id_repeat                             ANY]
			 	[-mep_id_step                               ANY]
			 	[-mip_count                                 ANY]
			 	[-oam_standard                              ANY]
			 	[-port_handle                               ANY]
			 	[-short_ma_name_format                      ANY]
			 	[-short_ma_name_length                      ANY]
			 	[-short_ma_name_value                       ANY]
			 	[-vlan_ether_type                           ANY]
			 	[-vlan_id                                   ANY]
			 	[-vlan_id_outer_repeat                      ANY]
			 	[-vlan_id_outer_step                        ANY]
			 	[-vlan_id_repeat                            ANY]
			 	[-vlan_id_step                              ANY]
			 	[-vlan_outer_ether_type                     ANY]
			 	[-vlan_outer_id                             ANY]
			x	[-bridge_id                                 ANY]
			x	[-bridge_id_step                            ANY]
			x	[-return_method                             ANY]
			x	[-short_ma_name_repeat                      ANY]
			x	[-short_ma_name_step                        ANY]
			x	[-short_ma_name_wc_start                    ANY]
			x	[-short_ma_name_wildcard                    ANY]
			n	[-ccdb_expect_conectivity                   ANY]
			n	[-ccdb_mac                                  ANY]
			n	[-ccdb_md_integer                           ANY]
			n	[-ccdb_md_level                             ANY]
			n	[-ccdb_md_mac                               ANY]
			n	[-ccdb_md_name                              ANY]
			n	[-ccdb_md_name_format                       ANY]
			n	[-ccdb_md_name_length                       ANY]
			n	[-ccdb_mep_id                               ANY]
			n	[-ccdb_oam_standard                         ANY]
			n	[-ccdb_short_ma_name_format                 ANY]
			n	[-ccdb_short_ma_name_length                 ANY]
			n	[-ccdb_short_ma_name_value                  ANY]
			n	[-ccdb_vlan_id                              ANY]
			n	[-ccdb_vlan_outer_id                        ANY]
			n	[-continuity_check_burst_delay              ANY]
			n	[-continuity_check_burst_size               ANY]
			n	[-continuity_check_mcast_mac_dst            ANY]
			n	[-continuity_check_remote_defect_indication ANY]
			n	[-continuity_check_ucast_mac_dst            ANY]
			n	[-fault_alarm_locked                        ANY]
			n	[-mac_remote                                ANY]
			n	[-mac_remote_incr_mode                      ANY]
			n	[-mac_remote_list                           ANY]
			n	[-mac_remote_repeat                         ANY]
			n	[-mac_remote_step                           ANY]
			n	[-mep_port_behavior                         ANY]
			n	[-multiple_levels_handle                    ANY]
			n	[-responder_latency                         ANY]
		
		Arguments:
			 	-mode
			 		Action to perform. This parameter is supported using the following:
			 		Valid choices are:
			    		create-Create -count OAM Bridges on -port_handle. Attach MIPs and MEPs to configure topology.
			    		reset-Remove all OAM bridges from port $port_handle and OAM bridge specified with -handle parameter.
			    		modify-NOT SUPPORTED
			 	-continuity_check
			 		Enable Continuity Check sending.
			 	-continuity_check_interval
			 		Define the interval between Continuity Check messages.
			 		Valid choices are:
			    		-
			    		1s - (DEFAULT)
			 	-count
			 		Number of OAM Bridges to configure. A topology will be created on each bridge using parameter mip_count, mep_count, md_level and domain_level. If a bridge with Bridge Id -bridge_id already exists on port -port_handle it will be used. Otherwise a new bridge is created.
			 	-domain_level
			 		If this parameter is configured to 'level0' the topology will be a Hub and Spoke topology. Ixia port will have a number of bridges equal to -count parameter. Each bridge will have -mip_count MIPs connected in series and -mep_count MEPs connected to the last MIP. If mip_count is 0, all MEPs are connected directly to the bridge.Example: -count = 1; mep_count = 2; mip_count = 1IxiaPort -- Bridge1 -- MIP1-- MEP1\--MEP2If this parameter is configured to any other level, the topology will be a Tree topology spanning across multiple levels. The starting md level will be configured with -md_level parameter and the ending md level will be configured using -domain_level parameter.Example -count = 1; mip_count = 1; mep_count = 2; -domain_level = 1; md_level = 0IxiaPort -- Bridge1 -- MIP1-- MEP1 -- MIP2 -- MEP2\\-- MEP3\--MEP4 -- MIP3 -- MEP5\-- MEP6
			 		Valid choices are:
			    		level0 - (DEFAULT)
			 	-encap
			 		The ethernet encapsulation for this port.
			 		Valid choices are:
			    		ethernet_ii - (DEFAULT)
			    		sap - NOT SUPPORTED
			 	-fault_alarm_interval
			 		Define the interval between alarm or lock signals.
			 		Valid choices are:
			    		1s - (DEFAULT)
			 	-fault_alarm_signal
			 		Enable the Alarm Indication Signal (AIS) transmission with a link is disabled.
			 	-handle
			 		OAM bridge handle for -mode 'reset'.
			 	-mac_local
			 		The MAC address for the Maintenance Points. If a bridge having Bridge ID equal to the value of the -bridge_id parameter already exists on the port handle, the default mac_local value will be calculated by incrementing the mac address of the last MP from this bridge. (DEFAULT =00de.<chassis><card>.<port>00)
			 	-mac_local_incr_mode
			 		How to modify MP mac address from one MP to the next.
			 		Valid choices are:
			    		none - (DEFAULT ) do not modify
			    		increment - increment using mac_local_step
			    		decrement - decrement using mac_local_step
			    		list - use mac addresses specified with mac_local_list. If the number of MAC
			    		random - generate random MAC addresses.
			 	-mac_local_list
			 		Use when -mac_local_incr_mode is list. List of MAC addresses.
			 	-mac_local_repeat
			 		Use when -mac_local_incr_mode is increment or decrement. Defines the number of times to use a MAC address before incrementing/decrementing.
			 	-mac_local_step
			 		Use when -mac_local_incr_mode is increment or decrement. Defines the step used to increment the MP Mac address.
			 	-md_integer
			 		Used when -md_name_format is 'mac_addr' along with -md_mac parameter. The MD Name will be <md_mac>-<md_integer>.
			 	-md_level
			 		Define the Maintenance Domain Level to be used.
			 	-md_mac
			 		Used when -md_name_format is 'mac_addr' along with -md_mac parameter. The MD Name will be <md_mac>-<md_integer>.
			 	-md_name
			 		Used when -md_name_format is 'domain_name' or 'char_str'. Define the MD Name.
			 	-md_name_format
			 		Define the format for MD Name.
			 		Valid choices are:
			    		none - do not use MD Name.
			    		domain_name - uses -md_name parameter to define the MD Name
			    		mac_addr - uses -md_mac and -md_integer parameters to define the MD Name
			    		char_str - (DEFAULT) uses -md_name parameter to define the MD Name
			    		icc_based - valid for -oam_standard itu-t_y1731 to define the MEG Id.
			 	-md_name_length
			 		Define the length of the MD Name.
			 	-mep_count
			 		Define the number of MEPs connected to the last simulated MIP.
			 	-mep_id
			 		Define the starting MEP Id value.
			 	-mep_id_incr_mode
			 		Configures how the MPE Id value will be modified between MEPs
			 		Valid choices are:
			    		none - (DEFAULT) do not alter MEP Id
			    		increment - Increment MEP Id using -mep_id_step parameter
			    		decrement - Decrement MEP Id using -mep_id_step parameter
			    		list - Use MEP IDs defined with -mep_id_list parameter. Last MEP ID from list will be
			    		random - Generate random MEP IDs.
			 	-mep_id_list
			 		Used when mep_id_incr_mode is 'list'. Contains a list of MEP IDs.
			 	-mep_id_repeat
			 		Used when mep_id_incr_mode is increment|decrement. Defines the number of times to use a MEP ID before incrementing or decrementing.
			 	-mep_id_step
			 		Used when mep_id_incr_mode is increment|decrement. Define the step to use when incrementing MEP ID.
			 	-mip_count
			 		Define the number of MIPs connected in series.
			 	-oam_standard
			 		Specify the Ethernet OAM standard to be used, either IEEE 802.1ag or ITU-T Y1731.
			 		Valid choices are:
			    		1ag - (DEFAULT)
			 	-port_handle
			 		Configure the port_handle to configure the OAM bridges and topologies on.
			 	-short_ma_name_format
			 		Configure Short MA Name format.
			 		Valid choices are:
			    		primary_vid - short_ma_name must be a number from 0 to 4095.
			    		char_str - short_ma_name must be valid string
			    		integer - (DEFAULT) short_ma_name must be a number from 0 to 65535
			    		rfc_2685_vpn_id - short_ma_name must be formatted <number1>-<number2>
			 	-short_ma_name_length
			 		Define the length for -short_ma_name
			 	-short_ma_name_value
			 		Define the value of the short_ma_name depending on -short_ma_name_format.
			 	-vlan_ether_type
			    		0x8100 - (DEFAULT)
			 	-vlan_id
			 		Configure VLAN ID.
			 	-vlan_id_outer_repeat
			 		Configure the number of times to use -vlan_outer_id before incrementing.
			 	-vlan_id_outer_step
			 		Configure the step to use when incrementing -vlan_outer_id.
			 	-vlan_id_repeat
			 		Configure the number of times to use -vlan_id before incrementing.
			 	-vlan_id_step
			 		Configure the step to use when incrementing -vlan_id.
			 	-vlan_outer_ether_type
			    		0x8100 - (DEFAULT)
			 	-vlan_outer_id
			 		Configure the starting VLAN Outer ID.
			x	-bridge_id
			x		Configure the Bridge ID Mac address. If a bridge with this Bridge ID alreadyexists on port -port_handle, all MPs will be configured on that bridge.(DEFAULT =00de.<chassis><card>.<port>00)
			x	-bridge_id_step
			x		Configure the step to increment Bridge ID with.
			x	-return_method
			x		keyed_list (default) - always return the traffic endpoint handles as a list using the 'traffic_handles' key, no matter how long it takeskeyed_list_or_array - when more than 2000 traffic enpoint handles need to be retrieved, the key'traffic_handles_array' will be returned instead of traffic endpoint handles as a list using the 'traffic_handles'. This key, traffic_handles_array, represents the name of the array to be used for reading the traffic endpoint handles. This method has been introduced to increase performance when returning and reading traffic handles. Returning a huge list in the tcl console can make the console hang.array - the key traffic_handles_array will be returned instead of the traffic_handles list of traffic endpoints. This key, traffic_handles_array, represents the name of the array to be used for reading the traffic handles. values are the statistics values. This method has been introduced to increase performance when returning and reading traffic handles. Returning a huge list in the tcl console can make the console hang.
			x	-short_ma_name_repeat
			x		Configure the number of times to use the same Bridge ID before incrementing short_ma_name_valueor before incrementing -short_ma_name_wc_start.
			x	-short_ma_name_step
			x		This is the step that will be used to increment the short_ma_name_value or the parameter -short_ma_name_wc_start if -short_ma_name_wildcard is 1.
			x	-short_ma_name_wc_start
			x		When short_ma_name_format is 'char_str' this is the starting value for the wildcard substitution.
			x	-short_ma_name_wildcard
			x		Enable or disable using wildcard substitution for short_ma_name_value. Wildcard character will be '?'
			x		Valid choices are:
			x   		0 - (DEFAULT ) Disable
			x   		1 - Enable
			n	-ccdb_expect_conectivity
			n	-ccdb_mac
			n	-ccdb_md_integer
			n	-ccdb_md_level
			n	-ccdb_md_mac
			n	-ccdb_md_name
			n	-ccdb_md_name_format
			n	-ccdb_md_name_length
			n	-ccdb_mep_id
			n	-ccdb_oam_standard
			n	-ccdb_short_ma_name_format
			n	-ccdb_short_ma_name_length
			n	-ccdb_short_ma_name_value
			n	-ccdb_vlan_id
			n	-ccdb_vlan_outer_id
			n	-continuity_check_burst_delay
			n	-continuity_check_burst_size
			n	-continuity_check_mcast_mac_dst
			n	-continuity_check_remote_defect_indication
			n	-continuity_check_ucast_mac_dst
			n	-fault_alarm_locked
			n	-mac_remote
			n	-mac_remote_incr_mode
			n	-mac_remote_list
			n	-mac_remote_repeat
			n	-mac_remote_step
			n	-mep_port_behavior
			n	-multiple_levels_handle
			n	-responder_latency
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                 value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information.
			 key:log                    value:When status is failure, contains more information.
		The list of OAM Bridges created.
			 key:handle                 value:The list of OAM Bridges created.
		List of handles that can be used as emulation_dst_handle and emulation_src_handle values in ::<namespace>::traffic_config.
			 key:traffic_handles        value:List of handles that can be used as emulation_dst_handle and emulation_src_handle values in ::<namespace>::traffic_config.
		The name of the array to be used for reading the traffic endpoint handles. This key is returned when more than 2000 traffic endpoint handles need to be retrieved.
			 key:traffic_handles_array  value:The name of the array to be used for reading the traffic endpoint handles. This key is returned when more than 2000 traffic endpoint handles need to be retrieved.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_oam_config_topology", kwargs)

	def emulation_oam_control(self, **kwargs):
		""" This procedure will start and stop E-OAM emulations.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_oam_control
			 	-action       ANY
			 	[-port_handle ANY]
			 	[-handle      ANY]
			n	[-link_level  ANY]
		
		Arguments:
			 	-action
			 		Action to perform. This parameter is supported using the following:
			 		Valid choices are:
			    		start-Start OAM emulation on ports specified with -port_handle and ports that are configured with OAM bridges specified with parameter -handle. Actions start, stop and reset are performed per-port.
			    		stop -Stop OAM emulation on ports specified with -port_handle and ports that are configured with OAM bridges specified with parameter -handle. Actions start, stop and reset are performed per-port.
			    		disable_link-Disable bridges configured on port -port_handle and bridges specified with parameter -handle.
			    		enable_all-Enable bridges configured on port -port_handle and bridges specified with parameter -handle.
			    		reset- Restart OAM emulation on ports specified with -port_handle and ports that are configured with OAM bridges specified with parameter -handle. Actions start, stop and reset are performed per-port.
			    		disable_terminating_link-NOT SUPPORTED
			    		lock_link- - NOT SUPPORTEDunlock_all - NOT SUPPORTED
			 	-port_handle
			 		At least one of the parameter -port_handle and -handle must be provided.When -action is start|stop|reset, action is performed on the ports from -port_handle. When -action is disable_link|enable_all, all bridges configured on the ports specified with -port_handle will be disabled/enabled.
			 	-handle
			 		At least one of the parameter -port_handle and -handle must be provided.Parameter -handle must contain bridge handles returned by emulation_oam_config_topology.When -action is start|stop|reset, action is performed on the ports on which the bridge handles specified with -handle are configured. When -action is disable_link|enable_all, all bridges specified with parameter -handle will be disabled/enabled.
			n	-link_level
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information.
			 key:log     value:When status is failure, contains more information.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_oam_control", kwargs)

	def emulation_oam_info(self, **kwargs):
		""" This procedure will get various data from E-OAM state machines.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_oam_info
			 	-mode         ANY
			 	[-action      ANY]
			 	[-port_handle ANY]
			 	[-handle      ANY]
		
		Arguments:
			 	-mode
			 		Define the desired mode for info return.
			 		Valid choices are:
			    		aggregate - get aggregate statistics. Depending on -action they will be topology stats or message_stats.
			    		session - get per sesssion statistics.
			 	-action
			 		Specify what type of data to poll.
			 		Valid choices are:
			    		-
			 	-port_handle
			 		Statistics can be polled only from one port with one procedure call. Specify the port to poll the data from. If -mode is session, all bridges from the port will be polled.
			 	-handle
			 		Use OAM topology handles returned by emulation_oam_config_topology. When -mode is session, and action is get_topology_stats, all topology statistics will be prepended with the topology handle.Use OAM message handles returned by emulation_oam_config_mesg when -mode is session and -action is 'get_topology_stats' to poll message statistics per message handle (message handles can be returned by emulation_oam_config_msg per_group or per_message). If a message handle is used, other handles are ignored (port_handle). A list of message handles can be polled with one call. Per session message statistic keys will be prepended with the handle that they belong to.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                   value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information.
			 key:log                                                      value:When status is failure, contains more information.
		The name of the array to be used for reading the stats. This key is returned when more than 2000 statistics values need to be retrieved. The indices of this array are the keys that you'll find explained below, and the values are the statistics values. This method has been introduced to increase performance when returning and reading stats. Returning a huge list in the tcl console can make the console hang.
			 key:handle                                                   value:The name of the array to be used for reading the stats. This key is returned when more than 2000 statistics values need to be retrieved. The indices of this array are the keys that you'll find explained below, and the values are the statistics values. This method has been introduced to increase performance when returning and reading stats. Returning a huge list in the tcl console can make the console hang.
		Number of transitions to the Waiting state.
			 key:linktrace.state_waiting                                  value:Number of transitions to the Waiting state.
		Number of transitions to the Received state.
			 key:linktrace.state_received                                 value:Number of transitions to the Received state.
		Number of transitions to the Failed state.
			 key:linktrace.state_failed                                   value:Number of transitions to the Failed state.
		Number of Link Trace Reply (LTR) packets received.
			 key:linktrace.receive_ltr_count                              value:Number of Link Trace Reply (LTR) packets received.
		Number of Link Trace Message (LTM) packets transmitted.
			 key:linktrace.transmit_ltm_count                             value:Number of Link Trace Message (LTM) packets transmitted.
		Number of Loopback Reply (LBR) packets received.
			 key:loopback.receive_lbr_count                               value:Number of Loopback Reply (LBR) packets received.
		Number of Loopback Message (LBM) packets transmitted.
			 key:loopback.transmit_lbm_count                              value:Number of Loopback Message (LBM) packets transmitted.
			 key:aggregate.rx.fm_pkts                                     value:
			 key:aggregate.rx.lbm_pkts                                    value:
			 key:aggregate.rx.ltm_pkts                                    value:
			 key:aggregate.rx.ccm_pkts                                    value:
			 key:aggregate.rx.ais_pkts                                    value:
			 key:aggregate.tx.fm_pkts                                     value:
			 key:aggregate.tx.lbm_pkts                                    value:
			 key:aggregate.tx.ltm_pkts                                    value:
			 key:aggregate.tx.ccm_pkts                                    value:
			 key:aggregate.tx.ais_pkts                                    value:
			 key:aggregate.error.lbm_pkts                                 value:
			 key:aggregate.error.ltm_pkts                                 value:
			 key:aggregate.error.ccm_pkts                                 value:
			 key:aggregate.detected_failure_stats.unexpected_cc_period    value:
			 key:aggregate.topology_stats.port_name                       value:
			 key:aggregate.topology_stats.total_maintenance_points        value:
			 key:aggregate.topology_stats.operational_maintenance_points  value:
			 key:aggregate.topology_stats.total_entries                   value:
			 key:aggregate.topology_stats.start_entries                   value:
			 key:aggregate.topology_stats.ok_entries                      value:
			 key:aggregate.topology_stats.fail_entries                    value:
			 key:md_level.<md_level>.mac.<mac>.vlan_outer                 value:
			 key:md_level.<md_level>.mac.<mac>.vlan                       value:
			 key:md_level.<md_level>.mac.<mac>.mep_id                     value:
			 key:md_level.<md_level>.mac.<mac>.md_name                    value:
			 key:md_level.<md_level>.mac.<mac>.short_ma_name              value:
			 key:md_level.<md_level>.mac.<mac>.state                      value:
			 key:md_level.<md_level>.mac.<mac>.last_state_change          value:
			 key:md_level.<md_level>.mac.<mac>.ccm_interval               value:
			 key:md_level.<md_level>.mac.<mac>.remote_failure_indicator   value:
			 key:linktrace.recent_reply_status                            value:
			 key:linktrace.average_hop_count                              value:
			 key:linktrace.vlan_id_outer                                  value:
			 key:linktrace.dst_mac_address                                value:
			 key:linktrace.md_level                                       value:
			 key:linktrace.no_reply_count                                 value:
			 key:linktrace.partial_reply_count                            value:
			 key:linktrace.recent_hop_count                               value:
			 key:linktrace.recent_hops                                    value:
			 key:linktrace.vlan_id                                        value:
			 key:linktrace.src_mac_address                                value:
			 key:linktrace.transmit_ltm_count_total                       value:
			 key:linktrace.receive_ltr_count_total                        value:
			 key:linktrace.no_reply_count_total                           value:
			 key:loopback.transmit_lbm_count_total                        value:
			 key:loopback.receive_ltr_count_total                         value:
			 key:loopback.no_reply_count_total                            value:
			 key:loopback.no_reply_count                                  value:
			 key:loopback.vlan_id_outer                                   value:
		dstMacAddress
			 key:loopback.dst_mac_address                                 value:dstMacAddress
		mdLevel
			 key:loopback.md_level                                        value:mdLevel
		recentReachability
			 key:loopback.recent_reachability                             value:recentReachability
		recentRtt
			 key:loopback.recent_rtt                                      value:recentRtt
		sVlan
			 key:loopback.vlan_id                                         value:sVlan
			 key:aggregate.rx.ltr_pkts                                    value:
			 key:aggregate.tx.ltr_pkts                                    value:
			 key:aggregate.tx.lbr_pkts                                    value:
			 key:aggregate.rx.ltr_pkts                                    value:
			 key:aggregate.error.ltr_rx_invalid                           value:
			 key:aggregate.rx.ccm_out_of_sequence                         value:
			 key:aggregate.topology.ma_configured                         value:
			 key:aggregate.topology.ma_running                            value:
			 key:aggregate.topology.remote_meps                           value:
			 key:aggregate.topology.rmeps_defective                       value:
			 key:aggregate.topology.rmep_error_no_defect                  value:
			 key:aggregate.topology.mep_fng_reset                         value:
			 key:aggregate.topology.mep_fng_defect                        value:
			 key:aggregate.topology.mep_fng_defect_reported               value:
			 key:aggregate.topology.mep_fng_defect_clearing               value:
			 key:md_level.<md_level>.mac.<mac>.short_maname_format        value:
			 key:md_level.<md_level>.mac.<mac>.all_rmep_dead              value:
			 key:md_level.<md_level>.mac.<mac>.err_ccm_defect             value:
			 key:md_level.<md_level>.mac.<mac>.md_name_format             value:
			 key:md_level.<md_level>.mac.<mac>.out_ofsequence_ccm_count   value:
			 key:md_level.<md_level>.mac.<mac>.received_ais               value:
			 key:md_level.<md_level>.mac.<mac>.received_iface_tlv_defect  value:
			 key:md_level.<md_level>.mac.<mac>.received_port_tlv_defect   value:
			 key:md_level.<md_level>.mac.<mac>.received_rdi               value:
			 key:md_level.<md_level>.mac.<mac>.rmep_ccm_defect            value:
			 key:Linktrace Messages not supported                         value:
			 key:linktrace.min_response_time                              value:
			 key:linktrace.avg_response_time                              value:
			 key:linktrace.max_response_time                              value:
			 key:Loopback Messages params not supported                   value:
			 key:loopback.min_response_time                               value:
			 key:loopback.avg_response_time                               value:
			 key:loopback.max_response_time                               value:
			 key:loopback.state_waiting                                   value:
			 key:loopback.state_received                                  value:
			 key:loopback.state_failed                                    value:
			 key:tst.transmit_count                                       value:
			 key:aggregate.rx.lck_pkts                                    value:
			 key:aggregate.rx.tst_pkts                                    value:
			 key:aggregate.rx.aps_pkts                                    value:
			 key:aggregate.rx.mcc_pkts                                    value:
			 key:aggregate.rx.exm_pkts                                    value:
			 key:aggregate.rx.exr_pkts                                    value:
			 key:aggregate.rx.vsm_pkts                                    value:
			 key:aggregate.rx.vsr_pkts                                    value:
			 key:aggregate.tx.lck_pkts                                    value:
			 key:aggregate.error.fm_pkts                                  value:
			 key:aggregate.error.ais_pkts                                 value:
			 key:aggregate.error.lck_pkts                                 value:
			 key:aggregate.detected_failure_stats.lock                    value:
			 key:aggregate.detected_failure_stats.unexpected_mep          value:
			 key:aggregate.detected_failure_stats.ais_pkts                value:
			 key:aggregate.detected_failure_stats.lck_pkts                value:
			 key:aggregate.sockets.cfmMcastRxSocket.state                 value:
			 key:aggregate.sockets.cfmMcastRxSocket.rx_pkts               value:
			 key:aggregate.sockets.cfmMcastRxSocket.tx_pkts               value:
			 key:aggregate.sockets.cfmSocket.state                        value:
			 key:aggregate.sockets.cfmSocket.rx_pkts                      value:
			 key:aggregate.sockets.cfmSocket.tx_pkts                      value:
			 key:aggregate.topology_stats.total_md_levels                 value:
			 key:aggregate.topology_stats.operational_md_levels           value:
			 key:aggregate.topology_stats.states                          value:
			 key:aggregate.topology_stats.disabled                        value:
			 key:aggregate.topology_stats.enabled                         value:
			 key:aggregate.topology_stats.maintenance_point_down          value:
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_oam_info", kwargs)

	def emulation_ospf_config(self, **kwargs):
		""" This procedure is used to add, enable, disable, modify, and delete one or more emulated Open  Shortest Path First (OSPF) routers  to a particular Ixia Interface. The user can then configure OSPF routes by using the procedure "emulation_ospf_route_config".
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ospf_config
			 	[-handle                                               ANY]
			x	[-return_detailed_handles                              CHOICES 0 1
			x                                                       DEFAULT 0]
			 	[-area_id                                              IPV4
			                                                        DEFAULT 0.0.0.0]
			 	[-area_id_step                                         IPV4]
			x	[-area_id_as_number                                    NUMERIC]
			x	[-area_id_as_number_step                               NUMERIC]
			x	[-area_id_type                                         CHOICES number
			x                                                       CHOICES ip
			x                                                       CHOICES area_id_as_number
			x                                                       CHOICES area_id_as_ip
			x                                                       DEFAULT ip]
			 	[-area_type                                            ANY]
			 	[-authentication_mode                                  CHOICES null simple md5]
			 	[-count                                                RANGE 1-2000
			                                                        DEFAULT 1]
			 	[-dead_interval                                        RANGE 1-65535]
			 	[-demand_circuit                                       CHOICES 0 1
			                                                        DEFAULT 0]
			 	[-enable_support_rfc_5838                              ANY]
			 	[-graceful_restart_enable                              CHOICES 0 1]
			 	[-hello_interval                                       RANGE 1-65535]
			x	[-ignore_db_desc_mtu                                   ANY]
			x	[-router_interface_active                              CHOICES 0 1]
			x	[-enable_fast_hello                                    CHOICES 0 1]
			x	[-hello_multiplier                                     NUMERIC]
			x	[-max_mtu                                              NUMERIC]
			x	[-protocol_name                                        ALPHA]
			x	[-router_active                                        CHOICES 0 1]
			x	[-router_asbr                                          CHOICES 0 1
			x                                                       DEFAULT 0]
			x	[-do_not_generate_router_lsa                           CHOICES 0 1]
			x	[-router_abr                                           CHOICES 0 1
			x                                                       DEFAULT 0]
			x	[-inter_flood_lsupdate_burst_gap                       NUMERIC]
			x	[-lsa_refresh_time                                     NUMERIC]
			x	[-lsa_retransmit_time                                  NUMERIC]
			x	[-max_ls_updates_per_burst                             NUMERIC]
			x	[-oob_resync_breakout                                  CHOICES 0 1]
			 	[-interface_cost                                       RANGE 0-4294967295]
			 	[-intf_ip_addr                                         IP]
			 	[-intf_ip_addr_step                                    IP
			                                                        DEFAULT 0.0.1.0]
			 	[-intf_prefix_length                                   RANGE 1-128
			                                                        DEFAULT 24]
			x	[-interface_handle                                     ANY]
			 	[-instance_id                                          RANGE 0-255
			                                                        DEFAULT 0]
			 	[-instance_id_step                                     RANGE 0-255
			                                                        DEFAULT 0]
			 	[-loopback_ip_addr                                     IP
			                                                        DEFAULT 0.0.0.0]
			 	[-loopback_ip_addr_step                                IP
			                                                        DEFAULT 0.0.0.0]
			 	[-lsa_discard_mode                                     CHOICES 0 1]
			x	[-mac_address_init                                     MAC]
			x	[-mac_address_step                                     MAC
			x                                                       DEFAULT 0000.0000.0001]
			 	[-md5_key                                              ALPHA]
			 	[-md5_key_id                                           RANGE 0-255]
			 	[-mtu                                                  RANGE 68-9216]
			 	[-network_type                                         CHOICES broadcast ptomp ptop]
			 	[-neighbor_intf_ip_addr                                IP
			                                                        DEFAULT 0.0.0.0]
			 	[-neighbor_intf_ip_addr_step                           IP
			                                                        DEFAULT 0.0.0.0]
			 	[-neighbor_router_id                                   IPV4]
			 	[-neighbor_router_id_step                              IPV4
			                                                        DEFAULT 0.0.1.0]
			 	[-option_bits                                          ANY]
			x	[-type_of_service_routing                              CHOICES 0 1]
			x	[-external_capabilities                                CHOICES 0 1]
			x	[-multicast_capability                                 CHOICES 0 1]
			x	[-nssa_capability                                      CHOICES 0 1]
			x	[-external_attribute                                   CHOICES 0 1]
			x	[-opaque_lsa_forwarded                                 CHOICES 0 1]
			x	[-unused                                               CHOICES 0 1]
			x	[-override_existence_check                             CHOICES 0 1
			x                                                       DEFAULT 0]
			x	[-override_tracking                                    CHOICES 0 1
			x                                                       DEFAULT 0]
			 	[-password                                             ALPHA]
			x	[-reset                                                FLAG]
			 	[-router_id                                            IPV4]
			 	[-router_id_step                                       IPV4
			                                                        DEFAULT 0.0.1.0]
			 	[-router_priority                                      RANGE 0-255]
			 	[-te_enable                                            CHOICES 0 1]
			 	[-te_max_bw                                            REGEXP ^[0-9]+]
			 	[-te_max_resv_bw                                       REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority0                               REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority1                               REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority2                               REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority3                               REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority4                               REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority5                               REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority6                               REGEXP ^[0-9]+$]
			 	[-te_unresv_bw_priority7                               REGEXP ^[0-9]+$]
			 	[-te_metric                                            RANGE 0-2147483647]
			 	[-te_router_id                                         ANY]
			x	[-vlan                                                 CHOICES 0 1]
			 	[-vlan_id_mode                                         CHOICES fixed increment
			                                                        DEFAULT increment]
			 	[-vlan_id                                              RANGE 0-4096]
			 	[-vlan_id_step                                         RANGE 0-4096
			                                                        DEFAULT 1]
			 	[-vlan_user_priority                                   RANGE 0-7
			                                                        DEFAULT 0]
			x	[-atm_encapsulation                                    ANY]
			x	[-bfd_registration                                     CHOICES 0 1
			x                                                       DEFAULT 0]
			x	[-enable_dr_bdr                                        CHOICES 0 1
			x                                                       DEFAULT 0]
			 	[-vci                                                  ANY]
			 	[-vci_step                                             ANY]
			 	[-vpi                                                  ANY]
			 	[-vpi_step                                             ANY]
			n	[-get_next_session_mode                                ANY]
			x	[-no_write                                             ANY]
			 	[-te_admin_group                                       HEX]
			x	[-validate_received_mtu                                CHOICES 0 1
			x                                                       DEFAULT 1]
			 	[-graceful_restart_helper_mode_enable                  CHOICES 0 1
			                                                        DEFAULT 0]
			 	[-strict_lsa_checking                                  CHOICES 0 1
			                                                        DEFAULT 1]
			 	[-support_reason_sw_restart                            CHOICES 0 1
			                                                        DEFAULT 1]
			 	[-support_reason_sw_reload_or_upgrade                  CHOICES 0 1
			                                                        DEFAULT 1]
			 	[-support_reason_switch_to_redundant_processor_control CHOICES 0 1
			                                                        DEFAULT 1]
			 	[-support_reason_unknown                               CHOICES 0 1
			                                                        DEFAULT 0]
			 	[-mode                                                 CHOICES create
			                                                        CHOICES delete
			                                                        CHOICES modify
			                                                        CHOICES enable
			                                                        CHOICES disable
			                                                        DEFAULT create]
			 	[-session_type                                         CHOICES ospfv2 ospfv3
			                                                        DEFAULT ospfv2]
			n	[-graceful_restart_restarting_mode_enable              ANY]
			n	[-grace_period                                         ANY]
			n	[-restart_reason                                       ANY]
			n	[-number_of_restarts                                   ANY]
			n	[-restart_start_time                                   ANY]
			n	[-restart_down_time                                    ANY]
			n	[-restart_up_time                                      ANY]
			x	[-port_handle                                          REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-rate_control_interval                                NUMERIC]
			x	[-flood_lsupdates_per_interval                         NUMERIC]
			x	[-attempt_scale_mode                                   CHOICES port device_group
			x                                                       DEFAULT port]
			x	[-attempt_rate                                         RANGE 1-10000]
			x	[-attempt_interval                                     NUMERIC]
			x	[-attempt_enabled                                      CHOICES 0 1]
			x	[-disconnect_scale_mode                                CHOICES port device_group
			x                                                       DEFAULT port]
			x	[-disconnect_rate                                      RANGE 1-10000]
			x	[-disconnect_interval                                  NUMERIC]
			x	[-disconnect_enabled                                   CHOICES 0 1]
			n	[-gre_checksum                                         ANY]
			n	[-gre_local_ip                                         ANY]
			n	[-gre_remote_ip                                        ANY]
			n	[-gre_tunnel                                           ANY]
			n	[-host_route                                           ANY]
			n	[-int_msg_exchange                                     ANY]
			n	[-lsa_retransmit_delay                                 ANY]
			n	[-max_lsas_per_pkt                                     ANY]
			n	[-neighbor_dr_eligibility                              ANY]
			n	[-poll_interval                                        ANY]
			n	[-transmit_delay                                       ANY]
			n	[-vlan_cfi                                             ANY]
			x	[-link_metric                                          RANGE 0-4294967295
			x                                                       DEFAULT 0]
			x	[-enable_ignore_db_desc_mtu                            CHOICES 0 1
			x                                                       DEFAULT 0]
			x	[-router_bit                                           CHOICES 0 1
			x                                                       DEFAULT 0]
			x	[-v6                                                   CHOICES 0 1
			x                                                       DEFAULT 0]
			x	[-disable_auto_generate_link_lsa                       ANY]
			x	[-ospfv3_lsa_flood_rate_control                        ANY
			x                                                       DEFAULT 1]
			x	[-intf_ipv6_addr                                       IPV6]
			x	[-intf_ipv6_addr_step                                  IPV6]
			x	[-ipv6_gateway_ip                                      IPV6]
			x	[-ipv6_gateway_ip_step                                 IPV6]
			x	[-intf_ipv6_prefix_length                              RANGE 1-128
			x                                                       DEFAULT 64]
			x	[-enable_segment_routing                               CHOICES 0 1]
			x	[-configure_s_i_d_index_label                          ANY]
			x	[-sid_index_label                                      ANY]
			x	[-algorithm                                            ANY]
			x	[-np_flag                                              ANY]
			x	[-m_flag                                               ANY]
			x	[-e_flag                                               ANY]
			x	[-v_flag                                               ANY]
			x	[-l_flag                                               ANY]
			x	[-srgb_range_count                                     NUMERIC]
			x	[-s_r_algorithm_count                                  NUMERIC]
			x	[-start_s_i_d_label                                    ANY]
			x	[-sid_count                                            ANY]
			x	[-enable_adj_s_i_d                                     ANY]
			x	[-adj_s_i_d                                            ANY]
			x	[-b_flag                                               ANY]
			x	[-s_flag                                               ANY]
			x	[-v_flag_if                                            ANY]
			x	[-l_flag_if                                            ANY]
			x	[-p_flag                                               ANY]
			x	[-weight                                               ANY]
			x	[-enable_s_r_l_g                                       ANY]
			x	[-srlg_count                                           NUMERIC]
			x	[-srlg_value                                           ANY]
			x	[-ospf_sr_algorithm                                    ANY]
			x	[-en_link_protection                                   ANY]
			x	[-extra_traffic                                        ANY]
			x	[-unprotected                                          ANY]
			x	[-shared                                               ANY]
			x	[-dedicated1_to1                                       ANY]
			x	[-dedicated1_plus1                                     ANY]
			x	[-enhanced                                             ANY]
			x	[-reserved40                                           ANY]
			x	[-reserved80                                           ANY]
			x	[-high_perf_learning_mode_for_sr                       ANY]
			x	[-enable_srlb                                          CHOICES 0 1]
			x	[-srlb_range_count                                     NUMERIC]
			x	[-srlb_start_sid_label                                 ANY]
			x	[-srlb_sid_count                                       ANY]
		
		Arguments:
			 	-handle
			 		OSPF session handle for using the modes delete, modify, enable, and disable.
			 		When -handle is provided with the /globals value the arguments that configure global protocol
			 		setting accept both multivalue handles and simple values.
			 		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
			 		that configure global settings will only accept simple values. In this situation, these arguments will
			 		configure only the settings of the parent device group or the ports associated with the parent topology.
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-area_id
			 		The OSPF area ID associated with the interface.
			 	-area_id_step
			 		The OSPF area ID step associated with the -area_id option on the ISPF
			 		interface.
			x	-area_id_as_number
			x		OSPF Area ID for a non-connected interface, displayed in Integer format
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-area_id_as_number_step
			x		OSPF Area ID step for a non-connected interface, displayed in Integer format
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-area_id_type
			x		Area ID Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		number -
			x   		ip -
			x   		area_id_as_number -
			x   		area_id_as_ip -
			 	-area_type
			 		The "area_type" advertised in the Router LSA interface list.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 		Valid choices are:
			    		external-capable - (default) A transit network.
			    		ppp - A point-to-point network.
			    		stub - A stub network.
			 	-authentication_mode
			 		This option defines the authentification mode used for OSPF.
			 		Valid choices are:
			    		null - (default) No authentication
			    		simple - Clear text authentication (see also -password)
			    		md5 - MD5 based authentication (see also -md5_key and -md5_key_id)
			 	-count
			 		Defines the number of OSPF routers to configure on the -port_handle.
			 	-dead_interval
			 		The time after which the DUT router is considered dead if it
			 		does not send HELLO messages.
			 	-demand_circuit
			 		Enables the Demand Circuit bit.Pertains to handling of demand
			 		circuits (DCs) by the router. CHOICES 0 1
			 	-enable_support_rfc_5838
			 		Enables the support for rfc 5838 in OSPFv3 router. This enables OSPFv3 router to advertise ipv4 and ipv6 unicast an multicast routes CHOICES 0 1
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-graceful_restart_enable
			 		Will enable graceful restart (HA) on the OSPF neighbor.
			 	-hello_interval
			 		The time between HELLO messages sent over the interface. RANGE 1-65535
			x	-ignore_db_desc_mtu
			x		This option is only available for OSPFv3 interfaces that are directly connected to the DUT. If the parameter ignore_db_desc_mtu is 0 the MTU will be verified during the exchange. If the parameter value is 1, the
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		0 - (default) verify MTU during the exchange.
			x   		1 - ignore MTU size during exchange.
			x	-router_interface_active
			x		Enable/disable router interface
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_fast_hello
			x		Enable/disable fast hello
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-hello_multiplier
			x		Hello multiplier value
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-max_mtu
			x		Max mtu value
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-protocol_name
			x		Name of the ospf protocol as it should appear in the IxNetwork GUI
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-router_active
			x		Enable/disable the ospf router
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-router_asbr
			x		If true (1), set router to be an AS boundary router (ASBR).
			x		Correspond to B (Border) bit in router LSA.
			x		This option is valid only when -type is router or grid, otherwise it
			x		is ignored.
			x		This option is available with IxTclNetwork and IxTclProtocol API.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-do_not_generate_router_lsa
			x		Generate/not generate router lsa
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-router_abr
			x		If true (1), set router to be an area boundary router (ABR).
			x		Correspond to E (external) bit in router LSA.
			x		This option is valid only when -type is router or grid, otherwise it
			x		is ignored.
			x		This option is available with IxTclNetwork and IxTclProtocol API.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-inter_flood_lsupdate_burst_gap
			x		Inter flood LSUpdate burst gap (ms)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lsa_refresh_time
			x		LSA refresh time (s)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lsa_retransmit_time
			x		LSA retransmit time (s)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-max_ls_updates_per_burst
			x		Max flood LSUpdates per burst
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-oob_resync_breakout
			x		Enable out-of-band resynchronization breakout
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-interface_cost
			 		The metric associated with the OSPF interface. RANGE 1-65535
			 	-intf_ip_addr
			 		The IP address of the Ixia Simulated OSPF router. This parameter is
			 		not valid on mode modify when IxTclProtocol is used. IP
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-intf_ip_addr_step
			 		What step will be use for incrementing the -intf_ip_addr option.
			 		This parameter is not valid on mode modify when IxTclProtocol is used.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-intf_prefix_length
			 		Defines the mask of the IP address used for the Ixia (-intf_ip_addr)
			 		and the DUT interface. This parameter is not valid on mode modify when
			 		IxTclProtocol is used. RANGE 1-128
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-interface_handle
			x		A handle or list of the handles that are returned from the
			x		interface_config call. These provide a direct link to an already
			x		existing interface and supercede the use of the intf_ip_addr value.
			x		Starting with IxNetwork 5.60 this parameter accepts handles returned by
			x		emulation_dhcp_group_config procedure and pppox_config procedure in the following format:
			x		<DHCP Group Handle>|<interface index X>,<interface index Y>-<interface index Z>, ...
			x		The DHCP ranges are separated from the Interface Index identifiers with the (|) character.
			x		The Interface Index identifiers are separated with comas (,).
			x		A range of Interface Index identifiers can be defined using the dash (-) character.
			x		Ranges along with the Interface Index identifiers are grouped together in TCL Lists. The
			x		lists can contain mixed items, protocol interface handles returned by interface_config
			x		and handles returned by emulation_dhcp_group_config along with the interface index.
			x		Example:
			x		count 10 (10 OSPF routers). 3 DHCP range handles returned by ::ixia::emulation_dhcp_group_config.
			x		Each DHCP range has 20 sessions (interfaces). If we pass 'interface_handle
			x		in the following format: [list $dhcp_r1|1,5 $dhcp_r2|1-3 $dhcp_r3|1,3,5-9,13]
			x		The interfaces will be distributed to the routers in the following manner:
			x		OSPF Router 1: $dhcp_r1 -> interface 1
			x		OSPF Router 2: $dhcp_r1 -> interface 5
			x		OSPF Router 3: $dhcp_r2 -> interface 1
			x		OSPF Router 4: $dhcp_r2 -> interface 2
			x		OSPF Router 5: $dhcp_r2 -> interface 3
			x		OSPF Router 6: $dhcp_r3 -> interface 1
			x		OSPF Router 7: $dhcp_r3 -> interface 3
			x		OSPF Router 8: $dhcp_r3 -> interface 5
			x		OSPF Router 9: $dhcp_r3 -> interface 6
			x		OSPF Router 10: $dhcp_r3 -> interface 7
			x		OSPF Router 11: $dhcp_r3 -> interface 8
			x		OSPF Router 12: $dhcp_r3 -> interface 9
			x		OSPF Router 13 $dhcp_r3 -> interface 13
			x		Valid for mode create for IxTclNetwork only.
			 	-instance_id
			 		Defines the instance ID of the OSPFv3 process. It allows
			 		multiple instances of the OSPFv3 protocol to be run simultaneously
			 		over the same link. RANGE 0-255
			 	-instance_id_step
			 		Step at which the -instance_id will be incremented. RANGE 0-255
			 	-loopback_ip_addr
			 		Defines the IP address of the loopback interface for MPLS VPN testing.
			 		This parameter is not valid on mode modify when IxTclProtocol is used.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-loopback_ip_addr_step
			 		Defines the IP address step of the loopback interface for MPLS VPN.
			 		This parameter is not valid on mode modify when IxTclProtocol is used.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-lsa_discard_mode
			 		Enables/Disables the LSA discard mode on the OSPF router. CHOICES 0 1
			x	-mac_address_init
			x		This option defines the MAC address that will be configured on
			x		the Ixia interface. This parameter is not valid on mode modify when
			x		IxTclProtocol is used.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-mac_address_step
			x		This option defines the incrementing step for the MAC address that
			x		will be configured on the Ixia interface. This option is valid only
			x		when IxTclNetwork API is used.
			 	-md5_key
			 		Active only when "MD5" is selected in the Authentication field.
			 		Enter a character string (maximum 16 characters) to be used as
			 		a "secret" MD5 Key.
			 	-md5_key_id
			 		Active only when "MD5" is selected in the Authentication field.
			 		Enter a value to be used as a Key ID.This identifier is associated
			 		with the MD5 Key entered previously.
			 	-mtu
			 		The advertised MTU value in database entries sent to other routers
			 		create on the Ixia interface. RANGE 68-9216.
			 		OSPFv2 Only. For OSPFv3 this option is ignored.
			 	-network_type
			 		Indicates the type of network for the interface.
			 		Valid choices are:
			    		broadcast - (default) Indicates that the network is a broadcast network, as in an Ethernet connection.
			    		ptomp - Indicates that the network is point to multi-point
			    		ptop - Indicates that the network is point to point.
			 	-neighbor_intf_ip_addr
			 		The IP address of the DUT OSPF Interface.
			 		This parameter is not valid on mode modify when IxTclProtocol is used.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-neighbor_intf_ip_addr_step
			 		This parameter is not valid on mode modify when IxTclProtocol is used.
			 		What step will be use for incrementing the -neighbor_intf_ip_addr option.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-neighbor_router_id
			 		Available only for use when the Point-Multipoint network type is
			 		selected. The DUT IP Interface address can be provided.
			 	-neighbor_router_id_step
			 		Available only for use when the Point-Multipoint network type is
			 		selected. The DUT IP Interface address step can be provided.
			 	-option_bits
			 		The bit sum of the different OSPF option bits. This switch is for
			 		users to customize options since area_type will determine a default
			 		value for those bits. The Demand circuit option can be modified with
			 		the -demand_circuit option. In HEX.
			 		If (option_bits &amp;amp; 0x8) then area_id must not be 0.
			 		(option_bits &amp;amp; 0x2) is not allowed - can't have external routing and NSSA capability at the same time.
			x	-type_of_service_routing
			x		Option bit 0
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-external_capabilities
			x		Option bit 1
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-multicast_capability
			x		Option bit 2
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-nssa_capability
			x		Option bit 3
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-external_attribute
			x		Option bit 4
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-opaque_lsa_forwarded
			x		Option bit 6
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-unused
			x		Option bit 7
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-override_existence_check
			x		If this option is enabled, the interface existence check is skipped but
			x		the list of interfaces is still created and maintained in order to keep
			x		track of existing interfaces if required. Using this option will speed
			x		up the interfaces' creation.
			x	-override_tracking
			x		If this option is enabled, the list of interfaces won't be created and
			x		maintained anymore, thus, speeding up the interfaces' creation even
			x		more. Also, it will enable -override_existence_check in case it wasn't
			x		already enabled because checking for interface existence becomes
			x		impossible if the the list of interfaces doesn't exist anymore.
			 	-password
			 		Password to be used in the OSPF authentication mode is enabled and
			 		set to "simple".
			x	-reset
			x		If this option is selected, this will clear any OSPF router on
			x		the targeted interface.
			 	-router_id
			 		The Router ID for this emulated OSPF Router, in IPv4 format. IP
			 	-router_id_step
			 		The Router ID step for this emulated OSPF Router, in IPv4 format. IP
			 	-router_priority
			 		The priority of the interface, for use in election of the designated or
			 		backup master. RANGE 0-255
			 	-te_enable
			 		If set to 1, this will enable Traffic Engineering on the OSPF router.
			 		The user can then configure the TE parameters by using "-te_metric",
			 		"-te_max_bw", "-te_max_resv_bw", "-te_unresv_bw_priority0-7".
			 	-te_max_bw
			 		If "-te_enable" is 1, then this indicates the maximum bandwidth
			 		that can be used on the link between this interface and its
			 		neighbors in the outbound direction.
			 	-te_max_resv_bw
			 		If "-te_enable" is 1, then this indicates the maximum bandwidth,
			 		in bytes per second, that can be reserved on the link between
			 		this interface and its neighbors in the outbound direction.
			 	-te_unresv_bw_priority0
			 		If "-te_enable" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 0 priority level. This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 0. The value must be less than the maxReservableBandwidth
			 		option.
			 	-te_unresv_bw_priority1
			 		If "-te_enable" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 1 priority level. This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 1. The value must be less than the maxReservableBandwidth
			 		option.
			 	-te_unresv_bw_priority2
			 		If "-te_enable" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 2 priority level. This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 2. The value must be less than the maxReservableBandwidth
			 		option.
			 	-te_unresv_bw_priority3
			 		If "-te_enable" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 3 priority level. This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 3. The value must be less than the maxReservableBandwidth
			 		option.
			 	-te_unresv_bw_priority4
			 		If "-te_enable" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 4 priority level.This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 4.The value must be less than the maxReservableBandwidth
			 		option.
			 	-te_unresv_bw_priority5
			 		If "-te_enable" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 5 priority level. This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 5. The value must be less than the maxReservableBandwidth
			 		option.
			 	-te_unresv_bw_priority6
			 		If "-te_enable" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 6 priority level. This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 6. The value must be less than the maxReservableBandwidth
			 		option.
			 	-te_unresv_bw_priority7
			 		If "-te_enable" is 1, then this value indicates the amount of bandwidth,
			 		in bytes per second, not yet reserved at the 7 priority level. This
			 		value corresponds to the bandwidth that can be reserved with a setup
			 		priority of 7. The value must be less than the maxReservableBandwidth
			 		option.
			 	-te_metric
			 		If set to 1, then this indicates the traffic engineering metric
			 		associated with the interface. RANGE 1-2147483647
			 	-te_router_id
			 		This parameter is ignored.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-vlan
			x		Enables vlan on the directly connected OSPF router interface.
			x		Valid options are: 0 - disable, 1 - enable.
			x		This option is valid only when -mode is create or -mode is modify
			x		and -handle is a OSPF router handle.
			x		This option is available only when IxNetwork tcl API is used.
			 	-vlan_id_mode
			 		If the user configures more than one interface on the Ixia with
			 		VLAN, he can choose to automatically increment the VLAN tag or
			 		leave it idle for each interface. CHOICES fixed increment.
			 		This parameter is not valid on mode modify when IxTclProtocol is used.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		fixed -
			    		increment -
			 	-vlan_id
			 		If VLAN is enable on the Ixia interface, this option will configure
			 		the VLAN number. This parameter is not valid on mode modify when
			 		IxTclProtocol is used. RANGE 0-4095
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_id_step
			 		This parameter is not valid on mode modify when IxTclProtocol is used.
			 		If the -vlan_id_mode is increment, this will be the step value by
			 		which the VLAN tags are incremented. RANGE 0-4095
			 		When vlan_id_step causes the vlan_id value to exceed it's maximum value the
			 		increment will be done modulo <number of possible vlan ids>.
			 		Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0
			 		vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_user_priority
			 		This parameter is not valid on mode modify when IxTclProtocol is used.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-atm_encapsulation
			x	-bfd_registration
			x   		Enable or disable BFD registration.
			x	-enable_dr_bdr
			x   		If 1, enables the OSPF Designated Router/Backup Designated Router
			x   		DR/BDR) feature for all router interfaces on this port.
			 	-vci
			    	-vci_step
			        	-vpi
			            	-vpi_step
			n               	-get_next_session_mode
			x                   	-no_write
			x                       		If this option is present, the protocol configuration will not be written to the server.
			x                       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			                    	-te_admin_group
			                        		Assignment of traffic engineering administrative group numbers to the interface.
			                        		Valid only with IxTclNetwork API.
			x                   	-validate_received_mtu
			x                       		Enabling this option means that the MTU will be verified during the DB exchange.
			x                       		This is only available for OSPFv2 interfaces that are directly connected to the DUT.
			                    	-graceful_restart_helper_mode_enable
			                        		This parameter -graceful_restart_helper_mode_enable will allow Ixia to
			                        		act as a helping neighbor to a restarting router.If the attribute is
			                        		set to 1, the router will act as restarting router's neighbors, which must
			                        		cooperate in order for the restart to be graceful.This attribute/argument
			                        		is valid when session_type is ospfV3.
			                        		Valid choices are:
			                        		0 - disable (default)
			                        		1 - enable
			                    	-strict_lsa_checking
			                        		If enabled, the helping router continues to help the restarting router even if there is a
			                        		topology change detected. Relevant with 'graceful_restart_helper_mode_enable'.
			                        		This attribute is associated with the four Graceful Restart reasons. This attribute/argument
			                        		is valid when session_type is ospfV3.
			                    	-support_reason_sw_restart
			                        		This is one of the reasons supported by this helping router when the neighboring router
			                        		gracefully restarts. Helping router will support only those restart reasons which are
			                        		enabled by the user. User can select more than one reason at a time. Relevant with
			                        		'graceful_restart_helper_mode_enable'.This attribute/argument is valid when session_type is ospfV3.
			                    	-support_reason_sw_reload_or_upgrade
			                        		This is one of the reasons supported by this helping router when the neighboring router gracefully restarts.
			                        		Helping router will support only those restart reasons which are enabled by the user. User can
			                        		select more than one reason at a time. Relevant with 'graceful_restart_helper_mode_enable'.
			                        		This attribute/argument is valid when session_type is ospfV3.
			                    	-support_reason_switch_to_redundant_processor_control
			                        		This is one of the reasons supported by this helping router when the neighboring router gracefully restarts.
			                        		Helping router will support only those restart reasons which are enabled by the user. User can
			                        		select more than one reason at a time. Relevant with 'graceful_restart_helper_mode_enable'.
			                        		This attribute/argument is valid when session_type is ospfV3.
			                    	-support_reason_unknown
			                        		This is one of the reasons supported by this helping router when the neighboring router gracefully restarts.
			                        		Helping router will support only those restart reasons which are enabled by the user. User can
			                        		select more than one reason at a time. Relevant with 'graceful_restart_helper_mode_enable'.
			                        		This attribute/argument is valid when session_type is ospfV3.
			                    	-mode
			                            		create - Creates the OSPF router on the Ixia interface.
			                            		delete - Deletes the OSPF router on the Ixia interface.
			                            		modify - Modifies the OSPF router on the Ixia interface.
			                            		enable - Enables the OSPF router on the Ixia interface.
			                            		disable - Disables the OSPF router.
			                    	-session_type
			                        		The OSPF version to be emulated. CHOICES: ospfv2 ospfv3.
			                        		Valid choices are:
			                            		ospfv2 -
			                            		ospfv3 -
			n                   	-graceful_restart_restarting_mode_enable
			n                       		The new attribute -graceful_restart_restarting_mode_enable will allow 0 - disable (default)1 - enable-grace_periodThis parameter denotes the time period (represent in seconds), between the restart/reload and the reestablishment of adjacencies, specified by the restarting router. Its value is specified in seconds and ranges from 1 to 1800.This attribute is valid/relevant when the router is in restarting mode, meaning graceful_restart_enable is set to 1.This attribute/argument is valid when session_type is ospfV3.-restart_reasonThis paramter allows user to select the reason for the router restart as one of the following options.This attribute is valid/relevant when the router is in restarting mode, i.e.graceful_restart_enable is set to 1.This attribute/argument is valid when session_type is ospfV3.unknown- The restart resaon is unknownsoftware_restart- (default) The restart resaon is software restartsoftware_reload_upgrade - The restart resaon is software reload or software upgrade.switch_to_redundant_control_processor - The restart resaon is swithing to redundant control processor.-number_of_restartsThe number of times the Ixia emulated OSPF router will move to Restarting and Up states before stopping the cycle.It ranges from 0 to the max value of a short type integer.This attribute is valid/relevant when the router is in restarting mode, i.e.graceful_restart_enable is set to 1. This attribute/argument is valid when session_type is ospfV3.-restart_start_timeThe router (Ixia) restarts after this timer gets fired, from the time the router reaches the full state.Its value is specified in seconds and ranges from 1 to the max value of a short type integer.This attribute is valid/relevant when the router is in restarting mode, i.e.graceful_restart_enable is set to 1.This attribute/argument is valid when session_type is ospfV3 and Valid if "number_of_restarts" value is greater than 0.-restart_down_timeThe time period the router will be down (to upgrade/reload software etc.) before sending any Hello packet or trying to re-establish the adjacencies. Its value is specified in seconds and ranges from 1 sec to the max value of a short type integer.It is user's responsibility to set the value less than the value of "grace_period" for a successful graceful restart. This attribute is valid/relevant when the router is in restarting mode, i.e.graceful_restart_enable is set to 1.This attribute/argument is valid when session_type is ospfV3.-restart_up_timeAfter the session becomes full (gracefully or ungracefully), Ixia will wait for this configured interval before trying to repeat the Restart cycle. Its value is specified in seconds and ranges from 1 sec to the max value of a short type integer.This attribute is valid/relevant when the router is in restarting mode, i.e.graceful_restart_enable is set to 1. This attribute/argument is valid when session_type is ospfV3 and valid if "number_of_restarts" value is greater than 1.
			n                       		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                   	-grace_period
			n                       	-restart_reason
			n                           	-number_of_restarts
			n                               	-restart_start_time
			n                                   	-restart_down_time
			n                                       	-restart_up_time
			x                                           	-port_handle
			x                                               		Ixia interface upon which to act.
			x                                           	-rate_control_interval
			x                                               		Flood link state updates per interval.
			x                                               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                           	-flood_lsupdates_per_interval
			x                                               		Flood link state updates per interval.
			x                                               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                           	-attempt_scale_mode
			x                                               		Indicates whether the control is specified per port or per device group.
			x                                               		This setting is global for all the ospf protocols configured in the ixncfg
			x                                               		and can be configured just when handle is /globals (when the user wants to configure just the global settings)
			x                                               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               		Valid choices are:
			x                                                   		port -
			x                                                   		device_group -
			x                                           	-attempt_rate
			x                                               		Number of times an action is triggered per second.
			x                                               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                           	-attempt_interval
			x                                               		Time interval used to calculate the rate for triggering an action(rate = count/interval).
			x                                               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                           	-attempt_enabled
			x                                               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                           	-disconnect_scale_mode
			x                                               		Indicates whether the control is specified per port or per device group.
			x                                               		This setting is global for all the ospf protocols configured in the ixncfg
			x                                               		and can be configured just when handle is /globals (when the user wants to configure just the global settings)
			x                                               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               		Valid choices are:
			x                                                   		port -
			x                                                   		device_group -
			x                                           	-disconnect_rate
			x                                               		Number of times an action is triggered per second.
			x                                               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                           	-disconnect_interval
			x                                               		Time interval used to calculate the rate for triggering an action(rate = count/interval).
			x                                               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                           	-disconnect_enabled
			x                                               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			n                                           	-gre_checksum
			n                                               		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                           	-gre_local_ip
			n                                               		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                           	-gre_remote_ip
			n                                               		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                           	-gre_tunnel
			n                                               		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                           	-host_route
			n                                               		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                           	-int_msg_exchange
			n                                               		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                           	-lsa_retransmit_delay
			n                                               		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                           	-max_lsas_per_pkt
			n                                               		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                           	-neighbor_dr_eligibility
			n                                               		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                           	-poll_interval
			n                                               		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                           	-transmit_delay
			n                                               		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                           	-vlan_cfi
			x                                               	-link_metric
			x                                                   		Link Metric
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-enable_ignore_db_desc_mtu
			x                                                   		Ignore DB-Desc MTU
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-router_bit
			x                                                   		Option bit 4
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-v6
			x                                                   		Option bit 0
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-disable_auto_generate_link_lsa
			x                                                   		Support graceful restart helper mode when restart reason is unknown and unplanned.
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-ospfv3_lsa_flood_rate_control
			x                                                   		Inter Flood LSUpdate burst gap (ms)
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-intf_ipv6_addr
			x                                                   		IPv6 addresses of the layer
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-intf_ipv6_addr_step
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-ipv6_gateway_ip
			x                                                   		gateways of the layer
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-ipv6_gateway_ip_step
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-intf_ipv6_prefix_length
			x                                                   		Defines the mask of the IP address used for the Ixia (-intf_ipv6_addr)
			x                                                   		and the DUT interface. This parameter is not valid on mode modify when
			x                                                   		IxTclProtocol is used. RANGE 1-128
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-enable_segment_routing
			x                                                   		Enable Segment Routing
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-configure_s_i_d_index_label
			x                                                   		Configure SID/Index/Label
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-sid_index_label
			x                                                   		SID/Index/Label
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-algorithm
			x                                                   		Algorithm for the Node SID/Label
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-np_flag
			x                                                   		No-PHP Flag
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-m_flag
			x                                                   		Mapping Server Flag
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-e_flag
			x                                                   		Explicit-Null Flag
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-v_flag
			x                                                   		Value or Index Flag
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-l_flag
			x                                                   		Local or Global Flag
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-srgb_range_count
			x                                                   		SRGB Range Count
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-s_r_algorithm_count
			x                                                   		SR Algorithm Count
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-start_s_i_d_label
			x                                                   		Start SID/Label
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-sid_count
			x                                                   		SID Count
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-enable_adj_s_i_d
			x                                                   		Enable Adj SID
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-adj_s_i_d
			x                                                   		Adjacency SID
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-b_flag
			x                                                   		Backup Flag
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-s_flag
			x                                                   		Set/Group Flag
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-v_flag_if
			x                                                   		Value/Index Flag
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-l_flag_if
			x                                                   		Local/Global Flag
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-p_flag
			x                                                   		Persistent Flag
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-weight
			x                                                   		Weight
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-enable_s_r_l_g
			x                                                   		This enables the SRLG on the OSPF link between two mentioned interfaces.
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-srlg_count
			x                                                   		This field value shows how many SRLG Value columns would be there in the GUI.
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-srlg_value
			x                                                   		This is the SRLG Value for the link between two mentioned interfaces.
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-ospf_sr_algorithm
			x                                                   		SR Algorithm
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-en_link_protection
			x                                                   		This enables the link protection on the OSPF link between two mentioned interfaces.
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-extra_traffic
			x                                                   		This is a Protection Scheme with value 0x01. It means that the link is protecting another link or links.The LSPs on a link of this type will be lost if any of the links it is protecting fail.
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-unprotected
			x                                                   		This is a Protection Scheme with value 0x02. It means that there is no other link protecting this link.The LSPs on a link of this type will be lost if the link fails.
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-shared
			x                                                   		This is a Protection Scheme with value 0x04. It means that there are one or more disjoint links of type Extra Traffic that are protecting this link.These Extra Traffic links are shared between one or more links of type Shared.
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-dedicated1_to1
			x                                                   		This is a Protection Scheme with value 0x08. It means that there is one dedicated disjoint link of type Extra Traffic that is protecting this link.
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-dedicated1_plus1
			x                                                   		This is a Protection Scheme with value 0x10. It means that a dedicated disjoint link is protecting this link.However, the protecting link is not advertised in the link state database and is therefore not available for the routing of LSPs.
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-enhanced
			x                                                   		This is a Protection Scheme with value 0x20. It means that a protection scheme that is more reliable than Dedicated 1+1, e.g., 4 fiber BLSR/MS-SPRING, is being used to protect this link.
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-reserved40
			x                                                   		This is a Protection Scheme with value 0x40.
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-reserved80
			x                                                   		This is a Protection Scheme with value 0x80.
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-high_perf_learning_mode_for_sr
			x                                                   		This option can be used to increase scale.When enabled then the minimum information required to generate traffic is stored instead of the entire LSA. For example, for SR traffic generation, sid, vflag, SRGB details are stored and label is calculated accordingly. Please note when this flag is enabled, we will not store any LSAs so Learned Info will not display any details. Currently this is supported for only SR opaque LSAs, other Opaque LSAs like BIER, Graceful Restart is not supported.
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-enable_srlb
			x                                                   		Enable SRLB
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-srlb_range_count
			x                                                   		SRLB Range Count
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-srlb_start_sid_label
			x                                                   		Start SID/Label
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                               	-srlb_sid_count
			x                                                   		SID Count
			x                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		                                           
		                                           Return Values:
		                                               A list containing the ethernet protocol stack handles that were added by the command (if any).
			x                                               key:ethernet_handle  value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		                                               A list containing the ipv4 protocol stack handles that were added by the command (if any).
			x                                               key:ipv4_handle      value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		                                               A list containing the ospfv2 protocol stack handles that were added by the command (if any).
			x                                               key:ospfv2_handle    value:A list containing the ospfv2 protocol stack handles that were added by the command (if any).
		                                               A list containing the ipv6 protocol stack handles that were added by the command (if any).
			x                                               key:ipv6_handle      value:A list containing the ipv6 protocol stack handles that were added by the command (if any).
		                                               A list containing the ospfv3 protocol stack handles that were added by the command (if any).
			x                                               key:ospfv3_handle    value:A list containing the ospfv3 protocol stack handles that were added by the command (if any).
		                                               $::SUCCESS or $::FAILURE
			                                                key:status           value:$::SUCCESS or $::FAILURE
		                                               If failure, will contain more information
			                                                key:log              value:If failure, will contain more information
		                                               The router numbers Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			                                                key:handle           value:The router numbers Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		                                               The router numbers
			                                                key:handle           value:The router numbers
		                                           
		                                           Examples:
		                                               See files starting with OSPFv2 and OSPFv3 in the Samples subdirectory. Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the OSPF usage.See the OSPF example in Appendix A, "Example APIs," for one specific example usage.
		                                           
		                                           Sample Input:
		                                           
		                                           Sample Output:
		                                           
		                                           Notes:
		                                               1) Coded versus functional specification.
		                                               2) When -handle is provided with the /globals value the arguments that configure global protocol
		                                               setting accept both multivalue handles and simple values.
		                                               When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
		                                               that configure global settings will only accept simple values. In this situation, these arguments will
		                                               configure only the settings of the parent device group or the ports associated with the parent topology.
		                                               If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		                                               1) Coded versus functional specification.
		                                           
		                                           See Also:
		                                           
		"""
		return self._run_keyword("emulation_ospf_config", kwargs)

	def emulation_ospf_control(self, **kwargs):
		""" This procedure is used to start, stop, and restart the protocol on an OSPF router. The user can also use this function to withdraw a route or an LSA handle and to control route flapping.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ospf_control
			 	[-port_handle        REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle             ANY]
			 	-mode                CHOICES start
			                      CHOICES stop
			                      CHOICES restart
			                      CHOICES abort
			                      CHOICES restart_down
			                      CHOICES resume_hello
			                      CHOICES stop_hello
			                      CHOICES age_out_routes
			                      CHOICES readvertise_routes
			                      CHOICES advertise
			                      CHOICES withdraw
			                      CHOICES disconnect
			                      CHOICES reconnect
			x	[-age_out_percent    NUMERIC]
			n	[-advertise          ANY]
			n	[-advertise_lsa      ANY]
			n	[-flap_count         ANY]
			 	[-flap_down_time     ANY]
			n	[-flap_interval_time ANY]
			n	[-flap_lsa           ANY]
			n	[-flap_routes        ANY]
			n	[-withdraw           ANY]
			n	[-withdraw_lsa       ANY]
		
		Arguments:
			 	-port_handle
			 		A list of ports on which to control the OSPF protocol. If this option
			 		is not present, the port in the handle option will be applied.
			 	-handle
			 		This option represents the handle the user *must* pass to the
			 		"emulation_ospf_control" procedure. This option specifies
			 		on which OSPF session to control. If port_handle option is present,
			 		the port_handle takes precedence over port in the router handle. The
			 		OSPF router handle(s) is returned by the procedure
			 	-mode
			 		Tells which option will be performed on the OSPF protocol.
			 		Valid options are:
			 		restart
			 		start
			 		stop
			 		abort
			 		restart_down
			 		resume_hello
			 		stop_hello
			 		age_out_routes
			 		readvertise_routes
			 		advertise
			 		withdraw
			 		disconnect
			 		reconnect
			 		Valid choices are:
			    		start -
			    		stop -
			    		restart -
			    		abort -
			    		restart_down -
			    		resume_hello -
			    		stop_hello -
			    		age_out_routes -
			    		readvertise_routes -
			    		advertise -
			    		withdraw -
			    		disconnect -
			    		reconnect -
			x	-age_out_percent
			x		The percentage of addresses that will be aged out.
			x		This argument is ignored when mode is not age_out_routes and *must* be specified
			x		in such circumstances.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			n	-advertise
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-advertise_lsa
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_count
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-flap_down_time
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_interval_time
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_lsa
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_routes
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-withdraw
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-withdraw_lsa
		
		Return Values:
		$::SUCCESS or $::FAILURE
			 key:status  value:$::SUCCESS or $::FAILURE
		If failure, will contain more information
			 key:log     value:If failure, will contain more information
		
		Examples:
		See files starting with OSPFv2 and OSPFv3 in the Samples subdirectory. Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the OSPF usage.See the OSPF example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) Coded versus functional specification.
		1) Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_ospf_control", kwargs)

	def emulation_ospf_info(self, **kwargs):
		""" This procedure retrieves information about the OSPF sessions and returns statistical information about the configuration.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ospf_info
			 	[-port_handle       REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle            ANY]
			 	-mode               CHOICES aggregate_stats
			                     CHOICES learned_info
			                     CHOICES clear_stats
			                     CHOICES session]
			x	[-execution_timeout NUMERIC
			x                    DEFAULT 1800]
			x	[-session_type      CHOICES ospfv2 ospfv3
			x                    DEFAULT ospfv2]
		
		Arguments:
			 	-port_handle
			 		The port from which to extract OSPF data.
			 		One of the two parameters is required: port_handle/handle.
			 	-handle
			 		The routers from which to extract OSPF data.
			 		One of the two parameters is required: port_handle/handle.
			 	-mode
			 		The action that should be taken.
			 		Valid choices are:
			    		aggregate_stats - retrieve stats aggregated per port/handle
			    		learned_info - retrieve learned information by the OSPF protocol
			    		clear_stats - clear stats
			    		session - retrieves non-aggregated stats per handle
			x	-execution_timeout
			x		This is the timeout for the function.
			x		The setting is in seconds.
			x		Setting this setting to 60 it will mean that the command must complete in under 60 seconds.
			x		If the command will last more than 60 seconds the command will be terminated by force.
			x		This flag can be used to prevent dead locks occuring in IxNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-session_type
			x		The Type of OSPF Router - OSPFv2 or OSPFv3.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		ospfv2 - OSPF v2
			x   		ospfv3 - OSPF v3
		
		Return Values:
		A list containing the  protocol stack handles that were added by the command (if any).
			xkey:handle                                                             value:A list containing the  protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:handles                                                            value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		$::SUCCESS | $::FAILURE
			 key:status                                                             value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                                                value:On status of failure, gives detailed information.
			 key:Learned info:                                                      value:
		the advertising router ID
			 key:<interface_handle>.<learned_info>.adv_router_id                    value:the advertising router ID
		the age of the learned LSA
			 key:<interface_handle>.<learned_info>.age                              value:the age of the learned LSA
		the LinkState ID
			 key:<interface_handle>.<learned_info>.link_state_id                    value:the LinkState ID
		the LSA type
			 key:<interface_handle>.<learned_info>.lsa_type                         value:the LSA type
		the sequence number of the LSA
			 key:<interface_handle>.<learned_info>.seq_number                       value:the sequence number of the LSA
		the advertising router ID
			 key:<interface_handle>.<learned_info>.adv_router_id                    value:the advertising router ID
		the age of the learned LSA
			 key:<interface_handle>.<learned_info>.age                              value:the age of the learned LSA
		the LinkState ID
			 key:<interface_handle>.<learned_info>.link_state_id                    value:the LinkState ID
		the LSA type
			 key:<interface_handle>.<learned_info>.lsa_type                         value:the LSA type
		the sequence number of the LSA
			 key:<interface_handle>.<learned_info>.seq_number                       value:the sequence number of the LSA
		the ipv4 address prefix learned
			 key:<interface_handle>.<learned_info>.prefix_v4_address                value:the ipv4 address prefix learned
		the ipv6 address prefix learned
			 key:<interface_handle>.<learned_info>.prefix_v6_address                value:the ipv6 address prefix learned
		prefix length of learned ipv4/ipv6 address
			 key:<interface_handle>.<learned_info>.prefix_length                    value:prefix length of learned ipv4/ipv6 address
			 key:Aggregate stats:                                                   value:
			 key:<handle>.aggregate.port_name                                       value:
			 key:<handle>.aggregate.sessions_configured                             value:
			 key:<handle>.aggregate.full_neighbors                                  value:
			 key:<handle>.aggregate.session_flap_count                              value:
			 key:<handle>.aggregate.neighbor_down_count                             value:
			 key:<handle>.aggregate.neighbor_attempt_count                          value:
			 key:<handle>.aggregate.neighbor_init_count                             value:
			 key:<handle>.aggregate.neighbor_2way_count                             value:
			 key:<handle>.aggregate.neighbor_exstart_count                          value:
			 key:<handle>.aggregate.neighbor_exchange_count                         value:
			 key:<handle>.aggregate.neighbor_loading_count                          value:
			 key:<handle>.aggregate.neighbor_full_count                             value:
			 key:<handle>.aggregate.hellos_tx                                       value:
			 key:<handle>.aggregate.hellos_rx                                       value:
			 key:<handle>.aggregate.database_description_tx                         value:
			 key:<handle>.aggregate.database_description_rx                         value:
			 key:<handle>.aggregate.linkstate_request_tx                            value:
			 key:<handle>.aggregate.linkstate_request_rx                            value:
			 key:<handle>.aggregate.linkstate_update_tx                             value:
			 key:<handle>.aggregate.linkstate_update_rx                             value:
			 key:<handle>.aggregate.linkstate_ack_tx                                value:
			 key:<handle>.aggregate.linkstate_ack_rx                                value:
			 key:<handle>.aggregate.linkstate_advertisement_tx                      value:
			 key:<handle>.aggregate.linkstate_advertisement_rx                      value:
			 key:<handle>.aggregate.router_lsa_tx                                   value:
			 key:<handle>.aggregate.router_lsa_rx                                   value:
			 key:<handle>.aggregate.network_lsa_tx                                  value:
			 key:<handle>.aggregate.network_lsa_rx                                  value:
			 key:<handle>.aggregate.external_lsa_tx                                 value:
			 key:<handle>.aggregate.external_lsa_rx                                 value:
			 key:<handle>.aggregate.summary_iplsa_tx                                value:
			 key:<handle>.aggregate.summary_iplsa_rx                                value:
			 key:<handle>.aggregate.summary_aslsa_tx                                value:
			 key:<handle>.aggregate.summary_aslsa_rx                                value:
			 key:<handle>.aggregate.nssa_lsa_tx                                     value:
			 key:<handle>.aggregate.nssa_lsa_rx                                     value:
			 key:<handle>.aggregate.opaque_local_lsa_tx                             value:
			 key:<handle>.aggregate.opaque_local_lsa_rx                             value:
			 key:<handle>.aggregate.opaque_area_lsa_tx                              value:
			 key:<handle>.aggregate.opaque_area_lsa_rx                              value:
			 key:<handle>.aggregate.opaque_domain_lsa_tx                            value:
			 key:<handle>.aggregate.opaque_domain_lsa_rx                            value:
			 key:<handle>.aggregate.grace_lsa_rx                                    value:
			 key:<handle>.aggregate.helpermode_attempted                            value:
			 key:<handle>.aggregate.helpermode_failed                               value:
			 key:<handle>.aggregate.rate_control_blocked_flood_lsupdate             value:
			 key:<handle>.aggregate.lsa_acknowledged                                value:
			 key:<handle>.aggregate.lsa_acknowledge_rx                              value:
			 key:<handle>.aggregate.link_lsa_tx                                     value:
			 key:<handle>.aggregate.link_lsa_rx                                     value:
			 key:<handle>.aggregate.intraarea_prefix_lsa_tx                         value:
			 key:<handle>.aggregate.intraarea_prefix_lsa_rx                         value:
			 key:<handle>.aggregate.interarea_prefix_lsa_tx                         value:
			 key:<handle>.aggregate.interarea_prefix_lsa_rx                         value:
			 key:<handle>.aggregate.interarea_router_lsa_tx                         value:
			 key:<handle>.aggregate.interarea_router_lsa_rx                         value:
			 key:<handle>.aggregate.retrasmitted_lsa                                value:
		the advertising router ID
			 key:<router_handle>.<interface_handle>.session.<number>.adv_router_id  value: the advertising router ID
		the age of the learned LSA
			 key:<router_handle>.<interface_handle>.session.<number>.age            value: the age of the learned LSA
		the LinkState ID
			 key:<router_handle>.<interface_handle>.session.<number>.link_state_id  value: the LinkState ID
		the LSA type
			 key:<router_handle>.<interface_handle>.session.<number>.lsa_type       value: the LSA type
		the sequence number of the LSA
			 key:<router_handle>.<interface_handle>.session.<number>.seq_number     value: the sequence number of the LSA
		the advertising router ID
			 key:<router_handle>.session.<number>.adv_router_id                     value: the advertising router ID
		the age of the learned LSA
			 key:<router_handle>.session.<number>.age                               value: the age of the learned LSA
		the LinkState ID
			 key:<router_handle>.session.<number>.link_state_id                     value: the LinkState ID
		the LSA type
			 key:<router_handle>.session.<number>.lsa_type                          value: the LSA type
		the sequence number of the LSA
			 key:<router_handle>.session.<number>.seq_number                        value: the sequence number of the LSA
			 key:<port_handle>.aggregate.port_name                                  value:
			 key:<port_handle>.aggregate.sessions_configured                        value:
			 key:<port_handle>.aggregate.full_neighbors                             value:
			 key:<port_handle>.aggregate.session_flap_count                         value:
			 key:<port_handle>.aggregate.neighbor_down_count                        value:
			 key:<port_handle>.aggregate.neighbor_attempt_count                     value:
			 key:<port_handle>.aggregate.neighbor_init_count                        value:
			 key:<port_handle>.aggregate.neighbor_2way_count                        value:
			 key:<port_handle>.aggregate.neighbor_exstart_count                     value:
			 key:<port_handle>.aggregate.neighbor_exchange_count                    value:
			 key:<port_handle>.aggregate.neighbor_loading_count                     value:
			 key:<port_handle>.aggregate.neighbor_full_count                        value:
			 key:<port_handle>.aggregate.hellos_tx                                  value:
			 key:<port_handle>.aggregate.hellos_rx                                  value:
			 key:<port_handle>.aggregate.database_description_tx                    value:
			 key:<port_handle>.aggregate.database_description_rx                    value:
			 key:<port_handle>.aggregate.linkstate_request_tx                       value:
			 key:<port_handle>.aggregate.linkstate_request_rx                       value:
			 key:<port_handle>.aggregate.linkstate_update_tx                        value:
			 key:<port_handle>.aggregate.linkstate_update_rx                        value:
			 key:<port_handle>.aggregate.linkstate_ack_tx                           value:
			 key:<port_handle>.aggregate.linkstate_ack_rx                           value:
			 key:<port_handle>.aggregate.linkstate_advertisement_tx                 value:
			 key:<port_handle>.aggregate.linkstate_advertisement_rx                 value:
			 key:<port_handle>.aggregate.router_lsa_tx                              value:
			 key:<port_handle>.aggregate.router_lsa_rx                              value:
			 key:<port_handle>.aggregate.network_lsa_tx                             value:
			 key:<port_handle>.aggregate.network_lsa_rx                             value:
			 key:<port_handle>.aggregate.external_lsa_tx                            value:
			 key:<port_handle>.aggregate.external_lsa_rx                            value:
			 key:<port_handle>.aggregate.summary_iplsa_tx                           value:
			 key:<port_handle>.aggregate.summary_iplsa_rx                           value:
			 key:<port_handle>.aggregate.summary_aslsa_tx                           value:
			 key:<port_handle>.aggregate.summary_aslsa_rx                           value:
			 key:<port_handle>.aggregate.nssa_lsa_tx                                value:
			 key:<port_handle>.aggregate.nssa_lsa_rx                                value:
			 key:<port_handle>.aggregate.opaque_local_lsa_tx                        value:
			 key:<port_handle>.aggregate.opaque_local_lsa_rx                        value:
			 key:<port_handle>.aggregate.opaque_area_lsa_tx                         value:
			 key:<port_handle>.aggregate.opaque_area_lsa_rx                         value:
			 key:<port_handle>.aggregate.opaque_domain_lsa_tx                       value:
			 key:<port_handle>.aggregate.opaque_domain_lsa_rx                       value:
			 key:<port_handle>.aggregate.grace_lsa_rx                               value:
			 key:<port_handle>.aggregate.helpermode_attempted                       value:
			 key:<port_handle>.aggregate.helpermode_failed                          value:
			 key:<port_handle>.aggregate.rate_control_blocked_flood_lsupdate        value:
			 key:<port_handle>.aggregate.lsa_acknowledged                           value:
			 key:<port_handle>.aggregate.lsa_acknowledge_rx                         value:
			 key:<port_handle>.aggregate.link_lsa_tx                                value:
			 key:<port_handle>.aggregate.link_lsa_rx                                value:
			 key:<port_handle>.aggregate.intraarea_prefix_lsa_tx                    value:
			 key:<port_handle>.aggregate.intraarea_prefix_lsa_rx                    value:
			 key:<port_handle>.aggregate.interarea_prefix_lsa_tx                    value:
			 key:<port_handle>.aggregate.interarea_prefix_lsa_rx                    value:
			 key:<port_handle>.aggregate.interarea_router_lsa_tx                    value:
			 key:<port_handle>.aggregate.interarea_router_lsa_rx                    value:
			 key:<port_handle>.aggregate.retrasmitted_lsa                           value:
		
		Examples:
		See files starting with OSPF_ in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handles
		
		See Also:
		
		"""
		return self._run_keyword("emulation_ospf_info", kwargs)

	def emulation_ospf_lsa_config(self, **kwargs):
		""" This procedure is useed to  add, modify, or delete a user LSA to a particular OSPF session. The user must create a OSPF session using the  "emulation_ospf_config" procedure.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_ospf_lsa_config
			 	-mode                               CHOICES create modify delete reset
			                                     DEFAULT create]
			 	-handle                             ANY]
			 	[-lsa_handle                        ANY]
			 	[-adv_router_id                     IP
			                                     DEFAULT 198.18.1.1]
			x	[-area_id                           IP
			x                                    DEFAULT 0.0.0.0]
			 	[-attached_router_id                IP
			                                     DEFAULT 14.0.0.1]
			 	[-external_number_of_prefix         ANY
			                                     DEFAULT 16]
			 	[-external_prefix_start             IP]
			 	[-external_prefix_length            ANY
			                                     DEFAULT 16]
			 	[-external_prefix_step              IP
			                                     DEFAULT 0.0.0.1]
			 	[-external_prefix_metric            RANGE 0-16777215
			                                     DEFAULT 1]
			 	[-external_prefix_type              CHOICES 1 2
			                                     DEFAULT 1]
			 	[-external_prefix_forward_addr      IP]
			 	[-external_route_tag                IP
			                                     DEFAULT 17.0.0.1]
			x	[-external_metric_fbit              CHOICES 1 0
			x                                    DEFAULT 1]
			x	[-external_metric_tbit              CHOICES 1 0
			x                                    DEFAULT 1]
			x	[-external_metric_ebit              CHOICES 1 0
			x                                    DEFAULT 0]
			 	[-link_state_id                     IP
			                                     DEFAULT 199.18.1.1]
			 	[-link_state_id_step                IPV4]
			 	[-ls_type_function_code             RANGE 0-8191
			                                     DEFAULT 0]
			x	[-lsa_group_mode                    CHOICES append create
			x                                    DEFAULT append]
			 	[-net_prefix_length                 ANY
			                                     DEFAULT 16]
			 	[-net_attached_router               CHOICES create delete reset
			                                     DEFAULT create]
			x	[-no_write                          FLAG]
			 	[-opaque_enable_link_id             CHOICES 0 1
			                                     DEFAULT 0]
			 	[-opaque_enable_link_local_ip_addr  CHOICES 0 1
			                                     DEFAULT 0]
			 	[-opaque_enable_link_max_bw         CHOICES 0 1
			                                     DEFAULT 0]
			 	[-opaque_enable_link_max_resv_bw    CHOICES 0 1
			                                     DEFAULT 0]
			 	[-opaque_enable_link_metric         CHOICES 0 1
			                                     DEFAULT 0]
			 	[-opaque_enable_link_remote_ip_addr CHOICES 0 1
			                                     DEFAULT 0]
			 	[-opaque_enable_link_resource_class CHOICES 0 1
			                                     DEFAULT 0]
			 	[-opaque_enable_link_type           CHOICES 0 1
			                                     DEFAULT 0]
			 	[-opaque_enable_link_unresv_bw      CHOICES 0 1
			                                     DEFAULT 0]
			 	[-opaque_link_id                    IP
			                                     DEFAULT 0.0.0.0]
			 	[-opaque_link_local_ip_addr         IP
			                                     DEFAULT 0.0.0.0]
			 	[-opaque_link_max_bw                ANY
			                                     DEFAULT 0]
			 	[-opaque_link_max_resv_bw           ANY
			                                     DEFAULT 0]
			 	[-opaque_link_metric                NUMERIC
			                                     DEFAULT 0]
			 	[-opaque_link_remote_ip_addr        IP
			                                     DEFAULT 0.0.0.0]
			 	[-opaque_link_resource_class        HEX
			                                     DEFAULT 0x00000000]
			 	[-opaque_link_type                  CHOICES ptop multiaccess
			                                     DEFAULT ptop]
			 	[-opaque_link_subtlvs               IP
			                                     DEFAULT 0.0.0.0]
			x	[-opaque_link_other_subtlvs         REGEXP ^(0x[0-9a-fA-F]+:[0-9]+:[0-9]+ )*0x[0-9a-fA-F]+:[0-9]+:[0-9]+$]
			 	[-opaque_link_unresv_bw_priority    ANY
			                                     DEFAULT 0]
			 	[-opaque_router_addr                IP
			                                     DEFAULT 0.0.0.0]
			 	[-opaque_tlv_type                   CHOICES link router
			                                     DEFAULT router]
			 	[-options                           RANGE 0-255]
			x	[-prefix_options                    RANGE 0-255]
			 	[-router_abr                        CHOICES 0 1
			                                     DEFAULT 0]
			 	[-router_asbr                       CHOICES 0 1
			                                     DEFAULT 0]
			 	[-router_virtual_link_endpt         CHOICES 0 1
			                                     DEFAULT 0]
			x	[-router_wildcard                   CHOICES 0 1
			x                                    DEFAULT 0]
			 	[-router_link_mode                  CHOICES create modify delete
			                                     DEFAULT create]
			 	[-router_link_id                    IP
			                                     DEFAULT 12.0.0.1]
			 	[-router_link_data                  IP
			                                     DEFAULT 13.0.0.1]
			 	[-router_link_type                  CHOICES ptop transit stub virtual
			                                     DEFAULT ptop]
			 	[-router_link_metric                RANGE 1-65535
			                                     DEFAULT 1]
			 	[-session_type                      CHOICES ospfv2 ospfv3
			                                     DEFAULT ospfv2]
			 	[-summary_number_of_prefix          ANY
			                                     DEFAULT 16]
			 	[-summary_prefix_start              IP
			                                     DEFAULT 15.0.0.1]
			 	[-summary_prefix_length             ANY
			                                     DEFAULT 16]
			 	[-summary_prefix_step               IP
			                                     DEFAULT 0.0.0.1]
			 	[-summary_prefix_metric             RANGE 0-16777215
			                                     DEFAULT 1]
			 	[-type                              CHOICES router
			                                     CHOICES network
			                                     CHOICES summary_pool
			                                     CHOICES asbr_summary
			                                     CHOICES ext_pool
			                                     CHOICES opaque_type_9
			                                     CHOICES opaque_type_10
			                                     CHOICES opaque_type_11
			                                     DEFAULT router]
			n	[-auto_ls_age                       ANY]
			n	[-auto_ls_checksum                  ANY]
			n	[-auto_ls_seq                       ANY]
			n	[-auto_update                       ANY]
			n	[-ls_age                            ANY]
			n	[-ls_checksum                       ANY]
			n	[-ls_seq                            ANY]
			n	[-ls_type_s_bits                    ANY]
			n	[-ls_type_u_bit                     ANY]
			n	[-nssa_number_of_prefix             ANY]
			n	[-nssa_prefix_forward_addr          ANY]
			n	[-nssa_prefix_length                ANY]
			n	[-nssa_prefix_metric                ANY]
			n	[-nssa_prefix_start                 ANY]
			n	[-nssa_prefix_step                  ANY]
			n	[-nssa_prefix_type                  ANY]
			n	[-router_link_idx                   ANY]
			n	[-te_tlv_type                       ANY]
			n	[-te_instance_id                    ANY]
			n	[-te_router_address                 ANY]
			n	[-te_link_id                        ANY]
			n	[-te_link_type                      ANY]
			n	[-te_metric                         ANY]
			n	[-te_local_ip                       ANY]
			n	[-te_remote_ip                      ANY]
			n	[-te_admin_group                    ANY]
			n	[-te_max_bw                         ANY]
			n	[-te_max_resv_bw                    ANY]
			n	[-te_max_resv_priority0             ANY]
			n	[-te_max_resv_priority1             ANY]
			n	[-te_max_resv_priority2             ANY]
			n	[-te_max_resv_priority3             ANY]
			n	[-te_max_resv_priority4             ANY]
			n	[-te_max_resv_priority5             ANY]
			n	[-te_max_resv_priority6             ANY]
			n	[-te_max_resv_priority7             ANY]
		
		Arguments:
			 	-mode
			 		Mode of the procedure call.Valid options are:
			 		create
			 		modify
			 		delete
			 		Valid choices are:
			    		create -
			    		modify -
			    		delete -
			    		reset -
			 	-handle
			 		This option represents the handle the user *must* pass to the
			 		"emulation_ospf_lsa_config" procedure. This option specifies
			 		on which OSPF router to configure the OSPF User LSA.
			 		The OSPF router handle(s) are returned by the procedure
			 		"emulation_ospf_config" when configuring OSPF routers on the
			 		Ixia interface.
			 	-lsa_handle
			 		This option specifies on which OSPF User LSA to configure. This option
			 		*must* be passed if the -mode option is modify or delete.
			 		The OSPF LSA handle(s) are returned by the procedure
			 		"emulation_ospf_lsa_config" when creating OSPF user LSA(s) on the Ixia
			 		interface.
			 	-adv_router_id
			 		The router ID of the router that is originating the LSA.
			x	-area_id
			x		The area ID of the User LSA Group.
			x		This option is valid only for IxTclNetwork API.
			 	-attached_router_id
			 		A list of router IDs in the area, in IP address format separated by
			 		spaces.
			 	-external_number_of_prefix
			 		The number of External IP LSAs to generate.
			 	-external_prefix_start
			 		This option is valid for OSPFv3 external route type. The prefix
			 		address to be advertised in the LSA. Although only prefixLength
			 		bits of the IPv6 address are meaningful, a full IPv6 address should
			 		be specified.
			 	-external_prefix_length
			 		The number of high-order bits of prefixAddress that are significant.
			 	-external_prefix_step
			 		If external_number_of_prefix is greater than 1,this is the value that
			 		will be added to the most significant external_prefix_length bits of
			 		external_prefix_start between generated LSAs. This is also the value
			 		to increment the link_state_id.
			 	-external_prefix_metric
			 		The cost of the route for all TOS levels.
			 	-external_prefix_type
			 		The type of external metric. A value of 1 implies type 2 metric.A
			 		value of 0 implies type 1.
			 		Valid choices are:
			    		1 -
			    		2 -
			 	-external_prefix_forward_addr
			 		If the external_metric_fbit is true, data traffic for the advertised
			 		destination will be forwarded to this fully qualified IPv6 address.
			 	-external_route_tag
			 		If the external_metric_tbit is true, an additional value to be used for
			 		external routes between AS boundary routers. This field is not used
			 		within OSPF.
			x	-external_metric_fbit
			x		The value of the external metric's F-bit. If true, then the
			x		forwardingAddress field is to be included in the LSA.
			x		Valid choices are:
			x   		1 -
			x   		0 -
			x	-external_metric_tbit
			x		The value of the external metric's T-bit. If true, then the
			x		externalRouteTag field will be included in the LSA.
			x		Valid choices are:
			x   		1 -
			x   		0 -
			x	-external_metric_ebit
			x		The value of the external metric's E-bit.
			x		Valid choices are:
			x   		1 -
			x   		0 -
			 	-link_state_id
			 		The router ID of the originating router. This field uniquely identified
			 		the LSA in the link-state database.
			 	-link_state_id_step
			 		If summary_number_of_prefix is greater than 1, the value to increment
			 		the link_state_id by for each LSA. The value is expressed in IPv4 format.
			 	-ls_type_function_code
			x	-lsa_group_mode
			x		The two modes are append or create. Append means appending the new LSA
			x		to the last LSA group created. Create means creating a new LSA group
			x		for the newly added LSA.
			x		This option is valid only for -mode create.
			x		This option is valid only for IxTclNetwork API.
			x		Valid choices are:
			x   		append -
			x   		create -
			 	-net_prefix_length
			 		The length in bits of the IP address mask for the network.
			 	-net_attached_router
			 		The option specifies the mode in configuring router IDs in the area.
			 		Note that delete and reset does not work. Valid options are:
			 		create
			 		delete
			 		reset
			 		Valid choices are:
			    		create -
			    		delete -
			    		reset -
			x	-no_write
			x		If this option is present, the protocol configuration will not be
			x		written to the server.
			 	-opaque_enable_link_id
			 		This will enable usage of link id. TLV Type 2. If checked, this will
			 		be the 4-octet IP address which identifies the other end of the link.
			 		For Point to Point, the Neighbor's Router ID.
			 		For Multi-access, the interface of the DR.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_enable_link_local_ip_addr
			 		This will enable the usage of local IP address. TLV Type 3.
			 		The IP address of the local interface for this link. Each address is
			 		a 4-octet value. The total length is N times 4 octets, where N is the
			 		number of addresses.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_enable_link_max_bw
			 		This will enable the usage of max bandwidth. TLV Type 6.
			 		Units are in bytes per second. The maximum bandwidth that can be used
			 		on this link in this direction (from originator to the neighbor).
			 		Four octets in length, expressed in IEEE floating point format.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_enable_link_max_resv_bw
			 		This will enable the usage of max reservable bandwidth. TLV Type 7.
			 		Units in bytes per second. The maximum bandwidth that can be reserved
			 		on this link in this direction (from originator to the neighbor).
			 		Four octets in length, expressed in IEEE floating point format. This
			 		may be greater than the maximum bandwidth.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_enable_link_metric
			 		This will enable the usage of link metric. TLV Type 5.
			 		The Traffic Engineering Metric.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_enable_link_remote_ip_addr
			 		This will enable the usage of the remote IP address. TLV Type 4.
			 		The IP address of the neighbor's interface for this link. The total
			 		length is N times four octets, where N is the number of addresses.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_enable_link_resource_class
			 		This will enable the usage of link resource class. TLV Type 9.
			 		A bit mask value, four octets in length, which specifies
			 		administrative group membership for this link.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_enable_link_type
			 		This will enable the usage of link type. TLV Type 1. Defines the type
			 		of link and is one octet in length.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_enable_link_unresv_bw
			 		This will enable the usage of the unreserved bandwidth. TLV Type 8.
			 		The amount of bandwidth not yet reserved at each of the eight
			 		priority levels. This value will be less than or equal to the maximum
			 		reservable bandwidth. 32 octets in length, expressed in IEEE floating
			 		point format. If checked, unreserved bandwidth may be assigned to
			 		each of the 8 priority levels (0 through 7).
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_link_id
			 		TLV Type 2. If checked, this will be the 4-octet IP address which
			 		identifies the other end of the link.
			 		For Point to Point, the Neighbor's Router ID.
			 		For Multiaccess, the interface of the DR.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_link_local_ip_addr
			 		TLV Type 3. The IP address of the local interface for this link.
			 		Each address is a 4-octet value. The total length is N times 4 octets,
			 		where N is the number of addresses.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_link_max_bw
			 		TLV Type 6. Units are in bytes per second. The maximum bandwidth that
			 		can be used on this link in this direction (from originator to the
			 		neighbor). Four octets in length, expressed in IEEE floating point
			 		format.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_link_max_resv_bw
			 		TLV Type 7. Units in bytes per second. The maximum bandwidth that can
			 		be reserved on this link in this direction (from originator to the
			 		neighbor). Four octets in length, expressed in IEEE floating point
			 		format. This may be greater than the maximum bandwidth.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_link_metric
			 		TLV Type 5. The Traffic Engineering Metric. Four octets in length.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_link_remote_ip_addr
			 		TLV Type 4. The IP address of the neighbor's interface for this link.
			 		The total length is N times four octets, where N is the number of
			 		addresses.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_link_resource_class
			 		TLV Type 9. A bit mask value, four octets in length, which specifies
			 		administrative group membership for this link.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_link_type
			 		TLV Type 1. Defines the type of link and is one octet in length.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 		Valid choices are:
			    		ptop -
			    		multiaccess -
			 	-opaque_link_subtlvs
			 		Allows the user to create custom type 10 Sub-TLVs with length 4 - for Traffic Engineering.
			 		When both -opaque_link_subtlvs and -opaque_link_other_subtlvs are
			 		provided then -opaque_link_subtlvs has a greater priority.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			x	-opaque_link_other_subtlvs
			x		Allows the user to create custom Sub-TLVs - for Traffic Engineering.
			x		To be provided with a list of parameters in the following format:
			x		<type>:<length>:<value>, where type is from 0 to 65535, length is a
			x		value from 0 to 65535 and value is a hex number preceeded by 0x with
			x		the length specified by <length> parameter.
			x		When both -opaque_link_subtlvs and -opaque_link_other_subtlvs are
			x		provided then -opaque_link_subtlvs has a greater priority.
			x		This option is valid only when type is opaque and opaque_tlv_type is link.
			x		This option is valid only for IxTclNetwork API.
			 	-opaque_link_unresv_bw_priority
			 		Unreserved Bandwidth in bytes per second per priority level.
			 		This option is valid only when type is opaque and opaque_tlv_type is link.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_router_addr
			 		TLVs are Type/Length/Value field combinations that make up part of the
			 		LSA payload and enable OSPF Traffic Engineering (OSPF-TE).
			 		If opaque_tlv_type is router, the field is for the four-octet IP
			 		address of the advertising router.
			 		This option is valid only when type is opaque and opaque_tlv_type is router.
			 		This option is valid only for IxTclNetwork API.
			 	-opaque_tlv_type
			 		TLVs are Type/Length/Value field combinations that make up part of the
			 		LSA payload and enable OSPF Traffic Engineering (OSPF-TE).
			 		If opaque_tlv_type is router, the field is for the four-octet IP
			 		address of the advertising router.
			 		Otherwise, if opaque_tlv_type is link, all the other TLVs from 1-9 can
			 		be enabled and used.
			 		This option is valid only when type is opaque.
			 		This option is valid only for IxTclNetwork API.
			 		Valid choices are:
			    		link -
			    		router -
			 	-options
			 		The optional capabilities supported by the OSPFv2 router. For OSPFv3,
			 		use OSPFv3 specific options.
			 		Multiple options may becombined using a logical "or".
			 		Valid choices are:
			 		ospfOptionBitTypeOfService - 0x01
			 		ospfOptionBitExternalRouting - 0x02
			 		ospfOptionBitMulticast - 0x04
			 		ospfOptionBitNSSACapability - 0x08
			 		ospfOptionBitExternalAttributes - 0x10
			 		ospfOptionBitDemandCircuit - 0x20
			 		ospfOptionBitLSANoForward - 0x40
			 		ospfOptionBitUnused - 0x80
			x	-prefix_options
			x		An 8-bit quantity with options related to the prefixAddress. Multiple
			x		bits may becombined using a logical or. If both options and prefix_options
			x		are provided, the options value takes priority.
			x		Valid choices are:
			x		ospfV3PrefixOptionPBit - 0x08--The propagate bit, which is set on
			x		NSSA area prefixes that should be re-advertised at
			x		the NSSA area border.
			x		ospfV3PrefixOptionMCBit - 0x04--The multicast capability bit, which
			x		should be set if the prefix should be included in IPv6
			x		multicast routing calculations.
			x		ospfV3PrefixOptionLABit - 0x02--The local address capability bit,
			x		which should be set if the prefix is actually an IPv6
			x		interface address of the advertising router.
			x		ospfV3PrefixOptionNUBit - 0x01--The no unicast bit, which should be
			x		set if the prefix should be excluded from IPv6 unicast
			x		calculations.
			 	-router_abr
			 		Set router to be an area boundary router (ABR). Correspond to E
			 		(external) bit in router LSA.
			 	-router_asbr
			 		Set router to be an AS boundary router (ASBR). Correspond to B
			 		(border) bit in router LSA.
			 	-router_virtual_link_endpt
			 		Set router to be an endpoint of an active virtual link. Correspond
			 		to V (virtual link endpoint) bit in router LSA.
			x	-router_wildcard
			x		Indicates that the router is a wild-card multicast receiver and will
			x		receive multicast datagrams regardless of destination.
			 	-router_link_mode
			 		This option specifies the mode for configuring router links in a router
			 		LSA.Note that the modify and delete mode do not work. Valid options are:
			 		create
			 		modify
			 		delete
			 		Valid choices are:
			    		create -
			    		modify -
			    		delete -
			 	-router_link_id
			 		Identifies the object that this router link connects to, depending on
			 		the router_link_type option. Valid choices are:
			 		ptop - The neighboring routers router ID.
			 		transit - The IP address of the Designated Router.
			 		stub - The IP network/subnet number.
			 		virtual - The neighboring routers router ID.
			 	-router_link_data
			 		The meaning of this option depends on the router_link_type option.
			 		Valid choices are:
			 		ptop - The interfaces MIB-II.
			 		transit - The router interfaces IP address.
			 		stub - The networks IP address mask.
			 		virtual - The router interfaces IP address.
			 	-router_link_type
			 		The type of the router link. Valid choices are:
			 		ptop - A point-to-point connection to another router.
			 		transit - (default) A connection to a transit network.
			 		stub - A connection a stub network.
			 		virtual - A virtual link.
			 		Valid choices are:
			    		ptop -
			    		transit -
			    		stub -
			    		virtual -
			 	-router_link_metric
			 		The cost of using the router link, applied to all TOS values.
			 	-session_type
			    		ospfv2 -
			    		ospfv3 -
			 	-summary_number_of_prefix
			 		The number of Summary IP LSAs to generate.
			 	-summary_prefix_start
			 		This option is valid for OSPFv3 summary_pool route type. The prefix
			 		address to be advertised in the LSA. Although only prefixLength
			 		bits of the IPv6 address are meaningful, a full IPv6 address should
			 		be specified.
			 	-summary_prefix_length
			 		The number of high-order bits of prefixAddress that are significant.
			 	-summary_prefix_step
			 		If summary_number_of_prefix is greater than 1, this is the value that
			 		will be added to the most significant summary_prefix_length bits of
			 		summary_prefix_start between generated LSAs.This is also the value
			 		to increment the link_state_id, if link_state_id_step is not present.
			 		This parameter can be provided as an IPv4/IPv6 address, depending on
			 		the prefix type, but the corresponding number of the IP address
			 		provided should not be greater than 4,294,967,295.
			 	-summary_prefix_metric
			 		The cost of the route for all TOS levels.
			 	-type
			 		This option specified the type of the LSA. The user *must* pass this option when creating a LSA. The choices are:
			 		router- ospfv2, ospfv3
			 		network- ospfv2, ospfv3
			 		summary_pool- ospfv2, ospfv3
			 		asbr_summary- ospfv2, ospfv3
			 		ext_pool- ospfv2, ospfv3
			 		opaque_type_9- ospfv2
			 		opaque_type_10- ospfv2
			 		opaque_type_11- ospfv2
			n	-auto_ls_age
			n	-auto_ls_checksum
			n	-auto_ls_seq
			n	-auto_update
			n	-ls_age
			n	-ls_checksum
			n	-ls_seq
			n	-ls_type_s_bits
			n	-ls_type_u_bit
			n	-nssa_number_of_prefix
			n	-nssa_prefix_forward_addr
			n	-nssa_prefix_length
			n	-nssa_prefix_metric
			n	-nssa_prefix_start
			n	-nssa_prefix_step
			n	-nssa_prefix_type
			n	-router_link_idx
			n	-te_tlv_type
			n	-te_instance_id
			n   	-te_router_address
			n       	-te_link_id
			n           	-te_link_type
			n               	-te_metric
			n                   	-te_local_ip
			n                       	-te_remote_ip
			n                           	-te_admin_group
			n                               	-te_max_bw
			n                                   	-te_max_resv_bw
			n                                       	-te_max_resv_priority0
			n                                           	-te_max_resv_priority1
			n                                               	-te_max_resv_priority2
			n                                                   	-te_max_resv_priority3
			n                                                       	-te_max_resv_priority4
			n                                                           	-te_max_resv_priority5
			n                                                               	-te_max_resv_priority6
			n                                                                   	-te_max_resv_priority7
		                                                                   
		                                                                   Return Values:
		                                                                       $::SUCCESS | $::FAILURE
			                                                                        key:status                                 value:$::SUCCESS | $::FAILURE
		                                                                       On status of failure, gives detailed information.
			                                                                        key:log                                    value:On status of failure, gives detailed information.
			                                                                        key:lsa_handle                             value:
			                                                                        key:adv_router_id                          value:
			                                                                        key:For Router LSA                         value:
			                                                                        key:router.links.<idx = 0>.id              value:
			                                                                        key:router.links.<idx = 0>.data            value:
			                                                                        key:router.links.<idx = 0>.type            value:
			                                                                        key:router.links.<idx = n>.id              value:
			                                                                        key:router.links.<idx = n>.data            value:
			                                                                        key:router.links.<idx = n>.type            value:
			                                                                        key:For Network LSA                        value:
			                                                                        key:network.attached_router_ids            value:
			                                                                        key:For Summary_Pool and ASBR_Summary LSA  value:
			                                                                        key:summary.num_prefix                     value:
			                                                                        key:summary.prefix_start                   value:
			                                                                        key:summary.prefix_length                  value:
			                                                                        key:summary.prefix_step                    value:
			                                                                        key:For Ext_Pool LSA                       value:
			                                                                        key:external.num_prefix                    value:
			                                                                        key:external.prefix_start                  value:
			                                                                        key:external.prefix_length                 value:
			                                                                        key:external.prefix_step                   value:
		                                                                   
		                                                                   Examples:
		                                                                       See files starting with OSPFv2 and OSPFv3 in the Samples subdirectory. Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the OSPF usage.
		                                                                       See the OSPF example in Appendix A, "Example APIs," for one specific example usage.
		                                                                       See files starting with OSPFv2 and OSPFv3 in the Samples subdirectory. Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the OSPF usage.See the OSPF example in Appendix A, "Example APIs," for one specific example usage.
		                                                                   
		                                                                   Sample Input:
		                                                                       .
		                                                                   
		                                                                   Sample Output:
		                                                                       .
		                                                                   
		                                                                   Notes:
		                                                                       1) Coded versus functional specification v5-3-6.
		                                                                       2) In OSPFv3, asbr_summary type and the summary_prefix_length field do not
		                                                                       apply and are not returned in returnList.
		                                                                       Caveats: Due to the problem with getting item with local lable ID, there
		                                                                       are the following limitations:
		                                                                       - handle (ospf_session_handle) must be gotten within the same wish
		                                                                       shell.
		                                                                       - router_link_mode of modify and delete is not supported.
		                                                                       - net_attached_router of delete and reset is not supported.
		                                                                       - For OSPFv3, only one lsa can be created per router handle.
		                                                                       1) Coded versus functional specification v5-3-6.2) In OSPFv3, asbr_summary type and the summary_prefix_length field do not apply and are not returned in returnList.
		                                                                       Caveats: Due to the problem with getting item with local lable ID, there are the following limitations:- handle (ospf_session_handle) must be gotten within the same wish shell.- router_link_mode of modify and delete is not supported.- net_attached_router of delete and reset is not supported.- For OSPFv3, only one lsa can be created per router handle.
		                                                                   
		                                                                   See Also:
		                                                                   
		"""
		return self._run_keyword("emulation_ospf_lsa_config", kwargs)

	def emulation_ospf_network_group_config(self, **kwargs):
		""" This procedure is used to add OSPF route(s) to a particular simulated OSPF router Ixia Interface. The user can configure the properties of the OSPF routes.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ospf_network_group_config
			 	-handle                                  ANY]
			 	[-mode                                   CHOICES create modify delete
			                                          DEFAULT create]
			 	[-type                                   CHOICES grid
			                                          CHOICES mesh
			                                          CHOICES custom
			                                          CHOICES ring
			                                          CHOICES hub-and-spoke
			                                          CHOICES tree
			                                          CHOICES ipv4-prefix
			                                          CHOICES fat-tree
			                                          CHOICES linear
			                                          CHOICES ipv6-prefix]
			x	[-protocol_name                          ALPHA]
			x	[-multiplier                             NUMERIC]
			x	[-enable_device                          CHOICES 0 1]
			 	[-grid_col                               RANGE 2-10000
			                                          DEFAULT 2]
			 	[-grid_row                               RANGE 2-10000
			                                          DEFAULT 2]
			x	[-grid_include_emulated_device           CHOICES 0 1]
			x	[-grid_link_multiplier                   NUMERIC]
			x	[-mesh_number_of_nodes                   NUMERIC]
			x	[-mesh_include_emulated_device           CHOICES 0 1]
			x	[-mesh_link_multiplier                   NUMERIC]
			x	[-ring_number_of_nodes                   NUMERIC]
			x	[-ring_include_emulated_device           CHOICES 0 1]
			x	[-ring_link_multiplier                   NUMERIC]
			x	[-hub_spoke_number_of_first_level        NUMERIC]
			x	[-hub_spoke_number_of_second_level       NUMERIC]
			x	[-hub_spoke_enable_level_2               CHOICES 0 1]
			x	[-hub_spoke_link_multiplier              NUMERIC]
			x	[-tree_number_of_nodes                   NUMERIC]
			x	[-tree_include_emulated_device           CHOICES 0 1]
			x	[-tree_use_tree_depth                    CHOICES 0 1]
			x	[-tree_depth                             NUMERIC]
			x	[-tree_max_children_per_node             NUMERIC]
			x	[-tree_link_multiplier                   NUMERIC]
			x	[-custom_link_multiplier                 NUMERIC]
			x	[-custom_from_node_index                 NUMERIC]
			x	[-custom_to_node_index                   NUMERIC]
			x	[-fat_tree_link_multiplier               NUMERIC]
			x	[-fat_tree_level_count                   NUMERIC]
			x	[-fat_tree_node_count                    NUMERIC]
			x	[-linear_nodes                           NUMERIC]
			x	[-linear_link_multiplier                 NUMERIC]
			x	[-active_router_id                       CHOICES 0 1]
			x	[-router_id                              IP
			x                                         DEFAULT 0.0.0.0]
			 	[-router_id_step                         IP
			                                          DEFAULT 0.0.0.0]
			x	[-router_system_id                       HEX8WITHSPACES]
			x	[-enable_advertise_as_stub_network       CHOICES 0 1]
			 	[-router_abr                             CHOICES 0 1
			                                          DEFAULT 0]
			 	[-router_asbr                            CHOICES 0 1
			                                          DEFAULT 0]
			x	[-router_active                          CHOICES 0 1]
			x	[-connected_to_handle                    ANY]
			x	[-from_ip                                IPV4]
			x	[-from_ip_step                           IPV4]
			x	[-to_ip                                  IPV4]
			x	[-to_ip_step                             IPV4]
			x	[-enable_ip                              CHOICES 0 1]
			x	[-subnet_prefix_length                   NUMERIC]
			x	[-subnet_ipv6_prefix_length              NUMERIC]
			 	[-link_te                                CHOICES 0 1]
			x	[-link_metric                            NUMERIC]
			 	[-link_te_metric                         RANGE 0-65535
			                                          DEFAULT 10]
			 	[-link_te_max_bw                         NUMERIC
			                                          DEFAULT 0]
			 	[-link_te_max_resv_bw                    NUMERIC
			                                          DEFAULT 0]
			 	[-link_te_unresv_bw_priority0            NUMERIC
			                                          DEFAULT 0]
			 	[-link_te_unresv_bw_priority1            NUMERIC
			                                          DEFAULT 0]
			 	[-link_te_unresv_bw_priority2            NUMERIC
			                                          DEFAULT 0]
			 	[-link_te_unresv_bw_priority3            NUMERIC
			                                          DEFAULT 0]
			 	[-link_te_unresv_bw_priority4            NUMERIC
			                                          DEFAULT 0]
			 	[-link_te_unresv_bw_priority5            NUMERIC
			                                          DEFAULT 0]
			 	[-link_te_unresv_bw_priority6            NUMERIC
			                                          DEFAULT 0]
			 	[-link_te_unresv_bw_priority7            NUMERIC
			                                          DEFAULT 0]
			x	[-link_te_administrator_group            NUMERIC
			x                                         DEFAULT 0]
			x	[-external1_metric                       NUMERIC]
			x	[-external1_active                       CHOICES 0 1]
			x	[-external1_network_address              IPV4]
			x	[-external1_network_address_step         IPV4
			x                                         DEFAULT 0.0.0.1]
			x	[-external1_number_of_routes             NUMERIC]
			x	[-external1_prefix                       NUMERIC]
			x	[-external2_metric                       NUMERIC]
			x	[-external2_active                       CHOICES 0 1]
			x	[-external2_network_address              IPV4]
			x	[-external2_network_address_step         IPV4
			x                                         DEFAULT 0.0.0.1]
			x	[-external2_number_of_routes             NUMERIC]
			x	[-external2_prefix                       NUMERIC]
			x	[-nssa_metric                            NUMERIC]
			x	[-nssa_active                            CHOICES 0 1]
			x	[-nssa_network_address                   IP]
			x	[-nssa_network_address_step              IP
			x                                         DEFAULT 0.0.0.1]
			x	[-nssa_number_of_routes                  NUMERIC]
			x	[-nssa_prefix                            NUMERIC]
			x	[-stub_metric                            NUMERIC]
			x	[-stub_active                            CHOICES 0 1]
			x	[-stub_network_address                   IPV4]
			x	[-stub_network_address_step              IPV4
			x                                         DEFAULT 0.0.0.1]
			x	[-stub_number_of_routes                  NUMERIC]
			x	[-stub_prefix                            NUMERIC]
			x	[-summary_metric                         NUMERIC]
			x	[-summary_active                         CHOICES 0 1]
			x	[-summary_network_address                IPV4]
			x	[-summary_network_address_step           IPV4
			x                                         DEFAULT 0.0.0.1]
			x	[-summary_number_of_routes               NUMERIC]
			x	[-summary_prefix                         NUMERIC]
			x	[-ipv4_prefix_network_address            IP]
			x	[-ipv4_prefix_network_address_step       IP
			x                                         DEFAULT 0.0.0.1]
			x	[-ipv4_prefix_length                     NUMERIC]
			x	[-ipv4_prefix_number_of_addresses        NUMERIC]
			x	[-ipv4_prefix_metric                     NUMERIC]
			x	[-ipv4_prefix_active                     CHOICES 0 1]
			x	[-ipv4_prefix_allow_propagate            CHOICES 0 1]
			x	[-ipv4_prefix_route_origin               CHOICES another_area
			x                                         CHOICES external_type_1
			x                                         CHOICES external_type_2
			x                                         CHOICES nssa
			x                                         CHOICES same_area
			x                                         DEFAULT another_area]
			x	[-return_detailed_handles                CHOICES 0 1
			x                                         DEFAULT 0]
			x	[-external_link_router_source            NUMERIC]
			x	[-external_link_router_destination       NUMERIC]
			x	[-external_link_network_group_handle     ANY]
			x	[-ipv6_prefix_network_address            IPV6]
			x	[-ipv6_prefix_network_address_step       IPV6]
			x	[-ipv6_prefix_length                     NUMERIC]
			x	[-ipv6_prefix_number_of_addresses        NUMERIC]
			x	[-ipv6_prefix_metric                     NUMERIC]
			x	[-ipv6_prefix_route_origin               CHOICES anotherarea
			x                                         CHOICES externaltype1
			x                                         CHOICES externaltype2
			x                                         CHOICES samearea
			x                                         CHOICES nssa]
			x	[-ipv6_prefix_active                     CHOICES 0 1]
			x	[-from_ipv6                              IPV6]
			x	[-from_ipv6_step                         IPV6]
			x	[-to_ipv6                                IPV6]
			x	[-to_ipv6_step                           IPV6]
			x	[-external_ipv6_network_address          IPV6]
			x	[-external_ipv6_network_address_step     IPV6
			x                                         DEFAULT 0:0:0:1:0:0:0:0]
			x	[-inter_area_destination_router_id       IPV4]
			x	[-inter_area_destination_router_id_step  IPV4]
			x	[-inter_area_link_state_id               IPV4]
			x	[-external_reference_ls_type             CHOICES ignore router network]
			x	[-external_forwarding_address            IPV6]
			x	[-external_external_route_tag            IPV4]
			x	[-external_referenced_link_state_id      IPV4]
			x	[-external_link_state_id                 IPV4]
			x	[-external_link_state_id_prefix          IPV4]
			x	[-intra_area_reference_ls_type           CHOICES router network]
			x	[-intra_area_referenced_link_state_id    IPV4]
			x	[-intra_area_referenced_router_id        IPV4]
			x	[-intra_area_link_state_id               IPV4]
			x	[-intra_area_link_state_id_prefix        IPV4]
			x	[-linklsa_router_priority                NUMERIC]
			x	[-linklsa_link_local_address             IPV6]
			x	[-linklsa_metric                         NUMERIC]
			x	[-linklsa_link_state_id                  IPV4]
			x	[-linklsa_link_state_id_prefix           IPV4]
			x	[-linklsa_active                         CHOICES 0 1]
			x	[-linklsa_network_address                IPV6]
			x	[-linklsa_prefix_count                   NUMERIC]
			x	[-linklsa_prefix                         NUMERIC]
			x	[-inter_area_metric                      NUMERIC]
			x	[-inter_area_active                      CHOICES 0 1]
			x	[-external_metric                        NUMERIC]
			x	[-external_active                        CHOICES 0 1]
			x	[-external_prefix_count                  NUMERIC]
			x	[-external_prefix                        ANY]
			x	[-auto_select_forwarding_address         CHOICES 0 1]
			x	[-allow_propagate                        CHOICES 0 1]
			x	[-forwarding_address                     IPV6]
			x	[-forwarding_address_step                IPV6]
			x	[-inter_area_prefix_metric               NUMERIC]
			x	[-inter_area_prefix_link_state_id        IPV4]
			x	[-inter_area_prefix_link_state_id_prefix IPV4]
			x	[-inter_area_prefix_active               CHOICES 0 1]
			x	[-inter_area_prefix_network_address      IPV6]
			x	[-inter_area_prefix_prefix_count         NUMERIC]
			x	[-inter_area_prefix_prefix               NUMERIC]
			x	[-nssa_propagate                         CHOICES 0 1]
			x	[-nssa_link_state_id                     IPV4]
			x	[-nssa_link_state_id_step                IPV4]
			x	[-intra_area_metric                      NUMERIC]
			x	[-intra_area_active                      CHOICES 0 1]
			x	[-intra_area_prefix_count                NUMERIC]
			x	[-prefix                                 ANY]
			x	[-inter_area_prefix_count                NUMERIC]
			x	[-nssa_include_forwarding_address        CHOICES 0 1]
			x	[-inter_area_link_state_id_step          IPV4]
			x	[-intra_area_network_address             IPV6]
			x	[-intra_area_network_address_step        IPV6]
			x	[-external_e_bit                         CHOICES 0 1]
			x	[-external_f_bit                         CHOICES 0 1]
			x	[-external_t_bit                         CHOICES 0 1]
			x	[-inter_area_reserved_bit7               CHOICES 0 1]
			x	[-inter_area_reserved_bit6               CHOICES 0 1]
			x	[-inter_area_d_c_bit                     CHOICES 0 1]
			x	[-inter_area_r_bit                       CHOICES 0 1]
			x	[-inter_area_n_bit                       CHOICES 0 1]
			x	[-inter_area_m_c_bit                     CHOICES 0 1]
			x	[-inter_area_e_bit                       CHOICES 0 1]
			x	[-inter_area_v6_bit                      CHOICES 0 1]
			x	[-external_unused_bit7                   CHOICES 0 1]
			x	[-external_unused_bit6                   CHOICES 0 1]
			x	[-external_unused_bit5                   CHOICES 0 1]
			x	[-external_unused_bit4                   CHOICES 0 1]
			x	[-external_p_bit                         CHOICES 0 1]
			x	[-external_m_c_bit                       CHOICES 0 1]
			x	[-external_l_a_bit                       CHOICES 0 1]
			x	[-external_n_u_bit                       CHOICES 0 1]
			x	[-intra_area_unused_bit7                 CHOICES 0 1]
			x	[-intra_area_unused_bit6                 CHOICES 0 1]
			x	[-intra_area_unused_bit5                 CHOICES 0 1]
			x	[-intra_area_unused_bit4                 CHOICES 0 1]
			x	[-intra_area_p_bit                       CHOICES 0 1]
			x	[-intra_area_m_c_bit                     CHOICES 0 1]
			x	[-intra_area_l_a_bit                     CHOICES 0 1]
			x	[-intra_area_n_u_bit                     CHOICES 0 1]
			x	[-inter_area_prefix_unused_bit7          CHOICES 0 1]
			x	[-inter_area_prefix_unused_bit6          CHOICES 0 1]
			x	[-inter_area_prefix_unused_bit5          CHOICES 0 1]
			x	[-inter_area_prefix_unused_bit4          CHOICES 0 1]
			x	[-inter_area_prefix_p_bit                CHOICES 0 1]
			x	[-inter_area_prefix_m_c_bit              CHOICES 0 1]
			x	[-inter_area_prefix_l_a_bit              CHOICES 0 1]
			x	[-inter_area_prefix_n_u_bit              CHOICES 0 1]
			x	[-linklsa_reserved_bit7                  CHOICES 0 1]
			x	[-linklsa_reserved_bit6                  CHOICES 0 1]
			x	[-linklsa_d_c_bit                        CHOICES 0 1]
			x	[-linklsa_r_bit                          CHOICES 0 1]
			x	[-linklsa_n_bit                          CHOICES 0 1]
			x	[-linklsa_x_bit                          CHOICES 0 1]
			x	[-linklsa_e_bit                          CHOICES 0 1]
			x	[-linklsa_v6_bit                         CHOICES 0 1]
			x	[-linklsa_unused_bit7                    CHOICES 0 1]
			x	[-linklsa_unused_bit6                    CHOICES 0 1]
			x	[-linklsa_unused_bit5                    CHOICES 0 1]
			x	[-linklsa_unused_bit4                    CHOICES 0 1]
			x	[-linklsa_p_bit                          CHOICES 0 1]
			x	[-linklsa_m_c_bit                        CHOICES 0 1]
			x	[-linklsa_l_a_bit                        CHOICES 0 1]
			x	[-linklsa_n_u_bit                        CHOICES 0 1]
			x	[-enable_segment_routing                 CHOICES 0 1]
			x	[-configure_s_i_d_index_label            ANY]
			x	[-sid_index_label                        ANY]
			x	[-algorithm                              ANY]
			x	[-np_flag                                ANY]
			x	[-m_flag                                 ANY]
			x	[-e_flag                                 ANY]
			x	[-v_flag                                 ANY]
			x	[-l_flag                                 ANY]
			x	[-srgb_range_count                       NUMERIC]
			x	[-s_r_algorithm_count                    NUMERIC]
			x	[-start_s_i_d_label                      ANY]
			x	[-sid_count                              ANY]
			x	[-ospf_sr_algorithm                      ANY]
			x	[-enable_s_r_l_g                         ANY]
			x	[-srlg_count                             NUMERIC]
			x	[-en_link_protection                     ANY]
			x	[-extra_traffic                          ANY]
			x	[-unprotected                            ANY]
			x	[-shared                                 ANY]
			x	[-dedicated1_to1                         ANY]
			x	[-dedicated1_plus1                       ANY]
			x	[-enhanced                               ANY]
			x	[-reserved40                             ANY]
			x	[-reserved80                             ANY]
			x	[-enable_adj_s_i_d                       ANY]
			x	[-adj_s_i_d                              ANY]
			x	[-b_flag                                 ANY]
			x	[-s_flag                                 ANY]
			x	[-p_flag                                 ANY]
			x	[-weight                                 ANY]
			x	[-srlg_value                             ANY]
			x	[-sid_index_label_ext_1                  ANY]
			x	[-configure_s_i_d_index_label_ext_1      ANY]
			x	[-algorithm_ext_1                        ANY]
			x	[-np_flag_ext_1                          ANY]
			x	[-m_flag_ext_1                           ANY]
			x	[-e_flag_ext_1                           ANY]
			x	[-v_flag_ext_1                           ANY]
			x	[-l_flag_ext_1                           ANY]
			x	[-configure_s_i_d_index_label_ext_2      ANY]
			x	[-sid_index_label_ext_2                  ANY]
			x	[-algorithm_ext_2                        ANY]
			x	[-np_flag_ext_2                          ANY]
			x	[-m_flag_ext_2                           ANY]
			x	[-e_flag_ext_2                           ANY]
			x	[-v_flag_ext_2                           ANY]
			x	[-l_flag_ext_2                           ANY]
			x	[-configure_s_i_d_index_label_stub       ANY]
			x	[-sid_index_label_stub                   ANY]
			x	[-algorithm_stub                         ANY]
			x	[-np_flag_stub                           ANY]
			x	[-m_flag_stub                            ANY]
			x	[-e_flag_stub                            ANY]
			x	[-v_flag_stub                            ANY]
			x	[-l_flag_stub                            ANY]
			x	[-configure_s_i_d_index_label_stub_net   ANY]
			x	[-sid_index_label_stub_net               ANY]
			x	[-algorithm_stub_net                     ANY]
			x	[-np_flag_stub_net                       ANY]
			x	[-m_flag_stub_net                        ANY]
			x	[-e_flag_stub_net                        ANY]
			x	[-v_flag_stub_net                        ANY]
			x	[-l_flag_stub_net                        ANY]
			x	[-configure_s_i_d_index_label_sum        ANY]
			x	[-sid_index_label_sum                    ANY]
			x	[-algorithm_sum                          ANY]
			x	[-np_flag_sum                            ANY]
			x	[-m_flag_sum                             ANY]
			x	[-e_flag_sum                             ANY]
			x	[-v_flag_sum                             ANY]
			x	[-l_flag_sum                             ANY]
			x	[-configure_s_i_d_index_label_pref_pool  ANY]
			x	[-sid_index_label_pref_pool              ANY]
			x	[-algorithm_pref_pool                    ANY]
			x	[-np_flag_pref_pool                      ANY]
			x	[-m_flag_pref_pool                       ANY]
			x	[-e_flag_pref_pool                       ANY]
			x	[-v_flag_pref_pool                       ANY]
			x	[-l_flag_pref_pool                       ANY]
			x	[-enable_srlb                            CHOICES 0 1]
			x	[-srlb_range_count                       NUMERIC]
			x	[-srlb_start_sid_label                   ANY]
			x	[-srlb_sid_count                         ANY]
		
		Arguments:
			 	-handle
			 		This option represents the handle the user *must* pass to the
			 		"emulation_ospf_network_group_config" procedure. This option specifies
			 		on which OSPF router to configure the OSPF route range.
			 		The OSPF router handle(s) are returned by the procedure
			 		"emulation_ospf_config" when configuring OSPF routers on the
			 		Ixia interface.
			 	-mode
			 		Mode of the procedure call.Valid options are:
			 		create
			 		modify
			 		delete
			 		Valid choices are:
			    		create -
			    		modify -
			    		delete -
			 	-type
			 		The type of topology route to create.
			 		Valid choices are:
			    		grid -
			    		mesh -
			    		custom -
			    		ring -
			    		hub-and-spoke -
			    		tree -
			    		ipv4-prefix -
			    		fat-tree -
			    		linear -
			    		ipv6-prefix -
			x	-protocol_name
			x	-multiplier
			x	-enable_device
			x		enables/disables device.
			 	-grid_col
			 		Defines number of columns in a grid.
			 		This option is valid only when -type is grid, otherwise it
			 		is ignored. This option is available with IxTclNetwork and IxTclProtocol API.
			 	-grid_row
			 		Defines number of rows in a grid.
			 		This option is valid only when -type is grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			x	-grid_include_emulated_device
			x	-grid_link_multiplier
			x	-mesh_number_of_nodes
			x	-mesh_include_emulated_device
			x	-mesh_link_multiplier
			x	-ring_number_of_nodes
			x	-ring_include_emulated_device
			x	-ring_link_multiplier
			x	-hub_spoke_number_of_first_level
			x	-hub_spoke_number_of_second_level
			x	-hub_spoke_enable_level_2
			x	-hub_spoke_link_multiplier
			x	-tree_number_of_nodes
			x	-tree_include_emulated_device
			x	-tree_use_tree_depth
			x	-tree_depth
			x	-tree_max_children_per_node
			x	-tree_link_multiplier
			x	-custom_link_multiplier
			x		number of links between two nodes
			x	-custom_from_node_index
			x	-custom_to_node_index
			x	-fat_tree_link_multiplier
			x		number of links between two nodes
			x	-fat_tree_level_count
			x		Number of Levels
			x	-fat_tree_node_count
			x		Number of Nodes Per Level
			x	-linear_nodes
			x		number of nodes
			x	-linear_link_multiplier
			x		number of links between two nodes
			x	-active_router_id
			x	-router_id
			x		The ID associated with the router.
			 	-router_id_step
			 		The ID associated with the router.
			x	-router_system_id
			x		6 Byte System Id in hex format.
			x	-enable_advertise_as_stub_network
			 	-router_abr
			 		If true (1), set router to be an area boundary router (ABR).
			 		Correspond to E (external) bit in router LSA.
			 		This option is valid only when -type is router or grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-router_asbr
			 		If true (1), set router to be an AS boundary router (ASBR).
			 		Correspond to B (Border) bit in router LSA.
			 		This option is valid only when -type is router or grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			x	-router_active
			x		Flag.
			x	-connected_to_handle
			x		Scenario element this connector is connecting to
			x	-from_ip
			x	-from_ip_step
			x	-to_ip
			x	-to_ip_step
			x	-enable_ip
			x		Enable Simulated Interface IP
			x	-subnet_prefix_length
			x	-subnet_ipv6_prefix_length
			 	-link_te
			 		This parameter enables Traffic Engineering on the link to the virtual ospf network Range topology.
			 		This field is applicable only when the -type is grid.
			 		This option is available with IxTclNetwork.
			x	-link_metric
			 	-link_te_metric
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_max_bw
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_max_resv_bw
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority0
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority1
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority2
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority3
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority4
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority5
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority6
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority7
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			x	-link_te_administrator_group
			x		This parameter is valid for -type router, grid.
			x		This parameter is valid with IxTclProtocol and IxTclNetwork.
			x	-external1_metric
			x	-external1_active
			x	-external1_network_address
			x	-external1_network_address_step
			x	-external1_number_of_routes
			x	-external1_prefix
			x	-external2_metric
			x	-external2_active
			x	-external2_network_address
			x	-external2_network_address_step
			x	-external2_number_of_routes
			x	-external2_prefix
			x	-nssa_metric
			x	-nssa_active
			x	-nssa_network_address
			x	-nssa_network_address_step
			x	-nssa_number_of_routes
			x	-nssa_prefix
			x	-stub_metric
			x	-stub_active
			x	-stub_network_address
			x	-stub_network_address_step
			x	-stub_number_of_routes
			x	-stub_prefix
			x	-summary_metric
			x	-summary_active
			x	-summary_network_address
			x	-summary_network_address_step
			x	-summary_number_of_routes
			x	-summary_prefix
			x	-ipv4_prefix_network_address
			x	-ipv4_prefix_network_address_step
			x	-ipv4_prefix_length
			x	-ipv4_prefix_number_of_addresses
			x	-ipv4_prefix_metric
			x	-ipv4_prefix_active
			x	-ipv4_prefix_allow_propagate
			x	-ipv4_prefix_route_origin
			x   		another_area -
			x   		external_type_1 -
			x   		external_type_2 -
			x   		nssa -
			x   		same_area -
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			x	-external_link_router_source
			x		Index of the originating node as defined in fromNetworkTopology
			x	-external_link_router_destination
			x		Index of the target node as defined in toNetworkTopology
			x	-external_link_network_group_handle
			x		Network Topology this link is pointing to
			x	-ipv6_prefix_network_address
			x		Network addresses of the simulated IPv4 network
			x	-ipv6_prefix_network_address_step
			x		Network addresses step of the simulated IPv6 network
			x	-ipv6_prefix_length
			x		Defines the length (in bits) of the mask to be used
			x		in conjunction with all the addresses created in the range.
			x	-ipv6_prefix_number_of_addresses
			x		Number of Network Addresses
			x	-ipv6_prefix_metric
			x		Route Metric
			x	-ipv6_prefix_route_origin
			x		Route Origin
			x		Valid choices are:
			x   		anotherarea -
			x   		externaltype1 -
			x   		externaltype2 -
			x   		samearea -
			x   		nssa -
			x	-ipv6_prefix_active
			x		Flag.
			x	-from_ipv6
			x		128 Bits IPv6 address.
			x	-from_ipv6_step
			x	-to_ipv6
			x		128 Bits IPv6 address.
			x	-to_ipv6_step
			x	-external_ipv6_network_address
			x		Network addresses of the simulated IPv6 network
			x	-external_ipv6_network_address_step
			x	-inter_area_destination_router_id
			x		Destination Router Id
			x	-inter_area_destination_router_id_step
			x		Destination Router Id Prefix
			x	-inter_area_link_state_id
			x		Link State Id of the simulated IPv6 network
			x	-external_reference_ls_type
			x		Reference LS Type
			x		Valid choices are:
			x   		ignore -
			x   		router -
			x   		network -
			x	-external_forwarding_address
			x		128 Bits IPv6 address.
			x	-external_external_route_tag
			x		External Route Tag
			x	-external_referenced_link_state_id
			x		Referenced Link State Id
			x	-external_link_state_id
			x		Link State Id of the simulated IPv6 network
			x	-external_link_state_id_prefix
			x		Link State Id Prefix
			x	-intra_area_reference_ls_type
			x		Reference LS Type
			x		Valid choices are:
			x   		router -
			x   		network -
			x	-intra_area_referenced_link_state_id
			x		Referenced Link State Id
			x	-intra_area_referenced_router_id
			x		Referenced Advertising Router Id
			x	-intra_area_link_state_id
			x		Link State Id of the simulated IPv6 network
			x	-intra_area_link_state_id_prefix
			x		Link State Id Prefix
			x	-linklsa_router_priority
			x		Router Priority
			x	-linklsa_link_local_address
			x		128 Bits IPv6 address.
			x	-linklsa_metric
			x		Metric
			x	-linklsa_link_state_id
			x		Link State Id of the simulated IPv6 network
			x	-linklsa_link_state_id_prefix
			x		Link State Id Prefix
			x	-linklsa_active
			x		Whether this is to be advertised or not
			x	-linklsa_network_address
			x		Network addresses of the simulated IPv6 network
			x	-linklsa_prefix_count
			x		Range Size
			x	-linklsa_prefix
			x		Prefix
			x	-inter_area_metric
			x		Metric
			x	-inter_area_active
			x		Whether this is to be advertised or not
			x	-external_metric
			x		Metric
			x	-external_active
			x		Whether this is to be advertised or not
			x	-external_prefix_count
			x		Prefix Count
			x	-external_prefix
			x		Prefix Length
			x	-auto_select_forwarding_address
			x		Auto Select Forwarding Address
			x	-allow_propagate
			x		Allow Propagate
			x	-forwarding_address
			x		Forwarding addresses of the Type-7 LSA
			x	-forwarding_address_step
			x	-inter_area_prefix_metric
			x		Metric
			x	-inter_area_prefix_link_state_id
			x		Link State Id of the simulated IPv6 network
			x	-inter_area_prefix_link_state_id_prefix
			x		Link State Id Prefix
			x	-inter_area_prefix_active
			x		Whether this is to be advertised or not
			x	-inter_area_prefix_network_address
			x		Prefixes of the simulated IPv6 network
			x	-inter_area_prefix_prefix_count
			x		Prefix Count
			x	-inter_area_prefix_prefix
			x		Prefix Length
			x	-nssa_propagate
			x		Propagate
			x	-nssa_link_state_id
			x		Start Link State Id for the LSAs to be generated for this set of IPv6 NSSA networks.
			x	-nssa_link_state_id_step
			x		Link State Id Step for the LSAs to be generated for this set of IPv6 NSSA networks.
			x	-intra_area_metric
			x		Metric
			x	-intra_area_active
			x		Whether this is to be advertised or not
			x	-intra_area_prefix_count
			x		Prefix Count
			x	-prefix
			x		Prefix Length
			x	-inter_area_prefix_count
			x		Count
			x	-nssa_include_forwarding_address
			x		Include Forwarding Address
			x	-inter_area_link_state_id_step
			x		Link State Id Step for the LSAs to be generated for this set of IPv6 Inter-Area networks.
			x	-intra_area_network_address
			x		Prefixes of the simulated IPv6 network
			x	-intra_area_network_address_step
			x	-external_e_bit
			x		External Metric Bit
			x	-external_f_bit
			x		Forwarding Address Bit
			x	-external_t_bit
			x		External Route Tag Bit
			x	-inter_area_reserved_bit7
			x		(7) Reserved Bit
			x	-inter_area_reserved_bit6
			x		(6) Reserved Bit
			x	-inter_area_d_c_bit
			x		Demand Circuit bit
			x	-inter_area_r_bit
			x		Router bit
			x	-inter_area_n_bit
			x		bit for handling Type 7 LSAs
			x	-inter_area_m_c_bit
			x		bit for forwarding of IP multicast datagrams
			x	-inter_area_e_bit
			x		bit describing how AS-external-LSAs are flooded
			x	-inter_area_v6_bit
			x		bit for excluding the router/link from IPv6 routing calculations. If clear, router/link is excluded
			x	-external_unused_bit7
			x		Options-(7)Unused
			x	-external_unused_bit6
			x		Options-(6)Unused
			x	-external_unused_bit5
			x		Options-(5)Unused
			x	-external_unused_bit4
			x		Options-(4)Unused
			x	-external_p_bit
			x		Options-P Bit(Propagate)
			x	-external_m_c_bit
			x		Options-MC Bit(Multicast)
			x	-external_l_a_bit
			x		Options-LA Bit(Local Address)
			x	-external_n_u_bit
			x		Options-NU Bit(No Unicast)
			x	-intra_area_unused_bit7
			x		Options-(7)Unused
			x	-intra_area_unused_bit6
			x		Options-(6)Unused
			x	-intra_area_unused_bit5
			x		Options-(5)Unused
			x	-intra_area_unused_bit4
			x		Options-(4)Unused
			x	-intra_area_p_bit
			x		Options-P Bit(Propagate)
			x	-intra_area_m_c_bit
			x		Options-MC Bit(Multicast)
			x	-intra_area_l_a_bit
			x		Options-LA Bit(Local Address)
			x	-intra_area_n_u_bit
			x		Options-NU Bit(No Unicast)
			x	-inter_area_prefix_unused_bit7
			x		Options-(7)Unused
			x	-inter_area_prefix_unused_bit6
			x		Options-(6)Unused
			x	-inter_area_prefix_unused_bit5
			x		Options-(5)Unused
			x	-inter_area_prefix_unused_bit4
			x		Options-(4)Unused
			x	-inter_area_prefix_p_bit
			x		Options-P Bit(Propagate)
			x	-inter_area_prefix_m_c_bit
			x		Options-MC Bit(Multicast)
			x	-inter_area_prefix_l_a_bit
			x		Options-LA Bit(Local Address)
			x	-inter_area_prefix_n_u_bit
			x		Options-NU Bit(No Unicast)
			x	-linklsa_reserved_bit7
			x		(7) Reserved Bit
			x	-linklsa_reserved_bit6
			x		(6) Reserved Bit
			x	-linklsa_d_c_bit
			x		Demand Circuit bit
			x	-linklsa_r_bit
			x		Router bit
			x	-linklsa_n_bit
			x		bit for handling Type 7 LSAs
			x	-linklsa_x_bit
			x		bit for forwarding of IP multicast datagrams
			x	-linklsa_e_bit
			x		bit describing how AS-external-LSAs are flooded
			x	-linklsa_v6_bit
			x		bit for excluding the router/link from IPv6 routing calculations. If clear, router/link is excluded
			x	-linklsa_unused_bit7
			x		Options-(7)Unused
			x	-linklsa_unused_bit6
			x		Options-(6)Unused
			x	-linklsa_unused_bit5
			x		Options-(5)Unused
			x	-linklsa_unused_bit4
			x		Options-(4)Unused
			x	-linklsa_p_bit
			x		Options-P Bit(Propagate)
			x	-linklsa_m_c_bit
			x		Options-MC Bit(Multicast)
			x	-linklsa_l_a_bit
			x		Options-LA Bit(Local Address)
			x	-linklsa_n_u_bit
			x		Options-NU Bit(No Unicast)
			x	-enable_segment_routing
			x		Enable Segment Routing
			x	-configure_s_i_d_index_label
			x		Configure SID/Index/Label
			x	-sid_index_label
			x		SID/Index/Label
			x	-algorithm
			x		Algorithm for the Node SID/Label
			x	-np_flag
			x		No-PHP Flag
			x	-m_flag
			x		Mapping Server Flag
			x	-e_flag
			x		Explicit-Null Flag
			x	-v_flag
			x		Value or Index Flag
			x	-l_flag
			x		Local or Global Flag
			x	-srgb_range_count
			x		SRGB Range Count
			x	-s_r_algorithm_count
			x		SR Algorithm Count
			x	-start_s_i_d_label
			x		Start SID/Label
			x	-sid_count
			x		SID Count
			x	-ospf_sr_algorithm
			x		SR Algorithm
			x	-enable_s_r_l_g
			x		This enables the SRLG on the OSPF link between two mentioned interfaces.
			x	-srlg_count
			x		This field value shows how many SRLG Value columns would be there in the GUI.
			x	-en_link_protection
			x		This enables the link protection on the OSPF link between two mentioned interfaces.
			x	-extra_traffic
			x		This is a Protection Scheme with value 0x01. It means that the link is protecting another link or links.The LSPs on a link of this type will be lost if any of the links it is protecting fail.
			x	-unprotected
			x		This is a Protection Scheme with value 0x02. It means that there is no other link protecting this link.The LSPs on a link of this type will be lost if the link fails.
			x	-shared
			x		This is a Protection Scheme with value 0x04. It means that there are one or more disjoint links of type Extra Traffic that are protecting this link.These Extra Traffic links are shared between one or more links of type Shared.
			x	-dedicated1_to1
			x		This is a Protection Scheme with value 0x08. It means that there is one dedicated disjoint link of type Extra Traffic that is protecting this link.
			x	-dedicated1_plus1
			x		This is a Protection Scheme with value 0x10. It means that a dedicated disjoint link is protecting this link.However, the protecting link is not advertised in the link state database and is therefore not available for the routing of LSPs.
			x	-enhanced
			x		This is a Protection Scheme with value 0x20. It means that a protection scheme that is more reliable than Dedicated 1+1, e.g., 4 fiber BLSR/MS-SPRING, is being used to protect this link.
			x	-reserved40
			x		This is a Protection Scheme with value 0x40.
			x	-reserved80
			x		This is a Protection Scheme with value 0x80.
			x	-enable_adj_s_i_d
			x		Enable Adj SID
			x	-adj_s_i_d
			x		Adjacency SID
			x	-b_flag
			x		Backup Flag
			x	-s_flag
			x		Set/Group Flag
			x	-p_flag
			x		Persistent Flag
			x	-weight
			x		Weight
			x	-srlg_value
			x		This is the SRLG Value for the link between two mentioned interfaces.
			x	-sid_index_label_ext_1
			x		SID/Index/Label
			x	-configure_s_i_d_index_label_ext_1
			x		Configure SID/Index/Label
			x	-algorithm_ext_1
			x		Algorithm
			x	-np_flag_ext_1
			x		No-PHP Flag
			x	-m_flag_ext_1
			x		Mapping Server Flag
			x	-e_flag_ext_1
			x		Explicit-Null Flag
			x	-v_flag_ext_1
			x		Value or Index Flag
			x	-l_flag_ext_1
			x		Local or Global Flag
			x	-configure_s_i_d_index_label_ext_2
			x		Configure SID/Index/Label
			x	-sid_index_label_ext_2
			x		SID/Index/Label
			x	-algorithm_ext_2
			x		Algorithm
			x	-np_flag_ext_2
			x		No-PHP Flag
			x	-m_flag_ext_2
			x		Mapping Server Flag
			x	-e_flag_ext_2
			x		Explicit-Null Flag
			x	-v_flag_ext_2
			x		Value or Index Flag
			x	-l_flag_ext_2
			x		Local or Global Flag
			x	-configure_s_i_d_index_label_stub
			x		Configure SID/Index/Label
			x	-sid_index_label_stub
			x		SID/Index/Label
			x	-algorithm_stub
			x		Algorithm
			x	-np_flag_stub
			x		No-PHP Flag
			x	-m_flag_stub
			x		Mapping Server Flag
			x	-e_flag_stub
			x		Explicit-Null Flag
			x	-v_flag_stub
			x		Value or Index Flag
			x	-l_flag_stub
			x		Local or Global Flag
			x	-configure_s_i_d_index_label_stub_net
			x		Configure SID/Index/Label
			x	-sid_index_label_stub_net
			x		SID/Index/Label
			x	-algorithm_stub_net
			x		Algorithm
			x	-np_flag_stub_net
			x		No-PHP Flag
			x	-m_flag_stub_net
			x		Mapping Server Flag
			x	-e_flag_stub_net
			x		Explicit-Null Flag
			x	-v_flag_stub_net
			x		Value or Index Flag
			x	-l_flag_stub_net
			x		Local or Global Flag
			x	-configure_s_i_d_index_label_sum
			x		Configure SID/Index/Label
			x	-sid_index_label_sum
			x		SID/Index/Label
			x	-algorithm_sum
			x		Algorithm
			x	-np_flag_sum
			x		No-PHP Flag
			x	-m_flag_sum
			x		Mapping Server Flag
			x	-e_flag_sum
			x		Explicit-Null Flag
			x	-v_flag_sum
			x		Value or Index Flag
			x	-l_flag_sum
			x		Local or Global Flag
			x	-configure_s_i_d_index_label_pref_pool
			x		Configure SID/Index/Label
			x	-sid_index_label_pref_pool
			x		SID/Index/Label
			x	-algorithm_pref_pool
			x		Algorithm
			x	-np_flag_pref_pool
			x		No-PHP Flag
			x	-m_flag_pref_pool
			x		Mapping Server Flag
			x	-e_flag_pref_pool
			x		Explicit-Null Flag
			x	-v_flag_pref_pool
			x		Value or Index Flag
			x	-l_flag_pref_pool
			x		Local or Global Flag
			x	-enable_srlb
			x		Enable SRLB
			x	-srlb_range_count
			x		SRLB Range Count
			x	-srlb_start_sid_label
			x		Start SID/Label
			x	-srlb_sid_count
			x		SID Count
		
		Return Values:
		A list containing the simulated router protocol stack handles that were added by the command (if any).
			xkey:simulated_router_handle           value:A list containing the simulated router protocol stack handles that were added by the command (if any).
		A list containing the external1 protocol stack handles that were added by the command (if any).
			xkey:external1_handle                  value:A list containing the external1 protocol stack handles that were added by the command (if any).
		A list containing the external2 protocol stack handles that were added by the command (if any).
			xkey:external2_handle                  value:A list containing the external2 protocol stack handles that were added by the command (if any).
		A list containing the nssa protocol stack handles that were added by the command (if any).
			xkey:nssa_handle                       value:A list containing the nssa protocol stack handles that were added by the command (if any).
		A list containing the stub protocol stack handles that were added by the command (if any).
			xkey:stub_handle                       value:A list containing the stub protocol stack handles that were added by the command (if any).
		A list containing the summary protocol stack handles that were added by the command (if any).
			xkey:summary_handle                    value:A list containing the summary protocol stack handles that were added by the command (if any).
		A list containing the simulated interface protocol stack handles that were added by the command (if any).
			xkey:simulated_interface_handle        value:A list containing the simulated interface protocol stack handles that were added by the command (if any).
		A list containing the ipv4 prefix interface protocol stack handles that were added by the command (if any).
			xkey:ipv4_prefix_interface_handle      value:A list containing the ipv4 prefix interface protocol stack handles that were added by the command (if any).
		A list containing the sim interface ipv4 config protocol stack handles that were added by the command (if any).
			xkey:sim_interface_ipv4_config_handle  value:A list containing the sim interface ipv4 config protocol stack handles that were added by the command (if any).
		A list containing the network group protocol stack handles that were added by the command (if any).
			xkey:network_group_handle              value:A list containing the network group protocol stack handles that were added by the command (if any).
		A list containing the ipv4 prefix pools protocol stack handles that were added by the command (if any).
			xkey:ipv4_prefix_pools_handle          value:A list containing the ipv4 prefix pools protocol stack handles that were added by the command (if any).
		A list containing the v3 inter area protocol stack handles that were added by the command (if any).
			xkey:v3_inter_area_handle              value:A list containing the v3 inter area protocol stack handles that were added by the command (if any).
		A list containing the v3 external protocol stack handles that were added by the command (if any).
			xkey:v3_external_handle                value:A list containing the v3 external protocol stack handles that were added by the command (if any).
		A list containing the v3 intra area prefix protocol stack handles that were added by the command (if any).
			xkey:v3_intra_area_prefix_handle       value:A list containing the v3 intra area prefix protocol stack handles that were added by the command (if any).
		A list containing the v3 nssa protocol stack handles that were added by the command (if any).
			xkey:v3_nssa_handle                    value:A list containing the v3 nssa protocol stack handles that were added by the command (if any).
		A list containing the v3 inter area prefix protocol stack handles that were added by the command (if any).
			xkey:v3_inter_area_prefix_handle       value:A list containing the v3 inter area prefix protocol stack handles that were added by the command (if any).
		A list containing the ipv6 prefix interface protocol stack handles that were added by the command (if any).
			xkey:ipv6_prefix_interface_handle      value:A list containing the ipv6 prefix interface protocol stack handles that were added by the command (if any).
		A list containing the ipv6 prefix pools protocol stack handles that were added by the command (if any).
			xkey:ipv6_prefix_pools_handle          value:A list containing the ipv6 prefix pools protocol stack handles that were added by the command (if any).
		A list containing the sim interface ipv6 config protocol stack handles that were added by the command (if any).
			xkey:sim_interface_ipv6_config_handle  value:A list containing the sim interface ipv6 config protocol stack handles that were added by the command (if any).
		A list containing the simulated v3 interface protocol stack handles that were added by the command (if any).
			xkey:simulated_v3_interface_handle     value:A list containing the simulated v3 interface protocol stack handles that were added by the command (if any).
		A list containing the v3 linklsa protocol stack handles that were added by the command (if any).
			xkey:v3_linklsa_handle                 value:A list containing the v3 linklsa protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:simulated_router_handles          value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:external1_handles                 value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:external2_handles                 value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:nssa_handles                      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:stub_handles                      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:summary_handles                   value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:simulated_interface_handles       value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:ipv4_prefix_interface_handles     value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:v3_inter_area_handles             value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:v3_external_handles               value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:v3_intra_area_prefix_handles      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:v3_nssa_handles                   value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:v3_inter_area_prefix_handles      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:ipv6_prefix_interface_handles     value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:simulated_v3_interface_handles    value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:v3_linklsa_handles                value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  simulated_router_handles, external1_handles, external2_handles, nssa_handles, stub_handles, summary_handles, simulated_interface_handles, ipv4_prefix_interface_handles, v3_inter_area_handles, v3_external_handles, v3_intra_area_prefix_handles, v3_nssa_handles, v3_inter_area_prefix_handles, ipv6_prefix_interface_handles, simulated_v3_interface_handles, v3_linklsa_handles
		
		See Also:
		
		"""
		return self._run_keyword("emulation_ospf_network_group_config", kwargs)

	def emulation_ospf_topology_route_config(self, **kwargs):
		""" This procedure will add OSPF route
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ospf_topology_route_config
			 	-mode                           CHOICES create
			                                 CHOICES modify
			                                 CHOICES delete
			                                 CHOICES enable
			                                 CHOICES disable
			 	-handle                         ANY
			 	[-type                          CHOICES router
			                                 CHOICES grid
			                                 CHOICES network
			                                 CHOICES summary_routes
			                                 CHOICES ext_routes]
			x	[-area_id                       ANY]
			x	[-bfd_registration              ANY]
			 	[-count                         RANGE 1-2000]
			x	[-dead_interval                 ANY]
			 	[-elem_handle                   ANY]
			 	[-enable_advertise              CHOICES 0 1
			                                 DEFAULT 1]
			x	[-enable_advertise_loopback     CHOICES 0 1
			x                                DEFAULT 0]
			x	[-entry_point_address           ANY]
			x	[-entry_point_prefix_length     ANY]
			 	[-external_address_family       ANY]
			 	[-external_ip_type              ANY]
			 	[-external_number_of_prefix     RANGE 1-16000000
			                                 DEFAULT 24]
			 	[-external_prefix_length        RANGE 0-128
			                                 DEFAULT 24]
			 	[-external_prefix_metric        RANGE 0-16777215
			                                 DEFAULT 1]
			 	[-external_prefix_start         IP
			                                 DEFAULT 0.0.0.0]
			 	[-external_prefix_step          RANGE 0-2147483647
			                                 DEFAULT 1]
			 	[-external_prefix_type          CHOICES 1 2
			                                 DEFAULT 1]
			 	[-grid_col                      RANGE 0-10000
			                                 DEFAULT 2]
			 	[-grid_connect                  ANY]
			 	[-grid_link_type                CHOICES broadcast
			                                 CHOICES ptop_numbered
			                                 CHOICES ptop_unnumbered
			                                 DEFAULT ptop_numbered]
			 	[-grid_prefix_length            RANGE 0-128
			                                 DEFAULT 24]
			 	[-grid_prefix_start             IP
			                                 DEFAULT 0.0.0.0]
			 	[-grid_prefix_step              IP
			                                 DEFAULT 0.0.0.1]
			 	[-grid_router_id                IP
			                                 DEFAULT 0.0.0.0]
			 	[-grid_router_id_step           IP
			                                 DEFAULT 0.0.0.0]
			 	[-grid_row                      RANGE 0-10000
			                                 DEFAULT 2]
			 	[-grid_te                       CHOICES 0 1
			                                 DEFAULT 0]
			x	[-hello_interval                ANY]
			 	[-interface_ip_address          IP
			                                 DEFAULT 0.0.0.0]
			 	[-interface_ip_mask             MASK]
			 	[-interface_ip_options          ANY]
			x	[-interface_metric              RANGE 0-65535
			x                                DEFAULT 10]
			x	[-interface_mode                ANY]
			x	[-interface_mode2               ANY]
			 	[-link_te                       CHOICES 0 1]
			 	[-link_te_metric                RANGE 0-65535
			                                 DEFAULT 10]
			 	[-link_te_max_bw                NUMERIC
			                                 DEFAULT 0]
			 	[-link_te_max_resv_bw           NUMERIC
			                                 DEFAULT 0]
			 	[-link_te_unresv_bw_priority0   NUMERIC
			                                 DEFAULT 0]
			 	[-link_te_unresv_bw_priority1   NUMERIC
			                                 DEFAULT 0]
			 	[-link_te_unresv_bw_priority2   NUMERIC
			                                 DEFAULT 0]
			 	[-link_te_unresv_bw_priority3   NUMERIC
			                                 DEFAULT 0]
			 	[-link_te_unresv_bw_priority4   NUMERIC
			                                 DEFAULT 0]
			 	[-link_te_unresv_bw_priority5   NUMERIC
			                                 DEFAULT 0]
			 	[-link_te_unresv_bw_priority6   NUMERIC
			                                 DEFAULT 0]
			 	[-link_te_unresv_bw_priority7   NUMERIC
			                                 DEFAULT 0]
			x	[-link_type                     ANY]
			x	[-neighbor_router_id            ANY]
			x	[-neighbor_router_prefix_length ANY]
			 	[-net_ip                        ANY]
			 	[-net_prefix_length             ANY]
			 	[-net_prefix_options            ANY]
			x	[-no_write                      ANY]
			 	[-router_abr                    CHOICES 0 1
			                                 DEFAULT 0]
			 	[-router_asbr                   CHOICES 0 1
			                                 DEFAULT 0]
			 	[-router_id                     IP
			                                 DEFAULT 0.0.0.0]
			 	[-router_te                     ANY]
			 	[-router_virtual_link_endpt     ANY]
			 	[-router_wcr                    ANY]
			 	[-summary_address_family        ANY]
			 	[-summary_ip_type               ANY]
			 	[-summary_number_of_prefix      RANGE 1-16000000
			                                 DEFAULT 24]
			 	[-summary_prefix_length         RANGE 0-128
			                                 DEFAULT 24]
			 	[-summary_prefix_metric         RANGE 0-16777215]
			 	[-summary_prefix_start          IP
			                                 DEFAULT 0.0.0.0]
			 	[-summary_prefix_step           RANGE 0-2147483647
			                                 DEFAULT 1]
			x	[-summary_route_type            CHOICES another_area same_area
			x                                DEFAULT another_area]
			n	[-grid_disconnect               ANY]
			n	[-link_te_link_id               ANY]
			n	[-link_te_local_ip_addr         ANY]
			n	[-link_te_remote_ip_addr        ANY]
			n	[-link_te_type                  ANY]
			n	[-link_te_instance              ANY]
			n	[-link_te_admin_group           ANY]
			n	[-link_metric                   ANY]
			n	[-link_intf_addr                ANY]
			n	[-link_enable                   ANY]
			n	[-external_connect              ANY]
			n	[-external_prefix_forward_addr  ANY]
			n	[-grid_connect_session          ANY]
			n	[-grid_start_gmpls_link_id      ANY]
			n	[-grid_start_te_ip              ANY]
			n	[-grid_stub_per_router          ANY]
			n	[-net_dr                        ANY]
			n	[-nssa_connect                  ANY]
			n	[-nssa_number_of_prefix         ANY]
			n	[-nssa_prefix_forward_add       ANY]
			n	[-nssa_prefix_length            ANY]
			n	[-nssa_prefix_metric            ANY]
			n	[-nssa_prefix_start             ANY]
			n	[-nssa_prefix_step              ANY]
			n	[-nssa_prefix_type              ANY]
			n	[-router_connect                ANY]
			n	[-router_disconnect             ANY]
			n	[-summary_connect               ANY]
			n	[-nssa_prefix_forward_addr      ANY]
		
		Arguments:
			 	-mode
			 		Mode of the procedure call.Valid options are:
			 		create
			 		modify
			 		delete
			 		enable
			 		disable
			 		Valid choices are:
			    		create -
			    		modify -
			    		delete -
			    		enable -
			    		disable -
			 	-handle
			 		This option represents the handle the user *must* pass to the
			 		"emulation_ospf_topology_route_config" procedure. This option specifies
			 		on which OSPF router to configure the OSPF route range.
			 		The OSPF router handle(s) are returned by the procedure
			 		"emulation_ospf_config" when configuring OSPF routers on the
			 		Ixia interface.
			 	-type
			 		The type of topology route to create.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 		Valid choices are:
			    		router - Individual OSPF router. This value is not supported in NGPF
			    		grid - A rectangular grid of routers
			    		network - A subnet behind the selected session router. This value is not supported in NGPF
			    		summary_routes - A pool of summary route addresses
			    		ext_routes - A pool of external route addresses
			x	-area_id
			x		The OSPF area ID associated with the interface. This parameter is valid for -type router, grid, network. This parameter is valid with IxTclProtocol and IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-bfd_registration
			x		Enable or disable BFD registration.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-count
			 		Number of route ranges to be configured.
			 		This parameter is valid for -type summary, ext_routes.
			 		This option is available with IxTclNetwork.
			x	-dead_interval
			x		The number of seconds before declaring a silent router down. This parameter is valid for -type router, grid, network. This parameter is valid with IxTclProtocol and IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-elem_handle
			 		This option specifies on which topology element to configure the
			 		route options. The user must pass in this option if the "type" is
			 		modify or delete.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-enable_advertise
			 		Enables the advertisement of a range of OSPF routers expressed as a
			 		matrix of n x m routers (grid).
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			x	-enable_advertise_loopback
			x		Used for Traffic Engineering. If checked, a stub interface will be
			x		added to each router with IP = Router ID with a 32-bit mask. (x.x.x.x/32).
			x		This parameter is valid for -type router, grid.
			x		This parameter is valid with IxTclProtocol and IxTclNetwork.
			x	-entry_point_address
			x		The entry point address of the OSPFv3 network range grid.This parameter is valid for -type grid. This parameter is valid with IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-entry_point_prefix_length
			x		The prefix length of the entry point address of the OSPFv3 network range grid.This parameter is valid for -type grid. This parameter is valid with IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-external_address_family
			 		The external route's address family, choices are unicast or multicast
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-external_ip_type
			 		The external route's ip type choices are ipv4 or ipv6
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-external_number_of_prefix
			 		The number of prefixes to be advertised.
			 		This option is valid only when -type is ext_routes, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-external_prefix_length
			 		The number of bits in the prefixes to be advertised. For example,
			 		a value of 24 is equivalent to a network mask of 255.255.255.0.
			 		This option is valid only when -type is ext_routes, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-external_prefix_metric
			 		The cost metric associated with the route.
			 		This option is valid only when -type is ext_routes, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-external_prefix_start
			 		The IP address of the routes to be advertised.
			 		This option is valid only when -type is ext_routes, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-external_prefix_step
			 		The increment used between generated addresses for ext_routes
			 		prefixes. For usage with IxNetwork this is the step between route
			 		range objects.
			 		This option is valid only when -type is ext_routes, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-external_prefix_type
			 		This option is valid only when -type is ext_routes, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 		Valid choices are:
			 		1 - (default) Outside the area.
			 		2 - Outside the area, but with metrics which are larger than any
			 		internal metric.
			 		Valid choices are:
			    		1 -
			    		2 -
			 	-grid_col
			 		Defines number of columns in a grid.
			 		This option is valid only when -type is grid, otherwise it
			 		is ignored. This option is available with IxTclNetwork and IxTclProtocol API.
			 	-grid_connect
			 		Connects a router in the grid, as specified by the row and column, to the session router of specified OSPF session. The format for entering the row and column is "grid_connect <row> <col>". By default, the 1st row and 1st column router is connected to the session router of its parent session.This option is valid only when -type is grid, otherwise it is ignored.This option is available with IxTclNetwork and IxTclProtocol API.(DEFAULT = 1 1)
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-grid_link_type
			 		This is the Link Type advertised in the Router LSA interface list.
			 		Choose one of: broadcast ptop_numbered ptop_unnumbered
			 		This option is valid only when -type is grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 		Valid choices are:
			    		broadcast - Not supported in ixiangpf
			    		ptop_numbered - Point to point grid
			    		ptop_unnumbered - Not supported in ixiangpf
			 	-grid_prefix_length
			 		The length of the mask associated with the grid_prefix_start.
			 		This option is valid only when -type is grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-grid_prefix_start
			 		The IP subnet address associated with the first router.
			 		This option is valid only when -type is grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-grid_prefix_step
			 		This is the value used to increment the subnet address by between
			 		successively generated routers.
			 		This option is valid only when -type is grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-grid_router_id
			 		The first router ID of the grid.
			 		This option is valid only when -type is grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-grid_router_id_step
			 		The increment step for the router ID in a grid.
			 		This option is valid only when -type is grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-grid_row
			 		Defines number of rows in a grid.
			 		This option is valid only when -type is grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-grid_te
			 		If true (1), enable traffic engineering on the router grid.OSPFv2
			 		only. This can overwrite the settings on the
			 		session router.
			 		This option is valid only when -type is grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			x	-hello_interval
			x		The number of seconds between Hello packets sent from an Ixia router. The Ixia state machine sends Hello packets at this interval for all of the defined interfaces. This parameter is valid for -type router, grid, network. This parameter is valid with IxTclProtocol and IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-interface_ip_address
			 		For OSPFv2 only.
			 		IP address of the unconnected interface between the router/grid
			 		to the session router.
			 		This option is valid only when -type is router or grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-interface_ip_mask
			 		For OSPFv2 only.
			 		IP mask of the un-connected interface between the router/grid
			 		to the session router.
			 		This option is for router and grid route only.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-interface_ip_options
			 		For OSPFv2 only. Options related to the interface. Multiple options may be combined using a logical or.This option is for router and grid route only.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 		Valid choices are:
			    		ospfOptionBitTypeOfService - 0x01
			    		ospfOptionBitExternalRouting - 0x02
			    		ospfOptionBitMulticast - 0x04
			    		ospfOptionBitNSSACapability - 0x08
			    		ospfOptionBitExternalAttributes - 0x10
			    		ospfOptionBitDemandCircuit - 0x20
			    		ospfOptionBitLSANoForward - 0x40
			    		ospfOptionBitUnused - 0x80
			x	-interface_metric
			x		This parameter is valid for OSPFv2 -type router, grid, network and OSPFv3 -type grid.
			x		This parameter is valid with IxTclProtocol and IxTclNetwork.
			x	-interface_mode
			x		Available only for use when the Point-Point link type is selected (-link_type ppp). When this option is provided as ospf_and_protocol_interface (default), an unconnected protocol interface will be created, having the IP address provided by -neighbor_router_id option and the gateway will be the OSPF router's connected interface. This parameter is valid for OSPFv2. This parameter is valid for -type router, grid; -enable_advertise 0; -link_type ppp. This parameter is valid with IxTclProtocol and IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-interface_mode2
			x		When this option is provided as ospf_and_protocol_interface (default), an unconnected protocol interface will be created, having the IP address provided by the -interface_ip_address option andthe gateway will be the ospf router's connected interface.This parameter is valid only for IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-link_te
			 		This parameter enables Traffic Engineering on the link to the virtual ospf network Range topology.
			 		This field is applicable only when the -type is grid.
			 		This option is available with IxTclNetwork.
			 	-link_te_metric
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_max_bw
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_max_resv_bw
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority0
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority1
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority2
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority3
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority4
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority5
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority6
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			 	-link_te_unresv_bw_priority7
			 		This parameter is valid for -type router, grid.
			 		This parameter is valid with IxTclProtocol and IxTclNetwork.
			x	-link_type
			x		The link type advertised in the Router LSA interface list. This option is for router and grid route only.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		external-capable - (default) A transit network.
			x   		ppp - A point-to-point network.
			x   		stub - A stub network.
			x	-neighbor_router_id
			x		Available only for use when the Point-Point link type is selected. The DUT IP Interface address can be provided. This parameter is valid for OSPFv2. This parameter is valid for -type router, grid; -enable_advertise 0; -link_type ppp. This parameter is valid with IxTclProtocol and IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-neighbor_router_prefix_length
			x		Available only for use when the Point-Point link type is selected. The prefix length of the DUT IP Interface address can be provided. This parameter is valid for OSPFv2. This parameter is valid for -type router, grid; -enable_advertise 0; -link_type ppp. This parameter is valid with IxTclProtocol and IxTclNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-net_ip
			 		IP address of the network (transit link) behind the session router.This option is valid only when -type is network, otherwise it is ignored.This option is available with IxTclNetwork and IxTclProtocol API.(DEFAULT = 0.0.0.0 | 0::0)
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-net_prefix_length
			 		IP mask of the network (transit link).This option is valid only when -type is network, otherwise it is ignored.This option is available with IxTclNetwork and IxTclProtocol API.(DEFAULT = 24 | 64)
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-net_prefix_options
			 		For OSPFv3 only.An 8-bit quantity with options related to the IP address of the network (transit link).Multiple bits may becombined using a logical "or". This option is valid only when -type is network, otherwise it is ignored.This option is available with IxTclNetwork and IxTclProtocol API.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 		Valid choices are:
			    		ospfV3PrefixOptionPBit - 0x08--The propagate bit, which is set on
			    		ospfV3PrefixOptionMCBit - 0x04--The multicast capability bit, which
			    		ospfV3PrefixOptionLABit - 0x02--The local address capability bit,
			    		ospfV3PrefixOptionNUBit - 0x01--The no unicast bit, which should be
			x	-no_write
			x		If this option is present, the protocol configuration will not be written to the server.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-router_abr
			 		If true (1), set router to be an area boundary router (ABR).
			 		Correspond to E (external) bit in router LSA.
			 		This option is valid only when -type is router or grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-router_asbr
			 		If true (1), set router to be an AS boundary router (ASBR).
			 		Correspond to B (Border) bit in router LSA.
			 		This option is valid only when -type is router or grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-router_id
			 		The ID associated with the router.
			 		This option is valid only when -type is router or grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-router_te
			 		If true (1), enable traffic engineering.OSPFv2 only.This option is valid only when -type is router or grid, otherwise it is ignored.This option is available with IxTclNetwork and IxTclProtocol API.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-router_virtual_link_endpt
			 		This option is supported for OSPFV3 only. Indicates that the router is an endpoint of one or more fully adjacent virtual links.This option is valid only when -type is grid, otherwise it is ignored.This option is available with IxTclNetwork and IxTclProtocol API.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-router_wcr
			 		Indicates that the router is a wild-card multicast receiver and will receive multicast datagrams regardless of destination.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-summary_address_family
			 		The summary route's address family, choices are unicast or multicast
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-summary_ip_type
			 		The summary route's ip type choices are ipv4 or ipv6
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-summary_number_of_prefix
			 		The number of prefixes to be advertised.
			 		This option is valid only when -type is summary_routes, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-summary_prefix_length
			 		The number of bits in the prefixes to be advertised. For example,
			 		a value of 24 is equivalent to a network mask of 255.255.255.0.
			 		This option is valid only when -type is summary_routes, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-summary_prefix_metric
			 		The cost metric associated with the route.
			 		This option is valid only when -type is summary_routes, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-summary_prefix_start
			 		The IP address of the routes to be advertised.
			 		This option is valid only when -type is summary_routes, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			 	-summary_prefix_step
			 		For usage with IxNetwork this is the step between route
			 		range objects.
			 		For usage with IxTclProtocol and IxTclNetwork this is the increment
			 		used to generate multiple summary addresses for OSPFv3 only.
			 		This option is valid only when -type is summary_routes, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			x	-summary_route_type
			x		The type of summary route to be created.
			x		This option is valid only when -type is summary_routes, otherwise it
			x		is ignored.
			x		This option is available with IxTclNetwork.
			x		Valid choices are:
			x   		another_area -
			x   		same_area -
			n	-grid_disconnect
			n	-link_te_link_id
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-link_te_local_ip_addr
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-link_te_remote_ip_addr
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-link_te_type
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-link_te_instance
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-link_te_admin_group
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-link_metric
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-link_intf_addr
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-link_enable
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-external_connect
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-external_prefix_forward_addr
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-grid_connect_session
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-grid_start_gmpls_link_id
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-grid_start_te_ip
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-grid_stub_per_router
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-net_dr
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-nssa_connect
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-nssa_number_of_prefix
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-nssa_prefix_forward_add
			n   	-nssa_prefix_length
			n       		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n   	-nssa_prefix_metric
			n       		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n   	-nssa_prefix_start
			n       		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n   	-nssa_prefix_step
			n       		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n   	-nssa_prefix_type
			n       		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n   	-router_connect
			n       		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n   	-router_disconnect
			n       		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n   	-summary_connect
			n       	-nssa_prefix_forward_addr
			n           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
		   
		   Return Values:
		       $::SUCCESS or $::FAILURE
			        key:status       value:$::SUCCESS or $::FAILURE
		       If failure, will contain more information
			        key:log          value:If failure, will contain more information
		       If mode is create this return list of current Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			        key:elem_handle  value:If mode is create this return list of current Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		       If mode is create this return list of current
			        key:elem_handle  value:If mode is create this return list of current 
		   
		   Examples:
		       See files starting with OSPFv2 and OSPFv3 in the Samples subdirectory. Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the OSPF usage.
		       See the OSPF example in Appendix A, "Example APIs," for one specific example usage.
		       See files starting with OSPFv2 and OSPFv3 in the Samples subdirectory. Also see some of the L2VPN, L3VPN, MPLS, and MVPN sample files for further examples of the OSPF usage.See the OSPF example in Appendix A, "Example APIs," for one specific example usage.
		   
		   Sample Input:
		   
		   Sample Output:
		   
		   Notes:
		       1) Coded versus functional specification.
		       Caveats:
		       This function does not support the following return values:
		       router
		       .  connected_handles
		       .      <handle1>.link_type   <link_type>
		       .                te_link_lsa <te_link_lsa_handle>
		       .  link_type            <link_type_list>
		       .  router_lsa           <router_lsa_handle>
		       .  link_lsa             <ospfv3_link_lsa_handle>
		       .  intra_area_pfx_lsa   <ospfv3_intra_area_prefix_lsa_handle>
		       .  te_router_lsa        <ospfv2_te_router_lsa_handle>
		       .  te_link_lsas         <ospfv2_te_link_lsa_handle_list
		       grid
		       .  router.$row.$col     <router_handle>
		       network
		       .  network_lsa          <lsa_handle>
		       .  intra_area_pfx_lsa   <ospfv3_intra_area_prefix_lsa_handle>
		       .  connected_routers    <router_handle_list>
		       summary
		       .  summary_lsas         <lsa_pool_handle>
		       .  connected_routers    <router_handle_list>
		       external
		       .  external_lsas         <lsa_pool_handle>
		       .  connected_routers     <router_handle_list>
		       nssa
		       .  nssa_lsas            <lsa_pool_handle>
		       .  connected_routers    <router_handle_list>
		       .  version              {ospfv2|ospfv3}
		       handle (ospf_session_handle)/elem_handle must be created and used within one
		       wish shell.
		       OSPFv3
		       Router and grid type do not support "modify" mode. This is due
		       to ixTclHal's lack of getNetworkRange option with a lableId.
		       To workaround, delete then re-create router or grid topology element.
		       OSPFv2/v3
		       Only types that support the enable/disable modes are summary_routes and ext_routes If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  elem_handle
		       1) Coded versus functional specification.
		       This function does not support the following return values:router.  connected_handles.      <handle1>.link_type   <link_type>.                te_link_lsa <te_link_lsa_handle>.  link_type            <link_type_list>.  router_lsa           <router_lsa_handle>.  link_lsa             <ospfv3_link_lsa_handle>.  intra_area_pfx_lsa   <ospfv3_intra_area_prefix_lsa_handle>.  te_router_lsa        <ospfv2_te_router_lsa_handle>.  te_link_lsas         <ospfv2_te_link_lsa_handle_listgrid.  router.$row.$col     <router_handle>network.  network_lsa          <lsa_handle>.  intra_area_pfx_lsa   <ospfv3_intra_area_prefix_lsa_handle>.  connected_routers    <router_handle_list>summary.  summary_lsas         <lsa_pool_handle>.  connected_routers    <router_handle_list>external.  external_lsas         <lsa_pool_handle>.  connected_routers     <router_handle_list>nssa.  nssa_lsas            <lsa_pool_handle>.  connected_routers    <router_handle_list>.  version              {ospfv2|ospfv3}
		       handle (ospf_session_handle)/elem_handle must be created and used within one wish shell.
		       OSPFv3Router and grid type do not support "modify" mode. This is due to ixTclHal's lack of getNetworkRange option with a lableId. To workaround, delete then re-create router or grid topology element.
		       OSPFv2/v3Only types that support the enable/disable modes are summary_routes and ext_routes
		   
		   See Also:
		   
		"""
		return self._run_keyword("emulation_ospf_topology_route_config", kwargs)

	def emulation_ovsdb_config(self, **kwargs):
		""" This procedure will add OVSDB Controller(s) to a particular Ixia Interface.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ovsdb_config
			x	[-port_handle                          REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-reset                                FLAG]
			 	[-handle                               ANY]
			x	[-return_detailed_handles              CHOICES 0 1
			x                                       DEFAULT 0]
			 	[-mode                                 CHOICES create
			                                        CHOICES modify
			                                        CHOICES delete
			                                        CHOICES getAttribute
			                                        DEFAULT create]
			x	[-attributeName                        CHOICES role
			x                                       CHOICES errorCode
			x                                       CHOICES errorTimeStamp
			x                                       CHOICES errorDesc
			x                                       CHOICES errorPhysicalSwitchName
			x                                       CHOICES errorLogicalSwitchName
			x                                       CHOICES serverAddDeleteStatus
			x                                       CHOICES latestDumpDbFileNames
			x                                       CHOICES latestErrorFileNames
			x                                       CHOICES serverAddDeleteConnectionError
			x                                       CHOICES bindingStatus
			x                                       CHOICES progressStatus
			x                                       CHOICES errorStatus]
			x	[-name                                 ALPHA]
			 	[-count                                RANGE 1-8000
			                                        DEFAULT 1]
			x	[-connection_type                      CHOICES tcp tls]
			x	[-controller_tcp_port                  RANGE 1-66535
			x                                       DEFAULT 6640]
			x	[-directory_name                       ANY]
			x	[-file_private_key                     ANY]
			x	[-file_certificate                     ANY]
			x	[-verify_peer_certificate              CHOICES 0 1
			x                                       DEFAULT 0]
			x	[-file_ca_certificate                  ANY]
			x	[-verify_hw_gateway_certificate        CHOICES 0 1
			x                                       DEFAULT 0]
			x	[-file_hw_gateway_certificate          ANY]
			x	[-time_out                             NUMERIC]
			x	[-dumpdb_directory_name                ANY]
			x	[-enable_ovsdb_server_ip               CHOICES 0 1
			x                                       DEFAULT 0]
			x	[-enable_logging                       CHOICES 0 1
			x                                       DEFAULT 0]
			x	[-ovsdb_server_ip                      IPV4
			x                                       DEFAULT 0.0.0.0]
			x	[-clear_dump_db_files                  CHOICES 0 1
			x                                       DEFAULT 1]
			x	[-error_log_directory_name             ANY]
			x	[-server_connection_ip                 IPV4
			x                                       DEFAULT 0.0.0.0]
			x	[-bindings_count                       NUMERIC]
			x	[-attach_at_start                      CHOICES 0 1
			x                                       DEFAULT 1]
			x	[-logical_switch_name                  ANY]
			x	[-vni                                  ANY]
			x	[-physical_switch_name                 ANY]
			x	[-physical_port_name                   ANY]
			x	[-sessions_per_vxlan                   RANGE 1-1600
			x                                       DEFAULT 1]
			x	[-pseudo_connected_to                  ANY]
			x	[-pseudo_connected_to_vxlan_replicator ANY]
			x	[-pseudo_connected_to_bfd              ANY]
			x	[-vxlan                                ANY]
			x	[-vxlan_replicator                     ANY]
			x	[-cluster_vlan_id                      RANGE 0-4096]
			x	[-create_full_stack                    CHOICES 0 1
			x                                       DEFAULT 0]
			x	[-table_names                          CHOICES all
			x                                       CHOICES global
			x                                       CHOICES manager
			x                                       CHOICES physical_switch
			x                                       CHOICES physical_port
			x                                       CHOICES physical_locator
			x                                       CHOICES physical_locator_set
			x                                       CHOICES tunnel
			x                                       CHOICES logical_switch
			x                                       CHOICES ucast_mac_local
			x                                       CHOICES ucast_mac_remote
			x                                       CHOICES mcast_mac_local
			x                                       CHOICES mcast_mac_remote]
		
		Arguments:
			x	-port_handle
			x		Ixia interface upon which to act.
			x	-reset
			x		If this option is selected, this will clear any Ovsdb Controller.
			 	-handle
			 		Ovsdb Controller handle for using the modes delete, modify, enable, and disable.
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			 	-mode
			 		Action to take on the port specified the handle argument.
			 		Valid choices are:
			    		create - Adds a new Ovsdb configuration on the port.
			    		modify - Modifies an existing Ovsdb configuration (specified by -handle).
			    		delete - Remove an existing Ovsdb configuration (specified by -handle).
			    		getAttribute - get attribute for existing Ovsdb configuration (specified by -handle).
			x	-attributeName
			x		attribute name for fetching value.
			x		Valid choices are:
			x   		role - role
			x   		errorCode - errorCode
			x   		errorTimeStamp - errorTimeStam
			x   		errorDesc - errorDesc
			x   		errorPhysicalSwitchName - errorPhysicalSwitchName
			x   		errorLogicalSwitchName - errorLogicalSwitchName
			x   		serverAddDeleteStatus - serverAddDeleteStatus
			x   		latestDumpDbFileNames - latestDumpDbFileNames
			x   		latestErrorFileNames - latestErrorFileNames
			x   		serverAddDeleteConnectionError - serverAddDeleteConnectionError
			x   		bindingStatus - bindingStatus
			x   		progressStatus - progressStatus
			x   		errorStatus - errorStatus
			x	-name
			x		Name of NGPF element, guaranteed to be unique in Scenario
			 	-count
			 		Defines the number of ovsdb controller to configure on the -port_handle.
			x	-connection_type
			x		Connection should use TCP or TLS
			x		Valid choices are:
			x   		tcp -
			x   		tls -
			x	-controller_tcp_port
			x		Specify the TCP port for the Controller
			x	-directory_name
			x		Location of Directory in Client where the Certificate and Key Files are available
			x	-file_private_key
			x		Private Key File
			x	-file_certificate
			x		Certificate File
			x	-verify_peer_certificate
			x		Verify Peer Certificate
			x	-file_ca_certificate
			x		CA Certificate File
			x	-verify_hw_gateway_certificate
			x		Verify HW Gateway Certificate
			x	-file_hw_gateway_certificate
			x		HW Gateway Certificate File
			x	-time_out
			x		Transact request Time Out in seconds. For scale scenarios increase this Timeout value.
			x	-dumpdb_directory_name
			x		Location of Directory in Client where the DumpDb Files are available
			x	-enable_ovsdb_server_ip
			x	-enable_logging
			x		If true, Port debug logs will be recorded.
			x	-ovsdb_server_ip
			x		The IP address of the DUT or Ovs Server.
			x	-clear_dump_db_files
			x	-error_log_directory_name
			x		Location of Directory in Client where the ErrorLog Files are available
			x	-server_connection_ip
			x		The IP address of the DUT or Ovs Server which needs to be Added/Deleted.
			x	-bindings_count
			x		Bindings Count
			x	-attach_at_start
			x		Attach at Start
			x	-logical_switch_name
			x		Logical_Switch Name
			x	-vni
			x		VNI
			x	-physical_switch_name
			x		Physical_Switch name
			x	-physical_port_name
			x		Physical_Port name
			x	-sessions_per_vxlan
			x		Indicates the multiplier per VXLAN entity for behind VM clients emulated.
			x	-pseudo_connected_to
			x		GUI-only connection
			x	-pseudo_connected_to_vxlan_replicator
			x		GUI-only connection
			x	-pseudo_connected_to_bfd
			x		GUI-only connection
			x	-vxlan
			x	-vxlan_replicator
			x	-cluster_vlan_id
			x		Cluster Data VLAN ID
			x	-create_full_stack
			x		flag to create full stack. this flag is introduced mainly for Scripgen Issue.
			x	-table_names
			x   		all -
			x   		global -
			x   		manager -
			x   		physical_switch -
			x   		physical_port -
			x   		physical_locator -
			x   		physical_locator_set -
			x   		tunnel -
			x   		logical_switch -
			x   		ucast_mac_local -
			x   		ucast_mac_remote -
			x   		mcast_mac_local -
			x   		mcast_mac_remote -
		
		Return Values:
		A list containing the ovsdb controller protocol stack handles that were added by the command (if any).
			xkey:ovsdb_controller_handle  value:A list containing the ovsdb controller protocol stack handles that were added by the command (if any).
		$::SUCCESS or $::FAILURE
			 key:status                   value:$::SUCCESS or $::FAILURE
		If failure, will contain more information
			 key:log                      value:If failure, will contain more information
		Ovsdb Controller Handles Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:handle                   value:Ovsdb Controller Handles Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		Cluster Data Handles Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:clusterdata_handle       value:Cluster Data Handles Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) Coded versus functional specification.
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle, clusterdata_handle
		
		See Also:
		
		"""
		return self._run_keyword("emulation_ovsdb_config", kwargs)

	def emulation_ovsdb_control(self, **kwargs):
		""" This procedure will we be used to execute all actions for ovsdb controller protocol.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ovsdb_control
			 	[-port_handle REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle      ANY]
			x	[-index       NUMERIC
			x              DEFAULT 1]
			 	[-values      RANGE 1-10000]
			 	-mode         CHOICES stop
			               CHOICES start
			               CHOICES restart
			               CHOICES dumpDB
			               CHOICES controllerDumpDB
			               CHOICES addServer
			               CHOICES deleteServer
			               CHOICES getServerAddDeleteStatus
			               CHOICES clearLastErrors
			               CHOICES attach
			               CHOICES detach]
		
		Arguments:
			 	-port_handle
			 		A list of ports on which to control the ovsdb controller protocol. If this option
			 		is not present, the port in the handle option will be applied.
			 	-handle
			 		Ovsdb controller / Clusterdata handle.It is returned by emulation_ovsdb_config call.
			x	-index
			x		index on which the action defined by the mode parameter will be applied
			 	-values
			 		The values for action to trigger on Ixia interface.
			 	-mode
			 		This option defines the action to be taken.Note: Valid options are:
			 		stop
			 		start
			 		restart
			 		abort
			 		dumpDB
			 		controllerDumpDB
			 		addServer
			 		deleteServer
			 		getServerAddDeleteStatus
			 		clearLastErrors
			 		attach
			 		detach.
			 		Valid choices are:
			    		stop -
			    		start -
			    		restart -
			    		abort -
			    		dumpDB -
			    		controllerDumpDB -
			    		addServer -
			    		deleteServer -
			    		getServerAddDeleteStatus -
			    		clearLastErrors -
			    		attach -
			    		detach -
		
		Return Values:
		$::SUCCESS or $::FAILURE
			 key:status  value:$::SUCCESS or $::FAILURE
		If failure, will contain more information
			 key:log     value:If failure, will contain more information
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_ovsdb_control", kwargs)

	def emulation_ovsdb_info(self, **kwargs):
		""" Retrieves information about the OVSDB Controller protocol.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_ovsdb_info
			 	-mode               CHOICES aggregate_stats
			                     CHOICES stats
			                     CHOICES clear_stats]
			x	[-execution_timeout NUMERIC
			x                    DEFAULT 1800]
			 	[-handle            ANY]
			 	[-port_handle       REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
		
		Arguments:
			 	-mode
			 		What action will be taken.Valid options are:
			 		aggregate_stats
			 		stats
			 		clear_stats
			x	-execution_timeout
			x		This is the timeout for the function.
			x		The setting is in seconds.
			x		Setting this setting to 60 it will mean that the command must complete in under 60 seconds.
			x		If the command will last more than 60 seconds the command will be terminated by force.
			x		This flag can be used to prevent dead locks occuring in IxNetwork.
			 	-handle
			 		The Ovsdb Controller /switch session handle to act upon.
			 	-port_handle
			 		The port from which to extract Ovsdb Controller data.
			 		One of the two parameters is required: port_handle/handle.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                        value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                                           value:If status is failure, detailed information provided.
			 key:Aggregate stats:                              value:
			 key:<port_handle>.aggregate.port_name             value:
			 key:<port_handle>.aggregate.sessions_up           value:
			 key:<port_handle>.aggregate.sessions_down         value:
			 key:<port_handle>.aggregate.sessions_not_started  value:
			 key:<port_handle>.aggregate.sessions_total        value:
			 key:<port_handle>.aggregate.json_rx               value:
			 key:<port_handle>.aggregate.json_tx               value:
			 key:<port_handle>.aggregate.invalid_json_rx       value:
			 key:<port_handle>.aggregate.monitor_tx            value:
			 key:<port_handle>.aggregate.monitor_rx            value:
			 key:<port_handle>.aggregate.transact_tx           value:
			 key:<port_handle>.aggregate.transact_rx           value:
			 key:<port_handle>.aggregate.reply_rx              value:
			 key:<port_handle>.aggregate.error_rx              value:
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_ovsdb_info", kwargs)

	def emulation_pbb_config(self, **kwargs):
		""" This procedure will configure PBB.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_pbb_config
			 	-mode                              ANY
			 	-port_handle                       ANY
			 	[-bridge_id                        ANY]
			 	[-bridge_id_step                   ANY]
			 	[-count                            ANY]
			 	[-enable_optional_tlv_validation   ANY]
			 	[-enable_out_of_sequence_detection ANY]
			 	[-ether_type                       ANY]
			 	[-handle                           ANY]
			 	[-interface_handle                 ANY]
			 	[-mac_address_init                 ANY]
			 	[-mac_address_step                 ANY]
			 	[-receive_ccm                      ANY]
			 	[-reset                            ANY]
			 	[-send_ccm                         ANY]
			 	[-vlan_id                          ANY]
			 	[-vlan_id_step                     ANY]
		
		Arguments:
			 	-mode
			 		Action to perform. This parameter is supported using the following:
			 		Valid choices are:
			    		create- Create new PBB Bridges on -port_handle.
			    		modify- Modify PBB Bridges specified with -handle parameter.
			    		enable- Enable PBB Bridges specified with -handle parameter.
			    		disable- Disable PBB Bridges specified with -handle parameter.
			    		remove-Remove PBB Bridges specified with -handle parameter.
			 	-port_handle
			 		Parameter -port_handle specifies the port to be configured with PBB. This parameter is supported using the following APIs: IxN.
			 	-bridge_id
			 		The bridge MAC address. This parameter is supported using the following APIs: IxN.
			 	-bridge_id_step
			 		The bridge MAC address step. This parameter is supported using the following APIs: IxN.
			 	-count
			 		Number of bridges to configure on port port_handle. This parameter is supported using the following APIs: IxN.
			 	-enable_optional_tlv_validation
			 		This parameter is configured for all PBB Bridges. This parameter is supported using the following APIs: IxN. 0 - Enable.1 - Disable.
			 	-enable_out_of_sequence_detection
			 		If 1, enables the detection of out of sequence CCM messages. This parameter is supported using the following APIs: IxN. 0 - Enable.1 - Disable.
			 	-ether_type
			 		Selects the ether type for the bridge. This parameter is supported using the following APIs: IxN. 8902 - 0x8902.88E6 - 0x88E6.
			 	-handle
			 		PBB handle. Used when -mode is modify|enable|disable|remove. This parameter is supported using the following APIs: IxN.
			 	-interface_handle
			 		List of interface_handles to associate with PBB. Length must be equal to the value of -count parameter. Interface handles are obtained using ::<namespace>::interface_config procedure. This parameter is supported using the following APIs: IxN.
			 	-mac_address_init
			 		Protocol interface parmater. Starting MAC address. This parameter is supported using the following APIs: IxN.
			 	-mac_address_step
			 		Protocol interface parmater. Mac address step. This parameter is supported using the following APIs: IxN.
			 	-receive_ccm
			 		If 1, the PBB protocol can receive PBB CCMs on this port. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-reset
			 		If 1 deletes all PBB bridges created on port -port_handle before creating new ones. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-send_ccm
			 		If 1, the PBB protocol can send PBB CCMs from this port. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-vlan_id
			 		Protocol interface parmater. This parameter is supported using the following APIs: IxN.
			 	-vlan_id_step
			 		Protocol interface parmater. This parameter is supported using the following APIs: IxN.
		
		Return Values:
		$::SUCCESS | $::FAILURE Status of procedure call.
			 key:status            value:$::SUCCESS | $::FAILURE Status of procedure call.
		When status is failure, contains more information.
			 key:log               value:When status is failure, contains more information.
		The list of PBB handles created.
			 key:handle            value:The list of PBB handles created.
		The list of PBB vport interfaces
			 key:interface_handle  value:The list of PBB vport interfaces
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_pbb_config", kwargs)

	def emulation_pbb_control(self, **kwargs):
		""" This procedure controls PBB actions.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_pbb_control
			 	-mode         ANY
			 	-port_handle  ANY
		
		Arguments:
			 	-mode
			 		Action to perform. This parameter is supported using the following:
			 		Valid choices are:
			    		start-Start PBB emulation.
			    		stop-Stop PBB emulation.
			 	-port_handle
			 		Parameter -port_handle specifies the port on which the PBB action is performed. Emulatoin is started | stopped for all PBB bridges on this port. This parameter is supported using the following APIs: IxN.
		
		Return Values:
		$::SUCCESS | $::FAILURE Status of procedure call.
			 key:status  value:$::SUCCESS | $::FAILURE Status of procedure call.
		When status is failure, contains more information.
			 key:log     value:When status is failure, contains more information.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_pbb_control", kwargs)

	def emulation_pbb_custom_tlv_config(self, **kwargs):
		""" This procedure configures Custom TLV properties on the bridge specified with bridge_handle.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_pbb_custom_tlv_config
			 	-bridge_handle   ANY
			 	-mode            ANY
			 	[-count          ANY]
			 	[-handle         ANY]
			 	[-include_in_ccm ANY]
			 	[-include_in_lbm ANY]
			 	[-include_in_lbr ANY]
			 	[-include_in_ltm ANY]
			 	[-include_in_ltr ANY]
			 	[-length         ANY]
			 	[-reset          ANY]
			 	[-type           ANY]
			 	[-value          ANY]
		
		Arguments:
			 	-bridge_handle
			 		The value of the -bridge_handle parameter must be a bridge handle returned by ::<namespace>::emulation_pbb_config procedure. This parameter is supported using the following APIs: IxN.
			 	-mode
			 		Action to perform. This parameter is supported using the following APIs. Valid choices are:
			    		create - Create new Custom TLV on -port_handle.
			    		modify - Modify Custom TLV specified with -handle parameter.
			    		enable - Enable Custom TLV specified with -handle parameter.
			    		disable - Disable Custom TLV specified with -handle parameter.
			    		remove - Remove Custom TLV specified with -handle parameter.
			 	-count
			 		Number of Custom TLVs that will be created for the PBB Bridge specified with -bridge_handle. This parameter is supported using the following APIs: IxN.
			 	-handle
			 		PBB Custom TLV handle. Used when -mode is modify|enable|disable|remove. This parameter is supported using the following APIs: IxN.
			 	-include_in_ccm
			 		If true, a custom TLV is included in the bridge CCM messages. This parameter is supported using the following APIs: IxN. 0 - False1 - True
			 	-include_in_lbm
			 		If true, a custom TLV is included in the bridge loopback messages. This parameter is supported using the following APIs: IxN. 0 - False1 - True
			 	-include_in_lbr
			 		If true, a custom TLV is included in the bridge loopback responses messages. This parameter is supported using the following APIs: IxN. 0 - False1 - True
			 	-include_in_ltm
			 		If true, a custom TLV is included in the bridge link trace messages. This parameter is supported using the following APIs: IxN. 0 - False1 - True
			 	-include_in_ltr
			 		If true, a custom TLV is included in the bridge link trace response messages. This parameter is supported using the following APIs: IxN. 0 - False1 - True
			 	-length
			 		TLV Length. This parameter is supported using the following APIs: IxN.
			 	-reset
			 		If 1 deletes all PBB Custom TLVs created on PBB Bridge -bridge_handle before creating new ones. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-type
			 		TLV Type. This parameter is supported using the following APIs: IxN.
			 	-value
			 		TLV Value. This parameter is supported using the following APIs: IxN.
		
		Return Values:
		$::SUCCESS | $::FAILURE Status of procedure call.
			 key:status  value:$::SUCCESS | $::FAILURE Status of procedure call.
		When status is failure, contains more information.
			 key:log     value:When status is failure, contains more information.
		A list of Custom TLV handles.
			 key:handle  value:A list of Custom TLV handles.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_pbb_custom_tlv_config", kwargs)

	def emulation_pbb_info(self, **kwargs):
		""" This procedure will configure PBB statistic filters and gathers various PBB statistics based on the -mode parameter.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_pbb_info
			 	-mode                        ANY
			 	[-handle                     ANY]
			 	[-port_handle                ANY]
			x	[-return_method              ANY]
			 	[-user_bvlan                 ANY]
			 	[-user_bvlan_id              ANY]
			 	[-user_bvlan_priority        ANY]
			 	[-user_bvlan_tpid            ANY]
			 	[-user_delay_type            ANY]
			 	[-user_dst_mac_address       ANY]
			 	[-user_dst_mep_id            ANY]
			 	[-user_dst_type              ANY]
			 	[-user_learned_info_time_out ANY]
			 	[-user_mdlevel               ANY]
			 	[-user_src_mac_address       ANY]
			 	[-user_src_mep_id            ANY]
			 	[-user_src_type              ANY]
			 	[-user_transaction_id        ANY]
			 	[-user_ttl_interval          ANY]
		
		Arguments:
			 	-mode
			 		Deterines whether statistic filters are set or if statistic are gathered and returned in keyed lists. This following parameters are supported:
			 		Valid choices are:
			    		set_filters-Configure statistic filtersfor bridge specified with -handle parameter.
			    		get_ccm-Return PBB-TE CCM information keys for bridge specified with -handle parameter.
			    		get_periodic_oam_lt- Return PBB-TE periodic OAM link trace learned information keys for bridge specified with -handle parameter.
			    		get_periodic_oam_lb-Return PBB-TE periodic OAM loopback learned information keys for bridge specified with -handle parameter.
			    		get_periodic_oam_dm- Return PBB-TE periodic OAM delay measurement learned information keys for bridge specified with -handle parameter.
			    		get_lt-Return PBB-TE link trace learned information keys for bridge specified with -handle parameter.
			    		get_lb- Return PBB-TE loopback learned information keys for bridge specified with -handle parameter.
			    		get_dm-Return PBB-TE delay measurement learned information keys for bridge specified with -handle parameter.
			    		get_all- Return all keys available.
			 	-handle
			 		PBB Bridge handle. Statistic filters will be set on this bridge handle if -mode is set_filters. Statistic keys will be returned from this bridge handle for all other modes. This parameter is supported using the following APIs: IxN.
			 	-port_handle
			 		Parameter -port_handle specifies the port configured with PBB. This parameter is supported using the following APIs: IxN.
			x	-return_method
			x		keyed_list (DEFAULT) - always return the stat values as a keyed list, no matter how long it takeskeyed_list_or_array - when more than 2000 statistics values need to be retrieved, the keyhandle will be returned instead of all the keyed list items specified in the section dedicated for returned values. This key, handle, represents the name of the array to be used for reading the stats. This key is returned when more than 2000 statistics values need to be retrieved. The indices of this array are the keys that you'll find explained in the returned values section, and the values are the statistics values. This method has been introduced to increase performance when returning and reading stats. Returning a huge list in the tcl console can make the console hang.array - the key handle will be returned instead of all the keyed list items specified in the section dedicated for returned values. This key, handle, represents the name of the array to be used for reading the stats. The indices of this array are the keys that you'll find explained in the returned values section, and the values are the statistics values. This method has been introduced to increase performance when returning and reading stats. Returning a huge list in the tcl console can make the console hang.
			 	-user_bvlan
			 		Sets the bridge filter for PBB-TE learned information for the VLAN. Use this parameter when -mode is set_filters. This parameter is all_vlan_id - Filters on all VLANs.no_vlan_id - Filters on no VLAN.vlan_id - Filters on a VLAN specified in user_bvlan_Id.
			 	-user_bvlan_id
			 		Sets the PBB-TE VLAN identifier for filtering learned information. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_bvlan_priority
			 		Sets the PBB-TE VLAN priority for filtering learned information. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_bvlan_tpid
			 		Sets the PBB-TE VLAN TPID for filtering learned information. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.Valid options are:81009100920088A8
			 	-user_delay_type
			 		Sets the type of delay measurement to use. Use this parameter when-mode is set_filters. This parameter is supported using the following dm - Delay Measurement. The amount of delay in seconds.dvm - Delay Variation Measurement. The difference in the amount of delay between messages.
			 	-user_dst_mac_address
			 		Filters on the destination MAC address specified. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_dst_mep_id
			 		Sets the MEP identifier for use with userSelectDstMepById. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_dst_type
			 		Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.Valid options are:mep_macmep_idmep_mac_allmep_id_all
			 	-user_learned_info_time_out
			 		The interval in millisecond for the learned record to timeout. Default: 5000. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_mdlevel
			 		Filters on the specified MD level. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN. Valid options are:0 through 7, orall_md - Filters on all MD levels.
			 	-user_src_mac_address
			 		Filters on the specified source MAC address. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_src_mep_id
			 		Sets the MEP identifier for use with userSelectSrcMepById. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_src_type
			 		. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.Valid options are:mep_macmep_idmep_mac_allmep_id_all
			 	-user_transaction_id
			 		The transaction identifier for the LTM packet if the configured MEP not found. Default: 1. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
			 	-user_ttl_interval
			 		Time to live value, in seconds. Default is 64. Use this parameter when -mode is set_filters. This parameter is supported using the following APIs: IxN.
		
		Return Values:
		$::SUCCESS | $::FAILURE Status of procedure call.
			 key:status                                   value:$::SUCCESS | $::FAILURE Status of procedure call.
		When status is failure, contains more information.
			 key:log                                      value:When status is failure, contains more information.
		The stacked VLAN identifier. Key returned when -mode is get_ccm.
			 key:ccm.c_vlan                               value:The stacked VLAN identifier. Key returned when -mode is get_ccm.
		The Continuity Check interval. Key returned when -mode is get_ccm.
			 key:ccm.cci_interval                         value:The Continuity Check interval. Key returned when -mode is get_ccm.
		If 1, a CCM defect error has been detected. Key returned when -mode is get_ccm.
			 key:ccm.err_ccm_defect                       value:If 1, a CCM defect error has been detected. Key returned when -mode is get_ccm.
		The number of CCM defect errors received. Key returned when -mode is get_ccm.
			 key:ccm.err_ccm_defect_count                 value:The number of CCM defect errors received. Key returned when -mode is get_ccm.
		The number of interface TLV defects received. Key returned when -mode is get_ccm.
			 key:ccm.iface_tlv_defect_count               value:The number of interface TLV defects received. Key returned when -mode is get_ccm.
		The MD level for the CCM message. Key returned when -mode is get_ccm.
			 key:ccm.md_level                             value:The MD level for the CCM message. Key returned when -mode is get_ccm.
		The MD name associated with the CCM message. Key returned when -mode is get_ccm.
			 key:ccm.md_name                              value:The MD name associated with the CCM message. Key returned when -mode is get_ccm.
		The MD Name Format of the CCM message. Key returned when -mode is get_ccm.
			 key:ccm.md_name_format                       value:The MD Name Format of the CCM message. Key returned when -mode is get_ccm.
		The number of Out of Sequence CCM messages received. Key returned when -mode is get_ccm.
			 key:ccm.out_ofsequence_ccm_count             value:The number of Out of Sequence CCM messages received. Key returned when -mode is get_ccm.
		The number of port TLV defect errors received. Key returned when -mode is get_ccm.
			 key:ccm.port_tlv_defect_count                value:The number of port TLV defect errors received. Key returned when -mode is get_ccm.
		If 1, interface TLV defect messages have been detected. Key returned when -mode is get_ccm.
			 key:ccm.received_iface_tlv_defect            value:If 1, interface TLV defect messages have been detected. Key returned when -mode is get_ccm.
		If 1, port TLV defect messages have been detected. Key returned when -mode is get_ccm.
			 key:ccm.received_port_tlv_defect             value:If 1, port TLV defect messages have been detected. Key returned when -mode is get_ccm.
		If 1, RDI messages have been detected. Key returned when -mode is get_ccm.
			 key:ccm.received_rdi                         value:If 1, RDI messages have been detected. Key returned when -mode is get_ccm.
		The remote MAC address for the CCM message. Key returned when -mode is get_ccm.
			 key:ccm.remote_mac_address                   value:The remote MAC address for the CCM message. Key returned when -mode is get_ccm.
		The number of RMEP defect errors received. Key returned when -mode is get_ccm.
			 key:ccm.remote_mep_defect_count              value:The number of RMEP defect errors received. Key returned when -mode is get_ccm.
		The RMEP identifier for the CCM. Key returned when -mode is get_ccm.
			 key:ccm.remote_mep_id                        value:The RMEP identifier for the CCM. Key returned when -mode is get_ccm.
		If 1, remote MEP CCM defect messages have been detected. Key returned when -mode is get_ccm.
			 key:ccm.rmep_ccm_defect                      value:If 1, remote MEP CCM defect messages have been detected. Key returned when -mode is get_ccm.
		The Short MA Name associated with the CCM message. Key returned when -mode is get_ccm.
			 key:ccm.short_maname                         value:The Short MA Name associated with the CCM message. Key returned when -mode is get_ccm.
		The Short MA Name format associated with the CCM message. Key returned when -mode is get_ccm.
			 key:ccm.short_maname_format                  value:The Short MA Name format associated with the CCM message. Key returned when -mode is get_ccm.
		The source MAC address for the CCM. Key returned when -mode is get_ccm.
			 key:ccm.src_mac_address                      value:The source MAC address for the CCM. Key returned when -mode is get_ccm.
		The source MEP identifier for the CCM. Key returned when -mode is get_ccm.
			 key:ccm.src_mep_id                           value:The source MEP identifier for the CCM. Key returned when -mode is get_ccm.
		The learned C-VLAN identifier. Key returned when -mode is get_cfm_itu.
			 key:dm.c_vlan                                value:The learned C-VLAN identifier. Key returned when -mode is get_cfm_itu.
		The learned destination MAC address for the bridge. Key returned when -mode is get_cfm_itu.
			 key:dm.dst_mac_address                       value:The learned destination MAC address for the bridge. Key returned when -mode is get_cfm_itu.
		The learned MD level for the bridge. Key returned when -mode is get_cfm_itu.
			 key:dm.md_level                              value:The learned MD level for the bridge. Key returned when -mode is get_cfm_itu.
		The learned source MAC address for the bridge. Key returned when -mode is get_cfm_itu.
			 key:dm.src_mac_address                       value:The learned source MAC address for the bridge. Key returned when -mode is get_cfm_itu.
		The delay measurement in nanoseconds. Key returned when -mode is get_cfm_itu.
			 key:dm.value_in_nano_sec                     value:The delay measurement in nanoseconds. Key returned when -mode is get_cfm_itu.
		The delay measurement in seconds. Key returned when -mode is get_cfm_itu.
			 key:dm.value_in_sec                          value:The delay measurement in seconds. Key returned when -mode is get_cfm_itu.
		The stacked VLAN identifier for the loopback message. Key returned when -mode is get_cfm_lb.
			 key:lb.c_vlan                                value:The stacked VLAN identifier for the loopback message. Key returned when -mode is get_cfm_lb.
		The destination MAC address for the loopback message. Key returned when -mode is get_cfm_lb.
			 key:lb.dst_mac_address                       value:The destination MAC address for the loopback message. Key returned when -mode is get_cfm_lb.
		The MD level for the loopback message. Key returned when -mode is get_cfm_lb.
			 key:lb.md_level                              value:The MD level for the loopback message. Key returned when -mode is get_cfm_lb.
		Indiates the status of the Ping. If true, the ping was responded to. Key returned when -mode is get_cfm_lb.
			 key:lb.reachability                          value:Indiates the status of the Ping. If true, the ping was responded to. Key returned when -mode is get_cfm_lb.
		The round trip time for the loopback message. Key returned when -mode is get_cfm_lb.
			 key:lb.rtt                                   value:The round trip time for the loopback message. Key returned when -mode is get_cfm_lb.
		The source MAC address for the loopback message. Key returned when -mode is get_cfm_lb.
			 key:lb.src_mac_address                       value:The source MAC address for the loopback message. Key returned when -mode is get_cfm_lb.
		The transaction identifier attached to the loopback message. Key returned when -mode is get_cfm_lb.
			 key:lb.transaction_id                        value:The transaction identifier attached to the loopback message. Key returned when -mode is get_cfm_lb.
		The stacked VLAN identifier for the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.c_vlan                                value:The stacked VLAN identifier for the link trace message. Key returned when -mode is get_cfm_lt.
		The destination MAC address associated with the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.dst_mac_address                       value:The destination MAC address associated with the link trace message. Key returned when -mode is get_cfm_lt.
		The hop count for the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.hop_count                             value:The hop count for the link trace message. Key returned when -mode is get_cfm_lt.
		The number of hops for the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.hops                                  value:The number of hops for the link trace message. Key returned when -mode is get_cfm_lt.
		The MD level associated with the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.md_level                              value:The MD level associated with the link trace message. Key returned when -mode is get_cfm_lt.
		Indicates the status of the reply for the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.reply_status                          value:Indicates the status of the reply for the link trace message. Key returned when -mode is get_cfm_lt.
		The source MAC address associated with the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.src_mac_address                       value:The source MAC address associated with the link trace message. Key returned when -mode is get_cfm_lt.
		The transaction identifier sent with the link trace message. Key returned when -mode is get_cfm_lt.
			 key:lt.transaction_id                        value:The transaction identifier sent with the link trace message. Key returned when -mode is get_cfm_lt.
		The link trace message egress MAC address. Key returned when -mode is get_cfm_lt.
			 key:lt.learned_hop.egress_mac                value:The link trace message egress MAC address. Key returned when -mode is get_cfm_lt.
		The link trace message ingress MAC address. Key returned when -mode is get_cfm_lt.
			 key:lt.learned_hop.ingress_mac               value:The link trace message ingress MAC address. Key returned when -mode is get_cfm_lt.
		The time-to-live value of the link trace hop information, in milliseconds. Key returned when -mode is get_cfm_lt.
			 key:lt.learned_hop.reply_ttl                 value:The time-to-live value of the link trace hop information, in milliseconds. Key returned when -mode is get_cfm_lt.
		The learned average delay in nanoseconds. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.average_delay_nano_sec   value:The learned average delay in nanoseconds. Key returned when -mode is get_periodic_oam_dm.
		The learned average delay in seconds. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.average_delay_sec        value:The learned average delay in seconds. Key returned when -mode is get_periodic_oam_dm.
		The learned C-VLAN identifier. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.c_vlan                   value:The learned C-VLAN identifier. Key returned when -mode is get_periodic_oam_dm.
		The learned number of DMMs sent. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.dmm_count_sent           value:The learned number of DMMs sent. Key returned when -mode is get_periodic_oam_dm.
		The learned destination MAC address. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.dst_mac_address          value:The learned destination MAC address. Key returned when -mode is get_periodic_oam_dm.
		The learned MD level for the periodic OAM. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.md_level                 value:The learned MD level for the periodic OAM. Key returned when -mode is get_periodic_oam_dm.
		The learned number of periodic OAM no replies. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.no_reply_count           value:The learned number of periodic OAM no replies. Key returned when -mode is get_periodic_oam_dm.
		The learned most recent delay measurement in nanoseconds. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.recent_delay_nano_sec    value:The learned most recent delay measurement in nanoseconds. Key returned when -mode is get_periodic_oam_dm.
		The learned most recent delay measurement in seconds. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.recent_delay_sec         value:The learned most recent delay measurement in seconds. Key returned when -mode is get_periodic_oam_dm.
		The learned source MAC address. Key returned when -mode is get_periodic_oam_dm.
			 key:periodic_oam_dm.src_mac_address          value:The learned source MAC address. Key returned when -mode is get_periodic_oam_dm.
		The learned average periodic OAM Round-Trip-Time. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.average_rtt              value:The learned average periodic OAM Round-Trip-Time. Key returned when -mode is get_periodic_oam_lb.
		The learned periodic OAM C-VLAN identifier. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.c_vlan                   value:The learned periodic OAM C-VLAN identifier. Key returned when -mode is get_periodic_oam_lb.
		The learned periodic OAM destination MAC address. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.dst_mac_address          value:The learned periodic OAM destination MAC address. Key returned when -mode is get_periodic_oam_lb.
		The learned number of periodic OAM loopback messages sent. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.lbm_sent_count           value:The learned number of periodic OAM loopback messages sent. Key returned when -mode is get_periodic_oam_lb.
		The learned MD level for the periodic OAM. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.md_level                 value:The learned MD level for the periodic OAM. Key returned when -mode is get_periodic_oam_lb.
		The learned number of periodic OAM no replies. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.no_reply_count           value:The learned number of periodic OAM no replies. Key returned when -mode is get_periodic_oam_lb.
		Indicates the status of the Ping. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.recent_reachability      value:Indicates the status of the Ping. Key returned when -mode is get_periodic_oam_lb.
		Indicates the status of the round-trip-time. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.recent_rtt               value:Indicates the status of the round-trip-time. Key returned when -mode is get_periodic_oam_lb.
		The learned periodic OAM source MAC address. Key returned when -mode is get_periodic_oam_lb.
			 key:periodic_oam_lb.src_mac_address          value:The learned periodic OAM source MAC address. Key returned when -mode is get_periodic_oam_lb.
		The learned average hop count. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.average_hop_count        value:The learned average hop count. Key returned when -mode is get_periodic_oam_lt.
		The learned C-VLAN identifier. (CFM only). Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.c_vlan                   value:The learned C-VLAN identifier. (CFM only). Key returned when -mode is get_periodic_oam_lt.
		The learned number of complete replies. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.complete_reply_count     value:The learned number of complete replies. Key returned when -mode is get_periodic_oam_lt.
		The learned destination MAC address. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.dst_mac_address          value:The learned destination MAC address. Key returned when -mode is get_periodic_oam_lt.
		The learned number of Link Trace messages sent. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.ltm_sent_count           value:The learned number of Link Trace messages sent. Key returned when -mode is get_periodic_oam_lt.
		The learned MD level. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.md_level                 value:The learned MD level. Key returned when -mode is get_periodic_oam_lt.
		The learned number of no replies. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.no_reply_count           value:The learned number of no replies. Key returned when -mode is get_periodic_oam_lt.
		The learned number of partial replies. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.partial_reply_count      value:The learned number of partial replies. Key returned when -mode is get_periodic_oam_lt.
		The learned recent hop count. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.recent_hop_count         value:The learned recent hop count. Key returned when -mode is get_periodic_oam_lt.
		The learned recent hops. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.recent_hops              value:The learned recent hops. Key returned when -mode is get_periodic_oam_lt.
		The learned recent replies. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.recent_reply_status      value:The learned recent replies. Key returned when -mode is get_periodic_oam_lt.
		The learned source MAC address. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.src_mac_address          value:The learned source MAC address. Key returned when -mode is get_periodic_oam_lt.
		The link trace message egress MAC address. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.learned_hop.egress_mac   value:The link trace message egress MAC address. Key returned when -mode is get_periodic_oam_lt.
		The link trace message ingress MAC address. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.learned_hop.ingress_mac  value:The link trace message ingress MAC address. Key returned when -mode is get_periodic_oam_lt.
		The time-to-live value of the link trace hop information, in milliseconds. Key returned when -mode is get_periodic_oam_lt.
			 key:periodic_oam_lt.learned_hop.reply_ttl    value:The time-to-live value of the link trace hop information, in milliseconds. Key returned when -mode is get_periodic_oam_lt.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_pbb_info", kwargs)

	def emulation_pbb_trunk_config(self, **kwargs):
		""" This procedure configures Trunk properties.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_pbb_trunk_config
			 	-bridge_handle                      ANY
			 	-mode                               ANY
			 	[-add_ccm_custom_tlvs               ANY]
			 	[-add_data_tlv                      ANY]
			 	[-add_interface_status_tlv          ANY]
			 	[-add_lbm_custom_tlvs               ANY]
			 	[-add_lbr_custom_tlvs               ANY]
			 	[-add_ltm_custom_tlvs               ANY]
			 	[-add_ltr_custom_tlvs               ANY]
			 	[-add_organization_specific_tlv     ANY]
			 	[-add_port_status_tlv               ANY]
			 	[-add_sender_id_tlv                 ANY]
			 	[-auto_dm_iteration                 ANY]
			 	[-auto_dm_timeout                   ANY]
			 	[-auto_dm_timer                     ANY]
			 	[-auto_lb_iteration                 ANY]
			 	[-auto_lb_timeout                   ANY]
			 	[-auto_lb_timer                     ANY]
			 	[-auto_lt_iteration                 ANY]
			 	[-auto_lt_timeout                   ANY]
			 	[-auto_lt_timer                     ANY]
			 	[-b_vlan_id                         ANY]
			 	[-b_vlan_id_step                    ANY]
			 	[-b_vlan_priority                   ANY]
			 	[-b_vlan_tp_id                      ANY]
			 	[-cci_interval                      ANY]
			 	[-ccm_priority                      ANY]
			 	[-chassis_id                        ANY]
			 	[-chassis_id_length                 ANY]
			 	[-chassis_id_step                   ANY]
			 	[-chassis_id_sub_type               ANY]
			 	[-count                             ANY]
			 	[-data_tlv_length                   ANY]
			 	[-data_tlv_step                     ANY]
			 	[-data_tlv_value                    ANY]
			 	[-dmm_priority                      ANY]
			 	[-dst_mac_address                   ANY]
			 	[-dst_mac_address_step              ANY]
			 	[-enable_auto_dm                    ANY]
			 	[-enable_auto_lb                    ANY]
			 	[-enable_auto_lt                    ANY]
			 	[-enable_reverse_bvlan              ANY]
			 	[-handle                            ANY]
			 	[-lbm_priority                      ANY]
			 	[-ltm_priority                      ANY]
			 	[-management_address                ANY]
			 	[-management_address_domain         ANY]
			 	[-management_address_domain_length  ANY]
			 	[-management_address_domain_step    ANY]
			 	[-management_address_length         ANY]
			 	[-md_level_id                       ANY]
			 	[-md_level_id_step                  ANY]
			 	[-md_name                           ANY]
			 	[-md_name_format                    ANY]
			 	[-md_name_mac_repeat_count          ANY]
			 	[-md_name_mac_step                  ANY]
			 	[-md_name_wildcard_enable           ANY]
			 	[-md_wildcard_question_repeat_count ANY]
			 	[-md_wildcard_question_start        ANY]
			 	[-md_wildcard_question_step         ANY]
			 	[-mep_id                            ANY]
			 	[-mep_id_step                       ANY]
			 	[-mr_c_vlan_id                      ANY]
			 	[-mr_c_vlan_priority                ANY]
			 	[-mr_c_vlan_tp_id                   ANY]
			 	[-mr_count                          ANY]
			 	[-mr_enable_vlan                    ANY]
			 	[-mr_i_tagi_sid                     ANY]
			 	[-mr_inner_count                    ANY]
			 	[-mr_mac_inter_range_step           ANY]
			 	[-mr_mac_inter_trunk_step           ANY]
			 	[-mr_mac_step                       ANY]
			 	[-mr_s_vlan_id                      ANY]
			 	[-mr_s_vlan_priority                ANY]
			 	[-mr_s_vlan_tp_id                   ANY]
			 	[-mr_stacked_vlan_id_step           ANY]
			 	[-mr_stacked_vlan_inter_trunk_step  ANY]
			 	[-mr_start_mac_address              ANY]
			 	[-mr_type                           ANY]
			 	[-mr_vlan_id_step                   ANY]
			 	[-mr_vlan_inter_trunk_step          ANY]
			 	[-organization_specific_tlv_length  ANY]
			 	[-organization_specific_tlv_value   ANY]
			 	[-override_vlan_priority            ANY]
			 	[-reset                             ANY]
			 	[-return_method                     ANY]
			 	[-reverse_bvlan_id                  ANY]
			 	[-reverse_bvlan_id_step             ANY]
			 	[-short_ma_name                     ANY]
			 	[-short_ma_name_format              ANY]
			 	[-src_mac_address                   ANY]
			 	[-src_mac_address_step              ANY]
		
		Arguments:
			 	-bridge_handle
			 		The value of the -bridge_handle parameter must be a bridge handle returned by ::<namespace>::emulation_pbb_config procedure. This parameter is supported using the following APIs: IxN.
			 	-mode
			 		Action to perform. This parameter is supported using the following create - Create new Trunk on -port_handle.modify - Modify Trunk specified with -handle parameter.enable - Enable Trunk specified with -handle parameter.disable - Disable Trunk specified with -handle parameter.remove - Remove Trunk specified with -handle parameter.
			 	-add_ccm_custom_tlvs
			 		If 1, adds a custom CCM TLV to bridge messages. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-add_data_tlv
			 		If 1, adds a data TLV to bridge messages. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-add_interface_status_tlv
			 		If 1, adds an interface status TLV to bridge messages. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-add_lbm_custom_tlvs
			 		If 1, adds a custom loopback message TLV to bridge messages. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-add_lbr_custom_tlvs
			 		If 1, adds a custom loopback response message TLV to bridge messages. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-add_ltm_custom_tlvs
			 		If 1, adds a custom link trace message TLV to bridge messages. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-add_ltr_custom_tlvs
			 		If 1, adds a custom link trace response message. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-add_organization_specific_tlv
			 		If 1, adds a custom organization specific message TLV to bridge messages. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-add_port_status_tlv
			 		If 1, adds a custom port status message TLV to bridge messages. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-add_sender_id_tlv
			 		If 1, adds a custom sender ID message TLV to bridge messages. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-auto_dm_iteration
			 		The count for how many times DMMs will be transmitted.(no limit). This parameter is supported using the following APIs: IxN.
			 	-auto_dm_timeout
			 		The timeout period in seconds to wait for a response to DMMs. This value should be less than the Auto LB Timer. This parameter is supported using the following APIs: IxN.
			 	-auto_dm_timer
			 		The time period in seconds between DMMs. This parameter is supported using the following APIs: IxN.
			 	-auto_lb_iteration
			 		The count for how many times LBM will be transmitted.(no limit). This parameter is supported using the following APIs: IxN.
			 	-auto_lb_timeout
			 		The timeout period in seconds to wait for a response to LTMs. This value should be less than the Auto LT Timer. This parameter is supported using the following APIs: IxN.
			 	-auto_lb_timer
			 		The time period in seconds between LTMs. This parameter is supported using the following APIs: IxN.
			 	-auto_lt_iteration
			 		The count for how many times LTM will be transmitted. This parameter is supported using the following APIs: IxN.
			 	-auto_lt_timeout
			 		The timeout period in seconds to wait for a response to LTMs. This value should be less than the Auto LT Timer. This parameter is supported using the following APIs: IxN.
			 	-auto_lt_timer
			 		The time period in seconds between LTMs. This parameter is supported using the following APIs: IxN.
			 	-b_vlan_id
			 		The VLAN identifier for the trunk. This parameter is supported using the following APIs: IxN.
			 	-b_vlan_id_step
			 		The incrementing step for the VLAN identifier for the trunk. This parameter is supported using the following APIs: IxN.
			 	-b_vlan_priority
			 		The VLAN priority for the trunk. This parameter is supported using the following APIs: IxN.
			 	-b_vlan_tp_id
			 		The VLAN TPID for the trunk. Ether_types identify the protocol that follows the VLAN header. Select from a list of hex options: 0x8100, 0x9100, 0x9200, and 0x88A8. This parameter is supported using the following APIs: IxN. 81009100920088a8
			 	-cci_interval
			 		Sets the continuity check interval for the trunk. This parameter is supported using the following APIs: IxN. 3.33msec10msec100msec1sec10sec1min10min
			 	-ccm_priority
			 		Sets the priority for Continuity Check Messages. This parameter is supported using the following APIs: IxN.
			 	-chassis_id
			 		Sets the chassis identification. This will take Hex value as input (0-255 byte). This parameter is supported using the following APIs: IxN.
			 	-chassis_id_length
			 		Sets the length of the Chassis ID field. This parameter is supported using the following APIs: IxN.
			 	-chassis_id_step
			 		Sets the chassis increment step when count >1. This will take Hex value as input (0-255 byte). This parameter is supported using the following APIs: IxN.
			 	-chassis_id_sub_type
			 		Sets the chassis identifier sub-type for the optional TLV messages. This parameter is supported using the following APIs: IxN. chassis_componentinterface_aliasport_componentmac_addressnetwork_addressinterface_namelocally_assigned
			 	-count
			 		Number of Trunks that will be created for the PBB Bridge specified with -bridge_handle. This parameter is supported using the following APIs: IxN.
			 	-data_tlv_length
			 		Sets the length of the Data TLV field. This parameter is supported using the following APIs: IxN.
			 	-data_tlv_step
			 		This attribute will take Hex value of data. Increment step for data_tlv_value. This parameter is supported using the following APIs: IxN.
			 	-data_tlv_value
			 		This attribute will take Hex value of data. This data TLV will be added both for periodic LBM and requested LBM transmit. This parameter is supported using the following APIs: IxN.
			 	-dmm_priority
			 		Sets the priority for DM Messages. This priority will be used only for periodic DMMs. This parameter is supported using the following APIs: IxN.
			 	-dst_mac_address
			 		Sets the destination MAC address for the trunk. This parameter is supported using the following APIs: IxN.
			 	-dst_mac_address_step
			 		The incrementing step for the destination MAC address for the trunk. This parameter is supported using the following APIs: IxN.
			 	-enable_auto_dm
			 		If 1, enables the automatic sending of DM Messages. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-enable_auto_lb
			 		If 1, enables the automatic sending of Loopback messages. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-enable_auto_lt
			 		If 1, enables the automatic sending of Link Trace messages. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-enable_reverse_bvlan
			 		If 1, enables the use of reverse B-VLANs on this trunk. In some cases, a PBB-TE Trunk will require a different B-VID in the reversed path. This option allows the user to specify whether a reverse B-VID is same as forward direction or not. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-handle
			 		PBB Trunk handle. Used when -mode is modify|enable|disable|remove. This parameter is supported using the following APIs: IxN.
			 	-lbm_priority
			 		Sets the priority for Loopback Messages. This priority will be used only for periodic LBMs. This parameter is supported using the following APIs: IxN.
			 	-ltm_priority
			 		Sets the priority for Link Trace Messages. This priority will be used only for periodic LTMs. This parameter is supported using the following APIs: IxN.
			 	-management_address
			 		Sets the trunk management address. Input type is HEX (0-255 byte). This parameter is supported using the following APIs: IxN.
			 	-management_address_domain
			 		Sets the trunk management address domain. This will take HEX input (0-255 byte). (Management Addr Domain). This parameter is supported using the following APIs: IxN. (DEFAULT = 4d:61:6e:61:67:65:6d:65:6e:74:20:41:64:64:72:20:44:6f:6d:61:69:6e)
			 	-management_address_domain_length
			 		Sets the length of the Management address domain field. This parameter is supported using the following APIs: IxN.
			 	-management_address_domain_step
			 		Sets the trunk management address domain step when -count > 1. This will take HEX input (0-255 byte). This parameter is supported using the following APIs: IxN. (DEFAULT = 00:00:00:00:00:00:00:00:00:00:00:00:00:00:00:00:00:00:00:00:00:01)
			 	-management_address_length
			 		Sets the length of the Management address field. This parameter is supported using the following APIs: IxN.
			 	-md_level_id
			 		Sets the MD level identification for the trunk. This parameter is supported using the following APIs: IxN.
			 	-md_level_id_step
			 		The step for the MD level identification for the trunk. This parameter is supported using the following APIs: IxN.
			 	-md_name
			 		Sets the MD name. This parameter is supported using the following APIs: IxN.
			 	-md_name_format
			 		Sets the MD Name format for the trunk. This parameter is supported using the following APIs: IxN. none - string - Parameter -name is used to configure the MD Name. Use '?' to configure wildcard.domain_name - Parameter -name is used to configure the MD Name. Use '?' to configure wildcard.mac_plus_2_octets - Parameter -name is used to configure MD Name (MAC Address format plus two octets, e.g. 00:11:22:33:44:55:66:77) .
			 	-md_name_mac_repeat_count
			 		Determines how many Maintenance Domains are configured before the MD name is incremented. This parameter is supported using the following APIs: IxN.
			 	-md_name_mac_step
			 		When -name_format is mac_plus_2_octets this will be the step used to increment the 8 octet value from the -name parameter. This parameter is supported using the following APIs: IxN.
			 	-md_name_wildcard_enable
			 		Enable wildcard incrementing for MD Name when -name_format is string or domain_name. Wildcard '?' will be substituted in the -name parameter value with value of -wildcard_start parameter and incremented using wildcard_step parameter. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-md_wildcard_question_repeat_count
			 		Determines how many Maintenance Domains are configured before wildcard is incremented. This parameter is supported using the following APIs: IxN.
			 	-md_wildcard_question_start
			 		Starting value for wildcard substitution. This parameter is supported using the following APIs: IxN.
			 	-md_wildcard_question_step
			 		Step value for the wildcard substitution. This parameter is supported using the following APIs: IxN.
			 	-mep_id
			 		Sets the MEP identifier for the trunk. This parameter is supported using the following APIs: IxN.
			 	-mep_id_step
			 		The incrementing step for the MEP identifier for the trunk. This parameter is supported using the following APIs: IxN.
			 	-mr_c_vlan_id
			 		The identifier for the C-VLAN for the MAC range. A unique,12-bit VLAN. This parameter is supported using the following APIs: IxN.
			 	-mr_c_vlan_priority
			 		The user priority of the tag: a value from 0 through 7. The use and interpretation of this field is defined in ISO/IEC 15802-3. This parameter is supported using the following APIs: IxN.
			 	-mr_c_vlan_tp_id
			 		The Tag Protocol ID. Ether_types identify the protocol that follows the VLAN header. Select from a list of hex options: 0x8100, 0x9100, 0x9200, 0x88A8. This parameter is supported using the following APIs: IxN. 81009100920088a8
			 	-mr_count
			 		Determines how many mac ranges per trunk will be configured. This parameter is supported using the following APIs: IxN.
			 	-mr_enable_vlan
			 		Enable vlan. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-mr_i_tagi_sid
			 		The I-Tag service instance identifier, and is a 3 octet field. This parameter is supported using the following APIs: IxN.
			 	-mr_inner_count
			 		Determines the mac address count per MAC range. This parameter is supported using the following APIs: IxN.
			 	-mr_mac_inter_range_step
			 		Step to increment -mr_start_mac_address from one mac_range to the next when -mr_count > 1. This parameter is supported using the following APIs: IxN.
			 	-mr_mac_inter_trunk_step
			 		Step to increment -mr_start_mac_address from one trunk to the next when -count > 1. This parameter is supported using the following APIs: IxN.
			 	-mr_mac_step
			 		Step to increment -mr_start_mac_address within a mac range. This parameter is supported using the following APIs: IxN.
			 	-mr_s_vlan_id
			 		Identifier which specifies the C-VLAN with which this frame is associated. A unique, 12-bit VLAN Identifier which specifies the VLAN with which this mr_frame is associated. This parameter is supported using the following APIs: IxN.
			 	-mr_s_vlan_priority
			 		The user priority of the tag: a value from 0 through 7. The use and interpretation of this field is defined in ISO/IEC 15802-3. This parameter is supported using the following APIs: IxN.
			 	-mr_s_vlan_tp_id
			 		The Tag Protocol ID. Ether_types identify the protocol that follows the VLAN header. Select from a list of hex options: 0x8100, 0x9100, 0x9200, 0x88A8. This parameter is supported using the following APIs: IxN. 81009100920088a8
			 	-mr_stacked_vlan_id_step
			 	-mr_stacked_vlan_inter_trunk_step
			 		Step to increment -mr_c_vlan_id from one trunk to the next when -count > 1. This parameter is supported using the following APIs: IxN.
			 	-mr_start_mac_address
			 		The MAC address of the first entry in the range. This parameter is supported using the following APIs: IxN.
			 	-mr_type
			 		Selects the VLAN type, either single or stacked. Stacked VLANS have an inner and outer value. This parameter is supported using the following APIs: IxN.
			 	-mr_vlan_id_step
			 		When -mr_count > 1 this is the step used to increment -mr_s_vlan_id from one vlan range to the next. This parameter is supported using the following APIs: IxN.
			 	-mr_vlan_inter_trunk_step
			 		When -count > 1 this is the step used to increment -mr_s_vlan_id from one trunk to the next. This parameter is supported using the following APIs: IxN.
			 	-organization_specific_tlv_length
			 		Sets the length of the organizational specific TLV field. This parameter is supported using the following APIs: IxN.
			 	-organization_specific_tlv_value
			 		Sets the value of the organizational specific TLV field. This attribute will take Hex value. This parameter is supported using the following APIs: IxN.
			 	-override_vlan_priority
			 		If 1, overrides the set VLAN priority for this bridge, and uses the advanced settings instead. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-reset
			 		If 1 deletes all PBB Trunks created on PBB Bridge -bridge_handle before creating new ones. This parameter is supported using the following APIs: IxN. 0 - Disable.1 - Enable.
			 	-return_method
			 		keyed_list (DEFAULT) - always return the stat values as a keyed list, no matter how long it takeskeyed_list_or_array - when more than 2000 statistics values need to be retrieved, the keyhandle will be returned instead of all the keyed list items specified in the section dedicated for returned values. This key, handle, represents the name of the array to be used for reading the stats. This key is returned when more than 2000 statistics values need to be retrieved. The indices of this array are the keys that you'll find explained in the returned values section, and the values are the statistics values. This method has been introduced to increase performance when returning and reading stats. Returning a huge list in the tcl console can make the console hang.array - the key handle will be returned instead of all the keyed list items specified in the section dedicated for returned values. This key, handle, represents the name of the array to be used for reading the stats. The indices of this array are the keys that you'll find explained in the returned values section, and the values are the statistics values. This method has been introduced to increase performance when returning and reading stats. Returning a huge list in the tcl console can make the console hang.
			 	-reverse_bvlan_id
			 		Specifies the B-VLAN identifier for the reverse path on this trunk. This parameter is supported using the following APIs: IxN.
			 	-reverse_bvlan_id_step
			 		The incrementing step for the B-VLAN identifier for the reverse path on this trunk. This parameter is supported using the following APIs: IxN.
			 	-short_ma_name
			 		Sets the Short MA Name for the trunk. This parameter is supported using the following APIs: IxN.
			 	-short_ma_name_format
			 		Sets the Short MA Name format for the trunk. This parameter is supported using the following APIs: IxN.
			 	-src_mac_address
			 		Sets the source MAC address for the trunk. This parameter is supported using the following APIs: IxN.
			 	-src_mac_address_step
			 		Sets the source MAC address for the trunk. This parameter is supported using the following APIs: IxN.
		
		Return Values:
		$::SUCCESS | $::FAILURE Status of procedure call.
			 key:status        value:$::SUCCESS | $::FAILURE Status of procedure call.
		When status is failure, contains more information.
			 key:log           value:When status is failure, contains more information.
		A list of Trunk handles. Trunk handles can be used as traffic endpoints but only if they have at least one Mac Range configured.
			 key:trunk_handle  value:A list of Trunk handles. Trunk handles can be used as traffic endpoints but only if they have at least one Mac Range configured. 
		A list of Mac Ranges. Mac Ranges can be used as traffic endpoints.
			 key:mr_handle     value:A list of Mac Ranges. Mac Ranges can be used as traffic endpoints.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_pbb_trunk_config", kwargs)

	def emulation_pcc_config(self, **kwargs):
		""" This procedure will add PCC(s) to a particular Ixia Interface.     The user can then configure, PCC by using the procedure     PCC Requested SR LSPs, Pre-Established SR LSPs and Expected PCE Initiated SR LSPs for Traffic.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_pcc_config
			 	-mode                                            CHOICES create
			                                                  CHOICES delete
			                                                  CHOICES modify
			                                                  CHOICES enable
			                                                  CHOICES disable]
			 	[-port_handle                                    REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle                                         ANY]
			x	[-lsp_update_capability                          ANY]
			x	[-sr_pce_capability                              ANY]
			x	[-maximum_sid_depth                              ANY]
			x	[-pcc_ppag_t_l_v_type                            ANY]
			x	[-pce_ipv4_address                               ANY]
			x	[-pce_ipv4_address_step                          ANY]
			x	[-max_lsp_per_pc_req                             ANY]
			x	[-max_lsps_per_pc_rpt                            ANY]
			x	[-keepalive_interval                             ANY]
			x	[-dead_interval                                  ANY]
			x	[-state_timeout_interval                         ANY]
			x	[-reconnect_interval                             ANY]
			x	[-max_reconnect_interval                         ANY]
			x	[-return_instantiation_error                     ANY]
			x	[-error_value                                    ANY]
			x	[-authentication                                 CHOICES null md5]
			x	[-m_d5_key                                       ANY]
			x	[-requested_lsps_per_pcc                         NUMERIC]
			x	[-pre_established_sr_lsps_per_pcc                NUMERIC]
			x	[-active_pre_established_lsps                    NUMERIC]
			x	[-expected_initiated_lsps_for_traffic            NUMERIC]
			x	[-number_of_backup_p_c_es                        NUMERIC]
			x	[-rate_control                                   ANY]
			x	[-burst_interval                                 ANY]
			x	[-max_requested_lsp_per_interval                 ANY]
			x	[-max_sync_lsp_per_interval                      ANY]
			x	[-pcc_active                                     ANY]
			x	[-pcc_name                                       ALPHA]
			x	[-expected_symbolic_path_name                    ANY]
			x	[-expected_source_ipv4_address                   ANY]
			x	[-expected_source_ipv4_address_step              ANY]
			x	[-expected_source_ipv6_address                   ANY]
			x	[-expected_source_ipv6_address_step              ANY]
			x	[-expected_max_expected_segment_count            NUMERIC]
			x	[-expected_insert_ipv6_explicit_null             CHOICES 0 1]
			x	[-expected_initiated_lsp_list_active             ANY]
			x	[-include_rp                                     ANY]
			x	[-include_end_points                             ANY]
			x	[-pcc_requested_include_lspa                     ANY]
			x	[-pcc_requested_include_bandwidth                ANY]
			x	[-pcc_requested_include_metric                   ANY]
			x	[-include_iro                                    ANY]
			x	[-include_xro                                    ANY]
			x	[-p_flag_rp                                      ANY]
			x	[-override_request_id                            CHOICES 0 1]
			x	[-request_id                                     ANY]
			x	[-loose                                          ANY]
			x	[-bi_directional                                 ANY]
			x	[-re_optimization                                ANY]
			x	[-priority                                       ANY]
			x	[-pflag_endpoints                                ANY]
			x	[-override_source_address                        ANY]
			x	[-ip_version                                     CHOICES ipv4 ipv6]
			x	[-source_end_point_i_pv4                         ANY]
			x	[-source_end_point_i_pv4_step                    ANY]
			x	[-destination_ipv4_address                       ANY]
			x	[-destination_ipv4_address_step                  ANY]
			x	[-source_end_point_i_pv6                         ANY]
			x	[-source_end_point_i_pv6_step                    ANY]
			x	[-destination_ipv6_address                       ANY]
			x	[-destination_ipv6_address_step                  ANY]
			x	[-pcc_requested_initial_delegation               ANY]
			x	[-p_flag_lsp                                     ANY]
			x	[-pcc_requested_override_plsp_id                 CHOICES 0 1]
			x	[-pcc_requested_plsp_id                          ANY]
			x	[-pcc_requested_include_symbolic_path_name_tlv   ANY]
			x	[-pcc_requested_symbolic_path_name               ANY]
			x	[-pcc_requested_redelegation_timeout_interval    ANY]
			x	[-p_flag_lspa                                    ANY]
			x	[-pcc_requested_setup_priority                   ANY]
			x	[-pcc_requested_holding_priority                 ANY]
			x	[-pcc_requested_local_protection                 ANY]
			x	[-pcc_requested_include_any                      ANY]
			x	[-pcc_requested_include_all                      ANY]
			x	[-pcc_requested_exclude_any                      ANY]
			x	[-p_flag_bandwidth                               ANY]
			x	[-pcc_requested_bandwidth                        ANY]
			x	[-max_number_of_metrics                          NUMERIC]
			x	[-p_flag_iro                                     ANY]
			x	[-max_no_of_iro_sub_objects                      NUMERIC]
			x	[-pcc_requested_p_flag_xro                       ANY]
			x	[-fail_bit                                       ANY]
			x	[-max_no_of_xro_sub_objects                      NUMERIC]
			x	[-active_data_traffic_end_points                 ANY]
			x	[-source_ipv4_address                            ANY]
			x	[-source_ipv4_address_step                       ANY]
			x	[-source_ipv6_address                            ANY]
			x	[-source_ipv6_address_step                       ANY]
			x	[-max_expected_segment_count                     NUMERIC]
			x	[-pcc_requested_insert_ipv6_explicit_null        CHOICES 0 1]
			x	[-pcc_requested_active                           ANY]
			x	[-iro_active                                     ANY]
			x	[-iro_sub_object_type                            CHOICES ipv4prefix
			x                                                 CHOICES ipv6prefix
			x                                                 CHOICES unnumberedinterfaceid
			x                                                 CHOICES asnumber]
			x	[-iro_prefix_length                              ANY]
			x	[-ipv4_address                                   ANY]
			x	[-ipv4_address_step                              ANY]
			x	[-ipv6_address                                   ANY]
			x	[-ipv6_address_step                              ANY]
			x	[-router_id                                      ANY]
			x	[-router_id_step                                 ANY]
			x	[-interface_id                                   ANY]
			x	[-iro_as_number                                  ANY]
			x	[-xro_active                                     ANY]
			x	[-p_flag_xro                                     ANY]
			x	[-exclude_bit                                    ANY]
			x	[-xro_attribute                                  CHOICES interface node srlg]
			x	[-xro_sub_object_type                            CHOICES ipv4prefix
			x                                                 CHOICES ipv6prefix
			x                                                 CHOICES unnumberedinterfaceid
			x                                                 CHOICES asnumber
			x                                                 CHOICES srlg]
			x	[-xro_prefix_length                              ANY]
			x	[-xro_ipv4_address                               ANY]
			x	[-xro_ipv4_address_step                          ANY]
			x	[-xro_ipv6_address                               ANY]
			x	[-xro_ipv6_address_step                          ANY]
			x	[-xro_router_id                                  ANY]
			x	[-xro_router_id_step                             ANY]
			x	[-xro_interface_id                               ANY]
			x	[-xro_as_number                                  ANY]
			x	[-srlg_id                                        ANY]
			x	[-pce_id32                                       ANY]
			x	[-pce_id128                                      ANY]
			x	[-pcc_requested_metric_active                    ANY]
			x	[-p_flag_metric                                  ANY]
			x	[-metric_type                                    CHOICES igp tg hopcount msd]
			x	[-metric_value                                   ANY]
			x	[-enable_cflag                                   ANY]
			x	[-enable_bflag                                   ANY]
			x	[-include_srp                                    ANY]
			x	[-include_lsp                                    ANY]
			x	[-include_ero                                    ANY]
			x	[-include_metric                                 ANY]
			x	[-include_bandwidth                              ANY]
			x	[-include_lspa                                   ANY]
			x	[-initial_delegation                             ANY]
			x	[-override_plsp_id                               CHOICES 0 1]
			x	[-plsp_id                                        ANY]
			x	[-include_symbolic_path_name_tlv                 ANY]
			x	[-symbolic_path_name                             ANY]
			x	[-pre_established_destination_ipv4_address       ANY]
			x	[-pre_established_destination_ipv4_address_step  ANY]
			x	[-redelegation_timeout_interval                  ANY]
			x	[-pre_established_include_t_e_path_binding_t_l_v ANY]
			x	[-pre_established_binding_type                   CHOICES mplslabel20bit mplslabel32bit]
			x	[-pre_established_mpls_label                     ANY]
			x	[-pre_established_tc                             ANY]
			x	[-pre_established_bos                            ANY]
			x	[-pre_established_ttl                            ANY]
			x	[-number_of_ero_sub_objects                      NUMERIC]
			x	[-number_of_metric_sub_object                    NUMERIC]
			x	[-bandwidth                                      ANY]
			x	[-setup_priority                                 ANY]
			x	[-holding_priority                               ANY]
			x	[-local_protection                               ANY]
			x	[-include_any                                    ANY]
			x	[-include_all                                    ANY]
			x	[-exclude_any                                    ANY]
			x	[-include_ppag                                   ANY]
			x	[-association_id                                 ANY]
			x	[-protection_lsp_bit                             ANY]
			x	[-standby_lsp_bit                                ANY]
			x	[-pre_established_active_data_traffic_endpoint   ANY]
			x	[-src_end_point_ipv4                             ANY]
			x	[-src_end_point_ipv4_step                        ANY]
			x	[-src_end_point_ipv6                             ANY]
			x	[-src_end_point_ipv6_step                        ANY]
			x	[-insert_ipv6_explicit_null                      CHOICES 0 1]
			x	[-pre_established_active                         ANY]
			x	[-ero_active                                     ANY]
			x	[-loose_hop                                      ANY]
			x	[-sub_object_type                                CHOICES null
			x                                                 CHOICES ipv4prefix
			x                                                 CHOICES ipv6prefix
			x                                                 CHOICES asnumber]
			x	[-prefix_length                                  ANY]
			x	[-ipv4_prefix                                    ANY]
			x	[-ipv4_prefix_step                               ANY]
			x	[-ipv6_prefix                                    ANY]
			x	[-ipv6_prefix_step                               ANY]
			x	[-as_number                                      ANY]
			x	[-sid_type                                       CHOICES null
			x                                                 CHOICES sid
			x                                                 CHOICES mplslabel20bit
			x                                                 CHOICES mplslabel32bit]
			x	[-sid                                            ANY]
			x	[-mpls_label                                     ANY]
			x	[-tc                                             ANY]
			x	[-bos                                            ANY]
			x	[-ttl                                            ANY]
			x	[-nai_type                                       CHOICES notapplicable
			x                                                 CHOICES ipv4nodeid
			x                                                 CHOICES ipv6nodeid
			x                                                 CHOICES ipv4adjacency
			x                                                 CHOICES ipv6adjacency
			x                                                 CHOICES unnumberedadjacencywithipv4nodeids]
			x	[-f_bit                                          ANY]
			x	[-ipv4_node_id                                   ANY]
			x	[-ipv4_node_id_step                              ANY]
			x	[-ipv6_node_id                                   ANY]
			x	[-ipv6_node_id_step                              ANY]
			x	[-local_ipv4_address                             ANY]
			x	[-local_ipv4_address_step                        ANY]
			x	[-remote_ipv4_address                            ANY]
			x	[-remote_ipv4_address_step                       ANY]
			x	[-local_ipv6_address                             ANY]
			x	[-local_ipv6_address_step                        ANY]
			x	[-remote_ipv6_address                            ANY]
			x	[-remote_ipv6_address_step                       ANY]
			x	[-local_node_id                                  ANY]
			x	[-local_node_id_step                             ANY]
			x	[-local_interface_id                             ANY]
			x	[-remote_node_id                                 ANY]
			x	[-remote_node_id_step                            ANY]
			x	[-remote_interface_id                            ANY]
			x	[-metric_active                                  ANY]
			x	[-pre_established_metric_type                    CHOICES igp tg hopcount msd]
			x	[-pre_established_metric_value                   ANY]
			x	[-b_flag                                         ANY]
			x	[-backup_pce_ipv4_address                        ANY]
			x	[-backup_pce_active                              ANY]
		
		Arguments:
			 	-mode
			 		This option defines whether to Create/Modify/Delete/Enable/Disable PCC and different types of LSPs under PCC.
			 		Valid choices are:
			    		create - Creates a PCC and different types of LSPs under PCC.
			    		delete - Deletes PCC.
			    		modify - Modifies a PCC and different types of LSPs under PCC.
			    		enable - Enables a PCC and different types of LSPs under PCC.
			    		disable - Disables a PCC and different types of LSPs under PCC.
			 	-port_handle
			 		Port handle.
			 	-handle
			 		Specifies the parent node/object handle on which the pcep configuration should be configured.
			 		In case of create/modify -mode, -handle generally denotes the parent node/object handle .
			 		In case of modesmodify/delete/disable/enable -handle denotes the object node handle on which the action needs to be performed.
			x	-lsp_update_capability
			x		If Stateful PCE Capability is enabled then this control should be activated to set the update capability in the Stateful PCE Capability TLV.
			x	-sr_pce_capability
			x		The SR PCE Capability TLV is an optional TLV associated with the OPEN Object to exchange SR capability of PCEP speakers.
			x	-maximum_sid_depth
			x		Maximum SID Depth field (MSD) specifies the maximum number of SIDs that a PCC is capable of imposing on a packet. Editable only if SR PCE Capability is enabled.
			x	-pcc_ppag_t_l_v_type
			x		PPAG TLV Type specifies PCC's capability of interpreting this type of PPAG TLV
			x	-pce_ipv4_address
			x		IPv4 address of the PCE. This column is greyed out in case of PCCv6.
			x	-pce_ipv4_address_step
			x		Step argument for IPv4 address of the PCE.
			x	-max_lsp_per_pc_req
			x		Max LSPs Per PCReq
			x	-max_lsps_per_pc_rpt
			x		Controls the maximum LSP information that can be present in a Path report message when the session is stateful session.
			x	-keepalive_interval
			x		Frequency/Time Interval of sending PCEP messages to keep the session active.
			x	-dead_interval
			x		This is the time interval, after the expiration of which, a PCEP peer declares the session down if no PCEP message has been received.
			x	-state_timeout_interval
			x		This is the time interval, after the expiration of which, LSP is cleaned up by PCC.
			x	-reconnect_interval
			x		This is the time interval, after the expiration of which, retry to establish the broken session by PCC happen.
			x	-max_reconnect_interval
			x		This is the maximum time interval, by which recoonect timer will be increased upto.
			x	-return_instantiation_error
			x		If enabled, then PCC will reply PCErr upon receiving PCInitiate message.
			x	-error_value
			x		To configure the type of error. Editable only if Return Instantiation Error is enabled.
			x	-authentication
			x		The type of cryptographic authentication to be used on this link interface
			x		Valid choices are:
			x   		null - NULL.
			x   		md5 - MD5.
			x	-m_d5_key
			x		A value to be used as the "secret" MD5 Key.
			x	-requested_lsps_per_pcc
			x		Requested LSPs per PCC
			x	-pre_established_sr_lsps_per_pcc
			x		Pre-Established SR LSPs per PCC
			x	-active_pre_established_lsps
			x		Active Pre Established LSps
			x	-expected_initiated_lsps_for_traffic
			x		Based on the value in this control the number of Expected Initiated LSPs for Traffic can be configured. This is used for traffic only.
			x	-number_of_backup_p_c_es
			x		Number of Backup PCEs
			x	-rate_control
			x		The rate control is an optional feature associated with PCE initiated LSP.
			x	-burst_interval
			x		Interval in milisecond in which desired rate of messages needs to be maintained.
			x	-max_requested_lsp_per_interval
			x		Maximum number of LSP computation request messages can be sent per interval.
			x	-max_sync_lsp_per_interval
			x		Maximum number of LSP sync can be sent per interval.
			x	-pcc_active
			x		Activate/Deactivate Configuration
			x	-pcc_name
			x		Name of NGPF element, guaranteed to be unique in Scenario
			x	-expected_symbolic_path_name
			x		This is used for generating the traffic for those LSPs from PCE for which the Symbolic Path Name is configured and matches the value.
			x	-expected_source_ipv4_address
			x		This is used to set the Source IPv4 address in the IP header of the generated traffic.
			x	-expected_source_ipv4_address_step
			x		Step argument for Source IPv4 address in the IP header of the generated traffic.
			x	-expected_source_ipv6_address
			x		This is used to set the Source IPv6 address in the IP header of the generated traffic.
			x	-expected_source_ipv6_address_step
			x		Step argument for Source IPv6 address in the IP header of the generated traffic.
			x	-expected_max_expected_segment_count
			x		This control is used to set the maximum Segment count/ MPLS labels that would be present in the generted traffic.
			x	-expected_insert_ipv6_explicit_null
			x		Insert IPv6 Explicit Null MPLS header if the traffic type is of type IPv6
			x	-expected_initiated_lsp_list_active
			x		Activate/Deactivate configuration for Expected PCE Initiated SR LSPs for Traffic
			x	-include_rp
			x		Include RP
			x	-include_end_points
			x		Include End Points
			x	-pcc_requested_include_lspa
			x		Include LSPA
			x	-pcc_requested_include_bandwidth
			x		Include Bandwidth
			x	-pcc_requested_include_metric
			x		Include Metric
			x	-include_iro
			x		Include IRO
			x	-include_xro
			x		Include XRO
			x	-p_flag_rp
			x		RP "P" Flag
			x	-override_request_id
			x		Override Request ID
			x	-request_id
			x		Request ID
			x	-loose
			x		Loose
			x	-bi_directional
			x		Bi-directional
			x	-re_optimization
			x		Re-optimization
			x	-priority
			x		Priority
			x	-pflag_endpoints
			x		End Points "P" Flag
			x	-override_source_address
			x		Override Source Address
			x	-ip_version
			x		IP Version
			x		Valid choices are:
			x   		ipv4 - IPv4.
			x   		ipv6 - IPv6.
			x	-source_end_point_i_pv4
			x		Source IPv4 Address
			x	-source_end_point_i_pv4_step
			x		Step argument for Source IPv4 Address
			x	-destination_ipv4_address
			x		Destination IPv4 Address
			x	-destination_ipv4_address_step
			x		Step argument for Destination IPv4 Address
			x	-source_end_point_i_pv6
			x		Source IPv6 Address
			x	-source_end_point_i_pv6_step
			x		Step argument for Source IPv6 Address
			x	-destination_ipv6_address
			x		Destination IPv6 Address
			x	-destination_ipv6_address_step
			x		Step argument for Destination IPv6 Address
			x	-pcc_requested_initial_delegation
			x		Initial Delegation
			x	-p_flag_lsp
			x		LSP "P" Flag
			x	-pcc_requested_override_plsp_id
			x		Override PLSP-ID
			x	-pcc_requested_plsp_id
			x		An identifier for the LSP. A PCC creates a unique PLSP-ID for each LSP that is constant for the lifetime of a PCEP session. The PCC will advertise the same PLSP-ID on all PCEP sessions it maintains at a given time.
			x	-pcc_requested_include_symbolic_path_name_tlv
			x		Include Symbolic Path Name TLV
			x	-pcc_requested_symbolic_path_name
			x		Symbolic Path Name
			x	-pcc_requested_redelegation_timeout_interval
			x		The period of time a PCC waits for, when a PCEP session is terminated, before revoking LSP delegation
			x		to a PCE and attempting to redelegate LSPs associated with the terminated PCEP session to PCE.
			x	-p_flag_lspa
			x		LSPA "P" Flag
			x	-pcc_requested_setup_priority
			x		Setup Priority
			x	-pcc_requested_holding_priority
			x		Holding Priority
			x	-pcc_requested_local_protection
			x		Local Protection
			x	-pcc_requested_include_any
			x		Include Any
			x	-pcc_requested_include_all
			x		Include All
			x	-pcc_requested_exclude_any
			x		Exclude Any
			x	-p_flag_bandwidth
			x		Bandwidth "P" Flag
			x	-pcc_requested_bandwidth
			x		Bandwidth (bits/sec)
			x	-max_number_of_metrics
			x		Max Number of Metrics
			x	-p_flag_iro
			x		IRO "P" Flag
			x	-max_no_of_iro_sub_objects
			x		Max Number of IRO Sub Objects
			x	-pcc_requested_p_flag_xro
			x		XRO "P" Flag
			x	-fail_bit
			x		Fail Bit
			x	-max_no_of_xro_sub_objects
			x		Max Number of IRO Sub Objects
			x	-active_data_traffic_end_points
			x		Specifies whether that specific Data Traffic Endpoint will generate data traffic
			x	-source_ipv4_address
			x		Source IPv4 Address
			x	-source_ipv4_address_step
			x		Step argument of Source IPv4 Address
			x	-source_ipv6_address
			x		Source IPv6 Address
			x	-source_ipv6_address_step
			x		Step argument of Source IPv6 Address
			x	-max_expected_segment_count
			x		This control is used to set the maximum Segment count/ MPLS labels that would be present in the generted traffic.
			x	-pcc_requested_insert_ipv6_explicit_null
			x		Insert IPv6 Explicit Null MPLS header if the traffic type is of type IPv6
			x	-pcc_requested_active
			x		Activate/Deactivate PCC Requested SR LSPs
			x	-iro_active
			x		Activate/Deactivate IRO
			x	-iro_sub_object_type
			x		Sub Object Type
			x		Valid choices are:
			x   		ipv4prefix - IPv4 Prefix.
			x   		ipv6prefix - IPv6 Prefix.
			x   		unnumberedinterfaceid - Unnumbered Interface ID.
			x   		asnumber - Autonomous System Number.
			x	-iro_prefix_length
			x		Prefix Length
			x	-ipv4_address
			x		IPv4 Address
			x	-ipv4_address_step
			x		Step argument of IPv4 Address
			x	-ipv6_address
			x		IPv6 Address
			x	-ipv6_address_step
			x		Step argument of IPv6 Address
			x	-router_id
			x		Router ID
			x	-router_id_step
			x		Step argument of Router ID
			x	-interface_id
			x		Interface ID
			x	-iro_as_number
			x		AS Number
			x	-xro_active
			x		Controls whether the XRO sub-object will be sent in the PCRequest message.
			x	-p_flag_xro
			x		XRO "P" Flag
			x	-exclude_bit
			x		Indicates whether the exclusion is mandatory or desired.
			x	-xro_attribute
			x		Indicates how the exclusion subobject is to be indicated.
			x		Valid choices are:
			x   		interface - 0 - Interface.
			x   		node - 1 - Node.
			x   		srlg - 2 - SRLG.
			x	-xro_sub_object_type
			x		Using the Sub Object Type control user can configure which sub object needs to be included from the following options: IPv4 Prefix, IPv6 Prefix, Unnumbered Interface ID, AS Number and SRLG.
			x		Valid choices are:
			x   		ipv4prefix - IPv4 Prefix.
			x   		ipv6prefix - IPv6 Prefix.
			x   		unnumberedinterfaceid - Unnumbered Interface ID.
			x   		asnumber - AS Number.
			x   		srlg - SRLG.
			x	-xro_prefix_length
			x		Prefix Length
			x	-xro_ipv4_address
			x		IPv4 Address
			x	-xro_ipv4_address_step
			x		Step argument of IPv4 Address
			x	-xro_ipv6_address
			x		IPv6 Address
			x	-xro_ipv6_address_step
			x		Step argument of IPv6 Address
			x	-xro_router_id
			x		Router ID
			x	-xro_router_id_step
			x		Step argument of Router ID
			x	-xro_interface_id
			x		Interface ID
			x	-xro_as_number
			x		AS Number
			x	-srlg_id
			x		SRLG ID
			x	-pce_id32
			x		32 bit PKS ID
			x	-pce_id128
			x		128 bit PKS ID
			x	-pcc_requested_metric_active
			x		Activate/Deactivate Metric
			x	-p_flag_metric
			x		Metric "P" Flag
			x	-metric_type
			x		Metric Type
			x		Valid choices are:
			x   		igp - IGP.
			x   		tg - TE.
			x   		hopcount - Hop Count.
			x   		msd - MSD.
			x	-metric_value
			x		Metric Value
			x	-enable_cflag
			x		C Flag
			x	-enable_bflag
			x		B Flag
			x	-include_srp
			x		Indicates whether SRP object will be included in a PCInitiate message. All other attributes in sub-tab-SRP would be editable only if this checkbox is enabled.
			x	-include_lsp
			x		Indicates whether LSP will be included in a PCInitiate message. All other attributes in sub-tab-LSP would be editable only if this checkbox is enabled.
			x	-include_ero
			x		Specifies whether ERO is active or inactive. All subsequent attributes of the sub-tab-ERO would be editable only if this is enabled.
			x	-include_metric
			x		Indicates whether the PCInitiate message will have the metric list that is configured. All subsequent attributes of the sub-tab-Metric would be editable only if this is enabled.
			x	-include_bandwidth
			x		Indicates whether Bandwidth will be included in a PCInitiate message. All other attributes in sub-tab-Bandwidth would be editable only if this checkbox is enabled.
			x	-include_lspa
			x		Indicates whether LSPA will be included in a PCInitiate message. All other attributes in sub-tab-LSPA would be editable only if this checkbox is enabled.
			x	-initial_delegation
			x		Initial Delegation
			x	-override_plsp_id
			x		Indicates if PLSP-ID will be set by the state machine or user. If disabled user wont have the control and state machine will set it.
			x	-plsp_id
			x		An identifier for the LSP. A PCC creates a unique PLSP-ID for each LSP that is constant for the lifetime of a PCEP session. The PCC will advertise the same PLSP-ID on all PCEP sessions it maintains at a given time.
			x	-include_symbolic_path_name_tlv
			x		Indicates if Symbolic-Path-Name TLV is to be included in PCInitiate message.
			x	-symbolic_path_name
			x		Each LSP (path) must have a symbolic name that is unique in the PCC. It must remain constant throughout a path's lifetime, which may span across multiple consecutive PCEP sessions and/or PCC restarts.
			x	-pre_established_destination_ipv4_address
			x		Destination IPv4 Address
			x	-pre_established_destination_ipv4_address_step
			x	-redelegation_timeout_interval
			x		The period of time a PCC waits for, when a PCEP session is terminated, before revoking LSP delegation
			x		to a PCE and attempting to redelegate LSPs associated with the terminated PCEP session to PCE.
			x	-pre_established_include_t_e_path_binding_t_l_v
			x		Indicates if TE-PATH-BINDING TLV is to be included in PCInitiate message.
			x	-pre_established_binding_type
			x		Indicates the type of binding included in the TLV. Types are as follows:
			x		20bit MPLS Label
			x		32bit MPLS Label.
			x		Default value is 20bit MPLS Label.
			x		Valid choices are:
			x   		mplslabel20bit - 0- MPLS Label 20 Bit.
			x   		mplslabel32bit - 1- MPLS Label 20 Bit
			x	-pre_established_mpls_label
			x		This control will be editable if the Binding Type is set to either 20bit or 32bit MPLS-Label. This field will take the 20bit value of the MPLS-Label
			x	-pre_established_tc
			x		This field is used to carry traffic class information. This control will be editable only if Binding Type is MPLS Label 32bit.
			x	-pre_established_bos
			x		This bit is set to True for the last entry in the label stack i.e., for the bottom of the stack, and False for all other label stack entries.
			x		This control will be editable only if Binding Type is MPLS Label 32bit.
			x	-pre_established_ttl
			x		This field is used to encode a time-to-live value. This control will be editable only if Binding Type is MPLS Label 32bit.
			x	-number_of_ero_sub_objects
			x		Value that indicates the number of ERO Sub Objects to be configured.
			x	-number_of_metric_sub_object
			x		Value that indicates the number of Metric Objects to be configured.
			x	-bandwidth
			x		Bandwidth (bits/sec)
			x	-setup_priority
			x		The priority of the LSP with respect to taking resources.The value 0 is the highest priority.The Setup Priority is used in deciding whether this session can preempt another session.
			x	-holding_priority
			x		The priority of the LSP with respect to holding resources. The value 0 is the highest priority.Holding Priority is used in deciding whether this session can be preempted by another session.
			x	-local_protection
			x		When set, this means that the path must include links protected with Fast Reroute
			x	-include_any
			x		This is a type of Resource Affinity Procedure that is used to validate a link. This control accepts a link if the link carries any of the attributes in the set.
			x	-include_all
			x		This is a type of Resource Affinity Procedure that is used to validate a link. This control excludes a link from consideration if the link carries any of the attributes in the set.
			x	-exclude_any
			x		This is a type of Resource Affinity Procedure that is used to validate a link. This control accepts a link only if the link carries all of the attributes in the set.
			x	-include_ppag
			x		Indicates whether Association will be included in a Sync PCReport message. All other attributes in sub-tab-PPAG would be editable only if this checkbox is enabled.
			x	-association_id
			x		The Association ID of this LSP.
			x	-protection_lsp_bit
			x		Indicates whether Protection LSP Bit is On.
			x	-standby_lsp_bit
			x		Indicates whether Standby LSP Bit is On.
			x	-pre_established_active_data_traffic_endpoint
			x		Specifies whether that specific Data Traffic Endpoint will generate data traffic
			x	-src_end_point_ipv4
			x		Source IPv4 address
			x	-src_end_point_ipv4_step
			x		Step argument of Source IPv4 address
			x	-src_end_point_ipv6
			x		Source IPv6 address
			x	-src_end_point_ipv6_step
			x		Step argument of Source IPv4 address
			x	-insert_ipv6_explicit_null
			x		Insert IPv6 Explicit Null MPLS header if the traffic type is of type IPv6
			x	-pre_established_active
			x		Activate/Deactivate Pre-Established SR LSPs
			x	-ero_active
			x		Controls whether the ERO sub-object will be sent in the PCInitiate message.
			x	-loose_hop
			x		Indicates if user wants to represent a loose-hop sub object in the LSP
			x	-sub_object_type
			x		Using the Sub Object Type control user can configure which sub object needs to be included from the following options: Not Applicable, IPv4 Prefix, IPv6 Prefix, AS Number.
			x		Valid choices are:
			x   		null - Not Applicable.
			x   		ipv4prefix - IPv4 Prefix.
			x   		ipv6prefix - IPv6 Prefix.
			x   		asnumber - AS Number.
			x	-prefix_length
			x		Prefix Length
			x	-ipv4_prefix
			x		IPv4 Prefix is specified as an IPv4 address.
			x	-ipv4_prefix_step
			x		Step Argument of IPv4 Prefix.
			x	-ipv6_prefix
			x		IPv6 Prefix is specified as an IPv6 address.
			x	-ipv6_prefix_step
			x		Step Argument of IPv6 Prefix.
			x	-as_number
			x		AS Number
			x	-sid_type
			x		Using the Segment Identifier Type control user can configure whether to include SID or not and if included what is its type. Types are as follows: Null, SID, 20bit MPLS Label, 32bit MPLS Label.
			x		If it is Null then S bit is set in the packet. Default value is 20bit MPLS Label.
			x		Valid choices are:
			x   		null - Null.
			x   		sid - SID.
			x   		mplslabel20bit - MPLS Label 20 Bit.
			x   		mplslabel32bit - MPLS Label 32 Bit.
			x	-sid
			x		SIDis the Segment Identifier
			x	-mpls_label
			x		This control will be editable if the SID Type is set to either 20bit or 32bit MPLS-Label. This field will take the 20bit value of the MPLS-Label
			x	-tc
			x		This field is used to carry traffic class information. This control will be editable only if SID Type is MPLS Label 32bit.
			x	-bos
			x		This bit is set to true for the last entry in the label stack i.e., for the bottom of the stack, and false for all other label stack entries.
			x		This control will be editable only if SID Type is MPLS Label 32bit.
			x	-ttl
			x		This field is used to encode a time-to-live value. This control will be editable only if SID Type is MPLS Label 32bit.
			x	-nai_type
			x		NAI (Node or Adjacency Identifier) contains the NAI associated with the SID. Depending on the value of SID Type, the NAI can have different formats such as:
			x		Not Applicable, IPv4 Node ID, IPv6 Node ID, IPv4 Adjacency, IPv6 Adjacency, Unnumbered Adjacency with IPv4 NodeIDs
			x		Valid choices are:
			x   		notapplicable - Not Applicable.
			x   		ipv4nodeid - IPv4 Node ID.
			x   		ipv6nodeid - IPv6 Node ID.
			x   		ipv4adjacency - IPv4 Adjacency.
			x   		ipv6adjacency - IPv6 Adjacency.
			x   		unnumberedadjacencywithipv4nodeids - Unnumbered Adjacency with IPv4 NodeIDs.
			x	-f_bit
			x		A Flag which is used to carry additional information pertaining to SID. When this bit is set, the NAI value in the subobject body is null.
			x	-ipv4_node_id
			x		IPv4 Node ID is specified as an IPv4 address. This control can be configured if NAI Type is set to IPv4 Node ID and F bit is disabled.
			x	-ipv4_node_id_step
			x		Step argument of IPv4 Node ID
			x	-ipv6_node_id
			x		IPv6 Node ID is specified as an IPv6 address. This control can be configured if NAI Type is set to IPv6 Node ID and F bit is disabled.
			x	-ipv6_node_id_step
			x		Step argument of IPv6 Node ID
			x	-local_ipv4_address
			x		This Control can be configured if NAI Type is set to IPv4 Adjacency and F bit is disabled.
			x	-local_ipv4_address_step
			x		Step argument of Local IPv4 Address
			x	-remote_ipv4_address
			x		This Control can be configured if NAI Type is set to IPv4 Adjacency and F bit is disabled.
			x	-remote_ipv4_address_step
			x		Step argument of Remote IPv4 Address
			x	-local_ipv6_address
			x		This Control can be configured if NAI Type is set to IPv6 Adjacency and F bit is disabled.
			x	-local_ipv6_address_step
			x		Step argument of Local IPv6 Address
			x	-remote_ipv6_address
			x		This Control can be configured if NAI Type is set to IPv6 Adjacency and F bit is disabled.
			x	-remote_ipv6_address_step
			x		Step argument of Remote IPv6 Address
			x	-local_node_id
			x		This is the Local Node ID of the Unnumbered Adjacency with IPv4 NodeIDs which is specified as a pair of Node ID / Interface ID tuples.
			x		This Control can be configured if NAI Type is set to Unnumbered Adjacency with IPv4 NodeIDs and F bit is disabled.
			x	-local_node_id_step
			x		Step argument of Local Node ID
			x	-local_interface_id
			x		This is the Local Interface ID of the Unnumbered Adjacency with IPv4 NodeIDs which is specified as a pair of Node ID / Interface ID tuples.
			x		This Control can be configured if NAI Type is set to Unnumbered Adjacency with IPv4 NodeIDs and F bit is disabled.
			x	-remote_node_id
			x		This is the Remote Node ID of the Unnumbered Adjacency with IPv4 NodeIDs which is specified as a pair of Node ID / Interface ID tuples.
			x		This Control can be configured if NAI Type is set to Unnumbered Adjacency with IPv4 NodeIDs and F bit is disabled.
			x	-remote_node_id_step
			x		Step argument of Remote Node ID
			x	-remote_interface_id
			x		This is the Remote Interface ID of the Unnumbered Adjacency with IPv4 NodeIDs which is specified as a pair of Node ID / Interface ID tuples.
			x		This Control can be configured if NAI Type is set to Unnumbered Adjacency with IPv4 NodeIDs and F bit is disabled.
			x	-metric_active
			x		Specifies whether the corresponding metric object is active or not.
			x	-pre_established_metric_type
			x		This is a drop down which has 4 choices:IGP/ TE/ Hop count/ MSD.
			x		Valid choices are:
			x   		igp - IGP.
			x   		tg - TE.
			x   		hopcount - Hop Count.
			x   		msd - MSD.
			x	-pre_established_metric_value
			x		User can specify the metric value corresponding to the metric type selected.
			x	-b_flag
			x		B (bound) flag MUST be set in the METRIC object, which specifies that the SID depth for the computed path MUST NOT exceed the metric-value.
			x	-backup_pce_ipv4_address
			x		IPv4 address of the backup PCE. This column is greyed out in case of PCCv6.
			x	-backup_pce_active
			x		Activate/Deactivate Configuration
		
		Return Values:
		A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
			xkey:ipv4_loopback_handle                value:A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
		A list containing the ipv4 protocol stack handles that were added by the command (if any).
			xkey:ipv4_handle                         value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE
			 key:status                              value:$::SUCCESS | $::FAILURE
		When status is $::FAILURE, log shows the detailed information of failure.
			 key:log                                 value:When status is $::FAILURE, log shows the detailed information of failure.
		Handle of PCC configured
			 key:pcc_handle                          value:Handle of PCC configured
		Handle of Expected PCE Initiated SR LSPs configured
			 key:expected_initiated_lsp_list_handle  value:Handle of Expected PCE Initiated SR LSPs configured
		Handle of PCC Requested SR LSPs configured
			 key:requested_lsps_handle               value:Handle of PCC Requested SR LSPs configured
		Handle of Pre-Established SR LSPs configured
			 key:pre_established_sr_lsps_handle      value:Handle of Pre-Established SR LSPs configured
		Handle of Backup PCEs configured
			 key:pcep_backup_pces_handle             value:Handle of Backup PCEs configured
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_pcc_config", kwargs)

	def emulation_pcc_control(self, **kwargs):
		""" This procedure performs control actions like start, stop or restart on PCC and does some right click actions on different type of LSPs.     The following operations are done:     1. Start     2. Stop     3. Restart     4. Restart Down     5. Abort
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_pcc_control
			 	-mode    CHOICES restart
			          CHOICES start
			          CHOICES restart_down
			          CHOICES stop
			          CHOICES abort
			          CHOICES delegate
			          CHOICES revoke_delegation]
			 	[-handle ANY]
		
		Arguments:
			 	-mode
			 		What is being done to the protocol.Valid choices are:
			 		restart- Restart the protocol.
			 		start- Start the protocol.
			 		stop- Stop the protocol.
			 		restart_down- Restart the down sessions.
			 		abort- Abort the protocol.
			 		delegate- Delegate PCC-Requested or Pre-Established SR LSPs.
			 		revoke_delegation- Revoke Delegation of PCC-Requested or Pre-Established SR LSPs.
			 		Valid choices are:
			    		restart - Restart the protocol.
			    		start - Start the protocol.
			    		restart_down - restart the down sessions
			    		stop - Stop the protocol.
			    		abort - Aborts the protcol.
			    		delegate - Delegate PCC-Requested or Pre-Established SR LSPs.
			    		revoke_delegation - Revoke Delegation of PCC-Requested or Pre-Established SR LSPs.
			 	-handle
			 		This option represents the handle the user must pass to the "emulation_pcc_control" procedure. This option specifies on which PCEP session to control.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		For mode choices restart, start, restart_down, stop and abort, PCC handle needs to be provided.
		For modes delegate and revoke_delegation, node handle of corresponding LSP type needs to be provided.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_pcc_control", kwargs)

	def emulation_pcc_info(self, **kwargs):
		""" This procedure retrieves information about the PCEP sessions.      This procedure is also used to fetch stats, learned information and configured properties of PCC, depending on the given mode and handle.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_pcc_info
			x	-mode                        CHOICES per_port_stats
			x                             CHOICES per_session_stats
			x                             CHOICES per_device_group_stats
			x                             CHOICES clear_stats
			x                             CHOICES fetch_info
			x                             CHOICES learned_info_sr_basic_pce_initiated
			x                             CHOICES learned_info_sr_basic_pcc_requested
			x                             CHOICES learned_info_sr_basic_pcc_sync
			x                             CHOICES learned_info_sr_basic_all
			x                             CHOICES learned_info_sr_detailed_all
			x                             CHOICES clear_learned_info]
			 	-handle                      ANY]
			 	[-port_handle                REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-lsp_delegation_state       FLAG]
			x	[-re_delegation_timer_status FLAG]
		
		Arguments:
			x	-mode
			x		For fetching per_port_stats provide any PCC handle, for per_session_stats and per_device_group_stats provide a PCC handle which is on the corresponding port.
			x		For fetching learned information, PCC handle needs to be given.
			x		Forfetch_info, provide handle of the node/object from which you need to fetch a property.
			x		Valid choices are:
			x   		per_port_stats - Retrieves PCEP PCC per port stats.
			x   		per_session_stats - Retrieves PCEP PCC per session stats.
			x   		per_device_group_stats - Retrieves PCEP PCC per device group stats.
			x   		clear_stats - Clear PCEP PCC statistics.
			x   		fetch_info - Get PCEP PCC Info.
			x   		learned_info_sr_basic_pce_initiated - Get SR-TE PCE Initiated LSP Basic Learned Information
			x   		learned_info_sr_basic_pcc_requested - Get SR-TE PCC Requested LSP Basic Learned Information
			x   		learned_info_sr_basic_pcc_sync - Get SR-TE PCC Sync/Report LSP Basic Learned Information
			x   		learned_info_sr_basic_all - Get SR-TE All LSPs Basic Learned Information
			x   		learned_info_sr_detailed_all - Get SR-TE All LSPs Detailed Learned Information
			x   		clear_learned_info - Clear PCEP PCC Learned Information
			 	-handle
			 		The PCEP PCC handle to act upon.
			 	-port_handle
			 		Port handle.
			x	-lsp_delegation_state
			x		Get LSP Delegation State. Mandatory flag for fetching LSP Delegation State of PCC Requested SR LSPs/ PCC Pre-Established SR LSPs
			x	-re_delegation_timer_status
			x		Get Re-Delegation Timer Status. Mandatory flag for fetching Re-Delegation Timer Status of PCC Requested SR LSPs/ PCC Pre-Established SR LSPs
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                       value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                                                          value:If status is failure, detailed information provided.
		Sessions Up
			xkey:sessions_up                                                  value:Sessions Up
		Sessions Down
			xkey:sessions_down                                                value:Sessions Down
		Sessions Not Started
			xkey:sessions_not_started                                         value:Sessions Not Started
		Sessions Total
			xkey:sessions_total                                               value:Sessions Total
		Session Flap Count
			xkey:session_flap_count                                           value:Session Flap Count
		Open Message Rx
			xkey:open_message_rx                                              value:Open Message Rx
		Open Message Tx
			xkey:open_message_tx                                              value:Open Message Tx
		Keepalive Message Rx
			xkey:keepalive_message_rx                                         value:Keepalive Message Rx
		Keepalive Message Tx
			xkey:keepalive_message_tx                                         value:Keepalive Message Tx
		Close Message Rx
			xkey:close_message_rx                                             value:Close Message Rx
		Close Message Tx
			xkey:close_message_tx                                             value:Close Message Tx
		Unknown Message Rx
			xkey:unknown_message_rx                                           value:Unknown Message Rx
		Total TCP Connection Established
			xkey:total_tcp_connection_established                             value:Total TCP Connection Established
		PCInitiate Message Rx
			xkey:pcinitiate_message_rx                                        value:PCInitiate Message Rx
		Remove Initiated LSP Rx
			xkey:remove_initiated_lsp_rx                                      value:Remove Initiated LSP Rx
		PCRpt Message Tx
			xkey:pcrpt_message_tx                                             value:PCRpt Message Tx
		PCUpdate Message Rx
			xkey:pcupdate_message_rx                                          value:PCUpdate Message Rx
		PCErr Message Rx
			xkey:pcerr_message_rx                                             value:PCErr Message Rx
		PCErr Message Tx
			xkey:pcerr_message_tx                                             value:PCErr Message Tx
		Total Initiated LSP Rx
			xkey:total_initiated_lsp_rx                                       value:Total Initiated LSP Rx
		Sync LSP Tx
			xkey:sync_lsp_tx                                                  value:Sync LSP Tx
		PCReq Message Tx
			xkey:pcreq_message_tx                                             value:PCReq Message Tx
		PCRep Message Rx
			xkey:pcrep_message_rx                                             value:PCRep Message Rx
		Total Requested LSP Tx
			xkey:total_requested_lsp_tx                                       value:Total Requested LSP Tx
		Total Responded LSP Rx
			xkey:total_responded_lsp_rx                                       value:Total Responded LSP Rx
		No Path Rx
			xkey:no_path_rx                                                   value:No Path Rx
		RSVP Going Up LSP Tx
			xkey:rsvp_going_up_lsp_tx                                         value:RSVP Going Up LSP Tx
		RSVP Up LSP Tx
			xkey:rsvp_up_lsp_tx                                               value:RSVP Up LSP Tx
		RSVP Remove LSP Tx
			xkey:rsvp_remove_lsp_tx                                           value:RSVP Remove LSP Tx
		RSVP Delegated LSP Tx
			xkey:rsvp_delegated_lsp_tx                                        value:RSVP Delegated LSP Tx
		RSVP Revoked LSP Tx
			xkey:rsvp_revoked_lsp_tx                                          value:RSVP Revoked LSP Tx
		RSVP Delegation Returned LSP Rx
			xkey:rsvp_delegation_returned_lsp_rx                              value:RSVP Delegation Returned LSP Rx
		SR Delegated LSP Tx
			xkey:sr_delegated_lsp_tx                                          value:SR Delegated LSP Tx
		SR Revoked LSP Tx
			xkey:sr_revoked_lsp_tx                                            value:SR Revoked LSP Tx
		SR Delegation Returned LSP Rx
			xkey:sr_delegation_returned_lsp_rx                                value:SR Delegation Returned LSP Rx
		PCE IP
			xkey:<handle>.pccsrlearnedinformation.learned_pce_ip_address      value:PCE IP
		LSP Type
			xkey:<handle>.pccsrlearnedinformation.learned_lsp_type            value:LSP Type
		Symbolic Path Name
			xkey:<handle>.pccsrlearnedinformation.symbolic_path_name          value:Symbolic Path Name
		PLSP-ID
			xkey:<handle>.pccsrlearnedinformation.plsp_id                     value:PLSP-ID
		Source IP Address
			xkey:<handle>.pccsrlearnedinformation.source_ip_address           value:Source IP Address
		Destination IP Address
			xkey:<handle>.pccsrlearnedinformation.dest_ip_address             value:Destination IP Address
		Bandwidth (Bps)
			xkey:<handle>.pccsrlearnedinformation.bandwidth                   value:Bandwidth (Bps)
		ERO Info
			xkey:<handle>.pccsrlearnedinformation.ero_info                    value:ERO Info
		Error Info
			xkey:<handle>.pccsrlearnedinformation.learned_error_info          value:Error Info
		LSP Index
			xkey:<handle>.pccdetailedlearnedinformation.learned_lsp_index     value:LSP Index
		LSP Type
			xkey:<handle>.pccdetailedlearnedinformation.learned_msg_db_type   value:LSP Type
		Request ID
			xkey:<handle>.pccdetailedlearnedinformation.request_id            value:Request ID
		LSP-ID
			xkey:<handle>.pccdetailedlearnedinformation.plsp_id               value:LSP-ID
		Symbolic Path Name
			xkey:<handle>.pccdetailedlearnedinformation.symbolic_path_name    value:Symbolic Path Name
		IP Version
			xkey:<handle>.pccdetailedlearnedinformation.ip_version            value:IP Version
		Source IPv4 Address
			xkey:<handle>.pccdetailedlearnedinformation.source_ipv4_address   value:Source IPv4 Address
		Destination IPv4 Address
			xkey:<handle>.pccdetailedlearnedinformation.dest_ipv4_address     value:Destination IPv4 Address
		Source IPv6 Address
			xkey:<handle>.pccdetailedlearnedinformation.source_ipv6_address   value:Source IPv6 Address
		Destination IPv6 Address
			xkey:<handle>.pccdetailedlearnedinformation.dest_ipv6_address     value:Destination IPv6 Address
		SID-Type
			xkey:<handle>.pccdetailedlearnedinformation.sid_type              value:SID-Type
		SID
			xkey:<handle>.pccdetailedlearnedinformation.sid                   value:SID
		MPLS Label
			xkey:<handle>.pccdetailedlearnedinformation.mpls_label            value:MPLS Label
		NAI-Type
			xkey:<handle>.pccdetailedlearnedinformation.nai_type              value:NAI-Type
		IPv4 Node ID
			xkey:<handle>.pccdetailedlearnedinformation.ipv4_node_id          value:IPv4 Node ID
		IPv6 Node ID
			xkey:<handle>.pccdetailedlearnedinformation.ipv6_node_id          value:IPv6 Node ID
		Local IPv4 Address
			xkey:<handle>.pccdetailedlearnedinformation.local_i_pv4address    value:Local IPv4 Address
		Remote IPv4 Address
			xkey:<handle>.pccdetailedlearnedinformation.remote_i_pv4address   value:Remote IPv4 Address
		Local IPv6 Address
			xkey:<handle>.pccdetailedlearnedinformation.local_i_pv6address    value:Local IPv6 Address
		Remote IPv6 Address
			xkey:<handle>.pccdetailedlearnedinformation.remote_i_pv6address   value:Remote IPv6 Address
		Local Node-ID
			xkey:<handle>.pccdetailedlearnedinformation.local_node_i_d        value:Local Node-ID
		Local Interface ID
			xkey:<handle>.pccdetailedlearnedinformation.local_inteface_i_d    value:Local Interface ID
		Remote Node-ID
			xkey:<handle>.pccdetailedlearnedinformation.remote_node_i_d       value:Remote Node-ID
		Remote Interface ID
			xkey:<handle>.pccdetailedlearnedinformation.remote_interface_i_d  value:Remote Interface ID
		Error Info
			xkey:<handle>.pccdetailedlearnedinformation.error_info            value:Error Info
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_pcc_info", kwargs)

	def emulation_pce_config(self, **kwargs):
		""" This procedure will add PCE and PCC Groups to a particular Ixia Interface.     The user can then configure, PCC Groups by using the procedure     PCRequest Match Criteria, PCReply LSP Parameters and PCE Initiated LSP Parameters.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_pce_config
			 	-mode                                         CHOICES create
			                                               CHOICES delete
			                                               CHOICES modify
			                                               CHOICES enable
			                                               CHOICES disable]
			 	[-port_handle                                 REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle                                      ANY]
			x	[-pce_active                                  ANY]
			x	[-pce_name                                    ALPHA]
			x	[-pce_action_mode                             CHOICES none
			x                                              CHOICES reset
			x                                              CHOICES rsvpPcInitiate
			x                                              CHOICES rsvpPcrep
			x                                              CHOICES rsvpPcupd
			x                                              CHOICES srPcrep]
			x	[-pc_reply_lsps_per_pcc                       NUMERIC]
			x	[-pcc_ipv4_address                            ANY]
			x	[-pcc_ipv4_address_step                       ANY]
			x	[-max_lsps_per_pc_initiate                    ANY]
			x	[-keepalive_interval                          ANY]
			x	[-dead_interval                               ANY]
			x	[-pce_initiated_lsps_per_pcc                  NUMERIC]
			x	[-stateful_pce_capability                     ANY]
			x	[-lsp_update_capability                       ANY]
			x	[-sr_pce_capability                           ANY]
			x	[-pce_ppag_t_l_v_type                         ANY]
			x	[-authentication                              CHOICES null md5]
			x	[-m_d5_key                                    ANY]
			x	[-rate_control                                ANY]
			x	[-burst_interval                              ANY]
			x	[-max_initiated_lsp_per_interval              ANY]
			x	[-pcc_group_active                            ANY]
			x	[-pcc_group_name                              ALPHA]
			x	[-multiplier                                  NUMERIC]
			x	[-path_setup_type                             CHOICES sr rsvpte]
			x	[-include_end_points                          ANY]
			x	[-include_srp                                 ANY]
			x	[-pce_initiate_include_lsp                    ANY]
			x	[-include_ero                                 ANY]
			x	[-pce_initiate_include_metric                 ANY]
			x	[-pce_initiate_include_bandwidth              ANY]
			x	[-pce_initiate_include_lspa                   ANY]
			x	[-pce_initiate_ip_version                     CHOICES ipv4 ipv6]
			x	[-src_end_point_ipv4                          ANY]
			x	[-src_end_point_ipv4_step                     ANY]
			x	[-dest_end_point_ipv4                         ANY]
			x	[-dest_end_point_ipv4_step                    ANY]
			x	[-src_end_point_ipv6                          ANY]
			x	[-src_end_point_ipv6_step                     ANY]
			x	[-dest_end_point_ipv6                         ANY]
			x	[-dest_end_point_ipv6_step                    ANY]
			x	[-override_srp_id_number                      CHOICES 0 1]
			x	[-srp_id_number                               ANY]
			x	[-override_plsp_id                            CHOICES 0 1]
			x	[-pce_initiate_plsp_id                        ANY]
			x	[-pce_initiate_include_symbolic_path_name_tlv ANY]
			x	[-pce_initiate_symbolic_path_name             ANY]
			x	[-pce_initiate_include_t_e_path_binding_t_l_v ANY]
			x	[-pce_initiate_send_empty_t_l_v               ANY]
			x	[-pce_initiate_binding_type                   CHOICES mplslabel20bit mplslabel32bit]
			x	[-pce_initiate_mpls_label                     ANY]
			x	[-pce_initiate_tc                             ANY]
			x	[-pce_initiate_bos                            ANY]
			x	[-pce_initiate_ttl                            ANY]
			x	[-pce_initiate_number_of_ero_sub_objects      NUMERIC]
			x	[-pce_initiate_number_of_metric_sub_object    NUMERIC]
			x	[-pce_initiate_bandwidth                      ANY]
			x	[-pce_initiate_setup_priority                 ANY]
			x	[-pce_initiate_holding_priority               ANY]
			x	[-pce_initiate_local_protection               ANY]
			x	[-pce_initiate_include_any                    ANY]
			x	[-pce_initiate_include_all                    ANY]
			x	[-pce_initiate_exclude_any                    ANY]
			x	[-include_association                         ANY]
			x	[-association_id                              ANY]
			x	[-protection_lsp                              ANY]
			x	[-standby_mode                                ANY]
			x	[-pce_initiate_enable_xro                     ANY]
			x	[-pce_initiate_fail_bit                       ANY]
			x	[-pce_initiate_number_of_Xro_sub_objects      NUMERIC]
			x	[-pce_initiate_lsp_parameters_active          ANY]
			x	[-pce_initiate_xro_active                     ANY]
			x	[-pce_initiate_exclude_bit                    ANY]
			x	[-pce_initiate_xro_attribute                  CHOICES interface node srlg]
			x	[-pce_initiate_xro_sub_object_type            CHOICES ipv4prefix
			x                                              CHOICES ipv6prefix
			x                                              CHOICES unnumberedinterfaceid
			x                                              CHOICES asnumber
			x                                              CHOICES srlg]
			x	[-pce_initiate_xro_prefix_length              ANY]
			x	[-pce_initiate_xro_ipv4_address               ANY]
			x	[-pce_initiate_xro_ipv4_address_step          ANY]
			x	[-pce_initiate_xro_ipv6_address               ANY]
			x	[-pce_initiate_xro_ipv6_address_step          ANY]
			x	[-pce_initiate_xro_router_id                  ANY]
			x	[-pce_initiate_xro_router_id_step             ANY]
			x	[-pce_initiate_xro_interface_id               ANY]
			x	[-pce_initiate_xro_as_number                  ANY]
			x	[-pce_initiate_srlg_id                        ANY]
			x	[-pce_initiate_pce_id32                       ANY]
			x	[-pce_initiate_pce_id128                      ANY]
			x	[-pcep_ero_sub_objects_list_active            ANY]
			x	[-loose_hop                                   ANY]
			x	[-sub_object_type                             CHOICES null
			x                                              CHOICES ipv4prefix
			x                                              CHOICES ipv6prefix
			x                                              CHOICES asnumber]
			x	[-prefix_length                               ANY]
			x	[-ipv4_prefix                                 ANY]
			x	[-ipv4_prefix_step                            ANY]
			x	[-ipv6_prefix                                 ANY]
			x	[-ipv6_prefix_step                            ANY]
			x	[-as_number                                   ANY]
			x	[-sid_type                                    CHOICES null
			x                                              CHOICES sid
			x                                              CHOICES mplslabel20bit
			x                                              CHOICES mplslabel32bit]
			x	[-sid                                         ANY]
			x	[-mpls_label                                  ANY]
			x	[-tc                                          ANY]
			x	[-bos                                         ANY]
			x	[-ttl                                         ANY]
			x	[-nai_type                                    CHOICES notapplicable
			x                                              CHOICES ipv4nodeid
			x                                              CHOICES ipv6nodeid
			x                                              CHOICES ipv4adjacency
			x                                              CHOICES ipv6adjacency
			x                                              CHOICES unnumberedadjacencywithipv4nodeids]
			x	[-f_bit                                       ANY]
			x	[-ipv4_node_id                                ANY]
			x	[-ipv4_node_id_step                           ANY]
			x	[-ipv6_node_id                                ANY]
			x	[-ipv6_node_id_step                           ANY]
			x	[-local_ipv4_address                          ANY]
			x	[-local_ipv4_address_step                     ANY]
			x	[-remote_ipv4_address                         ANY]
			x	[-remote_ipv4_address_step                    ANY]
			x	[-local_ipv6_address                          ANY]
			x	[-local_ipv6_address_step                     ANY]
			x	[-remote_ipv6_address                         ANY]
			x	[-remote_ipv6_address_step                    ANY]
			x	[-local_node_id                               ANY]
			x	[-local_node_id_step                          ANY]
			x	[-local_interface_id                          ANY]
			x	[-remote_node_id                              ANY]
			x	[-remote_node_id_step                         ANY]
			x	[-remote_interface_id                         ANY]
			x	[-pcep_metric_sub_objects_list_active         ANY]
			x	[-metric_type                                 CHOICES igp tg hopcount msd]
			x	[-metric_value                                ANY]
			x	[-b_flag                                      ANY]
			x	[-response_options                            CHOICES crep crepwithnopath]
			x	[-response_path_type                          CHOICES sr rsvpte]
			x	[-include_rp                                  ANY]
			x	[-pc_reply_include_lsp                        ANY]
			x	[-enable_ero                                  ANY]
			x	[-pc_reply_include_metric                     ANY]
			x	[-pc_reply_include_bandwidth                  ANY]
			x	[-pc_reply_include_lspa                       ANY]
			x	[-enable_xro                                  ANY]
			x	[-process_type                                CHOICES configure reflect]
			x	[-reflect_r_p                                 ANY]
			x	[-request_id                                  ANY]
			x	[-enable_loose                                ANY]
			x	[-bi_directional                              ANY]
			x	[-priority_value                              ANY]
			x	[-pc_reply_number_of_ero_sub_objects          NUMERIC]
			x	[-pc_reply_number_of_metric_sub_object        NUMERIC]
			x	[-pc_reply_bandwidth                          ANY]
			x	[-reflect_l_s_p                               ANY]
			x	[-pc_reply_plsp_id                            ANY]
			x	[-pc_reply_include_symbolic_path_name_tlv     ANY]
			x	[-pc_reply_symbolic_path_name                 ANY]
			x	[-pc_reply_include_t_e_path_binding_t_l_v     ANY]
			x	[-pc_reply_send_empty_t_l_v                   ANY]
			x	[-pc_reply_binding_type                       CHOICES mplslabel20bit mplslabel32bit]
			x	[-pc_reply_mpls_label                         ANY]
			x	[-pc_reply_tc                                 ANY]
			x	[-pc_reply_bos                                ANY]
			x	[-pc_reply_ttl                                ANY]
			x	[-pc_reply_setup_priority                     ANY]
			x	[-pc_reply_holding_priority                   ANY]
			x	[-pc_reply_local_protection                   ANY]
			x	[-pc_reply_include_any                        ANY]
			x	[-pc_reply_include_all                        ANY]
			x	[-pc_reply_exclude_any                        ANY]
			x	[-nature_of_issue                             ANY]
			x	[-enable_c_flag                               ANY]
			x	[-reflected_object_no_path                    CHOICES elect_reflected_object
			x                                              CHOICES metric
			x                                              CHOICES bandwidth
			x                                              CHOICES iro
			x                                              CHOICES lspa
			x                                              CHOICES xro]
			x	[-fail_bit                                    ANY]
			x	[-number_of_Xro_sub_objects                   NUMERIC]
			x	[-pc_reply_active                             ANY]
			x	[-xro_active                                  ANY]
			x	[-exclude_bit                                 ANY]
			x	[-xro_attribute                               CHOICES interface node srlg]
			x	[-xro_sub_object_type                         CHOICES ipv4prefix
			x                                              CHOICES ipv6prefix
			x                                              CHOICES unnumberedinterfaceid
			x                                              CHOICES asnumber
			x                                              CHOICES srlg]
			x	[-xro_prefix_length                           ANY]
			x	[-xro_ipv4_address                            ANY]
			x	[-xro_ipv4_address_step                       ANY]
			x	[-xro_ipv6_address                            ANY]
			x	[-xro_ipv6_address_step                       ANY]
			x	[-xro_router_id                               ANY]
			x	[-xro_router_id_step                          ANY]
			x	[-xro_interface_id                            ANY]
			x	[-xro_as_number                               ANY]
			x	[-srlg_id                                     ANY]
			x	[-pce_id32                                    ANY]
			x	[-pce_id128                                   ANY]
			x	[-pc_request_ip_version                       CHOICES ipv4 ipv6]
			x	[-src_ipv4_address                            ANY]
			x	[-src_ipv4_address_step                       ANY]
			x	[-dest_ipv4_address                           ANY]
			x	[-dest_ipv4_address_step                      ANY]
			x	[-src_ipv6_address                            ANY]
			x	[-src_ipv6_address_step                       ANY]
			x	[-dest_ipv6_address                           ANY]
			x	[-dest_ipv6_address_step                      ANY]
			x	[-pc_request_active                           ANY]
			x	[-learned_info_update_item                    NUMERIC]
			x	[-trigger_number_of_ero_sub_objects           NUMERIC]
			x	[-trigger_number_of_metric_sub_objects        NUMERIC]
			x	[-pce_triggers_choice_list                    CHOICES sendupdate]
			x	[-trigger_include_srp                         ANY]
			x	[-trigger_configure_lsp                       CHOICES dontinclude reflect modify]
			x	[-trigger_configure_ero                       CHOICES dontinclude reflect modify]
			x	[-trigger_configure_lspa                      CHOICES dontinclude reflect modify]
			x	[-trigger_configure_bandwidth                 CHOICES dontinclude reflect modify]
			x	[-trigger_configure_metric                    CHOICES dontinclude reflect modify]
			x	[-trigger_override_srp_id                     ANY]
			x	[-trigger_srp_id                              ANY]
			x	[-trigger_include_symbolic_path_name          ANY]
			x	[-trigger_include_t_e_path_binding_t_l_v      ANY]
			x	[-trigger_send_empty_t_l_v                    ANY]
			x	[-trigger_binding_type                        CHOICES mplslabel20bit mplslabel32bit]
			x	[-trigger_mpls_label                          ANY]
			x	[-trigger_tc                                  ANY]
			x	[-trigger_bos                                 ANY]
			x	[-trigger_ttl                                 ANY]
			x	[-trigger_bandwidth                           ANY]
			x	[-trigger_setup_priority                      ANY]
			x	[-trigger_holding_priority                    ANY]
			x	[-trigger_local_protection                    ANY]
			x	[-trigger_include_any                         ANY]
			x	[-trigger_include_all                         ANY]
			x	[-trigger_exclude_any                         ANY]
			x	[-trigger_rsvp_active_this_ero                ANY]
			x	[-trigger_rsvp_loose_hop                      ANY]
			x	[-trigger_rsvp_sub_object_type                CHOICES null
			x                                              CHOICES ipv4prefix
			x                                              CHOICES ipv6prefix
			x                                              CHOICES asnumber]
			x	[-trigger_rsvp_prefix_length                  ANY]
			x	[-trigger_rsvp_ipv4_prefix                    ANY]
			x	[-trigger_rsvp_ipv4_prefix_step               ANY]
			x	[-trigger_rsvp_ipv6_prefix                    ANY]
			x	[-trigger_rsvp_ipv6_prefix_step               ANY]
			x	[-trigger_rsvp_as_number                      ANY]
			x	[-trigger_rsvp_metric_type                    CHOICES igp tg hopcount]
			x	[-trigger_rsvp_active_this_metric             ANY]
			x	[-trigger_rsvp_metric_value                   ANY]
			x	[-trigger_rsvp_b_flag                         ANY]
			x	[-trigger_sr_active_this_ero                  ANY]
			x	[-trigger_sr_loose_hop                        ANY]
			x	[-trigger_sr_sid_type                         CHOICES null
			x                                              CHOICES sid
			x                                              CHOICES mplslabel20bit
			x                                              CHOICES mplslabel32bit]
			x	[-trigger_sr_sid                              ANY]
			x	[-trigger_sr_mpls_label                       ANY]
			x	[-trigger_sr_mpls_label32                     ANY]
			x	[-trigger_sr_tc                               ANY]
			x	[-trigger_sr_bos                              ANY]
			x	[-trigger_sr_ttl                              ANY]
			x	[-trigger_sr_nai_type                         CHOICES notapplicable
			x                                              CHOICES ipv4nodeid
			x                                              CHOICES ipv6nodeid
			x                                              CHOICES ipv4adjacency
			x                                              CHOICES ipv6adjacency
			x                                              CHOICES unnumberedadjacencywithipv4nodeids]
			x	[-trigger_sr_f_bit                            ANY]
			x	[-trigger_sr_ipv4_node_id                     ANY]
			x	[-trigger_sr_ipv4_node_id_step                ANY]
			x	[-trigger_sr_ipv6_node_id                     ANY]
			x	[-trigger_sr_ipv6_node_id_step                ANY]
			x	[-trigger_sr_local_ipv4_address               ANY]
			x	[-trigger_sr_local_ipv4_address_step          ANY]
			x	[-trigger_sr_remote_ipv4_address              ANY]
			x	[-trigger_sr_remote_ipv4_address_step         ANY]
			x	[-trigger_sr_local_ipv6_address               ANY]
			x	[-trigger_sr_local_ipv6_address_step          ANY]
			x	[-trigger_sr_remote_ipv6_address              ANY]
			x	[-trigger_sr_remote_ipv6_address_step         ANY]
			x	[-trigger_sr_local_node_id                    ANY]
			x	[-trigger_sr_local_node_id_step               ANY]
			x	[-trigger_sr_local_interface_id               ANY]
			x	[-trigger_sr_remote_node_id                   ANY]
			x	[-trigger_sr_remote_node_id_step              ANY]
			x	[-trigger_sr_remote_interface_id              ANY]
			x	[-trigger_sr_metric_type                      CHOICES igp tg hopcount msd]
			x	[-trigger_sr_active_this_metric               ANY]
			x	[-trigger_sr_metric_value                     ANY]
			x	[-trigger_sr_b_flag                           ANY]
		
		Arguments:
			 	-mode
			 		This option defines whether to Create/Modify/Delete/Enable/Disable PCE, PCC Group and different types of LSPs under PCE.
			 		Valid choices are:
			    		create - Creates PCE, PCC Group and different types of LSPs under PCE.
			    		delete - Deletes PCE and PCC Group.
			    		modify - Modifies PCE, PCC Group and different types of LSPs under PCE.
			    		enable - Enables PCE, PCC Group and different types of LSPs under PCE.
			    		disable - Disables PCE, PCC Group and different types of LSPs under PCE.
			 	-port_handle
			 		Port handle.
			 	-handle
			 		Specifies the parent node/object handle on which the pcep configuration should be configured.
			 		In case of create/modify -mode, -handle generally denotes the parent node/object handle .
			 		In case of modesmodify/delete/disable/enable -handle denotes the object node handle on which the action needs to be performed.
			x	-pce_active
			x		Activate/Deactivate PCE Configuration.
			x	-pce_name
			x		Name of NGPF element, guaranteed to be unique in Scenario.
			x	-pce_action_mode
			x		PCE Mode of Action.
			x		Valid choices are:
			x   		none - None.
			x   		reset - Reset.
			x   		rsvpPcInitiate - PC Initiate For RSVP-TE LSPs.
			x   		rsvpPcrep - RSVP PC Response.
			x   		rsvpPcupd - PC Update For RSVP-TE LSPs.
			x   		srPcrep - SR PC Response.
			x	-pc_reply_lsps_per_pcc
			x		Controls the maximum number of PCE LSPs that can be send as PATH Response.
			x	-pcc_ipv4_address
			x		IPv4 address of the PCC. This column is greyed out in case of PCEv6.
			x	-pcc_ipv4_address_step
			x		Step Argument of PCC IPv4 address.
			x	-max_lsps_per_pc_initiate
			x		Controls the maximum number of LSPs that can be present in a PCInitiate message.
			x	-keepalive_interval
			x		Frequency/Time Interval of sending PCEP messages to keep the session active.
			x	-dead_interval
			x		This is the time interval, after the expiration of which, a PCEP peer declares the session down if no PCEP message has been received.
			x	-pce_initiated_lsps_per_pcc
			x		Controls the maximum number of PCE LSPs that can be Initiated per PCC.
			x	-stateful_pce_capability
			x		If enabled, the server will work like a Stateful PCE else like a stateless PCE.
			x	-lsp_update_capability
			x		If the Stateful PCE Capability is enabled then this control should be activated to set the update capability in the Stateful PCE Capability TLV.
			x	-sr_pce_capability
			x		The SR PCE Capability TLV is an optional TLV associated with the OPEN Object to exchange SR capability of PCEP speakers.
			x	-pce_ppag_t_l_v_type
			x		PPAG TLV Type specifies PCE's capability of interpreting this type of PPAG TLV
			x	-authentication
			x		The type of cryptographic authentication to be used on this link interface.
			x		Valid choices are:
			x   		null - NULL.
			x   		md5 - MD5.
			x	-m_d5_key
			x		A value to be used as the "secret" MD5 Key.
			x	-rate_control
			x		The rate control is an optional feature associated with PCE initiated LSP.
			x	-burst_interval
			x		Interval in milisecond in which desired rate of messages needs to be maintained.
			x	-max_initiated_lsp_per_interval
			x		Maximum number of messages can be sent per interval.
			x	-pcc_group_active
			x		Activate/Deactivate PCE sessions.
			x	-pcc_group_name
			x		Name of NGPF element, guaranteed to be unique in Scenario.
			x	-multiplier
			x		Number of layer instances per parent instance (multiplier).
			x	-path_setup_type
			x		Indicates which type of LSP will be requested in the PCInitiated Request.
			x		Valid choices are:
			x   		sr - SR-TE.
			x   		rsvpte - RSVP-TE.
			x	-include_end_points
			x		Indicates whether END-POINTS object will be included in a PCInitiate message. All other attributes in sub-tab-End Points would be editable only if this checkbox is enabled.
			x	-include_srp
			x		Indicates whether SRP object will be included in a PCInitiate message. All other attributes in sub-tab-SRP would be editable only if this checkbox is enabled.
			x	-pce_initiate_include_lsp
			x		Indicates whether LSP will be included in a PCInitiate message. All other attributes in sub-tab-LSP would be editable only if this checkbox is enabled.
			x	-include_ero
			x		Specifies whether ERO is active or inactive. All subsequent attributes of the sub-tab-ERO would be editable only if this is enabled.
			x	-pce_initiate_include_metric
			x		Indicates whether the PCInitiate message will have the metric list that is configured. All subsequent attributes of the sub-tab-Metric would be editable only if this is enabled.
			x	-pce_initiate_include_bandwidth
			x		Indicates whether Bandwidth will be included in a PCInitiate message. All other attributes in sub-tab-Bandwidth would be editable only if this checkbox is enabled.
			x	-pce_initiate_include_lspa
			x		Indicates whether LSPA will be included in a PCInitiate message. All other attributes in sub-tab-LSPA would be editable only if this checkbox is enabled.
			x	-pce_initiate_ip_version
			x		Drop down to select the IP Version with 2 choices : IPv4 / IPv6.
			x		Valid choices are:
			x   		ipv4 - IPv4.
			x   		ipv6 - IPv6.
			x	-src_end_point_ipv4
			x		Source IPv4 address of the path for which a path computation is Initiated. Will be greyed out if IP Version is set to IPv6.
			x	-src_end_point_ipv4_step
			x		Step Argument of Source IPv4 address.
			x	-dest_end_point_ipv4
			x		Dest IPv4 address of the path for which a path computation is Initiated. Will be greyed out if IP Version is IPv6.
			x	-dest_end_point_ipv4_step
			x		Step Argument of Destination IPv4 address.
			x	-src_end_point_ipv6
			x		Source IPv6 address of the path for which a path computation is Initiated. Will be greyed out if IP version is set to IPv4.
			x	-src_end_point_ipv6_step
			x		Step Argument of Source IPv6 address.
			x	-dest_end_point_ipv6
			x		Dest IPv6 address of the path for which a path computation is Initiated. Will be greyed out if IP Version is IPv4.
			x	-dest_end_point_ipv6_step
			x		Step Argument of Destination IPv6 address.
			x	-override_srp_id_number
			x		Indicates whether SRP ID Number is overridable.
			x	-srp_id_number
			x		The SRP object is used to correlate between initiation requests sent by the PCE and the error reports and state reports sent by the PCC. This number is unique per PCEP session and is incremented per initiation.
			x	-override_plsp_id
			x		Indicates if PLSP-ID will be set by the state machine or user. If disabled user wont have the control and state machine will set it.
			x	-pce_initiate_plsp_id
			x		An identifier for the LSP. A PCC creates a unique PLSP-ID for each LSP that is constant for the lifetime of a PCEP session. The PCC will advertise the same PLSP-ID on all PCEP sessions it maintains at a given time.
			x	-pce_initiate_include_symbolic_path_name_tlv
			x		Indicates if Symbolic-Path-Name TLV is to be included in PCInitiate message.
			x	-pce_initiate_symbolic_path_name
			x		Each LSP (path) must have a symbolic name that is unique in the PCC. It must remain constant throughout a path's lifetime, which may span across multiple consecutive PCEP sessions and/or PCC restarts.
			x	-pce_initiate_include_t_e_path_binding_t_l_v
			x		Indicates if TE-PATH-BINDING TLV is to be included in PCInitiate message.
			x	-pce_initiate_send_empty_t_l_v
			x		If enabled all fields after Binding Type will be grayed out.
			x	-pce_initiate_binding_type
			x		Indicates the type of binding included in the TLV. Types are as follows:
			x		20bit MPLS Label
			x		32bit MPLS Label.
			x		Default value is 20bit MPLS Label.
			x		Valid choices are:
			x   		mplslabel20bit - 0- MPLS Label 20 Bit.
			x   		mplslabel32bit - 1- MPLS Label 20 Bit.
			x	-pce_initiate_mpls_label
			x		This control will be editable if the Binding Type is set to either 20bit or 32bit MPLS-Label. This field will take the 20bit value of the MPLS-Label
			x	-pce_initiate_tc
			x		This field is used to carry traffic class information. This control will be editable only if Binding Type is MPLS Label 32bit.
			x	-pce_initiate_bos
			x		This bit is set to True for the last entry in the label stack i.e., for the bottom of the stack, and False for all other label stack entries.
			x		This control will be editable only if Binding Type is MPLS Label 32bit.
			x	-pce_initiate_ttl
			x		This field is used to encode a time-to-live value. This control will be editable only if Binding Type is MPLS Label 32bit.
			x	-pce_initiate_number_of_ero_sub_objects
			x		Value that indicates the number of ERO Sub Objects to be configured.
			x	-pce_initiate_number_of_metric_sub_object
			x		Value that indicates the number of Metric Objects to be configured.
			x	-pce_initiate_bandwidth
			x		Bandwidth (bits/sec)
			x	-pce_initiate_setup_priority
			x		The priority of the LSP with respect to taking resources.The value 0 is the highest priority.The Setup Priority is used in deciding whether this session can preempt another session.
			x	-pce_initiate_holding_priority
			x		The priority of the LSP with respect to holding resources. The value 0 is the highest priority.Holding Priority is used in deciding whether this session can be preempted by another session.
			x	-pce_initiate_local_protection
			x		When set, this means that the path must include links protected with Fast Reroute
			x	-pce_initiate_include_any
			x		This is a type of Resource Affinity Procedure that is used to validate a link. This control accepts a link if the link carries any of the attributes in the set.
			x	-pce_initiate_include_all
			x		This is a type of Resource Affinity Procedure that is used to validate a link. This control excludes a link from consideration if the link carries any of the attributes in the set.
			x	-pce_initiate_exclude_any
			x		This is a type of Resource Affinity Procedure that is used to validate a link. This control accepts a link only if the link carries all of the attributes in the set.
			x	-include_association
			x		Indicates whether PPAG will be included in a PCInitiate message. All other attributes in sub-tab-PPAG would be editable only if this checkbox is enabled.
			x	-association_id
			x		The Association ID of this LSP.
			x	-protection_lsp
			x		Indicates whether Protection LSP Bit is On.
			x	-standby_mode
			x		Indicates whether Standby LSP Bit is On.
			x	-pce_initiate_enable_xro
			x		Include XRO
			x	-pce_initiate_fail_bit
			x		Fail Bit
			x	-pce_initiate_number_of_Xro_sub_objects
			x		Number of XRO Sub Objects
			x	-pce_initiate_lsp_parameters_active
			x		Activate/Deactivate PCE Initiated LSP Parameters.
			x	-pce_initiate_xro_active
			x		Activate/Deactivate XRO
			x	-pce_initiate_exclude_bit
			x		Indicates whether the exclusion is mandatory or desired.
			x	-pce_initiate_xro_attribute
			x		Indicates how the exclusion subobject is to be indicated.
			x		Valid choices are:
			x   		interface - 0 - Interface.
			x   		node - 1 - Node.
			x   		srlg - 2 - SRLG.
			x	-pce_initiate_xro_sub_object_type
			x		Using the Sub Object Type control user can configure which sub object needs to be included from the following options: IPv4 Prefix, IPv6 Prefix, Unnumbered Interface ID, AS Number, SRLG.
			x		Valid choices are:
			x   		ipv4prefix - IPv4 Prefix.
			x   		ipv6prefix - IPv6 Prefix.
			x   		unnumberedinterfaceid - Unnumbered Interface ID.
			x   		asnumber - AS Number.
			x   		srlg - SRLG.
			x	-pce_initiate_xro_prefix_length
			x		Prefix Length
			x	-pce_initiate_xro_ipv4_address
			x		IPv4 Address
			x	-pce_initiate_xro_ipv4_address_step
			x		Step argument of IPv4 Address
			x	-pce_initiate_xro_ipv6_address
			x		IPv6 Address
			x	-pce_initiate_xro_ipv6_address_step
			x		Step argument of IPv6 Address
			x	-pce_initiate_xro_router_id
			x		Router ID
			x	-pce_initiate_xro_router_id_step
			x		Step argument of Router ID
			x	-pce_initiate_xro_interface_id
			x		Interface ID
			x	-pce_initiate_xro_as_number
			x		AS Number
			x	-pce_initiate_srlg_id
			x		SRLG ID
			x	-pce_initiate_pce_id32
			x		32 bit PKS ID
			x	-pce_initiate_pce_id128
			x		128 bit PKS ID
			x	-pcep_ero_sub_objects_list_active
			x		Controls whether the ERO sub-object will be sent in the PCInitiate message.
			x	-loose_hop
			x		Indicates if user wants to represent a loose-hop sub object in the LSP
			x	-sub_object_type
			x		Using the Sub Object Type control user can configure which sub object needs to be included from the following options: Not Applicable, IPv4 Prefix, IPv6 Prefix, AS Number.
			x		Valid choices are:
			x   		null - Not Applicable.
			x   		ipv4prefix - IPv4 Prefix.
			x   		ipv6prefix - IPv6 Prefix.
			x   		asnumber - AS Number.
			x	-prefix_length
			x		Prefix Length
			x	-ipv4_prefix
			x		IPv4 Prefix is specified as an IPv4 address.
			x	-ipv4_prefix_step
			x		Step argument of IPv4 Prefix.
			x	-ipv6_prefix
			x		IPv6 Prefix is specified as an IPv6 address.
			x	-ipv6_prefix_step
			x		Step argument of IPv6 Prefix.
			x	-as_number
			x		AS Number
			x	-sid_type
			x		Using the Segment Identifier Type control user can configure whether to include SID or not and if included what is its type. Types are as follows: Null, SID, 20bit MPLS Label, 32bit MPLS Label.
			x		If it is Null then S bit is set in the packet. Default value is 20bit MPLS Label.
			x		Valid choices are:
			x   		null - Null.
			x   		sid - SID.
			x   		mplslabel20bit - MPLS Label 20 Bit.
			x   		mplslabel32bit - MPLS Label 32 Bit.
			x	-sid
			x		SIDis the Segment Identifier
			x	-mpls_label
			x		This control will be editable if the SID Type is set to either 20bit or 32bit MPLS-Label. This field will take the 20bit value of the MPLS-Label
			x	-tc
			x		This field is used to carry traffic class information. This control will be editable only if SID Type is MPLS Label 32bit.
			x	-bos
			x		This bit is set to true for the last entry in the label stack i.e., for the bottom of the stack, and false for all other label stack entries.
			x		This control will be editable only if SID Type is MPLS Label 32bit.
			x	-ttl
			x		This field is used to encode a time-to-live value. This control will be editable only if SID Type is MPLS Label 32bit.
			x	-nai_type
			x		NAI (Node or Adjacency Identifier) contains the NAI associated with the SID. Depending on the value of SID Type, the NAI can have different formats such as; Not Applicable, IPv4 Node ID, IPv6 Node ID, IPv4 Adjacency, IPv6 Adjacency, Unnumbered Adjacency with IPv4 NodeIDs
			x		Valid choices are:
			x   		notapplicable - Not Applicable.
			x   		ipv4nodeid - IPv4 Node ID.
			x   		ipv6nodeid - IPv6 Node ID.
			x   		ipv4adjacency - IPv4 Adjacency.
			x   		ipv6adjacency - IPv6 Adjacency.
			x   		unnumberedadjacencywithipv4nodeids - Unnumbered Adjacency with IPv4 NodeIDs.
			x	-f_bit
			x		A Flag which is used to carry additional information pertaining to SID. When this bit is set, the NAI value in the subobject body is null.
			x	-ipv4_node_id
			x		IPv4 Node ID is specified as an IPv4 address. This control can be configured if NAI Type is set to IPv4 Node ID and F bit is disabled.
			x	-ipv4_node_id_step
			x		Step argument of IPv4 Node ID.
			x	-ipv6_node_id
			x		IPv6 Node ID is specified as an IPv6 address. This control can be configured if NAI Type is set to IPv6 Node ID and F bit is disabled.
			x	-ipv6_node_id_step
			x		Step argument of IPv6 Node ID.
			x	-local_ipv4_address
			x		This Control can be configured if NAI Type is set to IPv4 Adjacency and F bit is disabled.
			x	-local_ipv4_address_step
			x		Step argument of Local IPv4 Address.
			x	-remote_ipv4_address
			x		This Control can be configured if NAI Type is set to IPv4 Adjacency and F bit is disabled.
			x	-remote_ipv4_address_step
			x		Step argument of Remote IPv4 Address.
			x	-local_ipv6_address
			x		This Control can be configured if NAI Type is set to IPv6 Adjacency and F bit is disabled.
			x	-local_ipv6_address_step
			x		Step argument of Local IPv6 Address.
			x	-remote_ipv6_address
			x		This Control can be configured if NAI Type is set to IPv6 Adjacency and F bit is disabled.
			x	-remote_ipv6_address_step
			x		Step argument of Remote IPv6 Address.
			x	-local_node_id
			x		This is the Local Node ID of the Unnumbered Adjacency with IPv4 NodeIDs which is specified as a pair of Node ID / Interface ID tuples.
			x		This Control can be configured if NAI Type is set to Unnumbered Adjacency with IPv4 NodeIDs and F bit is disabled.
			x	-local_node_id_step
			x		Step argument of Local Node ID.
			x	-local_interface_id
			x		This is the Local Interface ID of the Unnumbered Adjacency with IPv4 NodeIDs which is specified as a pair of Node ID / Interface ID tuples.
			x		This Control can be configured if NAI Type is set to Unnumbered Adjacency with IPv4 NodeIDs and F bit is disabled.
			x	-remote_node_id
			x		This is the Remote Node ID of the Unnumbered Adjacency with IPv4 NodeIDs which is specified as a pair of Node ID / Interface ID tuples.
			x		This Control can be configured if NAI Type is set to Unnumbered Adjacency with IPv4 NodeIDs and F bit is disabled.
			x	-remote_node_id_step
			x		Step argument of Remote Node ID.
			x	-remote_interface_id
			x		This is the Remote Interface ID of the Unnumbered Adjacency with IPv4 NodeIDs which is specified as a pair of Node ID / Interface ID tuples.
			x		This Control can be configured if NAI Type is set to Unnumbered Adjacency with IPv4 NodeIDs and F bit is disabled.
			x	-pcep_metric_sub_objects_list_active
			x		Specifies whether the corresponding metric object is active or not.
			x	-metric_type
			x		This is a drop down which has 4 choices:IGP/ TE/ Hop count/ MSD.
			x		Valid choices are:
			x   		igp - IGP.
			x   		tg - TE.
			x   		hopcount - Hop Count.
			x   		msd - MSD.
			x	-metric_value
			x		User can specify the metric value corresponding to the metric type selected.
			x	-b_flag
			x		B (bound) flag MUST be set in the METRIC object, which specifies that the SID depth for the computed path MUST NOT exceed the metric-value.
			x	-response_options
			x		Reply Options
			x		Valid choices are:
			x   		crep - PCReply.
			x   		crepwithnopath - PCReply with NO-PATH.
			x	-response_path_type
			x		Indicates which type of LSP will be responsed in the Path Request Response.
			x		Valid choices are:
			x   		sr - SR-TE.
			x   		rsvpte - RSVP-TE.
			x	-include_rp
			x		Include RP
			x	-pc_reply_include_lsp
			x		Include LSP
			x	-enable_ero
			x		Include ERO
			x	-pc_reply_include_metric
			x		Include Metric
			x	-pc_reply_include_bandwidth
			x		Include Bandwidth
			x	-pc_reply_include_lspa
			x		Include LSPA
			x	-enable_xro
			x		Include XRO
			x	-process_type
			x		Indicates how the XRO is responded in the Path Request Response.
			x		Valid choices are:
			x   		configure - Configure XRO.
			x   		reflect - Reflect XRO.
			x	-reflect_r_p
			x		Reflect RP
			x	-request_id
			x		Request ID
			x	-enable_loose
			x		Loose
			x	-bi_directional
			x		Bi-directional
			x	-priority_value
			x		Priority
			x	-pc_reply_number_of_ero_sub_objects
			x		Number of ERO Sub Objects
			x	-pc_reply_number_of_metric_sub_object
			x		Number of Metric
			x	-pc_reply_bandwidth
			x		Bandwidth (bits/sec)
			x	-reflect_l_s_p
			x		Reflect LSP
			x	-pc_reply_plsp_id
			x		An identifier for the LSP. A PCC creates a unique PLSP-ID for each LSP that is constant for the lifetime of a PCEP session. The PCC will advertise the same PLSP-ID on all PCEP sessions it maintains at a given time.
			x	-pc_reply_include_symbolic_path_name_tlv
			x		Indicates if Symbolic-Path-Name TLV is to be included in PCInitiate message.
			x	-pc_reply_symbolic_path_name
			x		Each LSP (path) must have a symbolic name that is unique in the PCC. It must remain constant throughout a path's lifetime, which may span across multiple consecutive PCEP sessions and/or PCC restarts.
			x	-pc_reply_include_t_e_path_binding_t_l_v
			x		Indicates if TE-PATH-BINDING TLV is to be included in PCInitiate message.
			x	-pc_reply_send_empty_t_l_v
			x		If enabled all fields after Binding Type will be grayed out.
			x	-pc_reply_binding_type
			x		Indicates the type of binding included in the TLV. Types are as follows:
			x		20bit MPLS Label
			x		32bit MPLS Label.
			x		Default value is 20bit MPLS Label.
			x		Valid choices are:
			x   		mplslabel20bit - 0- MPLS Label 20 Bit.
			x   		mplslabel32bit - 1- MPLS Label 20 Bit.
			x	-pc_reply_mpls_label
			x		This control will be editable if the Binding Type is set to either 20bit or 32bit MPLS-Label. This field will take the 20bit value of the MPLS-Label
			x	-pc_reply_tc
			x		This field is used to carry traffic class information. This control will be editable only if Binding Type is MPLS Label 32bit.
			x	-pc_reply_bos
			x		This bit is set to True for the last entry in the label stack i.e., for the bottom of the stack, and False for all other label stack entries.
			x		This control will be editable only if Binding Type is MPLS Label 32bit.
			x	-pc_reply_ttl
			x		This field is used to encode a time-to-live value. This control will be editable only if Binding Type is MPLS Label 32bit.
			x	-pc_reply_setup_priority
			x		Setup Priority
			x	-pc_reply_holding_priority
			x		Holding Priority
			x	-pc_reply_local_protection
			x		Local Protection
			x	-pc_reply_include_any
			x		Include Any
			x	-pc_reply_include_all
			x		Include All
			x	-pc_reply_exclude_any
			x		Exclude Any
			x	-nature_of_issue
			x		Nature Of Issue
			x	-enable_c_flag
			x		C Flag
			x	-reflected_object_no_path
			x		Reflected Object
			x		Valid choices are:
			x   		elect_reflected_object - Select Reflected Object.
			x   		metric - Metric.
			x   		bandwidth - Bandwidth.
			x   		iro - IRO.
			x   		lspa - LSPA.
			x   		xro - XRO.
			x	-fail_bit
			x		Fail Bit
			x	-number_of_Xro_sub_objects
			x		Number of XRO Sub Objects
			x	-pc_reply_active
			x		Activate/Deactivate PCReply LSP Parameters
			x	-xro_active
			x		Activate/Deactivate XRO
			x	-exclude_bit
			x		Indicates whether the exclusion is mandatory or desired.
			x	-xro_attribute
			x		Indicates how the exclusion subobject is to be indicated.
			x		Valid choices are:
			x   		interface - 0 - Interface.
			x   		node - 1 - Node.
			x   		srlg - 2 - SRLG.
			x	-xro_sub_object_type
			x		Using the Sub Object Type control user can configure which sub object needs to be included from the following options: IPv4 Prefix, IPv6 Prefix, Unnumbered Interface ID, AS Number, SRLG.
			x		Valid choices are:
			x   		ipv4prefix - IPv4 Prefix.
			x   		ipv6prefix - IPv6 Prefix.
			x   		unnumberedinterfaceid - Unnumbered Interface ID.
			x   		asnumber - AS Number.
			x   		srlg - SRLG.
			x	-xro_prefix_length
			x		Prefix Length
			x	-xro_ipv4_address
			x		IPv4 Address
			x	-xro_ipv4_address_step
			x		Step argument of IPv4 Address
			x	-xro_ipv6_address
			x		IPv6 Address
			x	-xro_ipv6_address_step
			x		Step argument of IPv6 Address
			x	-xro_router_id
			x		Router ID
			x	-xro_router_id_step
			x		Step argument of Router ID
			x	-xro_interface_id
			x		Interface ID
			x	-xro_as_number
			x		AS Number
			x	-srlg_id
			x		SRLG ID
			x	-pce_id32
			x		32 bit PKS ID
			x	-pce_id128
			x		128 bit PKS ID
			x	-pc_request_ip_version
			x		IP Version
			x		Valid choices are:
			x   		ipv4 - IPv4.
			x   		ipv6 - IPv6.
			x	-src_ipv4_address
			x		Source IPv4 Address
			x	-src_ipv4_address_step
			x		Step argument of Source IPv4 Address
			x	-dest_ipv4_address
			x		Destination IPv4 Address
			x	-dest_ipv4_address_step
			x		Step argument of Destination IPv4 Address
			x	-src_ipv6_address
			x		Source IPv6 Address
			x	-src_ipv6_address_step
			x		Step argument of Source IPv6 Address
			x	-dest_ipv6_address
			x		Destination IPv6 Address
			x	-dest_ipv6_address_step
			x		Step argument of Destination IPv6 Address
			x	-pc_request_active
			x		Activate/Deactivate PCRequest Match Criteria
			x	-learned_info_update_item
			x		Number that indicates which learnedInfoUpdate item needs to be configured.
			x	-trigger_number_of_ero_sub_objects
			x		Value that indicates the number of ERO Sub Objects to be configured.
			x	-trigger_number_of_metric_sub_objects
			x		Value that indicates the number of Metric Objects to be configured.
			x	-pce_triggers_choice_list
			x		Based on options selected, IxNetwork sends information to PCPU and refreshes the statistical data in the corresponding tab of Learned Information
			x		Valid choices are:
			x   		sendupdate - Send PCUpdate
			x	-trigger_include_srp
			x		Indicates whether SRP object will be included in a PCInitiate message. All other attributes in sub-tab-SRP would be editable only if this checkbox is enabled.
			x	-trigger_configure_lsp
			x		Configure LSP
			x		Valid choices are:
			x   		dontinclude - Don't Include Learned Object As Trigger Param
			x   		reflect - Reflect The Learned Object As Trigger Param
			x   		modify - Modify Learned Object As Trigger Param
			x	-trigger_configure_ero
			x		Configure ERO
			x		Valid choices are:
			x   		dontinclude - Don't Include Learned Object As Trigger Param
			x   		reflect - Reflect The Learned Object As Trigger Param
			x   		modify - Modify Learned Object As Trigger Param
			x	-trigger_configure_lspa
			x		Configure LSPA
			x		Valid choices are:
			x   		dontinclude - Don't Include Learned Object As Trigger Param
			x   		reflect - Reflect The Learned Object As Trigger Param
			x   		modify - Modify Learned Object As Trigger Param
			x	-trigger_configure_bandwidth
			x		Configure Bandwidth
			x		Valid choices are:
			x   		dontinclude - Don't Include Learned Object As Trigger Param
			x   		reflect - Reflect The Learned Object As Trigger Param
			x   		modify - Modify Learned Object As Trigger Param
			x	-trigger_configure_metric
			x		Configure Metric
			x		Valid choices are:
			x   		dontinclude - Don't Include Learned Object As Trigger Param
			x   		reflect - Reflect The Learned Object As Trigger Param
			x   		modify - Modify Learned Object As Trigger Param
			x	-trigger_override_srp_id
			x		Indicates whether SRP object will be included in a PCUpdate trigger parameters. All other attributes in sub-tab-SRP would be editable only if this checkbox is enabled.
			x	-trigger_srp_id
			x		The SRP object is used to correlate between initiation requests sent by the PCE and the error reports and state reports sent by the PCC. This number is unique per PCEP session and is incremented per initiation.
			x	-trigger_include_symbolic_path_name
			x		Indicates if Symbolic-Path-Name TLV is to be included in PCUpate trigger message.
			x	-trigger_include_t_e_path_binding_t_l_v
			x		Indicates if TE-PATH-BINDING TLV is to be included in PCUpate trigger message.
			x	-trigger_send_empty_t_l_v
			x		If enabled all fields after Binding Type will be grayed out.
			x	-trigger_binding_type
			x		Indicates the type of binding included in the TLV. Types are as follows:
			x		20bit MPLS Label
			x		32bit MPLS Label.
			x		Default value is 20bit MPLS Label.
			x		Valid choices are:
			x   		mplslabel20bit - 0-MPLS Label 20 Bit
			x   		mplslabel32bit - 1-MPLS Label 32 Bit
			x	-trigger_mpls_label
			x		This control will be editable if the Binding Type is set to either 20bit or 32bit MPLS-Label. This field will take the 20bit value of the MPLS-Label
			x	-trigger_tc
			x		This field is used to carry traffic class information. This control will be editable only if Binding Type is MPLS Label 32bit.
			x	-trigger_bos
			x		This bit is set to True for the last entry in the label stack i.e., for the bottom of the stack, and False for all other label stack entries.
			x		This control will be editable only if Binding Type is MPLS Label 32bit.
			x	-trigger_ttl
			x		This field is used to encode a time-to-live value. This control will be editable only if Binding Type is MPLS Label 32bit.
			x	-trigger_bandwidth
			x		Bandwidth (bps)
			x	-trigger_setup_priority
			x		Setup Priority
			x	-trigger_holding_priority
			x		Holding Priority
			x	-trigger_local_protection
			x		Local Protection
			x	-trigger_include_any
			x		Include Any
			x	-trigger_include_all
			x		Include All
			x	-trigger_exclude_any
			x		Exclude Any
			x	-trigger_rsvp_active_this_ero
			x		Controls whether the ERO sub-object will be sent in the PCInitiate message.
			x	-trigger_rsvp_loose_hop
			x		Indicates if user wants to represent a loose-hop sub object in the LSP
			x	-trigger_rsvp_sub_object_type
			x		Using the Sub Object Type control user can configure which sub object needs to be included from the following options:
			x		Not Applicable
			x		IPv4 Prefix
			x		IPv6 Prefix
			x		AS Number.
			x		Valid choices are:
			x   		null - Not Applicable
			x   		ipv4prefix - IPv4 Prefix
			x   		ipv6prefix - IPv6 Prefix
			x   		asnumber - AS Number
			x	-trigger_rsvp_prefix_length
			x		Prefix Length
			x	-trigger_rsvp_ipv4_prefix
			x		IPv4 Prefix is specified as an IPv4 address.
			x	-trigger_rsvp_ipv4_prefix_step
			x		Step argument for IPv4 Prefix Address
			x	-trigger_rsvp_ipv6_prefix
			x		IPv6 Prefix is specified as an IPv6 address.
			x	-trigger_rsvp_ipv6_prefix_step
			x		Step argument for IPv6 Prefix Address
			x	-trigger_rsvp_as_number
			x		AS Number
			x	-trigger_rsvp_metric_type
			x		This is a drop down which has 4 choices:IGP/ TE/ Hop count/ MSD.
			x		Valid choices are:
			x   		igp - IGP
			x   		tg - TE
			x   		hopcount - Hop Count
			x	-trigger_rsvp_active_this_metric
			x		Specifies whether the corresponding metric object is active or not.
			x	-trigger_rsvp_metric_value
			x		User can specify the metric value corresponding to the metric type selected.
			x	-trigger_rsvp_b_flag
			x		B (bound) flag MUST be set in the METRIC object, which specifies that the SID depth for the computed path MUST NOT exceed the metric-value.
			x	-trigger_sr_active_this_ero
			x		Controls whether the ERO sub-object will be sent in the PCInitiate message.
			x	-trigger_sr_loose_hop
			x		Indicates if user wants to represent a loose-hop sub object in the LSP
			x	-trigger_sr_sid_type
			x		Using the Segment Identifier Type control user can configure whether to include SID or not and if included what is its type. Types are as follows:
			x		Null
			x		SID
			x		20bit MPLS Label
			x		32bit MPLS Label.
			x		If it is Null then S bit is set in the packet. Default value is 20bit MPLS Label.
			x		Valid choices are:
			x   		null - Null
			x   		sid - SID
			x   		mplslabel20bit - MPLS Label 20 Bit
			x   		mplslabel32bit - MPLS Label 32 Bit
			x	-trigger_sr_sid
			x		SIDis the Segment Identifier
			x	-trigger_sr_mpls_label
			x		This control will be editable if the SID Type is set to either 20bit or 32bit MPLS-Label. This field will take the 20bit value of the MPLS-Label
			x	-trigger_sr_mpls_label32
			x		MPLS Label 32 Bit
			x	-trigger_sr_tc
			x		This field is used to carry traffic class information. This control will be editable only if SID Type is MPLS Label 32bit.
			x	-trigger_sr_bos
			x		This bit is set to true for the last entry in the label stack i.e., for the bottom of the stack, and false for all other label stack entries.
			x		This control will be editable only if SID Type is MPLS Label 32bit.
			x	-trigger_sr_ttl
			x		This field is used to encode a time-to-live value. This control will be editable only if SID Type is MPLS Label 32bit.
			x	-trigger_sr_nai_type
			x		NAI (Node or Adjacency Identifier) contains the NAI associated with the SID. Depending on the value of SID Type, the NAI can have different formats such as,
			x		Not Applicable
			x		IPv4 Node ID
			x		IPv6 Node ID
			x		IPv4 Adjacency
			x		IPv6 Adjacency
			x		Unnumbered Adjacency with IPv4 NodeIDs
			x		Valid choices are:
			x   		notapplicable - Not Applicable
			x   		ipv4nodeid - IPv4 Node ID
			x   		ipv6nodeid - IPv6 Node ID
			x   		ipv4adjacency - IPv4 Adjacency
			x   		ipv6adjacency - IPv6 Adjacency
			x   		unnumberedadjacencywithipv4nodeids - Unnumbered Adjacency with IPv4 NodeIDs
			x	-trigger_sr_f_bit
			x		A Flag which is used to carry additional information pertaining to SID. When this bit is set, the NAI value in the subobject body is null.
			x	-trigger_sr_ipv4_node_id
			x		IPv4 Node ID is specified as an IPv4 address. This control can be configured if NAI Type is set to IPv4 Node ID and F bit is disabled.
			x	-trigger_sr_ipv4_node_id_step
			x		Step Argument of IPv4 Node ID.
			x	-trigger_sr_ipv6_node_id
			x		IPv6 Node ID is specified as an IPv6 address. This control can be configured if NAI Type is set to IPv6 Node ID and F bit is disabled.
			x	-trigger_sr_ipv6_node_id_step
			x		Step Argument of IPv6 Node ID.
			x	-trigger_sr_local_ipv4_address
			x		This Control can be configured if NAI Type is set to IPv4 Adjacency and F bit is disabled.
			x	-trigger_sr_local_ipv4_address_step
			x		Step Argument of Local Ipv4 Address.
			x	-trigger_sr_remote_ipv4_address
			x		This Control can be configured if NAI Type is set to IPv4 Adjacency and F bit is disabled.
			x	-trigger_sr_remote_ipv4_address_step
			x		Step Argument of Remote Ipv4 Address.
			x	-trigger_sr_local_ipv6_address
			x		This Control can be configured if NAI Type is set to IPv6 Adjacency and F bit is disabled.
			x	-trigger_sr_local_ipv6_address_step
			x		Step Argument of Local Ipv6 Address.
			x	-trigger_sr_remote_ipv6_address
			x		This Control can be configured if NAI Type is set to IPv6 Adjacency and F bit is disabled.
			x	-trigger_sr_remote_ipv6_address_step
			x		Step Argument of Remote Ipv6 Address.
			x	-trigger_sr_local_node_id
			x		This is the Local Node ID of the Unnumbered Adjacency with IPv4 NodeIDs which is specified as a pair of Node ID / Interface ID tuples.
			x		This Control can be configured if NAI Type is set to Unnumbered Adjacency with IPv4 NodeIDs and F bit is disabled.
			x	-trigger_sr_local_node_id_step
			x		Step Argument of Local Node Id.
			x	-trigger_sr_local_interface_id
			x		This is the Local Interface ID of the Unnumbered Adjacency with IPv4 NodeIDs which is specified as a pair of Node ID / Interface ID tuples.
			x		This Control can be configured if NAI Type is set to Unnumbered Adjacency with IPv4 NodeIDs and F bit is disabled.
			x	-trigger_sr_remote_node_id
			x		This is the Remote Node ID of the Unnumbered Adjacency with IPv4 NodeIDs which is specified as a pair of Node ID / Interface ID tuples.
			x		This Control can be configured if NAI Type is set to Unnumbered Adjacency with IPv4 NodeIDs and F bit is disabled.
			x	-trigger_sr_remote_node_id_step
			x		Step Argument of Remote Node Id.
			x	-trigger_sr_remote_interface_id
			x		This is the Remote Interface ID of the Unnumbered Adjacency with IPv4 NodeIDs which is specified as a pair of Node ID / Interface ID tuples.
			x		This Control can be configured if NAI Type is set to Unnumbered Adjacency with IPv4 NodeIDs and F bit is disabled.
			x	-trigger_sr_metric_type
			x		This is a drop down which has 4 choices:IGP/ TE/ Hop count/ MSD.
			x		Valid choices are:
			x   		igp - IGP
			x   		tg - TE
			x   		hopcount - Hop Count
			x   		msd - MSD
			x	-trigger_sr_active_this_metric
			x		Specifies whether the corresponding metric object is active or not.
			x	-trigger_sr_metric_value
			x		User can specify the metric value corresponding to the metric type selected.
			x	-trigger_sr_b_flag
			x		B (bound) flag MUST be set in the METRIC object, which specifies that the SID depth for the computed path MUST NOT exceed the metric-value.
		
		Return Values:
		A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
			xkey:ipv4_loopback_handle                             value:A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
		A list containing the ipv4 protocol stack handles that were added by the command (if any).
			xkey:ipv4_handle                                      value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE
			 key:status                                           value:$::SUCCESS | $::FAILURE
		When status is $::FAILURE, log shows the detailed information of failure.
			 key:log                                              value:When status is $::FAILURE, log shows the detailed information of failure.
		Handle of PCE configured
			 key:pce_handle                                       value:Handle of PCE configured
		Handle of PccGroup configured
			 key:pcc_group_handle                                 value:Handle of PccGroup configured
		Handle of PCE Initiated LSP Parameters configured
			 key:pce_initiate_lsp_parameters_handle               value:Handle of PCE Initiated LSP Parameters configured
		Handle of PCReply LSP Parameters configured
			 key:pc_reply_lsp_parameters_handle                   value:Handle of PCReply LSP Parameters configured
		Handle of PCRequest Match Criteria configured
			 key:pc_request_match_criteria_handle                 value:Handle of PCRequest Match Criteria configured
		Handle of Detailed SR Learned Info Update configured
			 key:pce_detailed_sr_sync_lsp_update_params_handle    value:Handle of Detailed SR Learned Info Update configured
		Handle of Basic SR Learned Info Update configured
			 key:pce_basic_sr_sync_lsp_update_params_handle       value:Handle of Basic SR Learned Info Update configured
		Handle of Detailed RSVP Learned Info Update configured
			 key:pce_detailed_rsvp_sync_lsp_update_params_handle  value:Handle of Detailed RSVP Learned Info Update configured
		Handle of Basic RSVP Learned Info Update configured
			 key:pce_basic_rsvp_sync_lsp_update_params_handle     value:Handle of Basic RSVP Learned Info Update configured
		Handle of Learned Info Update
			 key:learned_info_update_handle                       value:Handle of Learned Info Update
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_pce_config", kwargs)

	def emulation_pce_control(self, **kwargs):
		""" This procedure performs control actions like start, stop or restart on PCE and PCC Group and does some right click actions on different type of LSPs.     The following operations are done:     1. Start     2. Stop     3. Restart     4. Restart Down     5. Abort
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_pce_control
			 	-mode                 CHOICES restart
			                       CHOICES start
			                       CHOICES restart_down
			                       CHOICES stop
			                       CHOICES abort
			                       CHOICES take_control
			                       CHOICES return_delegation
			                       CHOICES send_pc_update]
			 	[-handle              ANY]
			x	[-pc_update_indexlist ALPHA]
		
		Arguments:
			 	-mode
			 		What is being done to the protocol.Valid choices are:
			 		restart- Restart the protocol.
			 		start- Start the protocol.
			 		stop- Stop the protocol.
			 		restart_down- Restart the down sessions.
			 		abort- Abort the protocol.
			 		take_control- Take Control of PCE-Initiated LSPs.
			 		return_delegation- Return Delegation of PCE-Initiated or PCE-Replied LSPs.
			 		send_pc_update- SendPcUpdate for Learned Info Trigger Parameters.
			 		Valid choices are:
			    		restart - Restart the protocol.
			    		start - Start the protocol.
			    		restart_down - restart the down sessions
			    		stop - Stop the protocol.
			    		abort - Abort.
			    		take_control - Take Control of PCE-Initiated LSPs.
			    		return_delegation - Return Delegation of PCE-Initiated or PCE-Replied LSPs.
			    		send_pc_update - SendPcUpdate for Learned Info Trigger Parameters.
			 	-handle
			 		This option represents the handle the user *must* pass to the
			 		"emulation_pce_control" procedure. This option specifies
			 		on which PCEP session to control.
			x	-pc_update_indexlist
			x		Index list for Send PCUpdate action.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		For mode choices restart, start, restart_down, stop and abort, PCE/PCC Group handle needs to be provided.
		For take_control and return_delegation, node handle of corresponding LSP type needs to be provided.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_pce_control", kwargs)

	def emulation_pce_info(self, **kwargs):
		""" This procedure retrieves information about the PCEP sessions.      This procedure is also used to fetch stats, learned information and configured properties of PCE, depending on the given mode and handle.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_pce_info
			x	-mode                         CHOICES per_port_stats
			x                              CHOICES per_session_stats
			x                              CHOICES per_device_group_stats
			x                              CHOICES clear_stats
			x                              CHOICES fetch_info
			x                              CHOICES learned_info_sr_basic_pce_initiated
			x                              CHOICES learned_info_sr_basic_pcc_requested
			x                              CHOICES learned_info_sr_basic_pcc_sync
			x                              CHOICES learned_info_sr_basic_all
			x                              CHOICES learned_info_rsvp_basic_pce_initiated
			x                              CHOICES learned_info_rsvp_basic_pcc_requested
			x                              CHOICES learned_info_rsvp_basic_pcc_sync
			x                              CHOICES learned_info_rsvp_basic_all
			x                              CHOICES learned_info_sr_detailed_pce_initiated
			x                              CHOICES learned_info_sr_detailed_pcc_requested
			x                              CHOICES learned_info_sr_detailed_pcc_sync
			x                              CHOICES learned_info_sr_detailed_all
			x                              CHOICES learned_info_rsvp_detailed_pce_initiated
			x                              CHOICES learned_info_rsvp_detailed_pcc_requested
			x                              CHOICES learned_info_rsvp_detailed_pcc_sync
			x                              CHOICES learned_info_rsvp_detailed_all
			x                              CHOICES clear_learned_info]
			 	-handle                       ANY]
			 	[-port_handle                 REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-lsp_state                   FLAG]
			x	[-received_plsp_id            FLAG]
			x	[-received_symbolic_path_name FLAG]
		
		Arguments:
			x	-mode
			x		For fetching per_port_stats provide any PCE handle, for per_session_stats and per_device_group_stats provide a PCE handle which is on the corresponding port.
			x		For fetching learned information, PCE handle needs to be given.
			x		Forfetch_info, provide handle of the node/object from which you need to fetch a property.
			x		Valid choices are:
			x   		per_port_stats - Retrieves PCEP PCE per port stats.
			x   		per_session_stats - Retrieves PCEP PCE per session stats.
			x   		per_device_group_stats - Retrieves PCEP PCE per device group stats.
			x   		clear_stats - Clear PCEP PCE statistics.
			x   		fetch_info - Get PCEP PCE Info.
			x   		learned_info_sr_basic_pce_initiated - Get SR-TE PCE Initiated LSP Basic Learned Information
			x   		learned_info_sr_basic_pcc_requested - Get SR-TE PCC Requested LSP Basic Learned Information
			x   		learned_info_sr_basic_pcc_sync - Get SR-TE PCC Sync/Report LSP Basic Learned Information
			x   		learned_info_sr_basic_all - Get SR-TE All LSPs Basic Learned Information
			x   		learned_info_rsvp_basic_pce_initiated - Get RSVP-TE PCE Initiated LSP Basic Learned Information
			x   		learned_info_rsvp_basic_pcc_requested - Get RSVP-TE PCC Requested LSP Basic Learned Information
			x   		learned_info_rsvp_basic_pcc_sync - Get RSVP-TE PCC Sync/Report LSP Basic Learned Information
			x   		learned_info_rsvp_basic_all - Get RSVP-TE All LSPs Basic Learned Information
			x   		learned_info_sr_detailed_pce_initiated - Get SR-TE PCE Initiated LSP Detailed Learned Information
			x   		learned_info_sr_detailed_pcc_requested - Get SR-TE PCC Requested LSP Detailed Learned Information
			x   		learned_info_sr_detailed_pcc_sync - Get SR-TE PCC Sync/Report LSP Detailed Learned Information
			x   		learned_info_sr_detailed_all - Get SR-TE All LSPs Detailed Learned Information
			x   		learned_info_rsvp_detailed_pce_initiated - Get RSVP-TE PCE Initiated LSP Detailed Learned Information
			x   		learned_info_rsvp_detailed_pcc_requested - Get RSVP-TE PCC Requested LSP Detailed Learned Information
			x   		learned_info_rsvp_detailed_pcc_sync - Get RSVP-TE PCC Sync/Report LSP Detailed Learned Information
			x   		learned_info_rsvp_detailed_all - Get RSVP-TE All LSPs Detailed Learned Information
			x   		clear_learned_info - Clear PCEP PCE Learned Information
			 	-handle
			 		The PCEP PCE handle to act upon.
			 	-port_handle
			 		Port handle.
			x	-lsp_state
			x		Get LSP State. Mandatory flag for fetching LSP State of PCEInitiated LSP Parameters.
			x	-received_plsp_id
			x		Get Received PLSP-ID. Mandatory flag for fetching Received PLSP-ID of PCReply LSP Parameters.
			x	-received_symbolic_path_name
			x		Get Received Symbolic Path Name. Mandatory flag for fetching Received Symbolic Path Name of PCReply LSP Parameters.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                                   value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                                                                      value:If status is failure, detailed information provided.
		Sessions Up
			xkey:sessions_up                                                              value:Sessions Up
		Sessions Down
			xkey:sessions_down                                                            value:Sessions Down
		Sessions Not Started
			xkey:sessions_not_started                                                     value:Sessions Not Started
		Sessions Total
			xkey:sessions_total                                                           value:Sessions Total
		Session Flap Count
			xkey:session_flap_count                                                       value:Session Flap Count
		Open Message Rx
			xkey:open_message_rx                                                          value:Open Message Rx
		Open Message Tx
			xkey:open_message_tx                                                          value:Open Message Tx
		Keepalive Message Rx
			xkey:keepalive_message_rx                                                     value:Keepalive Message Rx
		Keepalive Message Tx
			xkey:keepalive_message_tx                                                     value:Keepalive Message Tx
		Close Message Rx
			xkey:close_message_rx                                                         value:Close Message Rx
		Close Message Tx
			xkey:close_message_tx                                                         value:Close Message Tx
		Unknown Message Rx
			xkey:unknown_message_rx                                                       value:Unknown Message Rx
		Total TCP Connection Request Received
			xkey:total_tcp_connection_request_received                                    value:Total TCP Connection Request Received
		PCInitiate Message Tx
			xkey:pcinitiate_message_tx                                                    value:PCInitiate Message Tx
		Remove Initiated LSP Tx
			xkey:remove_initiated_lsp_tx                                                  value:Remove Initiated LSP Tx
		PCRpt Message Rx
			xkey:pcrpt_message_rx                                                         value:PCRpt Message Rx
		PCUpdate Message Tx
			xkey:pcupdate_message_tx                                                      value:PCUpdate Message Tx
		PCErr Message Rx
			xkey:pcerr_message_rx                                                         value:PCErr Message Rx
		PCErr Message Tx
			xkey:pcerr_message_tx                                                         value:PCErr Message Tx
		Total Initiated LSP Tx
			xkey:total_initiated_lsp_tx                                                   value:Total Initiated LSP Tx
		Total Delegated LSP
			xkey:total_delegated_lsp                                                      value:Total Delegated LSP
		PCReq Message Rx
			xkey:pcreq_message_rx                                                         value:PCReq Message Rx
		PCRep Message Tx
			xkey:pcrep_message_tx                                                         value:PCRep Message Tx
		No Path Tx
			xkey:no_path_tx                                                               value:No Path Tx
		Total Requested LSP Rx
			xkey:total_requested_lsp_rx                                                   value:Total Requested LSP Rx
		Total Responded LSP Tx
			xkey:total_responded_lsp_tx                                                   value:Total Responded LSP Tx
		Sync LSP Rx
			xkey:sync_lsp_rx                                                              value:Sync LSP Rx
		PCC IP
			xkey:<handle>.pcebasiclearnedinformation.learned_pcc_ip_address               value:PCC IP
		LSP Type
			xkey:<handle>.pcebasiclearnedinformation.learned_lsp_type                     value:LSP Type
		Symbolic Path Name
			xkey:<handle>.pcebasiclearnedinformation.learned_symbolic_path_name           value:Symbolic Path Name
		PLSP-ID
			xkey:<handle>.pcebasiclearnedinformation.learned_plsp_id                      value:PLSP-ID
		Operational State
			xkey:<handle>.pcebasiclearnedinformation.learned_operational_state            value:Operational State
		Delegation State
			xkey:<handle>.pcebasiclearnedinformation.learned_delegation_state             value:Delegation State
		RRO Info
			xkey:<handle>.pcebasiclearnedinformation.learned_rro_info                     value:RRO Info
		Error Info
			xkey:<handle>.pcebasiclearnedinformation.learned_error_info                   value:Error Info
		Triggers
			xkey:<handle>.pcebasiclearnedinformation.pce_triggers_choice_list             value:Triggers
		Tunnel ID
			xkey:<handle>.pcersvpbasiclearnedinformation.learned_tunnel_id                value:Tunnel ID
		RSVP LSP ID
			xkey:<handle>.pcersvpbasiclearnedinformation.learned_rsvp_lsp_id              value:RSVP LSP ID
		Symbolic Path Name
			xkey:<handle>.pcedetailedlearnedinformation.learned_symbolic_path_name        value:Symbolic Path Name
		IPv4 Source Endpoint
			xkey:<handle>.pcedetailedlearnedinformation.learned_ipv4_tunnel_src_addr      value:IPv4 Source Endpoint
		IPv4 Destination Endpoint
			xkey:<handle>.pcedetailedlearnedinformation.learned_ipv4_tunnel_dest_addr     value:IPv4 Destination Endpoint
		IPv6 Source Endpoint
			xkey:<handle>.pcedetailedlearnedinformation.learned_ipv6_tunnel_src_addr      value:IPv6 Source Endpoint
		IPv6 Destination Endpoint
			xkey:<handle>.pcedetailedlearnedinformation.learned_ipv6_tunnel_dest_addr     value:IPv6 Destination Endpoint
		Actual Bandwidth(Bps)
			xkey:<handle>.pcedetailedlearnedinformation.learned_actual_bandwidth          value:Actual Bandwidth(Bps)
		Holding Priority
			xkey:<handle>.pcedetailedlearnedinformation.learned_holding_priority          value:Holding Priority
		Setup Priority
			xkey:<handle>.pcedetailedlearnedinformation.learned_setup_priority            value:Setup Priority
		Actual Metric Type
			xkey:<handle>.pcedetailedlearnedinformation.learned_actual_metric_type        value:Actual Metric Type
		Actual Metric Value
			xkey:<handle>.pcedetailedlearnedinformation.learned_actual_metric_value       value:Actual Metric Value
		RRO SID Type
			xkey:<handle>.pcesrdetailedlearnedinformation.learned_rro_sid_type            value:RRO SID Type
		RRO SID Value
			xkey:<handle>.pcesrdetailedlearnedinformation.learned_rro_sid_value           value:RRO SID Value
		RRO NAI Type
			xkey:<handle>.pcesrdetailedlearnedinformation.learned_rro_nai_type            value:RRO NAI Type
		RRO NAI Value
			xkey:<handle>.pcesrdetailedlearnedinformation.learned_rro_nai_value           value:RRO NAI Value
		RRO Sub-Object Type
			xkey:<handle>.pcersvpdetailedlearnedinformation.learned_rro_sub_object_type   value:RRO Sub-Object Type
		RRO Sub-Object Value
			xkey:<handle>.pcersvpdetailedlearnedinformation.learned_rro_sub_object_value  value:RRO Sub-Object Value
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_pce_info", kwargs)

	def emulation_pim_config(self, **kwargs):
		""" This procedure will configure PIM SM interface.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_pim_config
			 	[-port_handle                ANY]
			 	-mode                        CHOICES create
			                              CHOICES modify
			                              CHOICES delete
			                              CHOICES disable
			                              CHOICES enable
			                              DEFAULT create
			 	[-handle                     ANY]
			x	[-interface_handle           ANY]
			x	[-return_detailed_handles    CHOICES 0 1
			x                             DEFAULT 0]
			 	[-pim_mode                   CHOICES sm ssm
			                              DEFAULT sm]
			 	[-type                       CHOICES remote_rp]
			 	-ip_version                  CHOICES 4 6
			                              DEFAULT 4]
			x	[-bootstrap_enable           CHOICES 0 1
			x                             DEFAULT 0]
			x	[-bootstrap_support_unicast  CHOICES 0 1
			x                             DEFAULT 1]
			x	[-bootstrap_hash_mask_len    RANGE 0-128]
			x	[-bootstrap_interval         RANGE 0-65535
			x                             DEFAULT 60]
			x	[-bootstrap_priority         RANGE 0-255
			x                             DEFAULT 64]
			x	[-bootstrap_timeout          RANGE 0-65535
			x                             DEFAULT 130]
			 	[-count                      NUMERIC
			                              DEFAULT 1]
			 	[-intf_ip_addr               IP]
			 	[-intf_ip_addr_step          IP
			                              DEFAULT 0.0.1.0]
			x	[-intf_ip_prefix_length      RANGE 1-128]
			 	[-intf_ip_prefix_len         RANGE 1-128]
			 	[-learn_selected_rp_set      CHOICES 0 1
			                              DEFAULT 1]
			 	[-discard_learnt_rp_info     CHOICES 0 1
			                              DEFAULT 0]
			 	[-router_id                  IP]
			 	[-router_id_step             IP]
			x	[-gateway_intf_ip_addr       IP]
			x	[-gateway_intf_ip_addr_step  IP]
			x	[-auto_pick_neighbor         CHOICES 0 1]
			 	[-neighbor_intf_ip_addr      IP]
			 	[-neighbor_intf_ip_addr_step IP]
			 	[-dr_priority                NUMERIC
			                              DEFAULT 0]
			 	[-bidir_capable              CHOICES 0 1
			                              DEFAULT 0]
			 	[-hello_interval             NUMERIC
			                              DEFAULT 30]
			 	[-hello_holdtime             NUMERIC
			                              DEFAULT 105]
			 	[-join_prune_interval        NUMERIC
			                              DEFAULT 60]
			 	[-join_prune_holdtime        NUMERIC
			                              DEFAULT 180]
			 	[-prune_delay_enable         CHOICES 0 1
			                              DEFAULT 0]
			 	[-prune_delay                RANGE 100-32767
			                              DEFAULT 500]
			 	[-override_interval          RANGE 100-65535
			                              DEFAULT 2500]
			 	[-vlan_id                    RANGE 0-4096]
			 	[-vlan_id_mode               CHOICES fixed increment
			                              DEFAULT increment]
			 	[-vlan_id_step               RANGE 0-4096
			                              DEFAULT 1]
			 	[-vlan_user_priority         RANGE 0-7
			                              DEFAULT 0]
			x	[-reset                      ANY]
			x	[-generation_id_mode         CHOICES increment random constant]
			x	[-prune_delay_tbit           CHOICES 0 1]
			x	[-send_generation_id         CHOICES 0 1]
			x	[-mac_address_init           MAC]
			x	[-mac_address_step           MAC
			x                             DEFAULT 0000.0000.0001]
			x	[-vlan                       CHOICES 0 1]
			x	[-interface_name             ALPHA]
			x	[-interface_active           CHOICES 0 1]
			x	[-triggered_hello_delay      NUMERIC
			x                             DEFAULT 5]
			x	[-disable_triggered_hello    CHOICES 0 1]
			x	[-force_semantic             CHOICES 0 1]
			x	[-router_active              CHOICES 0 1]
			x	[-router_name                ALPHA]
			x	[-join_prunes_count          RANGE 0-255
			x                             DEFAULT 0]
			x	[-sources_count              RANGE 0-255
			x                             DEFAULT 0]
			x	[-crp_ranges_count           RANGE 0-255
			x                             DEFAULT 0]
			x	[-bfd_registration           CHOICES 0 1
			x                             DEFAULT 0]
			x	[-writeFlag                  ANY]
			x	[-no_write                   ANY]
			n	[-gre                        ANY]
			x	[-gre_enable                 ANY]
			x	[-gre_unique                 ANY]
			x	[-gre_dst_ip_addr            ANY]
			x	[-gre_count                  ANY]
			x	[-gre_ip_addr                ANY]
			x	[-gre_ip_addr_step           ANY]
			x	[-gre_ip_addr_lstep          ANY]
			x	[-gre_ip_addr_cstep          ANY]
			x	[-gre_ip_prefix_length       ANY]
			x	[-gre_dst_ip_addr_step       ANY]
			x	[-gre_dst_ip_addr_lstep      ANY]
			x	[-gre_dst_ip_addr_cstep      ANY]
			x	[-gre_key_in_step            ANY]
			x	[-gre_key_out_step           ANY]
			x	[-gre_src_ip_addr_mode       ANY]
			x	[-gre_seq_enable             ANY]
			x	[-loopback_count             NUMERIC
			x                             DEFAULT 0]
			x	[-loopback_ip_address        IP]
			x	[-loopback_ip_address_step   IP]
			x	[-loopback_ip_address_cstep  ANY]
			n	[-vlan_cfi                   ANY]
			 	[-mvpn_enable                ANY]
			 	[-mvpn_pe_count              ANY]
			 	[-mvpn_pe_ip                 ANY]
			 	[-mvpn_pe_ip_incr            ANY]
			 	[-mvrf_count                 ANY]
			x	[-mvrf_unique                ANY]
			 	[-default_mdt_ip             ANY]
			 	[-default_mdt_ip_incr        ANY]
			 	[-gre_checksum_enable        ANY]
			 	[-gre_key_enable             ANY]
			 	[-gre_key_in                 ANY]
			 	[-gre_key_out                ANY]
			n	[-bs_period                  ANY]
			n	[-c_bsr_addr                 ANY]
			n	[-c_bsr_adv                  ANY]
			n	[-c_bsr_group_addr           ANY]
			n	[-c_bsr_group_admin          ANY]
			n	[-c_bsr_group_bidir          ANY]
			n	[-c_bsr_group_prefix_len     ANY]
			n	[-c_bsr_priority             ANY]
			n	[-c_bsr_rp_addr              ANY]
			n	[-c_bsr_rp_handle            ANY]
			n	[-c_bsr_rp_holdtime          ANY]
			n	[-c_bsr_rp_mode              ANY]
			n	[-c_bsr_rp_priority          ANY]
			n	[-c_rp_addr                  ANY]
			n	[-c_rp_adv                   ANY]
			n	[-c_rp_adv_holdtime          ANY]
			n	[-c_rp_adv_interval          ANY]
			n	[-c_rp_bsr_addr              ANY]
			n	[-c_rp_group_addr            ANY]
			n	[-c_rp_group_admin           ANY]
			n	[-c_rp_group_bidir           ANY]
			n	[-c_rp_group_handle          ANY]
			n	[-c_rp_group_mode            ANY]
			n	[-c_rp_group_prefix_len      ANY]
			n	[-c_rp_priority              ANY]
			n	[-hello_max_delay            ANY]
			n	[-keepalive_period           ANY]
			n	[-register_probe_time        ANY]
			n	[-register_suppression_time  ANY]
		
		Arguments:
			 	-port_handle
			 		The port on which the PIM-SM neighbor pair is to be created.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-mode
			 		This option defines the action to be taken.Limitations: for modify
			 		mode, the following options cannot be changed: router_id, dr_priority,
			 		join_prune_holdtime, and join_prune_interval. Valid options are:
			 		create (DEFAULT)
			 		modify
			 		delete
			 		disable
			 		enable
			 		Valid choices are:
			    		create -
			    		modify -
			    		delete -
			    		disable -
			    		enable -
			 	-handle
			 		PIM-SM handle if the option -mode is not create.
			x	-interface_handle
			x		A handle or list of the handles that are returned from the interface_config call.These provide a direct link to an already existing interface and supercede the use of the intf_ip_addr value.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-pim_mode
			 		Supports SM (sparse mode) and SSM (source spefic multicast).
			 		(DEFAULT = sm)
			 		Valid choices are:
			    		sm -
			    		ssm -
			 	-type
			 		Type of the PIM session router.Supports remote_rp type only.
			 		c_rp and c_bsr types are not supported.
			 		Valid choices are:
			    		remote_rp -
			 	-ip_version
			 		The IP version of the interface.Choices are:4, 6
			 		(DEFAULT = 4)
			 		Valid choices are:
			    		4 -
			    		6 -
			x	-bootstrap_enable
			x		If 1, enables the PIM-SM interface to participate in Bootstrap
			x		Router election procedure.
			x		Valid choices are:
			x		0 - disable
			x		1 - enable
			x		(DEFAULT = 0)
			x	-bootstrap_support_unicast
			x		If 1, enables support for unicast trasmission in Bootstrap procedure.
			x		Valid choices are:
			x		0 - disable
			x		1 - enable
			x		(DEFAULT = 1)
			x	-bootstrap_hash_mask_len
			x		Hash Mask Length of the Bootstrap Router (BSR) that is set with
			x		the same name in all Bootstrap Messages sent by this BSR.
			x	-bootstrap_interval
			x		The time interval (in seconds) between two consecutive bootstrap
			x		messages sent by the BSR.
			x		(DEFAULT = 60)
			x	-bootstrap_priority
			x		Priority of the Bootstrap Router (BSR) that is set with the same
			x		name in all Bootstrap Messages sent by this BSR.
			x		(DEFAULT = 64)
			x	-bootstrap_timeout
			x		Amount of time (in seconds) of not receiving any Bootstrap Messages,
			x		after which the BSR if candidate at that point of time will decide that
			x		the currently elected BSR has gone down and will restart BSR election procedure.
			x		(DEFAULT = 130)
			 	-count
			 		Number of PIM-SM sessions to create on the interface.
			 		If this parameter is 1 then the default behaviour of this function is to create a router
			 		and add the <interface_handle> interfaces to it. In this case the following parameters may be lists:
			 		interface_handle
			 		ip_version
			 		generation_id_mode
			 		hello_holdtime
			 		hello_interval
			 		prune_delay
			 		prune_delay_tbit
			 		override_interval
			 		bidir_capable
			 		send_generation_id
			 		prune_delay_enable
			 		neighbor_intf_ip_addr
			 		bootstrap_support_unicast
			 		bootstrap_enable
			 		bootstrap_hash_mask_len
			 		bootstrap_interval
			 		bootstrap_priority
			 		bootstrap_timeout
			 		(only IxTclNetwork api)
			 		(DEFAULT = 1)
			 	-intf_ip_addr
			 		The interface IP address.
			 	-intf_ip_addr_step
			 		The interface IP address octet to be incremented by given step.
			x	-intf_ip_prefix_length
			x		The prefix length on the interface (DEFAULT = 24).
			x		NOTE: This value is being maintained for backwards compatibility
			x		and shouldn't be used going forward.
			x		Please use the -intf_ip_prefix_len value.
			 	-intf_ip_prefix_len
			 		The prefix length on the interface.
			 		(DEFAULT = 24)
			 	-learn_selected_rp_set
			 		Enable learning of elected BSR and Candidate RPs.
			 		(DEFAULT = 1)
			 	-discard_learnt_rp_info
			 		Discard the learnt BSR and Candidate RP info.
			 		(DEFAULT = 0)
			 	-router_id
			 		The ID of the router in IPv4 format.
			 		(DEFAULT = 0.0.0.1)
			 	-router_id_step
			 		The value use to increment the router_id when count > 1.
			 		(DEFAULT = 0.0.0.1)
			x	-gateway_intf_ip_addr
			x		The gateway IP address of the port interface.
			x		(DEFAULT = 0.0.0.0)
			x	-gateway_intf_ip_addr_step
			x		The gateway IP address octet to be incremented by given step.
			x		(DEFAULT = 0.0.0.1)
			x	-auto_pick_neighbor
			x		Auto pick Neighbor
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-neighbor_intf_ip_addr
			 		The interface IP address of PIM-SM neighbor (next hop).
			 		(DEFAULT = 0.0.0.0)
			 	-neighbor_intf_ip_addr_step
			 		The interface IP address step for the PIM-SM neighbor.
			 		(DEFAULT = 0.0.0.0)
			 	-dr_priority
			 		The Designated Router (DR) priority assigned to this simulated router.
			 		(DEFAULT = 0)
			 	-bidir_capable
			 		If true (1), enable bi-directional PIM.
			 		(DEFAULT = 0)
			 	-hello_interval
			 		Hello interval in seconds.
			 		(DEFAULT = 30)
			 	-hello_holdtime
			 		The length of time, in seconds, between the transmission of Hello
			 		messages.
			 		(DEFAULT = 105)
			 	-join_prune_interval
			 		The length of time, in seconds, between transmission of Join/Prune
			 		messages.Also called t_periodic in RFCs.
			 		(DEFAULT = 60)
			 	-join_prune_holdtime
			 		The period, in seconds, during which a router receiving a Join/Prune
			 		must keep the state alive.The default is 3 times the Join/Prune
			 		interval.If this value is 65536 (0xffff), then the timeout is
			 		infinite and if this value isi 0, the timeout is immediate.
			 		(DEFAULT = 180)
			 	-prune_delay_enable
			 		If true (1), the LAN prune propagation delay is enabled for this
			 		interface.
			 		(DEFAULT = 0)
			 	-prune_delay
			 		The value, in milliseconds, of the LAN prune propagation delay for this
			 		interface.It indicates to an upstream router how long to wait for
			 		a Join override message before it prunes an interface.
			 		(DEFAULT = 500)
			 	-override_interval
			 		The delay interval, in milliseconds, for randomizing the transmission
			 		time for override messages, which are used when scheduling a delayed
			 		Join message.
			 		(DEFAULT = 2500)
			 	-vlan_id
			 		If VLAN is enable on the Ixia interface, this option will configure
			 		the VLAN number. RANGE 0-4095.
			 		(DEFAULT = 100)
			 	-vlan_id_mode
			 		If the user configures more than one interface on the Ixia with
			 		VLAN, he can choose to automatically increment the VLAN tag or
			 		leave it idle for each interface.
			 		(DEFAULT = increment)
			 		Valid choices are:
			    		fixed -
			    		increment -
			 	-vlan_id_step
			 		If the -vlan_id_mode is increment, this will be the step value by
			 		which the VLAN tags are incremented. RANGE 0-4095
			 		When vlan_id_step causes the vlan_id value to exceed it's maximum value the
			 		increment will be done modulo <number of possible vlan ids>.
			 		Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0
			 		vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			 		(DEFAULT = 1)
			 	-vlan_user_priority
			 		VLAN user priority assigned to emulated router node.RANGE 0-7
			 		(DEFAULT = 0)
			x	-reset
			x		If this option is present, all the Pim Interface and router in the given device group are
			x		deleted.
			x	-generation_id_mode
			x		The mode used for creating the 32-bit value for the Generation
			x		Identifier (GenID) option in Hello messages.Valid options are:
			x		increment
			x		random
			x		constant
			x		Valid choices are:
			x   		increment -
			x   		random -
			x   		constant -
			x	-prune_delay_tbit
			x		If true (1), the T flag bit in the LAN Prune Delay option of the
			x		Hello message is set (= 1). Setting this bit specifies that the
			x		sending PIM-SM router has the ability to disable Join message
			x		suppression.
			x	-send_generation_id
			x		If true (1), the generation ID is included in Hello messages.
			x	-mac_address_init
			x		The MAC address of the directly connected interface.
			x	-mac_address_step
			x		The incrementing step for the MAC address of the interface.
			x		Valid only when IxNetwork Tcl API is used.
			x		(DEFAULT = 0000.0000.0001)
			x	-vlan
			x		Enables vlan on the directly connected PIM router interface.
			x		Valid options are: 0 - disable, 1 - enable.
			x		This option is valid only when -mode is create or -mode is modify
			x		and -handle is a PIM router handle.
			x		This option is available only when IxNetwork tcl API is used.
			x		(DEFAULT = 0)
			x	-interface_name
			x		Name of Pim interface stack in the scenario.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-interface_active
			x		Flag.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-triggered_hello_delay
			x		Triggered Hello Delay (sec)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-disable_triggered_hello
			x		Disable Triggered
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-force_semantic
			x		Force Semantic
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-router_active
			x		Flag.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-router_name
			x		Name of Pim Router stack in the scenario.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-join_prunes_count
			x		Number of Join/Prunes
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-sources_count
			x		Number of Sources
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-crp_ranges_count
			x		Number of C-RP Ranges
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-bfd_registration
			x		Enable or disable BFD registration.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-writeFlag
			x		DEPRECATED - use -no_write instead.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-no_write
			x		If this option is present, the configuration is not written to the hardware. This option can be used to queue up multiple configurations before writing to the hardware.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			n	-gre
			x	-gre_enable
			x   	-gre_unique
			x       	-gre_dst_ip_addr
			x           	-gre_count
			x               	-gre_ip_addr
			x                   	-gre_ip_addr_step
			x                       	-gre_ip_addr_lstep
			x                           	-gre_ip_addr_cstep
			x                               	-gre_ip_prefix_length
			x                                   	-gre_dst_ip_addr_step
			x                                       	-gre_dst_ip_addr_lstep
			x                                           	-gre_dst_ip_addr_cstep
			x                                               	-gre_key_in_step
			x                                                   	-gre_key_out_step
			x                                                       	-gre_src_ip_addr_mode
			x                                                           	-gre_seq_enable
			x                                                               	-loopback_count
			x                                                                   		If this parameter is > 0 and gre_enable is '0' the router interfaces will be
			x                                                                   		the loopback protocol interfaces. The number of loopback interfaces will be
			x                                                                   		count * loopback_count.
			x                                                                   		Valid only when:
			x                                                                   		IxTclProtocols HLTSET and
			x                                                                   		loopback_count > 0 and
			x                                                                   		mode create and
			x                                                                   		mvpn_enable 0 and
			x                                                                   		interface_handle missing.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                               	-loopback_ip_address
			x                                                                   		Valid only when:
			x                                                                   		IxTclProtocols HLTSET and
			x                                                                   		loopback_count > 0 and
			x                                                                   		mode create and
			x                                                                   		mvpn_enable 0 and
			x                                                                   		interface_handle missing.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                               	-loopback_ip_address_step
			x                                                                   		The step used to increment the 'loopback_ip_address' when moving from one loopback
			x                                                                   		interface to the next.
			x                                                                   		Valid only when:
			x                                                                   		IxTclProtocols HLTSET and
			x                                                                   		loopback_count > 1 and
			x                                                                   		mode create and
			x                                                                   		mvpn_enable 0 and
			x                                                                   		interface_handle missing.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                               	-loopback_ip_address_cstep
			n                                                                   	-vlan_cfi
			                                                                        	-mvpn_enable
			                                                                            		Will enable the mVPN on the PIM router.
			                                                                            		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			                                                                        	-mvpn_pe_count
			                                                                            		Defines the number of mVPN PIM routers to create by the command.
			                                                                            		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			                                                                        	-mvpn_pe_ip
			                                                                            		Defines the IP address of the mVPN PIM router.Also defines the Router ID of the mVPN PIM Local Router and has to be consistent with the IGP protocol router ID. Note: The global PIM router ID shall take the interface IP address for Router ID.
			                                                                            		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			                                                                        	-mvpn_pe_ip_incr
			                                                                            		Defines the IP increment for the mVPN PIM router if multiples are being created.Also defines the Router ID increment of the mVPN PIM Local Router ID and has to be consistent with the IGP protocol router ID increment.
			                                                                            		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			                                                                        	-mvrf_count
			                                                                            		Defines the number of mVRFs per mVPN (PIM router) which needs to be consistent with the BGP mVRF count.Also when creating the GRE tunnels, each GRE tunnel grouping needs to have the PE loopback address as the IP source.
			                                                                            		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x                                                                       	-mvrf_unique
			x                                                                           		When -mvpn_enable is 1, this option is used for creation of unique MVRFs if enabled.
			x                                                                           		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			                                                                        	-default_mdt_ip
			                                                                            		Defines the IP address of the default MDT, if multiple mVPN PEs are created.
			                                                                            		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			                                                                        	-default_mdt_ip_incr
			                                                                            		Defines the IP address increment for each default MDT.
			                                                                            		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			                                                                        	-gre_checksum_enable
			                                                                            		Checksum for GRE tunneling.
			                                                                            		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			                                                                        	-gre_key_enable
			                                                                            		Key for GRE tunneling.
			                                                                            		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			                                                                        	-gre_key_in
			                                                                            		The in key for GRE tunneling.
			                                                                            		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			                                                                        	-gre_key_out
			                                                                            		The out key for GRE tunneling.
			                                                                            		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-bs_period
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_bsr_addr
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_bsr_adv
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_bsr_group_addr
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_bsr_group_admin
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_bsr_group_bidir
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_bsr_group_prefix_len
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_bsr_priority
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_bsr_rp_addr
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_bsr_rp_handle
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_bsr_rp_holdtime
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_bsr_rp_mode
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_bsr_rp_priority
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_rp_addr
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_rp_adv
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_rp_adv_holdtime
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_rp_adv_interval
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_rp_bsr_addr
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_rp_group_addr
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_rp_group_admin
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_rp_group_bidir
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_rp_group_handle
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_rp_group_mode
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_rp_group_prefix_len
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-c_rp_priority
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-hello_max_delay
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-keepalive_period
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-register_probe_time
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n                                                                       	-register_suppression_time
			n                                                                           		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
		                                                                   
		                                                                   Return Values:
		                                                                       A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
			x                                                                       key:ipv4_loopback_handle     value:A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
		                                                                       A list containing the ipv6 loopback protocol stack handles that were added by the command (if any).
			x                                                                       key:ipv6_loopback_handle     value:A list containing the ipv6 loopback protocol stack handles that were added by the command (if any).
		                                                                       A list containing the ipv4 protocol stack handles that were added by the command (if any).
			x                                                                       key:ipv4_handle              value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		                                                                       A list containing the ipv6 protocol stack handles that were added by the command (if any).
			x                                                                       key:ipv6_handle              value:A list containing the ipv6 protocol stack handles that were added by the command (if any).
		                                                                       A list containing the ethernet protocol stack handles that were added by the command (if any).
			x                                                                       key:ethernet_handle          value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		                                                                       A list containing the pim router protocol stack handles that were added by the command (if any).
			x                                                                       key:pim_router_handle        value:A list containing the pim router protocol stack handles that were added by the command (if any).
		                                                                       A list containing the pim v4 interface protocol stack handles that were added by the command (if any).
			x                                                                       key:pim_v4_interface_handle  value:A list containing the pim v4 interface protocol stack handles that were added by the command (if any).
		                                                                       A list containing the pim v6 interface protocol stack handles that were added by the command (if any).
			x                                                                       key:pim_v6_interface_handle  value:A list containing the pim v6 interface protocol stack handles that were added by the command (if any).
		                                                                       $::SUCCESS | $::FAILURE
			                                                                        key:status                   value:$::SUCCESS | $::FAILURE
		                                                                       When status is failure, contains more information
			                                                                        key:log                      value:When status is failure, contains more information
		                                                                       The handles for the PIM-SM router created Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			                                                                        key:handle                   value:The handles for the PIM-SM router created Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		                                                                       All the interfaces created using the command Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			                                                                        key:interfaces               value:All the interfaces created using the command Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		                                                                       The handles for the PIM-SM router created
			                                                                        key:handle                   value:The handles for the PIM-SM router created
		                                                                       All the interfaces created using the command
			                                                                        key:interfaces               value:All the interfaces created using the command
		                                                                   
		                                                                   Examples:
		                                                                       See files starting with PIM_ in the Samples subdirectory.  Also see some of the MVPN sample files for further examples of the PIM usage.
		                                                                       See the PIM example in Appendix A, "Example APIs," for one specific example usage.
		                                                                       See files starting with PIM_ in the Samples subdirectory.  Also see some of the MVPN sample files for further examples of the PIM usage.See the PIM example in Appendix A, "Example APIs," for one specific example usage.
		                                                                   
		                                                                   Sample Input:
		                                                                   
		                                                                   Sample Output:
		                                                                   
		                                                                   Notes:
		                                                                       1) MVPN parameters are not supported with IxTclNetwork API (new API). If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle, interfaces
		                                                                       1) MVPN parameters are not supported with IxTclNetwork API (new API).
		                                                                   
		                                                                   See Also:
		                                                                   
		"""
		return self._run_keyword("emulation_pim_config", kwargs)

	def emulation_pim_control(self, **kwargs):
		""" This procedure controls the PIM simulation session.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_pim_control
			 	-mode                 CHOICES stop
			                       CHOICES start
			                       CHOICES restart
			                       CHOICES stop_hello
			                       CHOICES resume_hello
			                       CHOICES send_bsm
			                       CHOICES stop_bsm
			                       CHOICES resume_bsm
			                       CHOICES join
			                       CHOICES leave
			                       CHOICES stop_periodic_join
			                       CHOICES resume_periodic_join
			                       CHOICES abort
			 	[-port_handle         REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle              ANY]
			x	[-flap                CHOICES 0 1]
			x	[-flap_interval       RANGE 1-65535]
			n	[-group_member_handle ANY]
		
		Arguments:
			 	-mode
			 		This option defines the action to be taken.Note:join and
			 		prune options are not supported. Valid options are:
			 		stop
			 		start
			 		restart.
			 		Valid choices are:
			    		stop -
			    		start -
			    		restart -
			    		stop_hello -
			    		resume_hello -
			    		send_bsm -
			    		stop_bsm -
			    		resume_bsm -
			    		join -
			    		leave -
			    		stop_periodic_join -
			    		resume_periodic_join -
			    		abort -
			 	-port_handle
			 		The port on which to perform action.
			 	-handle
			 		PIM-SM session handle.It is returned by emulation_pim_config call.
			x	-flap
			x		If true (1), enables simulated flapping of this joins/prune.
			x		(DEFAULT = false)
			x	-flap_interval
			x		If flap is true, this is the amount of time, in seconds, between
			x		simulated flap events.
			n	-group_member_handle
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		
		Examples:
		See files starting with PIM_ in the Samples subdirectory.  Also see some of the MVPN sample files for further examples of the PIM usage.
		See the PIM example in Appendix A, "Example APIs," for one specific example usage.
		See files starting with PIM_ in the Samples subdirectory.  Also see some of the MVPN sample files for further examples of the PIM usage.See the PIM example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) MVPN parameters are not supported with IxTclNetwork API (new API).
		1) MVPN parameters are not supported with IxTclNetwork API (new API).
		
		See Also:
		
		"""
		return self._run_keyword("emulation_pim_control", kwargs)

	def emulation_pim_group_config(self, **kwargs):
		""" This procedure configures Multicast groups added to a PIM session.  This allows adding
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_pim_group_config
			 	[-mode                               CHOICES create
			                                      CHOICES delete
			                                      CHOICES modify
			                                      CHOICES clear_all
			                                      CHOICES disable
			                                      CHOICES enable
			                                      DEFAULT create]
			 	[-session_handle                     ANY]
			 	[-group_pool_handle                  ANY]
			 	[-source_pool_handle                 ANY]
			 	[-handle                             ANY]
			x	[-return_detailed_handles            CHOICES 0 1
			x                                     DEFAULT 0]
			 	[-adv_hold_time                      RANGE 2-65535
			                                      DEFAULT 150]
			 	[-back_off_interval                  RANGE 0-255
			                                      DEFAULT 3]
			 	[-crp_ip_addr                        IP]
			 	[-rp_ip_addr                         IP]
			x	[-rp_ip_addr_step                    IP]
			 	[-group_pool_mode                    CHOICES send register candidate_rp]
			 	[-join_prune_aggregation_factor      CHOICES 0 1]
			 	[-wildcard_group                     CHOICES 0 1]
			 	[-s_g_rpt_group                      CHOICES 0 1]
			 	[-rate_control                       CHOICES 0 1]
			 	[-interval                           RANGE 0-1000]
			 	[-join_prune_per_interval            NUMERIC]
			 	[-register_per_interval              NUMERIC]
			x	[-register_stop_per_interval         NUMERIC]
			x	[-hello_message_per_interval         NUMERIC]
			x	[-discard_join_prune_processing      CHOICES 0 1]
			x	[-crp_advertise_message_per_interval NUMERIC]
			x	[-bootstrap_message_per_interval     NUMERIC]
			x	[-flap_interval                      RANGE 1-65535]
			 	[-periodic_adv_interval              RANGE 1-65535
			                                      DEFAULT 60]
			 	[-pri_change_interval                RANGE 1-65535
			                                      DEFAULT 60]
			 	[-pri_type                           CHOICES same incremental random]
			 	[-pri_value                          RANGE 0-255
			                                      DEFAULT 192]
			x	[-register_tx_iteration_gap          RANGE 100-2147483647]
			x	[-register_stop_trigger_count        RANGE 1-127]
			x	[-register_udp_destination_port      RANGE 1-65535]
			x	[-register_udp_source_port           RANGE 1-65535]
			x	[-register_triggered_sg              CHOICES 0 1]
			 	[-router_count                       RANGE 1-65535
			                                      DEFAULT 1]
			x	[-spt_switchover                     CHOICES 0 1]
			x	[-source_group_mapping               CHOICES fully_meshed one_to_one]
			x	[-switch_over_interval               RANGE 0-65535]
			x	[-send_null_register                 CHOICES 0 1
			x                                     DEFAULT 0]
			 	[-trigger_crp_msg_count              RANGE 1-3
			                                      DEFAULT 3]
			x	[-writeFlag                          ANY]
			x	[-no_write                           ANY]
			x	[-default_mdt_mode                   CHOICES neighbor auto
			x                                     DEFAULT neighbor]
			n	[-border_bit                         ANY]
			x	[-group_range_type                   CHOICES startorp
			x                                     CHOICES startogroup
			x                                     CHOICES sourcetogroup
			x                                     CHOICES stargtosourcegroup
			x                                     CHOICES registeredtriggered]
			x	[-enable_flap_info                   ANY]
			x	[-discard_sg_join_states             ANY]
			x	[-multicast_data_length              ANY]
			x	[-supression_time                    ANY]
			x	[-register_probe_time                ANY]
			x	[-prune_source_address               IP]
			x	[-prune_source_mask_width            NUMERIC]
			x	[-prune_source_address_count         NUMERIC]
			x	[-crp_group_mask_len                 NUMERIC]
			x	[-join_prune_group_mask_width        NUMERIC]
			x	[-join_prune_source_mask_width       NUMERIC]
		
		Arguments:
			 	-mode
			 		This option defines the action to be taken. Note: modify and delete
			 		options are not supported for IxTclProtocol. Valid choices are:
			 		create- (default) An existing multicast group pool is associated/linked
			 		with the specified PIM session.
			 		delete- Remove one group pools from this session
			 		clear_all - Removes all group pools from this session.
			 		modify- Modifies group pools from this session.
			 		enable- Enables the given item provided by -handle.
			 		disable- Disables the given item provided by -handle.
			 		Valid choices are:
			    		create - An existing multicast group/source pool is associated/linked with the specified PIM session. It is also used to add join/prune, sources and crpRanges to a Pim session.
			    		delete - Remove one group pools from this session. Also used to remove join/prunes, sources and crpRanges from Pim session.
			    		modify - Modifies group pools from this session. Also used to modify join/prunes, sources and crpRanges from Pim session.
			    		clear_all - Removes all group pools from this session. Also removes all join/prunes, sources and crpRanges from the Pim session.
			    		disable - Disable the given item provided by -handle
			    		enable - Enable the given item provided by -handle
			 	-session_handle
			 		PIM-SM session handle.
			 	-group_pool_handle
			 		Groups to be added beforehand through procedure
			 		emulation_multicast_group_config. This parameter may be a list. If the case,
			 		all other parameters that can be lists should have the same list length.
			 	-source_pool_handle
			 		Associate source pool(s) with the group.The source pool(s) must be
			 		added beforehand through procedure emulation_multicast_source_config.
			 		Specify one or more source pool handle(s) for (S,G) entries.None
			 		for (*,G) entries.If one or more are specified, source-specific
			 		join/prune will be enabled; otherwise it is disabled. This parameter may be a list. If the case,
			 		all other parameters that can be lists should have the same list length.
			 	-handle
			 		Group membership handle that associates a group pool with a PIM
			 		session.This option is returned from previous call to this proc
			 		with "create" mode.In "modify" mode, membership handle must be
			 		used in conjunction with the session handle to identify the member
			 		group pool. If this is a list, all other parameters that can be lists
			 		should have the same list length. As such, multiple router interfaces
			 		will be created with the given parameters.
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-adv_hold_time
			 		This parameter represents the time interval (in seconds) between two
			 		consecutive Candidate RP advertisements.
			 	-back_off_interval
			 		The back off time interval for the C-RP-Adv messages.
			 	-crp_ip_addr
			 		Start address of the set of candidate RPs to be simulated.
			 	-rp_ip_addr
			 		The IP address of Rendezvous Point router for the multicast group
			 		pool. This parameter may be a list. If the case,
			 		all other parameters that can be lists should have the same list length.
			x	-rp_ip_addr_step
			x		The incrementing step for the IP address of Rendezvous Point router
			x		for the multicast group pool.
			 	-group_pool_mode
			 		Specifies whether the membership pool is used to send or receive
			 		PIM messages. Note: no configuration required for receive mode.
			 		Valid choices are:
			 		send - Sends Join/Prunes (downstream DR) messages.
			 		register - Sends Register and NULL Register messages. (source DR)
			 		and receive Stop-Register messages.
			 		candidate_rp - Creates new Candidate Rendez-Vous.
			 		Valid choices are:
			    		send - Sends Join/Prunes (downstream DR) messages.
			    		register - Sends Register and NULL Register messages. (source DR)
and receive Stop-Register messages.
			    		candidate_rp - Creates new Candidate Rendez-Vous.
			 	-join_prune_aggregation_factor
			 		If 1, enables the packing of multiple groups in a single packet;
			 		however, this option does not specify the exact number groups in a
			 		packet. This parameter may be a list. If the case,
			 		all other parameters that can be lists should have the same list length.
			 	-wildcard_group
			 		If true (1), enable wildcard group.When enabled, (*,*,RP) Join/
			 		Prune messages are sent.Takes effect only if (S,G) is disabled.
			 		(no source pool). This parameter may be a list. If the case,
			 		all other parameters that can be lists should have the same list length.
			 		(DEFAULT = 0)
			 	-s_g_rpt_group
			 		If true (1), enable (S,G,rpt).When enabled, (S,G,rpt) Join/Prune
			 		messages are sent.Takes effect only if (S,G) is enabled.
			 		Note: only one of s_g_rpt_group, register_triggered_sg,
			 		spt_switchover options can be enabled per multicast group. This parameter may be a list. If the case,
			 		all other parameters that can be lists should have the same list length.
			 		(DEFAULT = 0)
			 	-rate_control
			 		If true (1), enable rate control on Join/Prune and register messages.
			 	-interval
			 		The length of interval (in ms) during which a number of messages will
			 		be sent.If 0, send as fast as possible.
			 	-join_prune_per_interval
			 		The number of Join/Prune messages sent per interval.
			 	-register_per_interval
			 		The number of Register messages sent per interval.
			x	-register_stop_per_interval
			x		The number of Register Stop messages sent per interval.
			x	-hello_message_per_interval
			x		Hello Messages per Interval
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-discard_join_prune_processing
			x		Discard join/Prune Processing
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-crp_advertise_message_per_interval
			x		C-RP Advertise Messages per Interval
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-bootstrap_message_per_interval
			x		Bootstrap Messages Per Interval
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-flap_interval
			x		If flap is enabled thru the emulation_pim_control, this is the amount
			x		amount of time, in seconds, between simulated flap events.
			x		(DEFAULT= 60)
			 	-periodic_adv_interval
			 		Rate controlling variable indicating how many C-RP-Adv messages can be sent
			 		in the specified time interval.
			 	-pri_change_interval
			 		Time interval after which priority of all the RPs get changed, if priority type is
			 		incremental or random.
			 	-pri_type
			 		priorityType This indicates the type of priority to be held by the
			 		candidate RPs (CRPs). One of:
			 		same- (default) CRPs send advertisement messages
			 		with time invariant fixed priority as specified
			 		in CRP Advertisement Message Priority.
			 		incremental - Priority starts from the configured value and
			 		with every Priority Change Interval,
			 		the CRPs priority get incremented by 1.
			 		random- The start value is selected based on a
			 		pseudorandom number generator with every Priority
			 		Change Interval, when sending the next
			 		batch of CRP-Adv messages.
			 		Valid choices are:
			    		same -
			    		incremental -
			    		random -
			 	-pri_value
			 		Value of priority field sent in candidate RP advertisement messages.
			x	-register_tx_iteration_gap
			x		The gap, in milliseconds, between periodically transmitted Register
			x		messages. This parameter may be a list. If the case,
			x		all other parameters that can be lists should have the same list length.
			x		(DEFAULT = 5000)
			x	-register_stop_trigger_count
			x		If register_triggered_sg option is enabled (1), this is the count of
			x		register messages received that will trigger transmission of a (S,G)
			x		message. This parameter may be a list. If the case,
			x		all other parameters that can be lists should have the same list length.
			x		(DEFAULT = 10)
			x	-register_udp_destination_port
			x		The number of UDP destination ports in the receiving multicast group. This parameter may be a list. If the case,
			x		all other parameters that can be lists should have the same list length.
			x		(DEFAULT = 3000)
			x	-register_udp_source_port
			x		The number of UDP source ports sending encapsulated UDP packets to
			x		multicast groups via Register messages to the RP. This parameter may be a list. If the case,
			x		all other parameters that can be lists should have the same list length.
			x		(DEFAULT = 3000)
			x	-register_triggered_sg
			x		When enabled (1), sends (S,G) Join/Prune messages when matching
			x		registers have been received. Sends register stop after
			x		registerStopTriggerCount registers have been received.
			x		Note: only one of s_g_rpt_group, register_triggered_sg,
			x		spt_switchover options can be enabled per PIM group.
			 	-router_count
			 		Total number of candidate RPs to be simulated starting from C-RP Address.
			 		A contiguous address range is used for this RP range simulation.
			x	-spt_switchover
			x		When enabled (1), Sends (*,G)->(S,G) switchover type. Indicates that
			x		the simulated router will switch over from a non-source specific
			x		group state to a source specific group state.
			x		Note: only one of s_g_rpt_group, register_triggered_sg,
			x		spt_switchover options can be enabled per PIM group. This parameter may be a list. If the case,
			x		all other parameters that can be lists should have the same list length.
			x	-source_group_mapping
			x		Set the type of mapping that occurs when routes are advertised. This
			x		only applies for (S,G) and switchover types for MGR and is meaningful
			x		for RR.Choices are: fully_meshed, one_to_one. This parameter may be a list. If the case,
			x		all other parameters that can be lists should have the same list length.
			x		Valid choices are:
			x   		fully_meshed -
			x   		one_to_one -
			x	-switch_over_interval
			x		The time interval, in seconds, allowed for the switch from using the
			x		RP tree to using a source-specific tree. Used when spt_switchover
			x		option is enabled. This parameter may be a list. If the case,
			x		all other parameters that can be lists should have the same list length.
			x		(DEFAULT = 0)
			x	-send_null_register
			x		Enables the transmission of an initial null registration at
			x		emulation startup. This parameter may be a list. If the case,
			x		all other parameters that can be lists should have the same list length.
			x		(DEFAULT = 0)
			 	-trigger_crp_msg_count
			 		The number of times CRP Advertisments is sent to the newly elected Bootstrap Router.
			x	-writeFlag
			x		DEPRECATED - use -no_write instead.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-no_write
			x		If this option is present, the configuration is not written to the hardware. This option can be used to queue up multiple configurations before writing to the hardware.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-default_mdt_mode
			x		If this parameter is set on auto, the mvpn specific verifications will be bypassed
			x		and the emulation_pim_group_config call will assume that all received interfaces/groups/sources
			x		are correctly configured.
			x		(DEFAULT = neighbor)
			x		Valid choices are:
			x   		neighbor -
			x   		auto -
			n	-border_bit
			x	-group_range_type
			x   		Range Type
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		startorp -
			x       		startogroup -
			x       		sourcetogroup -
			x       		stargtosourcegroup -
			x       		registeredtriggered -
			x	-enable_flap_info
			x   		Enable Flap info
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-discard_sg_join_states
			x   		The learned join states sent by the RP (DUT) in response to this specific register message will be discarded
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-multicast_data_length
			x   		The length of multicast data, in bytes
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-supression_time
			x   		Register Suppression Time
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-register_probe_time
			x   		Register Probe Time
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-prune_source_address
			x   		Prune Source address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-prune_source_mask_width
			x   		Prune source address Maskwidth
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-prune_source_address_count
			x   		Prune Source Address count
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-crp_group_mask_len
			x   		CRP group mask length
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-join_prune_group_mask_width
			x   		Join/Prune group address Maskwidth
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-join_prune_source_mask_width
			x   		Join/Prune source address Maskwidth
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		A list containing the pim v4 join prune protocol stack handles that were added by the command (if any).
			xkey:pim_v4_join_prune_handle    value:A list containing the pim v4 join prune protocol stack handles that were added by the command (if any).
		A list containing the pim v4 candidate rp protocol stack handles that were added by the command (if any).
			xkey:pim_v4_candidate_rp_handle  value:A list containing the pim v4 candidate rp protocol stack handles that were added by the command (if any).
		A list containing the pim v4 source protocol stack handles that were added by the command (if any).
			xkey:pim_v4_source_handle        value:A list containing the pim v4 source protocol stack handles that were added by the command (if any).
		A list containing the pim v6 join prune protocol stack handles that were added by the command (if any).
			xkey:pim_v6_join_prune_handle    value:A list containing the pim v6 join prune protocol stack handles that were added by the command (if any).
		A list containing the pim v6 candidate rp protocol stack handles that were added by the command (if any).
			xkey:pim_v6_candidate_rp_handle  value:A list containing the pim v6 candidate rp protocol stack handles that were added by the command (if any).
		A list containing the pim v6 source protocol stack handles that were added by the command (if any).
			xkey:pim_v6_source_handle        value:A list containing the pim v6 source protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:interfaces                  value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		$::SUCCESS | $::FAILURE
			 key:status                      value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information
			 key:log                         value:When status is failure, contains more information
		group_member_handle
			 key:handle                      value:group_member_handle
		group_pool_handle
			 key:group_pool_handle           value:group_pool_handle
		source_pool_handles
			 key:source_pool_handles         value:source_pool_handles
		
		Examples:
		See files starting with PIM_ in the Samples subdirectory.  Also see some of the MVPN sample files for further examples of the PIM usage.
		See the PIM example in Appendix A, "Example APIs," for one specific example usage.
		See files starting with PIM_ in the Samples subdirectory.  Also see some of the MVPN sample files for further examples of the PIM usage.See the PIM example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) MVPN parameters are not supported with IxTclNetwork API (new API). If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  interfaces
		1) MVPN parameters are not supported with IxTclNetwork API (new API).
		
		See Also:
		
		"""
		return self._run_keyword("emulation_pim_group_config", kwargs)

	def emulation_pim_info(self, **kwargs):
		""" This command is used to retrieve aggregate statistics about PIM from a port, and learned CRP_BSR info.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_pim_info
			 	-handle  ANY]
			 	[-mode   CHOICES aggregate
			          CHOICES stats_per_device_group
			          CHOICES stats_per_session
			          CHOICES learned_crp
			          CHOICES clear_stats
			          DEFAULT aggregate]
		
		Arguments:
			 	-handle
			 		For -mode aggregate, this parameter should be provided with an emulated
			 		router or join/prune or source handle, but the command will return per port
			 		aggregated stats. For -mode learned_crp, this parameters should be provided
			 		with an emulated router or interface (for the emulated router) and the
			 		command will return per interface learned CRP and BSR info.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-mode
			 		Using this argument, you can return aggregate statistics or learned crp-bsr info
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		aggregate -
			    		stats_per_device_group -
			    		stats_per_session -
			    		learned_crp -
			    		clear_stats -
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                                   value:On status of failure, gives detailed information.
		PIMSM Aggregated Hellos Tx; valid only with -mode aggregate
			 key:port_name                                             value:PIMSM Aggregated Hellos Tx; valid only with -mode aggregate
		PIMSM Aggregated Hellos Tx; valid only with -mode aggregate
			 key:hello_tx                                              value:PIMSM Aggregated Hellos Tx; valid only with -mode aggregate
		PIMSM Aggregated Hellos Rx; valid only with -mode aggregate
			 key:hello_rx                                              value:PIMSM Aggregated Hellos Rx; valid only with -mode aggregate
		PIMSM Aggregated Join (*,G) Tx; valid only with -mode aggregate
			 key:group_join_tx                                         value:PIMSM Aggregated Join (*,G) Tx; valid only with -mode aggregate
		PIMSM Aggregated Join (*,G) Rx; valid only with -mode aggregate
			 key:group_join_rx                                         value:PIMSM Aggregated Join (*,G) Rx; valid only with -mode aggregate
		PIMSM Aggregated Prune (*,G) Tx; valid only with -mode aggregate
			 key:group_prune_tx                                        value:PIMSM Aggregated Prune (*,G) Tx; valid only with -mode aggregate
		PIMSM Aggregated Prune (*,G) Rx; valid only with -mode aggregate
			 key:group_prune_rx                                        value:PIMSM Aggregated Prune (*,G) Rx; valid only with -mode aggregate
		PIMSM Aggregated Join (S,G) Tx; valid only with -mode aggregate
			 key:s_g_join_tx                                           value:PIMSM Aggregated Join (S,G) Tx; valid only with -mode aggregate
		PIMSM Aggregated Join(S,G) Rx; valid only with -mode aggregate
			 key:s_g_join_rx                                           value:PIMSM Aggregated Join(S,G) Rx; valid only with -mode aggregate
		PIMSM Aggregated Prune(S,G) Tx; valid only with -mode aggregate
			 key:s_g_prune_tx                                          value:PIMSM Aggregated Prune(S,G) Tx; valid only with -mode aggregate
		PIMSM Aggregated Prune(S,G) Rx; valid only with -mode aggregate
			 key:s_g_prune_rx                                          value:PIMSM Aggregated Prune(S,G) Rx; valid only with -mode aggregate
		PIMSM Aggregated Register Tx; valid only with -mode aggregate
			 key:reg_tx                                                value:PIMSM Aggregated Register Tx; valid only with -mode aggregate
		PIMSM Aggregated Register Rx; valid only with -mode aggregate
			 key:reg_rx                                                value:PIMSM Aggregated Register Rx; valid only with -mode aggregate
		PIMSM Aggregated RegisterStop Tx; valid only with -mode aggregate
			 key:reg_stop_tx                                           value:PIMSM Aggregated RegisterStop Tx; valid only with -mode aggregate
		PIMSM Aggregated RegisterStop Rx; valid only with -mode aggregate
			 key:reg_stop_rx                                           value:PIMSM Aggregated RegisterStop Rx; valid only with -mode aggregate
		PIMSM Aggregated RegisterNull Tx; valid only with -mode aggregate
			 key:null_reg_tx                                           value:PIMSM Aggregated RegisterNull Tx; valid only with -mode aggregate
		PIMSM Aggregated RegisterNull Rx; valid only with -mode aggregate
			 key:null_reg_rx                                           value:PIMSM Aggregated RegisterNull Rx; valid only with -mode aggregate
		PIMSM Aggregated Hellos Tx
			 key:<port handle>.aggregate.port_name                     value:PIMSM Aggregated Hellos Tx
		PIMSM Aggregated Hellos Tx
			 key:<port handle>.aggregate.hello_tx                      value:PIMSM Aggregated Hellos Tx
		PIMSM Aggregated Hellos Rx
			 key:<port handle>.aggregate.hello_rx                      value:PIMSM Aggregated Hellos Rx
		PIMSM Aggregated Join (*,G) Tx
			 key:<port handle>.aggregate.group_join_tx                 value:PIMSM Aggregated Join (*,G) Tx
		PIMSM Aggregated Join (*,G) Rx
			 key:<port handle>.aggregate.group_join_rx                 value:PIMSM Aggregated Join (*,G) Rx
		PIMSM Aggregated Prune (*,G) Tx
			 key:<port handle>.aggregate.group_prune_tx                value:PIMSM Aggregated Prune (*,G) Tx
		PIMSM Aggregated Prune (*,G) Rx
			 key:<port handle>.aggregate.group_prune_rx                value:PIMSM Aggregated Prune (*,G) Rx
		PIMSM Aggregated Join (S,G) Tx
			 key:<port handle>.aggregate.s_g_join_tx                   value:PIMSM Aggregated Join (S,G) Tx
		PIMSM Aggregated Join(S,G) Rx
			 key:<port handle>.aggregate.s_g_join_rx                   value:PIMSM Aggregated Join(S,G) Rx
		PIMSM Aggregated Prune(S,G) Tx
			 key:<port handle>.aggregate.s_g_prune_tx                  value:PIMSM Aggregated Prune(S,G) Tx
		PIMSM Aggregated Prune(S,G) Rx
			 key:<port handle>.aggregate.s_g_prune_rx                  value:PIMSM Aggregated Prune(S,G) Rx
		PIMSM Aggregated Register Tx
			 key:<port handle>.aggregate.reg_tx                        value:PIMSM Aggregated Register Tx
		PIMSM Aggregated Register Rx
			 key:<port handle>.aggregate.reg_rx                        value:PIMSM Aggregated Register Rx
		PIMSM Aggregated RegisterStop Tx
			 key:<port handle>.aggregate.reg_stop_tx                   value:PIMSM Aggregated RegisterStop Tx
		PIMSM Aggregated RegisterStop Rx
			 key:<port handle>.aggregate.reg_stop_rx                   value:PIMSM Aggregated RegisterStop Rx
		PIMSM Aggregated RegisterNull Tx
			 key:<port handle>.aggregate.null_reg_tx                   value:PIMSM Aggregated RegisterNull Tx
		PIMSM Aggregated RegisterNull Rx
			 key:<port handle>.aggregate.null_reg_rx                   value:PIMSM Aggregated RegisterNull Rx
		PIMSM Number of Routers Configured; valid only with -mode aggregate
			xkey:num_routers_configured                                value:PIMSM Number of Routers Configured; valid only with -mode aggregate
		PIMSM Number of Routers Running; valid only with -mode aggregate
			xkey:num_routers_running                                   value:PIMSM Number of Routers Running; valid only with -mode aggregate
		PIMSM Number of Neighbors Learnt; valid only with -mode aggregate
			xkey:num_neighbors_learnt                                  value:PIMSM Number of Neighbors Learnt; valid only with -mode aggregate
		PIMSM Aggregated Join (*,*,RP) Tx; valid only with -mode aggregate
			xkey:rp_join_tx                                            value:PIMSM Aggregated Join (*,*,RP) Tx; valid only with -mode aggregate
		PIMSM Aggregated Join (*,*,RP) Rx; valid only with -mode aggregate
			xkey:rp_join_rx                                            value:PIMSM Aggregated Join (*,*,RP) Rx; valid only with -mode aggregate
		PIMSM Aggregated Prune (*,*,RP) Tx; valid only with -mode aggregate
			xkey:rp_prune_tx                                           value:PIMSM Aggregated Prune (*,*,RP) Tx; valid only with -mode aggregate
		PIMSM Aggregated Prune (*,*,RP) Rx; valid only with -mode aggregate
			xkey:rp_prune_rx                                           value:PIMSM Aggregated Prune (*,*,RP) Rx; valid only with -mode aggregate
		PIMSM Aggregated Join (S,G,RPT) Tx; valid only with -mode aggregate
			xkey:s_g_rpt_join_tx                                       value:PIMSM Aggregated Join (S,G,RPT) Tx; valid only with -mode aggregate
		PIMSM Aggregated Join (S,G,RPT) Rx; valid only with -mode aggregate
			xkey:s_g_rpt_join_rx                                       value:PIMSM Aggregated Join (S,G,RPT) Rx; valid only with -mode aggregate
		PIMSM Aggregated Prune (S,G,RPT) Tx; valid only with -mode aggregate
			xkey:s_g_rpt_prune_tx                                      value:PIMSM Aggregated Prune (S,G,RPT) Tx; valid only with -mode aggregate
		PIMSM Aggregated Prune (S,G,RPT) Rx; valid only with -mode aggregate
			xkey:s_g_rpt_prune_rx                                      value:PIMSM Aggregated Prune (S,G,RPT) Rx; valid only with -mode aggregate
		PIMSM Aggregated DataMDT TLV Tx; valid only with -mode aggregate
			xkey:data_mdt_tlv_tx                                       value:PIMSM Aggregated DataMDT TLV Tx; valid only with -mode aggregate
		PIMSM Aggregated DataMDT TLV Rx; valid only with -mode aggregate
			xkey:data_mdt_tlv_rx                                       value:PIMSM Aggregated DataMDT TLV Rx; valid only with -mode aggregate
		PIMSM Number of Routers Configured
			xkey:<port handle>.aggregate.num_routers_configured        value:PIMSM Number of Routers Configured
		PIMSM Number of Routers Running
			xkey:<port handle>.aggregate.num_routers_running           value:PIMSM Number of Routers Running
		PIMSM Number of Neighbors Learnt
			xkey:<port handle>.aggregate.num_neighbors_learnt          value:PIMSM Number of Neighbors Learnt
		PIMSM Aggregated Join (*,*,RP) Tx
			xkey:<port handle>.aggregate.rp_join_tx                    value:PIMSM Aggregated Join (*,*,RP) Tx
		PIMSM Aggregated Join (*,*,RP) Rx
			xkey:<port handle>.aggregate.rp_join_rx                    value:PIMSM Aggregated Join (*,*,RP) Rx
		PIMSM Aggregated Prune (*,*,RP) Tx
			xkey:<port handle>.aggregate.rp_prune_tx                   value:PIMSM Aggregated Prune (*,*,RP) Tx
		PIMSM Aggregated Prune (*,*,RP) Rx
			xkey:<port handle>.aggregate.rp_prune_rx                   value:PIMSM Aggregated Prune (*,*,RP) Rx
		PIMSM Aggregated Join (S,G,RPT) Tx
			xkey:<port handle>.aggregate.s_g_rpt_join_tx               value:PIMSM Aggregated Join (S,G,RPT) Tx
		PIMSM Aggregated Join (S,G,RPT) Rx
			xkey:<port handle>.aggregate.s_g_rpt_join_rx               value:PIMSM Aggregated Join (S,G,RPT) Rx
		PIMSM Aggregated Prune (S,G,RPT) Tx
			xkey:<port handle>.aggregate.s_g_rpt_prune_tx              value:PIMSM Aggregated Prune (S,G,RPT) Tx
		PIMSM Aggregated Prune (S,G,RPT) Rx
			xkey:<port handle>.aggregate.s_g_rpt_prune_rx              value:PIMSM Aggregated Prune (S,G,RPT) Rx
		PIMSM Aggregated DataMDT TLV Tx
			xkey:<port handle>.aggregate.data_mdt_tlv_tx               value:PIMSM Aggregated DataMDT TLV Tx
		PIMSM Aggregated DataMDT TLV Rx
			xkey:<port handle>.aggregate.data_mdt_tlv_rx               value:PIMSM Aggregated DataMDT TLV Rx
		the RP address expresing candidacy for the specific group of RPs; valid only with -mode learned_crp
			xkey:learned_crp.<interface_handle>.<id>.crp_addr          value:the RP address expresing candidacy for the specific group of RPs; valid only with -mode learned_crp
		the expiry timer for the specific record as received in CRP Adv Message; valid only with -mode learned_crp
			xkey:learned_crp.<interface_handle>.<id>.expiry_timer      value:the expiry timer for the specific record as received in CRP Adv Message; valid only with -mode learned_crp
		the Group Address learnt through Candidate RP advertisments; valid only with -mode learned_crp
			xkey:learned_crp.<interface_handle>.<id>.group_addr        value:the Group Address learnt through Candidate RP advertisments; valid only with -mode learned_crp
		shows the prefix lenght of the group address learnt; valid only with -mode learned_crp
			xkey:learned_crp.<interface_handle>.<id>.group_mask_width  value:shows the prefix lenght of the group address learnt; valid only with -mode learned_crp
		priority of the selected Candidate RP; valid only with -mode learned_crp
			xkey:learned_crp.<interface_handle>.<id>.priority          value:priority of the selected Candidate RP; valid only with -mode learned_crp
		the address of the elected bootstrap router that is sending periodic bootstrap messages; valid only with -mode learned_crp
			xkey:learned_bsr.<interface_handle>.bsr_addr               value:the address of the elected bootstrap router that is sending periodic bootstrap messages; valid only with -mode learned_crp
		indicates the elapsed time (in seconds) since the last bootstrap message was received or sent; valid only with -mode learned_crp
			xkey:learned_bsr.<interface_handle>.last_bsm_send_recv     value:indicates the elapsed time (in seconds) since the last bootstrap message was received or sent; valid only with -mode learned_crp
		indicates the state of the configured bootstrap router; valid only with -mode learned_crp
			xkey:learned_bsr.<interface_handle>.our_bsr_state          value:indicates the state of the configured bootstrap router; valid only with -mode learned_crp
		priority of the elected bootstrap router as received in Bootstrap messages or configured priority; valid only with -mode learned_crp
			xkey:learned_bsr.<interface_handle>.priority               value:priority of the elected bootstrap router as received in Bootstrap messages or configured priority; valid only with -mode learned_crp
		
		Examples:
		ixia::emulation_pim_info -handle <router_handle> -mode aggregate
		::<namespace>::emulation_pim_info -handle <router_handle> -mode aggregate
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) For many handles specified as parameters this procedure will return a keyed
		list formatted as follows: <port_handle>.aggregate.<key_name> when mode is aggregate,
		or learned_crp.<interface_handle>.<key_name>, learned_bsr.<interface_handle>.<key_name>
		when mode is learned_crp.
		2) MVPN parameters are not supported with IxTclNetwork API (new API).
		1) For many handles specified as parameters this procedure will return a keyed list formatted as follows: <port_handle>.aggregate.<key_name> when mode is aggregate, or learned_crp.<interface_handle>.<key_name>, learned_bsr.<interface_handle>.<key_name> when mode is learned_crp.
		2) MVPN parameters are not supported with IxTclNetwork API (new API).
		
		See Also:
		
		"""
		return self._run_keyword("emulation_pim_info", kwargs)

	def emulation_rip_config(self, **kwargs):
		""" This procedure will configure RIP routers in a particular interface. The user can create single or multiple RIP routers.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_rip_config
			 	-mode                        ANY
			 	[-port_handle                ANY]
			 	[-handle                     ANY]
			 	[-session_type               ANY]
			 	[-count                      ANY]
			 	[-gre_checksum_enable        ANY]
			 	[-gre_count                  ANY]
			 	[-gre_dst_ip_addr            ANY]
			 	[-gre_dst_ip_addr_cstep      ANY]
			 	[-gre_dst_ip_addr_step       ANY]
			 	[-gre_ipv6_addr              ANY]
			 	[-gre_ipv6_addr_cstep        ANY]
			 	[-gre_ipv6_addr_step         ANY]
			 	[-gre_ipv6_prefix_length     ANY]
			 	[-gre_key_enable             ANY]
			 	[-gre_key_in                 ANY]
			 	[-gre_key_in_step            ANY]
			 	[-gre_key_out                ANY]
			 	[-gre_key_out_step           ANY]
			 	[-gre_seq_enable             ANY]
			 	[-intf_ip_addr               ANY]
			 	[-intf_prefix_length         ANY]
			 	[-intf_ip_addr_step          ANY]
			 	[-interface_handle           ANY]
			 	[-intf_count                 ANY]
			 	[-interface_metric           ANY]
			 	[-neighbor_intf_ip_addr      ANY]
			 	[-neighbor_intf_ip_addr_step ANY]
			 	[-update_interval            ANY]
			 	[-update_interval_offset     ANY]
			 	[-authentication_mode        ANY]
			 	[-password                   ANY]
			 	[-update_mode                ANY]
			 	[-vpi                        ANY]
			 	[-vci                        ANY]
			 	[-vpi_step                   ANY]
			 	[-vci_step                   ANY]
			 	[-vlan_id                    ANY]
			 	[-vlan_id_mode               ANY]
			 	[-vlan_id_step               ANY]
			 	[-vlan_user_priority         ANY]
			 	[-router_id                  ANY]
			 	[-router_id_step             ANY]
			 	[-send_type                  ANY]
			 	[-receive_type               ANY]
			 	[-time_period                ANY]
			 	[-num_routes_per_period      ANY]
			x	[-atm_encapsulation          ANY]
			x	[-mac_address_init           ANY]
			x	[-mac_address_step           ANY]
			x	[-no_write                   ANY]
			x	[-override_existence_check   ANY]
			x	[-override_tracking          ANY]
			x	[-reset                      ANY]
			x	[-vlan                       ANY]
			n	[-md5_key                    ANY]
			n	[-md5_key_id                 ANY]
			n	[-triggered_interval         ANY]
			n	[-expiration_interval        ANY]
			n	[-garbage_interval           ANY]
		
		Arguments:
			 	-mode
			 		This option defines the action to be taken. Valid choices are:
			    		create- creates a RIP router with the parameters given by user.
			    		delete-given a list of router handles deletes these routers.
			    		modify- given a list of router handles modifies the routers to match the other configuration parameters given by the user. Protocol interface parameters will be ignored when using RIPng and IxNetwork.
			    		disable- - given a list of router handles disables them.
			    		enable-given a list of router handles enables them.
			 	-port_handle
			 		The port on which the session is to be created.
			 	-handle
			 		RIP session handle used for mode other than create.
			 	-session_type
			 		The version of RIP to be used: ripv1 ripv2 ripng.
			 	-count
			 		Define number of sessions to create on the interface.
			 	-gre_checksum_enable
			 		This parameter enables/disables the checksum on a GRE interface.Notes: ignored when -mode = modify.Dependencies: This option is valid only when -mode is create or -mode is modify and -handle is a RIPng router interface and -session_type is ripng.0 - disable (Default)1 - enable. Only available for IxNetwork RIPng.
			 	-gre_count
			 		The number of GRE tunnels to be created per directly connected interface. Only available for IxNetwork RIPngNotes: intf_count * gre_count cannot be greater than 100.Dependencies: This option is valid only when -mode is create and/or -gre_ipv6_addr are present and -session_type is ripng.
			 	-gre_dst_ip_addr
			 		The first GRE tunnel destination IPv4/6 address that will be configured. Only available for IxNetwork RIPng.Notes: ignored when -mode modify.Dependencies: This option is valid only when -mode is create or -mode is modify and -handle is a RIPng router interface and -session_type is ripng.
			 	-gre_dst_ip_addr_cstep
			 		The destination IPv4/6 address incrementing step of the GRE tunnels that will be configured when passing from a connected interface to another. Only available for IxNetwork RIPng.Notes: If gre_dst_ip_addr_cstep is not present, the incrementing is based on gre_dst_ip_addr_step.ignored when -mode is modifyExample: Please see example under gre_ipv6_addr_cstep.Dependencies: This option is valid only when -mode is create and -session_type is ripng.
			 	-gre_dst_ip_addr_step
			 		The destination IPv4/6 address incrementing step of the GRE tunnels that will be configured. Only available for IxNetwork RIPng.(DEFAULT = 0.0.0.0 | 0:0:0:1::0).Notes: ignored when -mode is modifyDependencies: This option is valid only when -mode is create and -session_type is ripng.
			 	-gre_ipv6_addr
			 		The first GRE IPv6 address that will be configured. Only available for IxNetwork RIPngNotes: ignored when -mode modify.Dependencies: This option is valid only when -mode is create or -mode is modify and -handle is a RIPng router interface and -session_type is ripng.
			 	-gre_ipv6_addr_cstep
			 		The IPv6 address incrementing step of the GRE interfaces that will be configured when passing from a connected interface to another. Only available for IxNetwork RIPng.Notes: If gre_ipv6_addr_cstep is not present, the incrementing is based on gre_ipv6_addr_step.ignored when -mode is modifyExample: The GRE tunnels have the connected interfaces as sourceintf_count2gre_count3gre_ipv6_addr10::1gre_ipv6_addr_step::1gre_ipv6_addr_cstep0:1::0The following list of GRE IP addresses will be generated:Connected1, GRE1 - 10::1; Connected1, GRE2 - 10::2; Connected1, GRE3 - 10::3Connected2, GRE7 - 10:1::1; Connected2, GRE8 - 10:1::2; Connected2, GRE9 - 10:1::3Dependencies: This option is valid only when -mode is create and -session_type is ripng.
			 	-gre_ipv6_addr_step
			 		The IPv6 address incrementing step of the GRE interfaces that will be configured. Only available for IxNetwork RIPngNotes:ignored when -mode is modify.Dependencies: This option is valid only when -mode is create and -session_type isripng.
			 	-gre_ipv6_prefix_length
			 		The IPv6 address prefix of the GREinterfaces that will be configured. Only available for IxNetwork RIPng.Notes:ignored when -mode is modify.Dependencies: This option is valid only when -mode is create or -mode is modify and -handle is a RIPng router interface and -session_type is ripng.
			 	-gre_key_enable
			 		This parameter enables/disables the in/out keys on a GRE interface.Notes: ignored when -mode modify.Dependencies: This option is valid only when -mode is create or -mode is modify and -handle is a RIPng router interface and -session_type is ripng.0 - disable (DEFAULT)1 - enable. Only available for IxNetwork RIPng.
			 	-gre_key_in
			 		This parameter represents the GRE tunnel in key. The range of values is between 0 and 4,294,967,295. Only available for IxNetwork RIPng.Notes: ignored when -mode modify.Dependencies: This option is valid only when -mode is create and -gre_enable_key is 1 or -mode is modify and -handle is a RIPng router interface, -gre_enable_key is 1 and -session_type is ripng.
			 	-gre_key_in_step
			 		This parameter represents the GRE tunnel in key step. The range of values is between 0 and 4,294,967,295. Only available for IxNetwork RIPng.Notes: ignored when -mode is modify.Dependencies: This option is valid only when -mode is create and -session_type is ripng.
			 	-gre_key_out
			 		This parameter represents the GRE tunnel out key. The range of values is between 0 and 4,294,967,295. Only available for IxNetwork RIPng.Notes: ignored when -mode modify.Dependencies: This option is valid only when -mode is create and -gre_enable_key is 1 or -mode is modify and -handle is a RIPng router interface, -gre_enable_key is 1 and -session_type is ripng.
			 	-gre_key_out_step
			 		This parameter represents the GRE tunnel out key step. The range of values is between 0 and 4,294,967,295. Only available for IxNetwork RIPng.Notes: ignored when -mode modify.Dependencies: This option is valid only when -mode is create and -session_type is ripng.
			 	-gre_seq_enable
			 		This parameter enables/disables the sequencingon a GRE interface.Notes: ignored when -mode modify.Dependencies: This option is valid only when -mode is create or -mode is modify and -handle is a RIPng router interface and -session_type is ripng.0 - disable (DEFAULT)1 - enable. Only available for IxNetwork RIPng.
			 	-intf_ip_addr
			 		Interface IP address of RIP session router.
			 	-intf_prefix_length
			 		Prefix length on the interface.(DEFAULT = 24 for RIPv1 and RIPv2)(DEFAULT = 64 for RIPng)
			 	-intf_ip_addr_step
			 		The IP address step between each session for multiple sessions.
			 	-interface_handle
			 		Handle of an existing interface.
			 	-intf_count
			 		The number of directly connected protocol interfaces to be created per RIPng router.The number of RIPng router interfaces per router will be equal to <intf_count> * <gre_count>. Available only for RIPngNotes: intf_count * gre_count cannot be greater than 100.Dependencies: This option is valid only when -mode is createand -session_type is ripng.
			 	-interface_metric
			 		The value of the metric associated with the interface. This value is added to the metric in the routing table before transmitting updates through this interface.For RIPng only.The values can be one of the following 0+, 0-16.If interface_metric is 0, the interface metric is disabled.If interface_metric is 0+ or 1-16, the interface metric is enabled.
			 	-neighbor_intf_ip_addr
			 		Neighbor's (SUT) interface IP for sending unicast packets.
			 	-neighbor_intf_ip_addr_step
			 		Define neighbor's interface IP for multiple sessions across multiple sub-interfaces.
			 	-update_interval
			 		The time, in seconds, between transmitted update messages. RANGE 1-1000.
			 	-update_interval_offset
			 		The maximum update-interval variance in seconds; that is, the maximum of a random time interval used to add or substract from the time at which updates are sent. RANGE 0-15.
			 	-authentication_mode
			 		For RIPv2 only. Valid options are: null, text, md5.
			 	-password
			 		For RIPv2 only. The password is used in simple text authentication mode.
			 	-update_mode
			 		Select learned routes to be included in outgoing RIP update
			 		Valid choices are:
			    		no_horizon - Include all routes learned from all neighbors.
			    		split_horizon - Do not include routes from the neighbor to which
			    		poison_reverse - Include all routes learned from the neighbor
			    		discard - Discard all routes learned from all neighbors.
			 	-vpi
			 		VPI for emulatedrouter node. RANGE 0-255.
			 	-vci
			 		VCI for emulatedrouter node. RANGE 0-65535.
			 	-vpi_step
			 		Step value to apply to VPI field. RANGE 0-256.When vpi_step causes the vpi value to exceed it's maximum value the increment will be done modulo <number of possible vpi ids>.Examples: vpi = 254; vpi_step = 2-> new vpi value = 0vpi = 255; vpi_step = 11 -> new vpi value = 10
			 	-vci_step
			 		Step value to apply to VCI field. RANGE 0-256.When vci_step causes the vci value to exceed it's maximum value the increment will be done modulo <number of possible vci ids>.Examples: vci = 65534; vci_step = 2-> new vci value = 0vci = 65535; vci_step = 11 -> new vci value = 10
			 	-vlan_id
			 		VLAN ID for emulated router node. RANGE 0-4095.
			 	-vlan_id_mode
			 		For multiple neighbor configuration, configures the VLAN ID mode to fixed or increment.
			 	-vlan_id_step
			 		When vlan_id_mode is set to increment, this defines the step for every VLAN. RANGE 0-4096When vlan_id_step causes the vlan_id value to exceed it's maximum value the increment will be done modulo <number of possible vlan ids>.Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			 	-vlan_user_priority
			 		VLAN user priority assigned to emulated router node. RANGE 0-7.
			 	-router_id
			 		Router ID of RIP session router, use intf_ip_address if not specified by user.
			 	-router_id_step
			 		Used to define router ID for multiple sessions.(DEFAULT 1)
			 	-send_type
			 		Configure version &amp;amp; destination address of outgoing RIP packets. Thechoices for send type are: multicast broadcast_v1 broadcast_v2. Multicast is for RIPv2 only.Broadcast address can be used for both v1 &amp;amp; v2.
			 	-receive_type
			 		Configure which version of RIP incoming packets is received. The choices for receive type are v1, v2, v1_v2 for RIPv1 and RIPv2, and ignore and store for RIPng.
			 	-time_period
			 		The time period to use for throttling updates, in milliseconds. A value of 0 disables this feature and transmits all routes immediately for all updates. RANGE 0-999999.
			 	-num_routes_per_period
			 		The number of routes to transmit every time period in milliseconds. A value of 0 disables this feature and transmits all routes immediately for all updates. RANGE 0-999999.
			x	-atm_encapsulation
			x		The encapsulation of the ATM protocol interface associated with the emulated router.
			x	-mac_address_init
			x		The MAC address for the interface to be created.
			x	-mac_address_step
			x		The incrementing step for the MAC address of the interface to be created. Valid only when IxNetwork Tcl API is used.
			x	-no_write
			x		If this option is present, the configuration is not written to the hardware. This option can be used to queue up multiple configurations before writing to the hardware.
			x	-override_existence_check
			x		If this option is enabled, the interface existence check is skipped but the list of interfaces is still created and maintained in order to keep track of existing interfaces, if required. Using this option will speed up the creation of interfaces.
			x	-override_tracking
			x		If this option is enabled, the list of interfaces will no longer be created and maintained, thus speeding up the creation of interfaces even more. Also, it will enable -override_existence_check in case it was not already enabled because checking for interface existence becomes impossible if the the list of interfaces no longer exists.
			x	-reset
			x		Clear all existent routers on the specified port. Valid only in create mode.
			x	-vlan
			x		Enables vlan on the directly connected RIP router interface. Valid options are: 0 - disable, 1 - enable.This option is valid only when -mode is create or -mode is modify and -handle is a RIPv1 or RIPv2 router handle.This option is available only when IxNetwork tcl API is used.
			n	-md5_key
			n	-md5_key_id
			n	-triggered_interval
			n	-expiration_interval
			n	-garbage_interval
		
		Return Values:
		$::SUCCESS | $::FAILURE.
			 key:status  value:$::SUCCESS | $::FAILURE.
		When status is failure, contains more information.
			 key:log     value:When status is failure, contains more information.
		The list of routers created.
			 key:handle  value:The list of routers created.
		
		Examples:
		See files starting with RIP_ in the Samples subdirectory.  Also see some of the L3VPN and MPLS sample files for further examples of the RIP usage.
		See the RIP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.The router_id option will not be set properly on hardware.For IxNetwork the following new RIPng features are available:RIPng routers can have multiple RIPng router interfaces.By specifying the intf_... parameters there will be created a number equal to intf_count of directly connected interfaces per RIPng  router.By specifying the gre_... parameters there will be created a number equal to gre_count of GRE tunnel per connected.At the end the number of RIPng router interfaces per RIPng router will be intf_count * gre_count (can not be greater than 100).Protocol interfaces created with ::<namespace>::emulation_rip_config can not be modified.Each RIPng router interface will be associated to:A directly connected interface, if the user specifies only the intf_... parametersA GRE tunnel, if the user specifies the intf_ and the gre_... parametersWhen -mode is modify and -handle contains only one RIPng router handle, the router interface parameters must have either one value, in which case the value will be applied to all interfaces of the associated RIPng router, either the same number of values as the number of interfaces that the associated RIPng router has and each router interface will take the corresponding value from the list.When -mode is modify and -handle contains a list of RIPng router handles, the interface parameters must have either one value, in which case all interfaces of all routers will be assigned with that value, either a list of values equal to the number of RIPng router handles and all interfaces of a router handle will take the corresponding value from the list of arguments.Example: -handle [list $ripR1 $ripR2 $ripR3] -interface_metric [list 3 4 5] All interfaces of $ripR1 will have a metric of 3; all interfaces of $ripR2 will have a metric of 4 and all interfaces of ripR3 will have a metric of 5.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_rip_config", kwargs)

	def emulation_rip_control(self, **kwargs):
		""" Stop, start, or restart the protocol.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_rip_control
			 	[-port_handle        ANY]
			 	[-handle             ANY]
			 	[-mode               ANY]
			 	[-advertise          ANY]
			 	[-withdraw           ANY]
			n	[-flap_routes        ANY]
			n	[-flap_count         ANY]
			n	[-flap_interval_time ANY]
		
		Arguments:
			 	-port_handle
			 		Port where to take the RIP action.
			 	-handle
			 		Session where to take the RIP action.
			 	-mode
			 		Stop, start, restart the protocol or flap routes.
			 	-advertise
			 		Advertise prefixes in route pool.
			 	-withdraw
			 		Withdraw prefixes in route pool
			n	-flap_routes
			n	-flap_count
			n	-flap_interval_time
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		See files starting with RIP_ in the Samples subdirectory.  Also see some of the L3VPN and MPLS sample files for further examples of the RIP usage.
		See the RIP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_rip_control", kwargs)

	def emulation_rip_route_config(self, **kwargs):
		""" This procedure will configure RIP routes to a targeted RIP router.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_rip_route_config
			 	-mode           ANY
			 	[-handle        ANY]
			 	[-route_handle  ANY]
			 	[-num_prefixes  ANY]
			 	[-prefix_start  ANY]
			 	[-prefix_length ANY]
			 	[-prefix_step   ANY]
			 	[-metric        ANY]
			 	[-next_hop      ANY]
			 	[-route_tag     ANY]
		
		Arguments:
			 	-mode
			 		The action to be taken. The choices for mode are: create, modify, and delete.
			 	-handle
			 		Session to create route pools or route ranges on.
			 	-route_handle
			 		The route handle is used for modes other than create.
			 	-num_prefixes
			 		Number of prefixes (routes) advertised in update messages. RANGE 1-1000000.
			 	-prefix_start
			 		First route (prefix) to be advertised.
			 	-prefix_length
			 		Network mask width. RANGE 1-128.
			 	-prefix_step
			 		How to increment prefixes.Default is using prefix length (minimum step).The value would be rounded to the prefix length.
			 	-metric
			 		The total cost for these routes.RANGE 0-4,294,967,295.
			 	-next_hop
			 		The immediate next hop IP address on the way to the destination prefix.Used by RIPv2 &amp;amp; RIPng, default is all zeros IP address which indicates the next hop is update source address.
			 	-route_tag
			 		An arbitrary value associated with the routes in this range.Used by RIPv2 &amp;amp; RIPng.RANGE 0-65535.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status        value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information
			 key:log           value:When status is failure, contains more information
		The list of route range numbers added
			 key:route_handle  value:The list of route range numbers added
		
		Examples:
		See files starting with RIP_ in the Samples subdirectory.  Also see some of the L3VPN and MPLS sample files for further examples of the RIP usage.
		See the RIP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_rip_route_config", kwargs)

	def emulation_rsvpte_tunnel_control(self, **kwargs):
		""" Control Operation on the RSVP TE Tunnel     The following operations are done:     1. Start     2. Stop     3. Restart     4. Restart Down     5. Abort     6. Graft SubLSP     7. Prune SubLSP
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_rsvpte_tunnel_control
			 	-mode                        CHOICES restart
			                              CHOICES start
			                              CHOICES restart_down
			                              CHOICES stop
			                              CHOICES abort
			                              CHOICES make_before_break
			                              CHOICES initiate_path_reoptimization
			                              CHOICES graft_sub_lsp
			                              CHOICES prune_sub_lsp
			                              CHOICES p2mp_make_before_break
			                              CHOICES p2mp_initiate_path_reoptimization
			                              CHOICES exclude_ero_or_sero
			                              CHOICES include_ero_or_sero
			                              CHOICES egress_graft_sub_lsp
			                              CHOICES egress_prune_sub_lsp
			                              CHOICES pcep_delegate
			                              CHOICES pcep_revoke_delegation]
			 	[-handle                     ANY]
			x	[-graft_sub_lsp_id           NUMERIC]
			x	[-prune_sub_lsp_id           NUMERIC]
			x	[-egress_graft_sub_lsp_id    NUMERIC]
			x	[-egress_prune_sub_lsp_id    NUMERIC]
			x	[-include_ero_or_sero_lsp_id NUMERIC]
			x	[-exclude_ero_or_sero_lsp_id NUMERIC]
		
		Arguments:
			 	-mode
			 		What is being done to the protocol.Valid choices are:
			 		restart - Restart the protocol.
			 		start- Start the protocol.
			 		stop- Stop the protocol.
			 		restart_down- Restart the down sessions.
			 		abort- Abort the protocol.
			 		Valid choices are:
			    		restart - Restart the protocol.
			    		start - Start the protocol.
			    		restart_down - restart the down sessions
			    		stop - Stop the protocol.
			    		abort - Abort.
			    		make_before_break - Make Before Break.
			    		initiate_path_reoptimization - Initiate Path Reoptimization.
			    		graft_sub_lsp - Graft SubLSP
			    		prune_sub_lsp - Prune SubLSP
			    		p2mp_make_before_break - Make Before Break
			    		p2mp_initiate_path_reoptimization - Initiate Path Reoptimization
			    		exclude_ero_or_sero - Exclude ERO/SERO
			    		include_ero_or_sero - Include ERO/SERO
			    		egress_graft_sub_lsp - Graft SubLSP
			    		egress_prune_sub_lsp - Prune SubLSP
			    		pcep_delegate - Pcep Delegate
			    		pcep_revoke_delegation - Pcep Revoke Delegation
			 	-handle
			 		RSVP TE Tunnel handle where the rsvp te tunnel control action is applied.
			x	-graft_sub_lsp_id
			x		The index of the Sub LSP which is to be grafted. This argument MUST be specified when grafting Sub LSPs.
			x	-prune_sub_lsp_id
			x		The index of the Sub LSP which is to be pruned. This argument MUST be specified when pruning Sub LSPs.
			x	-egress_graft_sub_lsp_id
			x		The index of the Sub LSP which is to be grafted. This argument MUST be specified when grafting Sub LSPs.
			x	-egress_prune_sub_lsp_id
			x		The index of the Sub LSP which is to be pruned. This argument MUST be specified when pruning Sub LSPs.
			x	-include_ero_or_sero_lsp_id
			x		The index of the Sub LSP whose ERO or SERO is to be included. This argument MUST be specified when trying to include ERO or SERO.
			x	-exclude_ero_or_sero_lsp_id
			x		The index of the Sub LSP whose ERO or SERO is to be excluded. This argument MUST be specified when trying to exclude ERO or SERO.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		For modes pcep_delegate and pcep_revoke_delegation, node handle of corresponding LSP type needs to be provided.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_rsvpte_tunnel_control", kwargs)

	def emulation_rsvp_config(self, **kwargs):
		""" This procedure will configure RSVP TE
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_rsvp_config
			 	-mode                                         CHOICES create
			                                               CHOICES delete
			                                               CHOICES modify
			                                               CHOICES enable
			                                               CHOICES disable
			 	[-port_handle                                 REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle                                      ANY]
			x	[-return_detailed_handles                     CHOICES 0 1
			x                                              DEFAULT 0]
			 	[-count                                       ANY
			                                               DEFAULT 1]
			 	[-mac_address_init                            MAC]
			x	[-mac_address_step                            MAC
			x                                              DEFAULT 0000.0000.0001]
			x	[-vlan                                        CHOICES 0 1]
			 	[-vlan_id                                     RANGE 0-4095]
			 	[-vlan_id_mode                                CHOICES fixed increment
			                                               DEFAULT increment]
			 	[-vlan_id_step                                RANGE 0-4096
			                                               DEFAULT 1]
			 	[-vlan_user_priority                          RANGE 0-7
			                                               DEFAULT 0]
			 	[-intf_ip_addr                                IPV4
			                                               DEFAULT 0.0.0.0]
			 	[-intf_prefix_length                          RANGE 1-32
			                                               DEFAULT 24]
			 	[-intf_ip_addr_step                           IPV4
			                                               DEFAULT 0.0.1.0]
			x	[-gateway_ip_addr                             IPV4]
			x	[-gateway_ip_addr_step                        IPV4
			x                                              DEFAULT 0.0.1.0]
			x	[-using_gateway_ip                            CHOICES 0 1]
			x	[-dut_ip                                      ANY]
			x	[-label_space_start                           ANY]
			x	[-label_space_end                             ANY]
			x	[-enable_refresh_reduction                    CHOICES 0 1]
			x	[-summary_refresh_interval                    ANY]
			x	[-enable_bundle_message_sending               CHOICES 0 1]
			x	[-enable_hello_extension                      CHOICES 0 1]
			x	[-hello_interval                              ANY]
			x	[-hello_timeout_multiplier                    ANY]
			x	[-enable_graceful_restart_helper_mode         CHOICES 0 1]
			x	[-enable_graceful_restart_restarting_mode     CHOICES 0 1]
			x	[-advertised_restart_time                     ANY]
			x	[-actual_restart_time                         ANY]
			x	[-recovery_time                               ANY]
			x	[-number_of_restarts                          ANY]
			x	[-restart_start_time                          ANY]
			x	[-restart_up_time                             ANY]
			x	[-enable_bfd_registration                     CHOICES 0 1]
			x	[-rsvp_neighbor_active                        CHOICES 0 1]
			x	[-enable_bundle_message_threshold_timer       ANY]
			x	[-bundle_message_threshold_time               ANY]
			x	[-use_same_authentication_keyfor_peer         ANY]
			x	[-authentication_algorithm                    CHOICES none md5 sha1]
			x	[-handshake_required                          ANY]
			x	[-check_integrityfor_received_packets         ANY]
			x	[-authentication_keyfor_received_packets      ANY]
			x	[-auto_generate_authentication_key_identifier ANY]
			x	[-authentication_key_identifier               ANY]
			x	[-generate_sequence_number_basedon_real_time  ANY]
			x	[-initial_sequence_number                     ANY]
			x	[-authentication_key_for_sent_packets         ANY]
			 	[-bundle_msgs                                 ANY]
			 	[-egress_label_mode                           ANY]
			 	[-graceful_restart                            ANY]
			 	[-graceful_restart_recovery_time              ANY]
			 	[-graceful_restart_restart_time               ANY]
			 	[-hello_msgs                                  ANY]
			 	[-hello_retry_count                           ANY]
			 	[-max_label_value                             ANY]
			 	[-min_label_value                             ANY]
			 	[-neighbor_intf_ip_addr                       ANY]
			 	[-neighbor_intf_ip_addr_step                  ANY]
			 	[-path_state_refresh_timeout                  ANY]
			 	[-path_state_timeout_count                    ANY]
			 	[-record_route                                ANY]
			 	[-refresh_interval                            ANY]
			 	[-refresh_reduction                           ANY]
			 	[-refresh_retry_count                         ANY]
			 	[-reliable_delivery                           ANY]
			 	[-resv_confirm                                ANY]
			 	[-resv_state_refresh_timeout                  ANY]
			 	[-resv_state_timeout_count                    ANY]
			 	[-router_alert                                ANY]
			 	[-srefresh_interval                           ANY]
			 	[-summary_refresh                             ANY]
			 	[-ttl                                         ANY]
			 	[-vci                                         ANY]
			 	[-vci_step                                    ANY]
			 	[-vpi                                         ANY]
			 	[-vpi_step                                    ANY]
			x	[-atm_encapsulation                           ANY]
			x	[-bfd_registration                            ANY]
			x	[-bundle_msg_sending                          ANY]
			x	[-enable_bgp_over_lsp                         ANY]
			x	[-graceful_restart_helper_mode                ANY]
			x	[-graceful_restart_start_time                 ANY]
			x	[-graceful_restart_up_time                    ANY]
			x	[-graceful_restarts_count                     ANY]
			x	[-hello_tlvs                                  ANY]
			x	[-interface_handle                            ANY]
			x	[-ip_version                                  ANY]
			x	[-no_write                                    ANY]
			x	[-override_existence_check                    ANY]
			x	[-override_tracking                           ANY]
			x	[-reset                                       ANY]
			x	[-writeFlag                                   ANY]
			n	[-vlan_cfi                                    ANY]
			n	[-bundle_interval                             ANY]
			n	[-cfi                                         ANY]
			n	[-loopback_ip_addr                            ANY]
			n	[-max_ack_delay                               ANY]
			n	[-max_lsps                                    ANY]
			n	[-mtu                                         ANY]
			n	[-precedence                                  ANY]
			n	[-rapid_retx_delta                            ANY]
			n	[-rapid_retx_interval                         ANY]
			n	[-rapid_retx_limit                            ANY]
			n	[-timeout                                     ANY]
		
		Arguments:
			 	-mode
			    		create -
			    		delete -
			    		modity -
			    		enable -
			    		disable -
			 	-port_handle
			 	-handle
			 		Specifies the parent node/object handle on which the rsvp configuration should be configured.
			 		In case modesmodify/delete/disable/enablethis denotes the object node handle on which the action needs to be performed. The handle value syntax is dependent on the vendor.
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-count
			 		The number of RsvpIf to configure on the targeted Ixia
			 		interface.The range is 0-1000.
			 	-mac_address_init
			 		MAC address to be used for the first session.
			x	-mac_address_step
			x		Valid only for -mode create.
			x		The incrementing step for the MAC address configured on the dirrectly
			x		connected interfaces. Valid only when IxNetwork Tcl API is used.
			x	-vlan
			x		Enables vlan on the directly connected ISIS router interface.
			x		Valid options are: 0 - disable, 1 - enable.
			x		This option is valid only when -mode is create or -mode is modify
			x		and -handle is an ISIS router handle.
			 	-vlan_id
			 		VLAN ID for protocol interface.
			 	-vlan_id_mode
			 		For multiple neighbor configuration, configures the VLAN ID mode.
			 		Valid choices are:
			    		fixed - VLAN ID mode is fixed.
			    		increment - (default) VLAN ID mode to increment.
			 	-vlan_id_step
			 		Valid only for -mode create.
			 		Defines the step for the VLAN ID when the VLAN ID mode is increment.
			 		When vlan_id_step causes the vlan_id value to exceed its maximum value the
			 		increment will be done modulo <number of possible vlan ids>.
			 		Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0
			 		vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			 	-vlan_user_priority
			 		VLAN user priority assigned to protocol interface.
			 	-intf_ip_addr
			 		Interface IP address of the RSVP session router. Mandatory when -mode is create.
			 		When using IxTclNetwork (new API) this parameter can be omitted if -interface_handle is used.
			 		For IxTclProtocol (old API), when -mode is modify and one of the layer
			 		2-3 parameters (-intf_ip_addr, -gateway_ip_addr, -loopback_ip_addr, etc)
			 		needs to be modified, the emulation_ldp_config command must be provided
			 		with the entire list of layer 2-3 parameters. Otherwise they will be
			 		set to their default values.
			 	-intf_prefix_length
			 		Prefix length on the interface.
			 	-intf_ip_addr_step
			 		Define interface IP address for multiple sessions.
			 		Valid only for -mode create.
			x	-gateway_ip_addr
			x		Gives the gateway IP address for the protocol interface that will
			x		be created for use by the simulated routers.
			x	-gateway_ip_addr_step
			x		Valid only for -mode create.
			x		Gives the step for the gateway IP address.
			x	-using_gateway_ip
			x		Using Gateway IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dut_ip
			x		DUT IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-label_space_start
			x		Label Space Start
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-label_space_end
			x		Label Space End
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_refresh_reduction
			x		Enable Refresh Reduction
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-summary_refresh_interval
			x		Summary Refresh Interval (ms)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_bundle_message_sending
			x		Enable Bundle Message Sending
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_hello_extension
			x		Enable Hello Extension
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-hello_interval
			x		Hello Interval (ms)
			x	-hello_timeout_multiplier
			x		Hello Timeout Multiplier
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_graceful_restart_helper_mode
			x		Enable Helper-Mode
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_graceful_restart_restarting_mode
			x		Enable Restarting-Mode
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-advertised_restart_time
			x		Advertised Restart Time (ms)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-actual_restart_time
			x		Actual Restart Time (ms)
			x	-recovery_time
			x		Recovery Time (ms)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-number_of_restarts
			x		Number of Restarts
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-restart_start_time
			x		Restart Start Time (ms)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-restart_up_time
			x		Restart Up Time (ms)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_bfd_registration
			x		Enable BFD Registration
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-rsvp_neighbor_active
			x		Activate/Deactivate Configuration
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_bundle_message_threshold_timer
			x		Enable Bundle Message Threshold Timer
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-bundle_message_threshold_time
			x		Bundle Message Threshold Time (ms)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-use_same_authentication_keyfor_peer
			x		Use Same Authentication Key for Peer
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-authentication_algorithm
			x		Authentication Algorithm
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		none -
			x   		md5 -
			x   		sha1 -
			x	-handshake_required
			x		Handshake Required
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-check_integrityfor_received_packets
			x		Check Integrity for Received Packets
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-authentication_keyfor_received_packets
			x		Authentication Key for Received Packets
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-auto_generate_authentication_key_identifier
			x		Auto Generate Authentication Key Identifier
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-authentication_key_identifier
			x		Authentication Key Identifier
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-generate_sequence_number_basedon_real_time
			x		Generate Sequence Number Based on Real Time
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-initial_sequence_number
			x		Initial Sequence Number
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-authentication_key_for_sent_packets
			x		Authentication Key for Sent Packets
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-bundle_msgs
			 		If set to 1, combines multiple RSVP messages into a single PDU to reduce processing overhead and bandwidth consumption. If set to 0, does not combine messages.refresh_reduction, reliable_delivery, summary_refresh, and bundle_msgs work together.If anyone of them is turned on, all the options are enabled.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-egress_label_mode
			 		Specifies the label advertisement for the egress of an LSP as one of nextlabel - Advertises the next available label.exnull- Advertises label 9, the explicit null label.imnull- Advertises label 3, the implicit null label.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-graceful_restart
			 		Available only with IxTclNetwork.If true (1), enable graceful restart which adds RESTART_CAP object in Hello messages. Enable this will enable hello_msgs automatically.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-graceful_restart_recovery_time
			 		Available only with IxTclNetwork.Recovery Time ( in ms ). Minimum value 0 ms. Ixia will wait for this configured interval for the DUT to help it recover the egress LSPs. If no recovery label is received from the DUT within this time, those Egress LSPs would be treated as having time-outed i.e. labels will be removed. If 0 Recovery-time is configured, then the restarting Ixia side will tear down its Egress sessions as soon as the Restart period ends, but no Resv Tear message will be sent.This parameter is valid only when -graceful_restart is 1 AND the graceful_restarts_number value is greater than 1
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-graceful_restart_restart_time
			 		Available only with IxTclNetwork.Restart Start Time in ms. Minimum value 100 ms ( Immediate Restart ).We will stop sending Hellos after this timer gets fired, from the time the Neighborship comes up.This parameter is valid only when -graceful_restart is 1.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-hello_msgs
			 		Enables (1) ordisables (0) hello timer/messages.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-hello_retry_count
			 		Specifies the number of timeout intervals to wait until a session timeout occurs.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-max_label_value
			 		Specifies the maximum LSP label value.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-min_label_value
			 		Specifies the minimum LSP label value.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-neighbor_intf_ip_addr
			 		The interface IP address of RSVP neighbor (next hop).
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-neighbor_intf_ip_addr_step
			 		The neightbor IP address octet to be incremented by given step
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-path_state_refresh_timeout
			 		Specifies the timeout interval in seconds to wait before sending a Path message.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-path_state_timeout_count
			 		Specifies the number of Path state intervals to wait before a teardown message is sent.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-record_route
			 		If set to 1, includes the RECORD_ROUTE object in the Path message. If set to 0, does not include the RECORD_ROUTE object in the Path message.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-refresh_interval
			 		Specifies the time in milliseconds between seding RSVP messages to refresh state.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-refresh_reduction
			 		Enables (1) or disables (0) refresh reduction.refresh_reduction, reliable_delivery, summary_refresh, and bundle_msgs work together. If anyone of them is turns on, all the options are enabled.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-refresh_retry_count
			 		Specifies the number of refresh intervals to wait before RSVP state is turned down.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-reliable_delivery
			 		If set to 1, sends message IDs and acknowledgements for each message received. If set to 0, which is the default value, does not send message IDs.refresh_reduction, reliable_delivery, summary_refresh, and bundle_msgs work together.If anyone of them is turns on, all the options are enabled.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-resv_confirm
			 		If set to 1, enables and requires Resv confirmation with final parameters from the egress. If set to 0, which is the default value, disables the sending of Resv confirmation messages.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-resv_state_refresh_timeout
			 		Specifies the timeout interval in seconds to wait before sending a Resv message.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-resv_state_timeout_count
			 		Specifies the number of Resv state intervals to wait before a teardown message is sent.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-router_alert
			 		If set to 1, enables a router to recognize the router alert option in a packet.This option is always set to 1.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-srefresh_interval
			 		Specifies the time interval in ms to gather refresh messages that would have been sent out individually. Messages are sent out as a single refresh message upon interval expiration or when the message size exceeds the MTU.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-summary_refresh
			 		If set to 1, enable summary refresh generation. refresh_reduction, reliable_delivery, summary_refresh, and bundle_msgs work together. If anyone of them is turns on, all the options are enabled.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-ttl
			 		Time-to-live value used n RSVP header.It is not user configurable. By default it is 1 for hello messages and for anything else it is 64.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vci
			 		VCI for emulated router node. RANGE 0-65535
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vci_step
			 		The step value used for incrementing the -vci option. RANGE 0-65535 When vci_step causes the vci value to exceed it's maximum value the increment will be done modulo <number of possible vci ids>.Examples: vci = 65534; vci_step = 2-> new vci value = 0vci = 65535; vci_step = 11 -> new vci value = 10
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vpi
			 		VPI for emulated router node. RANGE 0-255
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vpi_step
			 		The step value used for incrementing the -vpi option. RANGE 0-255When vpi_step causes the vpi value to exceed it's maximum value the increment will be done modulo <number of possible vpi ids>.Examples: vpi = 254; vpi_step = 2-> new vpi value = 0vpi = 255; vpi_step = 11 -> new vpi value = 10
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-atm_encapsulation
			x		The encapsulation of the ATM protocol interface associated with the emulated router.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-bfd_registration
			x		Enable or disable BFD registration.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-bundle_msg_sending
			x		Enable or disable bundle message sending.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-enable_bgp_over_lsp
			x		Available only with IxTclNetwork.Enables the ability to exchange labels over LSP for VPNs. When a protocol packet is transmitted by an Ixia port and the IP details match an established LSP, the packet is MPLS encapsulated. The MPLS label is set to the value learned from the LSP.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-graceful_restart_helper_mode
			x		Available only with IxTclNetwork.If true (1), enable graceful restart helper mode.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-graceful_restart_start_time
			x		Available only with IxTclNetwork.Restart Start Time in ms. Minimum value 50 ms ( Immediate Restart ).We will stop sending Hellos after this timer gets fired, from the time the Neighborship comes up.This parameter is valid only when -graceful_restart is 1.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-graceful_restart_up_time
			x		Available only with IxTclNetwork.Restart Up time in ms. Minimum value 50 ms. After the Restarting time is over, Ixia will wait for this configured interval before trying to repeat the Restart cycle. This is effective only untill the number of restarts is not equal to the user-configured number of Graceful Restart cycles. After that Ixia will not take any action to being down a Neighborship on its own.This parameter is valid only when -graceful_restart is 1 AND the graceful_restarts_count value is greater than 1
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-graceful_restarts_count
			x		Available only with IxTclNetwork.Number of Restart. The number of times the Ixia emulated RSVP neighbor will move to Restarting / Recovering and Up states before stopping the cycle.This parameter is valid only when -graceful_restart is 1
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-hello_tlvs
			x		Available only with IxTclNetwork.Generalized TLV messages that are included with all HELLO. Allows the user to custom-configure the optional Hello extension for sending Hello Messages between immediate RSVP neighbors - for determining reachability. The Hello extension contains a Hello message (Class Type = 20), a Hello Request object, and a Hello Ack object, as specified in RFC 3209. Struct of form class,cType,data:class,cType,data:...Example: "22,1,aa:22,2,bb:23,2,13"class = The class distinguisher of the TLV. The HELLOclass is 22.cType = The C-Type distinguisher of the TLV. The C_Type of the included Object. C_Type 1 = Hello Request; C_Type 2 = Hello Acknowledgement.data = The data associated with the TLV. The length of the TLV will be calculated from the length of this data. One 32-bit Source Instance plus one 32-bit Destination Instance for each object: For the Hello Request, the instance value is changed due to sender reset or reboot, or when link to the neighbor is down. It must not be set to 0. For the Hello Ack, the most recent instance value received from the neighbor. It must = 0 if no instance value has ever been received from that neighbor.When -mode is create and -count > 1 the value of this parameter will be set on ALL neighbor pairs created.When -mode is modify and a list of handles is passed to -handle parameter: if hello_tlvs is a list of parameters, it must either have the same length as the list of handles and each hello_tlv value from the list will be set on the according rsvp handle; if hello_tlvs is a single value, it will be set on ALL handles from the handle list. Trying to modify this parameter will overwrite previous values.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-interface_handle
			x		A handle or list of the handles that are returned from the interface_config call.These provide a direct link to an already existing interface and supercede the use of the intf_ip_addr value.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-ip_version
			x		The IP version interface.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-no_write
			x		If this option is present, the configuration is not written to the hardware. This option can be used to queue up multiple configurations before writing to the hardware.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-override_existence_check
			x		If this option is enabled, the interface existence check is skipped but the list of interfaces is still created and maintained in order to keep track of existing interfaces if required. Using this option will speed up the creation of the interfaces.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-override_tracking
			x		If this option is enabled, the list of interfaces will no longer be created and maintained, thus speeding up the creation of interfaces even more. Also, it will enable -override_existence_check in case it was not already enabled because checking for interface existence becomes impossible if the list of interfaces does not exist anymore.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-reset
			x		If this option is present, all the neightbor pair on the router is deleted.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-writeFlag
			x		DEPRECATED - use -no_write instead.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			n	-vlan_cfi
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-bundle_interval
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-cfi
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-loopback_ip_addr
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-max_ack_delay
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-max_lsps
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-mtu
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-precedence
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-rapid_retx_delta
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-rapid_retx_interval
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-rapid_retx_limit
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-timeout
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
		
		Return Values:
		A list containing the ipv4 protocol stack handles that were added by the command (if any).
			xkey:ipv4_handle                       value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		A list containing the ethernet protocol stack handles that were added by the command (if any).
			xkey:ethernet_handle                   value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE
			 key:status                            value:$::SUCCESS | $::FAILURE
		When status is $::FAILURE, contains more information
			 key:log                               value:When status is $::FAILURE, contains more information
		RSVP IF configured
			 key:rsvp_if_handle                    value:RSVP IF configured
		When status is failure, contains more information
			 key:log                               value:When status is failure, contains more information
		The handles for the RSVP TE created
			 key:handles                           value:The handles for the RSVP TE created
		Handle of protocol interface
			 key:router_interface_handle.<handle>  value: Handle of protocol interface
		
		Examples:
		See files starting with RSVP_ in the Samples subdirectory.  Also see some of the MVPN sample files for further examples of the RSVP usage.
		See the RSVP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_rsvp_config", kwargs)

	def emulation_rsvp_control(self, **kwargs):
		""" Stop, start or restart the RSVP protocol
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_rsvp_control
			 	-mode                CHOICES restart
			                      CHOICES start
			                      CHOICES restart_down
			                      CHOICES stop
			                      CHOICES abort
			                      CHOICES restart_neighbor
			                      CHOICES start_hello
			                      CHOICES stop_hello
			                      CHOICES start_s_refresh
			                      CHOICES stop_s_refresh
			 	[-handle             ANY]
			 	[-port_handle        ANY]
			 	[-restore            ANY]
			 	[-teardown           ANY]
			n	[-flap_count         ANY]
			n	[-flap_down_time     ANY]
			n	[-flap_interval_time ANY]
		
		Arguments:
			 	-mode
			 		What is being done to the protocol.Valid choices are:
			 		restart - Restart the protocol.
			 		start- Start the protocol.
			 		stop- Stop the protocol.
			 		restart_down- Restart the down sessions.
			 		abort- Abort the protocol.
			 		restart_neighbor - Restart the Neighbor.
			 		Valid choices are:
			    		restart - Restart the protocol.
			    		start - Start the protocol.
			    		restart_down - restart the down sessions
			    		stop - Stop the protocol.
			    		abort - Abort.
			    		restart_neighbor - Restart Neighbor.
			    		start_hello - Start Hello.
			    		stop_hello - Stop Hello.
			    		start_s_refresh - Start SRefresh.
			    		stop_s_refresh - Stop SRefresh.
			 	-handle
			 		RSVP TE handle where the rsvp control action is applied.
			 	-port_handle
			 		The port where the RSVP is to be controlled.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-restore
			 		Set up the list of LSP tunnels when mode is start or restore.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-teardown
			 		Tear down the list of LSP tunnels when mode is stop or restore.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_count
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_down_time
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-flap_interval_time
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		See files starting with RSVP_ in the Samples subdirectory.  Also see some of the MVPN sample files for further examples of the RSVP usage.
		See the RSVP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		
		See Also:
		
		"""
		return self._run_keyword("emulation_rsvp_control", kwargs)

	def emulation_rsvp_info(self, **kwargs):
		""" For a test port running RSVP emulation, retrieves the RSVP tunnel information for both incoming and outgoing tunnels.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_rsvp_info
			x	-mode                        CHOICES stats
			x                             CHOICES clear_stats
			x                             CHOICES fetch_info
			x                             CHOICES learned_info]
			 	-handle                      ANY]
			 	[-port_handle                REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-lsp_delegation_state       FLAG]
			x	[-re_delegation_timer_status FLAG]
			x	[-session_information        FLAG]
			x	[-lsp_self_ping_status       FLAG]
		
		Arguments:
			x	-mode
			x   		stats - Gather RSVP statistics.
			x   		clear_stats - Clear RSVP TE IF statistics.
			x   		fetch_info - Get RSVP TE Info.
			x   		learned_info - Get RSVP TE IF Learned Information
			 	-handle
			 		The RSVP-TE IF handle to act upon.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-port_handle
			x	-lsp_delegation_state
			x		Get LSP Delegation State of RSVP-TE p2p Head ( Ingress ) LSPs
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-re_delegation_timer_status
			x		Get Re-Delegation Timer Status of RSVP-TE p2p Head ( Ingress ) LSPs
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-session_information
			x		Get Session Information of RSVP-TE PCEP Expected Initiated LSPs
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lsp_self_ping_status
			x		Get the LSP Self Ping Status ( Ingress ) LSPs.
			x		This is a read-only field that shows the status of the LSP Self Ping session.
			x		The status can be one of following based on different scenarios: Success, Timed Out.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                         value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                                            value:If status is failure, detailed information provided.
		Sessions Up
			xkey:sessions_up                                    value:Sessions Up
		Sessions Down
			xkey:sessions_down                                  value:Sessions Down
		Sessions Not Started
			xkey:sessions_not_started                           value:Sessions Not Started
		Sessions Total
			xkey:sessions_total                                 value:Sessions Total
		Ingress Lsps Configured
			nkey:ingress_lsps_configured                        value:Ingress Lsps Configured
		Ingress SubLSPs Configured
			nkey:ingress_sub_lsps_configured                    value:Ingress SubLSPs Configured
		Ingress Lsps Up
			nkey:ingress_lsps_up                                value:Ingress Lsps Up
		The number of LSP self ping messages transmitted by Ingress.
			nkey:lsp_self_ping_sent_from_ingress                value:The number of LSP self ping messages transmitted by Ingress.
		The number of LSP self ping messages received by Ingress.
			nkey:lsp_self_ping_received_by_ingress              value:The number of LSP self ping messages received by Ingress.
		The number of LSP self ping messages received by Egress.
			nkey:lsp_self_ping_received_by_egress               value:The number of LSP self ping messages received by Egress.
		The number of LSP self ping messages forwarded by Egress.
			nkey:lsp_self_ping_forwarded_by_egress              value:The number of LSP self ping messages forwarded by Egress. 
		Ingress SubLSPs Up
			nkey:ingress_sub_lsps_up                            value:Ingress SubLSPs Up
		Egress LSPs Up
			nkey:egress_lsps_up                                 value:Egress LSPs Up
		Egress Sub LSPs Up
			nkey:egress_sub_lsps_up                             value:Egress Sub LSPs Up
		Session Flap Count
			nkey:session_flap_count                             value:Session Flap Count
		Down State Count
			nkey:down_state_count                               value:Down State Count
		Path Sent State Count
			nkey:path_sent_state_count                          value:Path Sent State Count
		Up State Count
			nkey:up_state_count                                 value:Up State Count
		Paths Tx
			nkey:paths_tx                                       value:Paths Tx
		Paths Rx
			nkey:paths_rx                                       value:Paths Rx
		Resvs Tx
			nkey:resvs_tx                                       value:Resvs Tx
		Resvs Rx
			nkey:resvs_rx                                       value:Resvs Rx
		Path Tears Tx
			nkey:path_tears_tx                                  value:Path Tears Tx
		Path Tears Tx
			 key:path_tears_rx                                  value:Path Tears Tx
		Resv Tears Tx
			 key:resv_tears_tx                                  value:Resv Tears Tx
		Resv Tears Rx
			 key:resv_tears_rx                                  value:Resv Tears Rx
		Path Errs Tx
			 key:path_errs_tx                                   value:Path Errs Tx
		Path Errs Rx
			 key:path_errs_rx                                   value:Path Errs Rx
		Resv_Errs_Tx
			 key:resv_errs_tx                                   value:Resv_Errs_Tx
		Resv Errs Rx
			 key:resv_errs_rx                                   value:Resv Errs Rx
		Resv Confs Tx
			 key:resv_confs_tx                                  value:Resv Confs Tx
		Resv Confs Rx
			 key:resv_confs_rx                                  value:Resv Confs Rx
		Ingress Out Of Order Messages Rx
			 key:ingress_out_of_order_messages_rx               value:Ingress Out Of Order Messages Rx
		Egress Out Of Order Messages Rx
			 key:egress_out_of_order_messages_rx                value:Egress Out Of Order Messages Rx
		Hellos Tx
			 key:hellos_tx                                      value:Hellos Tx
		Hellos Rx
			nkey:hellos_rx                                      value:Hellos Rx
		Acks Tx
			nkey:acks_tx                                        value:Acks Tx
		Acks Tx
			nkey:acks_rx                                        value:Acks Tx
		Nacks Tx
			 key:nacks_tx                                       value:Nacks Tx
		Nacks Rx
			nkey:nacks_rx                                       value:Nacks Rx
		Srefreshs Tx
			 key:srefreshs_tx                                   value:Srefreshs Tx
		Srefreshs Rx
			 key:srefreshs_rx                                   value:Srefreshs Rx
		Bundle Messages Tx
			 key:bundle_messages_tx                             value:Bundle Messages Tx
		Bundle Messages Rx
			 key:bundle_messages_rx                             value:Bundle Messages Rx
		Paths With Recovery Labels Tx
			 key:paths_with_recovery_labels_tx                  value:Paths With Recovery Labels Tx
		Paths With Recovery Labels Rx
			 key:paths_with_recovery_labels_rx                  value:Paths With Recovery Labels Rx
		Unrecovered Resvs Deleted
			 key:unrecovered_resvs_deleted                      value:Unrecovered Resvs Deleted
		Own Graceful Restarts
			 key:own_graceful_restarts                          value:Own Graceful Restarts
		Peer Graceful Restarts
			 key:peer_graceful_restarts                         value:Peer Graceful Restarts
		Number Of Path Reoptimizations
			 key:number_of_path_reoptimizations                 value:Number Of Path Reoptimizations
		Path Reevaluation Request Tx
			 key:path_reevaluation_request_tx                   value:Path Reevaluation Request Tx
		Device ID
			xkey:<handle>.assigned.device_id                    value:Device ID
		Our IP
			xkey:<handle>.assigned.our_ip                       value:Our IP
		DUT IP
			xkey:<handle>.assigned.dut_ip                       value:DUT IP
		Session IP
			xkey:<handle>.assigned.session_ip                   value:Session IP
		Tunnel ID
			xkey:<handle>.assigned.tunnel_id                    value:Tunnel ID
		Headend IP
			xkey:<handle>.assigned.headend_ip                   value:Headend IP
		LSP ID
			xkey:<handle>.assigned.lsp_id                       value:LSP ID
		Last Flap Reason
			xkey:<handle>.assigned.last_flap_reason             value:Last Flap Reason
		Current State
			xkey:<handle>.assigned.current_state                value:Current State
		Label Value
			xkey:<handle>.assigned.label                        value:Label Value
		Reservation State
			xkey:<handle>.assigned.reservation_state            value:Reservation State
		Setup Time(ms)
			xkey:<handle>.assigned.setup_time                   value:Setup Time(ms)
		Up Time(ms)
			xkey:<handle>.assigned.up_time                      value:Up Time(ms)
		BandWidth (in bps)
			xkey:<handle>.assigned.bandwidth                    value:BandWidth (in bps)
		ERO Type
			xkey:<handle>.assigned.ero_type                     value:ERO Type
		ERO IP
			xkey:<handle>.assigned.ero_ip                       value:ERO IP
		ERO Prefix Length
			xkey:<handle>.assigned.ero_prefix_length            value:ERO Prefix Length
		ERO AS Number
			xkey:<handle>.assigned.ero_as_number                value:ERO AS Number
		Device ID
			xkey:<handle>.received.device_id                    value:Device ID
		Our IP
			xkey:<handle>.received.our_ip                       value:Our IP
		DUT IP
			xkey:<handle>.received.dut_ip                       value:DUT IP
		Session IP
			xkey:<handle>.received.session_ip                   value:Session IP
		Tunnel ID
			xkey:<handle>.received.tunnel_id                    value:Tunnel ID
		Headend IP
			xkey:<handle>.received.headend_ip                   value:Headend IP
		LSP ID
			xkey:<handle>.received.lsp_id                       value:LSP ID
		Last Flap Reason
			xkey:<handle>.received.last_flap_reason             value:Last Flap Reason
		Current State
			xkey:<handle>.received.current_state                value:Current State
		Label Value
			xkey:<handle>.received.label                        value:Label Value
		Reservation State
			xkey:<handle>.received.reservation_state            value:Reservation State
		Setup Time(ms)
			xkey:<handle>.received.setup_time                   value:Setup Time(ms)
		Up Time(ms)
			xkey:<handle>.received.up_time                      value:Up Time(ms)
		BandWidth (in bps)
			xkey:<handle>.received.bandwidth                    value:BandWidth (in bps)
		ERO Type
			xkey:<handle>.received.ero_type                     value:ERO Type
		ERO IP
			xkey:<handle>.received.ero_ip                       value:ERO IP
		ERO Prefix Length
			xkey:<handle>.received.ero_prefix_length            value:ERO Prefix Length
		ERO AS Number
			xkey:<handle>.received.ero_as_number                value:ERO AS Number
		RRO Type
			xkey:<handle>.received.rro_type                     value:RRO Type
		RRO IP
			xkey:<handle>.received.rro_ip                       value:RRO IP
		RRO Label
			xkey:<handle>.received.rro_label                    value:RRO Label
		RRO C-Type
			xkey:<handle>.received.rro_c_type                   value:RRO C-Type
		Symbolic Path Name
			xkey:<handle>.received.symbolic_path_name           value:Symbolic Path Name
		Device ID
			xkey:<handle>.p2mpassigned.device_id                value:Device ID
		Our IP
			xkey:<handle>.p2mpassigned.our_ip                   value:Our IP
		Dut IP
			xkey:<handle>.p2mpassigned.dut_ip                   value:Dut IP
		P2MP ID
			xkey:<handle>.p2mpassigned.p2mp_id                  value:P2MP ID
		P2MP ID as Number
			xkey:<handle>.p2mpassigned.p2mp_id_as_number        value:P2MP ID as Number
		Tunnel ID
			xkey:<handle>.p2mpassigned.tunnel_id                value:Tunnel ID
		Head End IP
			xkey:<handle>.p2mpassigned.head_end_ip              value:Head End IP
		LSP ID
			xkey:<handle>.p2mpassigned.lsp_id                   value:LSP ID
		Leaf IP
			xkey:<handle>.p2mpassigned.leaf_ip                  value:Leaf IP
		Sub Group Originator ID
			xkey:<handle>.p2mpassigned.sub_group_originator_id  value:Sub Group Originator ID
		Sub Group ID
			xkey:<handle>.p2mpassigned.sub_group_id             value:Sub Group ID
		Current State
			xkey:<handle>.p2mpassigned.current_state            value:Current State
		Last Flap Reason
			xkey:<handle>.p2mpassigned.last_flap_reason         value:Last Flap Reason
		Label
			xkey:<handle>.p2mpassigned.label                    value:Label
		Reservation State
			xkey:<handle>.p2mpassigned.reservation_state        value:Reservation State
		Setup Time(ms)
			xkey:<handle>.p2mpassigned.setup_time               value:Setup Time(ms)
		Up Time(ms)
			xkey:<handle>.p2mpassigned.up_time                  value:Up Time(ms)
		Device ID
			xkey:<handle>.p2mpreceived.device_id                value:Device ID
		Our IP
			xkey:<handle>.p2mpreceived.our_ip                   value:Our IP
		Dut IP
			xkey:<handle>.p2mpreceived.dut_ip                   value:Dut IP
		P2MP ID
			xkey:<handle>.p2mpreceived.p2mp_id                  value:P2MP ID
		P2MP ID as Number
			xkey:<handle>.p2mpreceived.p2mp_id_as_number        value:P2MP ID as Number
		Tunnel ID
			xkey:<handle>.p2mpreceived.tunnel_id                value:Tunnel ID
		Head End IP
			xkey:<handle>.p2mpreceived.head_end_ip              value:Head End IP
		LSP ID
			xkey:<handle>.p2mpreceived.lsp_id                   value:LSP ID
		Leaf IP
			xkey:<handle>.p2mpreceived.leaf_ip                  value:Leaf IP
		Sub Group Originator ID
			xkey:<handle>.p2mpreceived.sub_group_originator_id  value:Sub Group Originator ID
		Sub Group ID
			xkey:<handle>.p2mpreceived.sub_group_id             value:Sub Group ID
		Current State
			xkey:<handle>.p2mpreceived.current_state            value:Current State
		Last Flap Reason
			xkey:<handle>.p2mpreceived.last_flap_reason         value:Last Flap Reason
		Label
			xkey:<handle>.p2mpreceived.label                    value:Label
		Reservation State
			xkey:<handle>.p2mpreceived.reservation_state        value:Reservation State
		Setup Time(ms)
			xkey:<handle>.p2mpreceived.setup_time               value:Setup Time(ms)
		Up Time(ms)
			xkey:<handle>.p2mpreceived.up_time                  value:Up Time(ms)
		Routing Protocol
			 key:routing_protocol                               value:Routing Protocol
		Ingress Attempt Setup Msg
			 key:ingress_attempt_setup_msg                      value:Ingress Attempt Setup Msg
		CIngress Success Setup Msg
			 key:ingress_success_setup_msg                      value:CIngress Success Setup Msg
		Ingress Resv Errors
			 key:ingress_resv_errors                            value:Ingress Resv Errors
		Egress Attemp Setup Msg
			 key:egress_attemp_setup_msg                        value:Egress Attemp Setup Msg
		Egress Success Setup Msg
			 key:egress_success_setup_msg                       value:Egress Success Setup Msg
		Egress Resv Timeout
			 key:egress_resv_timeout                            value:Egress Resv Timeout
		Egress Resv Errors
			 key:egress_resv_errors                             value:Egress Resv Errors
		Msg Rx
			 key:msg_rx                                         value:Msg Rx
		Msg Tx
			 key:msg_tx                                         value:Msg Tx
		Lsp Created
			 key:lsp_created                                    value:Lsp Created
		Lsp Deleted
			 key:lsp_deleted                                    value:Lsp Deleted
		Total Setup Time
			 key:total_setup_time                               value:Total Setup Time
		Min Setup Time
			 key:min_setup_time                                 value:Min Setup Time
		Max Setup Time
			 key:max_setup_time                                 value:Max Setup Time
		Msg Retx
			 key:msg_retx                                       value:Msg Retx
		Out of Order Message
			 key:out_of_order_msg                               value:Out of Order Message
		
		Examples:
		See files starting with RSVP_ in the Samples subdirectory.  Also see some of the MVPN sample files for further examples of the RSVP usage.
		See the RSVP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		For  -mode choice fetch_info, provide handle of the node/object from which you need to fetch a property.
		Coded versus functional specification.For settings:intf_ip_address          a.b.c.dneighbor_intf_ip_addr    a.b.c.d
		For neighbors:neighbors                value:list of neighborsWhen P2MP is used, the neighbor list will have the following format:{ Type: P2MP Src: <traffic head IP> Dst: <p2mp id> T: <tunnel id> Leaf: <p2mp leaf ip> Label: <label> ReservationStateForGracefulRestart: <graceful restart reservation state>}For labels:labels                   value:list of labels in the following format{labels {\{LSP_tunnel1 label1} \{LSP_tunnel2 label2} \... ... ... ... ...  \{LSP_tunneln labeln} \}}
		
		See Also:
		
		"""
		return self._run_keyword("emulation_rsvp_info", kwargs)

	def emulation_rsvp_tunnel_config(self, **kwargs):
		""" This procedure will configure RSVP TE
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_rsvp_tunnel_config
			 	-mode                                               CHOICES create
			                                                     CHOICES delete
			                                                     CHOICES modify
			                                                     CHOICES enable
			                                                     CHOICES disable
			 	[-port_handle                                       REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle                                            ANY]
			x	[-return_detailed_handles                           CHOICES 0 1
			x                                                    DEFAULT 0]
			 	[-count                                             ANY
			                                                     DEFAULT 1]
			 	[-mac_address_init                                  MAC]
			x	[-mac_address_step                                  MAC
			x                                                    DEFAULT 0000.0000.0001]
			x	[-vlan                                              CHOICES 0 1]
			 	[-vlan_id                                           RANGE 0-4095]
			 	[-vlan_id_mode                                      CHOICES fixed increment
			                                                     DEFAULT increment]
			 	[-vlan_id_step                                      RANGE 0-4096
			                                                     DEFAULT 1]
			 	[-vlan_user_priority                                RANGE 0-7
			                                                     DEFAULT 0]
			 	[-intf_ip_addr                                      IPV4
			                                                     DEFAULT 0.0.0.0]
			 	[-intf_prefix_length                                RANGE 1-32
			                                                     DEFAULT 24]
			 	[-intf_ip_addr_step                                 IPV4
			                                                     DEFAULT 0.0.1.0]
			x	[-gateway_ip_addr                                   IPV4]
			x	[-gateway_ip_addr_step                              IPV4
			x                                                    DEFAULT 0.0.1.0]
			x	[-loopback_ip_addr                                  IPV4]
			x	[-loopback_ip_addr_step                             IPV4
			x                                                    DEFAULT 0.0.1.0]
			x	[-rsvp_p2p_egress_enable                            FLAG]
			x	[-rsvp_p2p_ingress_enable                           FLAG]
			x	[-rsvp_p2mp_egress_enable                           FLAG]
			x	[-rsvp_p2mp_ingress_enable                          FLAG]
			x	[-rsvp_p2mp_ingress_sublsp_enable                   FLAG]
			x	[-p2p_ingress_lsps_count                            NUMERIC]
			x	[-enable_p2p_egress                                 CHOICES 0 1]
			x	[-lsp_active                                        ANY]
			x	[-remote_ip                                         ANY]
			x	[-tunnel_id                                         ANY]
			x	[-lsp_id                                            ANY]
			x	[-bandwidth                                         ANY]
			x	[-ingress_refresh_interval                          ANY]
			x	[-ingress_timeout_multiplier                        ANY]
			x	[-do_mbb_on_apply_changes                           CHOICES 0 1]
			x	[-using_headend_ip                                  ANY]
			x	[-source_ip                                         ANY]
			x	[-autoroute_traffic                                 ANY]
			x	[-auto_generate_session_name                        ANY]
			x	[-session_name                                      ANY]
			x	[-setup_priority                                    ANY]
			x	[-holding_priority                                  ANY]
			x	[-local_protection_desired                          ANY]
			x	[-label_recording_desired                           ANY]
			x	[-se_style_desired                                  ANY]
			x	[-bandwidth_protection_desired                      ANY]
			x	[-node_protection_desired                           ANY]
			x	[-resource_affinities                               ANY]
			x	[-exclude_any                                       ANY]
			x	[-include_any                                       ANY]
			x	[-include_all                                       ANY]
			x	[-token_bucket_rate                                 ANY]
			x	[-token_bucket_size                                 ANY]
			x	[-peak_data_rate                                    ANY]
			x	[-minimum_policed_unit                              ANY]
			x	[-maximum_packet_size                               ANY]
			x	[-enable_fast_reroute                               ANY]
			x	[-fast_reroute_setup_priority                       ANY]
			x	[-fast_reroute_holding_priority                     ANY]
			x	[-hop_limit                                         ANY]
			x	[-fast_reroute_bandwidth                            ANY]
			x	[-fast_reroute_exclude_any                          ANY]
			x	[-fast_reroute_include_any                          ANY]
			x	[-fast_reroute_include_all                          ANY]
			x	[-one_to_one_backup_desired                         ANY]
			x	[-facility_backup_desired                           ANY]
			x	[-send_detour                                       ANY]
			x	[-number_of_detour_sub_objects                      NUMERIC]
			x	[-backup_lsp_id                                     ANY]
			x	[-backup_lsp_session_id                             NUMERIC]
			x	[-enable_path_re_optimization                       ANY]
			x	[-enable_periodic_re_evaluation_request             ANY]
			x	[-re_evaluation_request_interval                    ANY]
			x	[-enable_ero                                        ANY]
			x	[-prepend_dut_to_ero                                CHOICES dontprepend
			x                                                    CHOICES prependloose
			x                                                    CHOICES prependstrict]
			x	[-ingress_p2p_prefix_length                         ANY]
			x	[-number_of_ero_sub_objects                         NUMERIC]
			x	[-send_rro                                          ANY]
			x	[-ingress_number_of_rro_sub_objects                 NUMERIC]
			x	[-p2p_ingress_active                                ANY]
			x	[-plr_id                                            ANY]
			x	[-avoid_node_id                                     ANY]
			x	[-ero_type                                          CHOICES ip as]
			x	[-ero_ip                                            ANY]
			x	[-prefix_length                                     ANY]
			x	[-as_number                                         ANY]
			x	[-loose_flag                                        ANY]
			x	[-rro_type                                          CHOICES ip label]
			x	[-rro_ip                                            ANY]
			x	[-ingress_protection_available                      ANY]
			x	[-ingress_protection_in_use                         ANY]
			x	[-ingress_label                                     ANY]
			x	[-ingress_c_type                                    ANY]
			x	[-ingress_global_label                              ANY]
			x	[-ingress_bandwidth_protection                      ANY]
			x	[-ingress_node_protection                           ANY]
			x	[-egress_refresh_interval                           ANY]
			x	[-egress_timeout_multiplier                         ANY]
			x	[-send_reservation_confirmation                     ANY]
			x	[-enable_fixed_label_for_reservations               ANY]
			x	[-label_value                                       ANY]
			x	[-reservation_style                                 CHOICES se ff auto]
			x	[-reflect_rro                                       ANY]
			x	[-egress_number_of_rro_sub_objects                  NUMERIC]
			x	[-egress_active                                     ANY]
			x	[-egress_type                                       CHOICES ip label]
			x	[-egress_ip                                         ANY]
			x	[-egress_protection_available                       ANY]
			x	[-egress_protection_in_use                          ANY]
			x	[-egress_label                                      ANY]
			x	[-egress_c_type                                     ANY]
			x	[-egress_global_label                               ANY]
			x	[-egress_bandwidth_protection                       ANY]
			x	[-egress_node_protection                            ANY]
			x	[-source_ipv6                                       ANY]
			x	[-insert_ipv6_explicit_null                         ANY]
			x	[-end_point_ipv6                                    ANY]
			x	[-p2mp_ingress_lsp_count                            NUMERIC]
			x	[-p2mp_egress_tunnel_count                          NUMERIC]
			x	[-p2mp_egress_active                                ANY]
			x	[-type_p2mp_id                                      CHOICES iP p2MPId]
			x	[-p2mp_id_as_number                                 ANY]
			x	[-p2mp_id_ip                                        ANY]
			x	[-p2mp_egress_refresh_interval                      ANY]
			x	[-p2mp_egress_timeout_multiplier                    ANY]
			x	[-p2mp_send_reservation_confirmation                ANY]
			x	[-p2mp_enable_fixed_label_for_reservations          ANY]
			x	[-p2mp_label_value                                  ANY]
			x	[-p2mp_reservation_style                            CHOICES se ff auto]
			x	[-sub_lsps_down                                     ANY]
			x	[-p2mp_destination_ipv4_group_address               ANY]
			x	[-p2mp_end_point_ipv6                               ANY]
			x	[-p2mp_reflect_rro                                  ANY]
			x	[-p2mp_include_leaf_ip_at_bottom                    ANY]
			x	[-p2mp_include_connected_ip_on_top                  ANY]
			x	[-p2mp_send_as_rro                                  ANY]
			x	[-p2mp_send_as_srro                                 ANY]
			x	[-p2mp_egress_number_of_rro_sub_objects             NUMERIC]
			x	[-p2mp_egress_rro_type                              CHOICES ip label]
			x	[-p2mp_egress_ip                                    ANY]
			x	[-p2mp_egress_protection_available                  ANY]
			x	[-p2mp_egress_protection_in_use                     ANY]
			x	[-p2mp_egress_label                                 ANY]
			x	[-p2mp_egress_c_type                                ANY]
			x	[-p2mp_egress_global_label                          ANY]
			x	[-p2mp_egress_bandwidth_protection                  ANY]
			x	[-p2mp_egress_node_protection                       ANY]
			x	[-p2mp_ingress_active                               ANY]
			x	[-ingress_type_p2mp_id                              CHOICES iP p2MPId]
			x	[-ingress_p2mp_id_as_number                         ANY]
			x	[-ingress_p2mp_id_ip                                ANY]
			x	[-p2mp_tunnel_id                                    ANY]
			x	[-p2mp_lsp_id                                       ANY]
			x	[-p2mp_ingress_refresh_interval                     ANY]
			x	[-p2mp_ingress_timeout_multiplier                   ANY]
			x	[-ingress_p2mp_sub_lsp_ranges                       NUMERIC]
			x	[-p2mp_using_headend_ip                             ANY]
			x	[-p2mp_source_ipv4                                  ANY]
			x	[-p2mp_source_ipv6                                  ANY]
			x	[-insert_i_pv6_explicit_null                        ANY]
			x	[-p2mp_auto_generate_session_name                   ANY]
			x	[-p2mp_session_name                                 ANY]
			x	[-p2mp_setup_priority                               ANY]
			x	[-p2mp_holding_priority                             ANY]
			x	[-p2mp_local_protection_desired                     ANY]
			x	[-p2mp_label_recording_desired                      ANY]
			x	[-p2mp_se_style_desired                             ANY]
			x	[-p2mp_bandwidth_protection_desired                 ANY]
			x	[-p2mp_node_protection_desired                      ANY]
			x	[-p2mp_resource_affinities                          ANY]
			x	[-p2mp_exclude_any                                  ANY]
			x	[-p2mp_include_any                                  ANY]
			x	[-p2mp_include_all                                  ANY]
			x	[-p2mp_token_bucket_rate                            ANY]
			x	[-p2mp_token_bucket_size                            ANY]
			x	[-p2mp_peak_data_rate                               ANY]
			x	[-p2mp_minimum_policed_unit                         ANY]
			x	[-p2mp_maximum_packet_size                          ANY]
			x	[-p2mp_enable_fast_reroute                          ANY]
			x	[-p2mp_fast_reroute_setup_priority                  ANY]
			x	[-p2mp_fast_reroute_holding_priority                ANY]
			x	[-p2mp_hop_limit                                    ANY]
			x	[-p2mp_fast_reroute_bandwidth                       ANY]
			x	[-p2mp_fast_reroute_exclude_any                     ANY]
			x	[-p2mp_fast_reroute_include_any                     ANY]
			x	[-p2mp_fast_reroute_include_all                     ANY]
			x	[-p2mp_one_to_one_backup_desired                    ANY]
			x	[-p2mp_facility_backup_desired                      ANY]
			x	[-p2mp_send_detour                                  ANY]
			x	[-p2mp_number_of_detour_sub_objects                 NUMERIC]
			x	[-p2mp_backup_lsp_id                                ANY]
			x	[-p2mp_enable_path_re_optimization                  ANY]
			x	[-p2mp_enable_periodic_re_evaluation_request        ANY]
			x	[-p2mp_re_evaluation_request_interval               ANY]
			x	[-p2mp_include_head_ip_at_bottom                    ANY]
			x	[-include_connected_ip_on_top                       ANY]
			x	[-p2mp_number_of_rro_sub_objects                    NUMERIC]
			x	[-p2mp_send_rro                                     ANY]
			x	[-p2mp_ingress_rro_type                             CHOICES ip label]
			x	[-p2mp_ingress_ip                                   ANY]
			x	[-p2mp_ingress_protection_available                 ANY]
			x	[-p2mp_ingress_protection_in_use                    ANY]
			x	[-p2mp_ingress_label                                ANY]
			x	[-p2mp_ingress_c_type                               ANY]
			x	[-p2mp_ingress_global_label                         ANY]
			x	[-p2mp_ingress_node_protection                      ANY]
			x	[-p2mp_ingress_bandwidth_protection                 ANY]
			x	[-sub_lsp_active                                    ANY]
			x	[-leaf_ip                                           ANY]
			x	[-prepend_dut                                       CHOICES dontprepend
			x                                                    CHOICES prependloose
			x                                                    CHOICES prependstrict]
			x	[-prefix_length_of_dut                              ANY]
			x	[-append_leaf                                       CHOICES dontappend
			x                                                    CHOICES appendloose
			x                                                    CHOICES appendstrict]
			x	[-prefix_length_of_leaf                             ANY]
			x	[-send_as_ero                                       ANY]
			x	[-send_as_sero                                      ANY]
			x	[-p2mp_enable_ero                                   ANY]
			x	[-p2mp_number_of_ero_sub_objects                    NUMERIC]
			x	[-p2mp_ero_type                                     CHOICES ip as]
			x	[-p2mp_ero_ip                                       ANY]
			x	[-p2mp_ero_as_number                                ANY]
			x	[-p2mp_ero_loose_flag                               ANY]
			x	[-p2mp_ero_prefix_length                            ANY]
			x	[-t_spec_same_as_primary                            CHOICES 0 1]
			x	[-backup_lsp_token_bucket_size                      ANY]
			x	[-backup_lsp_token_bucket_rate                      ANY]
			x	[-backup_lsp_peak_data_rate                         ANY]
			x	[-backup_lsp_minimum_policed_unit                   ANY]
			x	[-backup_lsp_maximum_packet_size                    ANY]
			x	[-ero_same_as_primary                               CHOICES 0 1]
			x	[-backup_lsp_enable_ero                             ANY]
			x	[-backup_lsp_prepend_dut_to_ero                     CHOICES dontprepend
			x                                                    CHOICES prependloose
			x                                                    CHOICES prependstrict]
			x	[-backup_lsp_prefix_length                          ANY]
			x	[-backup_lsp_number_of_ero_sub_objects              NUMERIC]
			x	[-backuplsp_ero_ip                                  ANY]
			x	[-backuplsp_ero_type                                CHOICES ip as]
			x	[-backuplsp_ero_prefix_length                       ANY]
			x	[-backuplsp_ero_as_number                           ANY]
			x	[-backuplsp_ero_loose_flag                          ANY]
			x	[-delay_lsp_switch_over                             CHOICES 0 1]
			x	[-lsp_switch_over_delay_time                        NUMERIC]
			x	[-p2mp_delay_lsp_switch_over                        CHOICES 0 1]
			x	[-p2mp_lsp_switch_over_delay_time                   NUMERIC]
			x	[-symbolic_path_name                                ANY]
			x	[-enable_r_r_o                                      ANY]
			x	[-pcep_expected_initiated_active                    ANY]
			x	[-pcep_expected_initiated_number_of_rro_sub_objects NUMERIC]
			x	[-pcep_expected_initiated_backup_lsp_id             ANY]
			x	[-expected_pce_initiated_lsps_count                 NUMERIC]
			x	[-initial_delegation                                ANY]
			x	[-redelegation_timeout_interval                     ANY]
			x	[-lsp_operative_mode                                CHOICES lspopeativemodesyncreport
			x                                                    CHOICES lspopeativemoderequest]
			x	[-configure_sync_lsp_object                         CHOICES elect_objects ppag]
			x	[-enable_bfd_mpls                                   ANY]
			x	[-enable_lsp_ping                                   ANY]
			x	[-include_association                               ANY]
			x	[-association_id                                    ANY]
			x	[-protection_lsp                                    ANY]
			x	[-standby_mode                                      ANY]
			x	[-disable_r_s_v_p_signal                            ANY]
			x	[-enable_lsp_self_ping                              CHOICES 0 1]
			x	[-lsp_self_ping_sessionId                           NUMERIC]
			x	[-ip_ttl_of_lsp_self_ping                           NUMERIC]
			x	[-ip_dscp_of_lsp_self_ping                          NUMERIC]
			x	[-lsp_self_ping_retry_count                         NUMERIC]
			x	[-lsp_self_ping_retry_interval                      NUMERIC]
			x	[-forward_lsp_self_ping                             CHOICES 0 1]
			x	[-ip_ttl_decrement_count                            NUMERIC]
			x	[-retain_lsp_self_ping_dscp                         CHOICES 0 1]
			x	[-lsp_self_ping_ip_dscp                             NUMERIC]
			x	[-initial_lsp_self_ping_drop_count                  NUMERIC]
			 	[-adspec                                            ANY]
			 	[-egress_ip_addr                                    ANY]
			 	[-egress_ip_step                                    ANY]
			 	[-ero                                               ANY]
			 	[-ero_dut_pfxlen                                    ANY]
			 	[-ero_list_as_num                                   ANY]
			 	[-ero_list_ipv4                                     ANY]
			 	[-ero_list_loose                                    ANY]
			 	[-ero_list_pfxlen                                   ANY]
			 	[-ero_list_type                                     ANY]
			 	[-ero_mode                                          ANY]
			 	[-facility_backup                                   ANY]
			 	[-fast_reroute                                      ANY]
			 	[-fast_reroute_hop_limit                            ANY]
			 	[-ingress_bandwidth                                 ANY]
			 	[-ingress_ip_addr                                   ANY]
			 	[-ingress_ip_count                                  ANY]
			 	[-ingress_ip_step                                   ANY]
			x	[-ingress_enable_interface_creation                 ANY]
			 	[-lsp_id_count                                      ANY]
			 	[-lsp_id_start                                      ANY]
			 	[-lsp_id_step                                       ANY]
			 	[-no_write                                          ANY]
			 	[-one_to_one_backup                                 ANY]
			 	[-rro                                               ANY]
			 	[-rro_list_ctype                                    ANY]
			 	[-rro_list_flags                                    ANY]
			 	[-rro_list_ipv4                                     ANY]
			 	[-rro_list_label                                    ANY]
			 	[-rro_list_type                                     ANY]
			 	[-rsvp_behavior                                     ANY]
			 	[-sender_tspec_max_pkt_size                         ANY]
			 	[-sender_tspec_min_policed_size                     ANY]
			 	[-sender_tspec_peak_data_rate                       ANY]
			 	[-sender_tspec_token_bkt_rate                       ANY]
			 	[-sender_tspec_token_bkt_size                       ANY]
			 	[-session_attr                                      ANY]
			 	[-session_attr_bw_protect                           ANY]
			 	[-session_attr_flags                                ANY]
			 	[-session_attr_hold_priority                        ANY]
			 	[-session_attr_label_record                         ANY]
			 	[-session_attr_local_protect                        ANY]
			 	[-session_attr_name                                 ANY]
			 	[-session_attr_node_protect                         ANY]
			 	[-session_attr_ra_exclude_any                       ANY]
			 	[-session_attr_ra_include_all                       ANY]
			 	[-session_attr_ra_include_any                       ANY]
			 	[-session_attr_reroute                              ANY]
			 	[-session_attr_resource_affinities                  ANY]
			 	[-session_attr_se_style                             ANY]
			 	[-session_attr_setup_priority                       ANY]
			 	[-tunnel_id_count                                   ANY]
			 	[-tunnel_id_start                                   ANY]
			 	[-tunnel_id_step                                    ANY]
			 	[-tunnel_pool_handle                                ANY]
			 	[-writeFlag                                         ANY]
			x	[-egress_behavior                                   ANY]
			x	[-egress_ip_addr                                    ANY]
			x	[-egress_ip_count                                   ANY]
			x	[-egress_ip_step                                    ANY]
			x	[-egress_leaf_ip_count                              ANY]
			x	[-egress_leaf_range_count                           ANY]
			x	[-egress_leaf_range_param_type                      ANY]
			x	[-egress_leaf_range_step                            ANY]
			x	[-emulation_type                                    ANY]
			x	[-enable_append_connected_ip                        ANY]
			x	[-enable_prepend_tunnel_leaf_ip                     ANY]
			x	[-enable_prepend_tunnel_head_ip                     ANY]
			x	[-enable_send_as_rro                                ANY]
			x	[-enable_send_as_srro                               ANY]
			x	[-explicit_traffic_item                             ANY]
			x	[-h2l_info_dut_hop_type                             ANY]
			x	[-h2l_info_dut_prefix_length                        ANY]
			x	[-h2l_info_enable_append_tunnel_leaf                ANY]
			x	[-h2l_info_enable_prepend_dut                       ANY]
			x	[-h2l_info_ero_sero_list                            ANY]
			x	[-h2l_info_enable_send_as_ero                       ANY]
			x	[-h2l_info_enable_send_as_sero                      ANY]
			x	[-h2l_info_tunnel_leaf_count                        ANY]
			x	[-h2l_info_tunnel_leaf_hop_type                     ANY]
			x	[-h2l_info_tunnel_leaf_ip_start                     ANY]
			x	[-h2l_info_tunnel_leaf_prefix_length                ANY]
			x	[-head_traffic_inter_tunnel_ip_step                 ANY]
			x	[-head_traffic_ip_count                             ANY]
			x	[-head_traffic_ip_type                              ANY]
			x	[-head_traffic_start_ip                             ANY]
			x	[-p2mp_id                                           ANY]
			x	[-p2mp_id_step                                      ANY]
			x	[-path_error_tlv                                    ANY]
			x	[-path_tear_tlv                                     ANY]
			x	[-path_tlv                                          ANY]
			x	[-record_route                                      ANY]
			x	[-reservation_error_tlv                             ANY]
			x	[-reservation_tear_tlv                              ANY]
			x	[-reservation_tlv                                   ANY]
			x	[-tail_traffic_inter_tunnel_ip_step                 ANY]
			x	[-tail_traffic_ip_count                             ANY]
			x	[-tail_traffic_ip_type                              ANY]
			x	[-tail_traffic_start_ip                             ANY]
			n	[-extended_tunnel_id_type                           ANY]
		
		Arguments:
			 	-mode
			    		create -
			    		delete -
			    		modity -
			    		enable -
			    		disable -
			 	-port_handle
			 	-handle
			 		Specifies the parent node/object handle on which the rsvp configuration should be configured.
			 		In case modesmodify/delete/disable/enablethis denotes the object node handle on which the action needs to be performed. The handle value syntax is dependent on the vendor.
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-count
			 		The number of RsvpLsp to configure on the targeted Ixia
			 		interface.The range is 0-1000.
			 	-mac_address_init
			 		MAC address to be used for the first session.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-mac_address_step
			x		Valid only for -mode create.
			x		The incrementing step for the MAC address configured on the dirrectly
			x		connected interfaces. Valid only when IxNetwork Tcl API is used.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-vlan
			x		Enables vlan on the directly connected ISIS router interface.
			x		Valid options are: 0 - disable, 1 - enable.
			x		This option is valid only when -mode is create or -mode is modify
			x		and -handle is an ISIS router handle.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-vlan_id
			 		VLAN ID for protocol interface.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_id_mode
			 		For multiple neighbor configuration, configures the VLAN ID mode.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		fixed - VLAN ID mode is fixed.
			    		increment - (default) VLAN ID mode to increment.
			 	-vlan_id_step
			 		Valid only for -mode create.
			 		Defines the step for the VLAN ID when the VLAN ID mode is increment.
			 		When vlan_id_step causes the vlan_id value to exceed its maximum value the
			 		increment will be done modulo <number of possible vlan ids>.
			 		Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0
			 		vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_user_priority
			 		VLAN user priority assigned to protocol interface.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-intf_ip_addr
			 		Interface IP address of the RSVP session router. Mandatory when -mode is create.
			 		When using IxTclNetwork (new API) this parameter can be omitted if -interface_handle is used.
			 		For IxTclProtocol (old API), when -mode is modify and one of the layer
			 		2-3 parameters (-intf_ip_addr, -gateway_ip_addr, -loopback_ip_addr, etc)
			 		needs to be modified, the emulation_ldp_config command must be provided
			 		with the entire list of layer 2-3 parameters. Otherwise they will be
			 		set to their default values.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-intf_prefix_length
			 		Prefix length on the interface.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-intf_ip_addr_step
			 		Define interface IP address for multiple sessions.
			 		Valid only for -mode create.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-gateway_ip_addr
			x		Gives the gateway IP address for the protocol interface that will
			x		be created for use by the simulated routers.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-gateway_ip_addr_step
			x		Valid only for -mode create.
			x		Gives the step for the gateway IP address.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-loopback_ip_addr
			x		The IP address of the unconnected protocol interface that will be
			x		created behind the intf_ip_addr interface. The loopback(unconnected)
			x		interface is the one that will be used for RSVP emulation. This type
			x		of interface is needed when creating extended Martini sessions.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-loopback_ip_addr_step
			x		Valid only for -mode create.
			x		The incrementing step for the loopback_ip_addr parameter.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-rsvp_p2p_egress_enable
			x		Enable Rsvp P2P Egress
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-rsvp_p2p_ingress_enable
			x		Enable Rsvp P2P Inress
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-rsvp_p2mp_egress_enable
			x		Enable Rsvp P2MP Egress
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-rsvp_p2mp_ingress_enable
			x		Enable Rsvp P2MP Ingress
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-rsvp_p2mp_ingress_sublsp_enable
			x		Enable Rsvp P2MP Ingress SubLsps
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2p_ingress_lsps_count
			x		Number of P2P Ingress LSPs configured per IPv4 Loopback
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_p2p_egress
			x		Enable to configure P2P Egress LSPs
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lsp_active
			x		Activate/Deactivate Configuration
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-remote_ip
			x		Remote IP Address
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-tunnel_id
			x		Tunnel ID
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lsp_id
			x		LSP Id
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-bandwidth
			x		Bandwidth (bps)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ingress_refresh_interval
			x		Refresh Interval (ms)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ingress_timeout_multiplier
			x		Timeout Multiplier
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-do_mbb_on_apply_changes
			x		Do Make Before Break on Apply Changes
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-using_headend_ip
			x		Using Headend IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-source_ip
			x		Source IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-autoroute_traffic
			x		Autoroute Traffic
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-auto_generate_session_name
			x		Auto Generate Session Name
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-session_name
			x		Session Name
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-setup_priority
			x		Setup Priority
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-holding_priority
			x		Holding Priority
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-local_protection_desired
			x		Local Protection Desired
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-label_recording_desired
			x		Label Recording Desired
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-se_style_desired
			x		SE Style Desired
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-bandwidth_protection_desired
			x		Bandwidth Protection Desired
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-node_protection_desired
			x		Node Protection Desired
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-resource_affinities
			x		Resource Affinities
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-exclude_any
			x		Exclude Any
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-include_any
			x		Include Any
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-include_all
			x		Include All
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-token_bucket_rate
			x		Token Bucket Rate
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-token_bucket_size
			x		Token Bucket Size
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-peak_data_rate
			x		Peak Data Rate
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-minimum_policed_unit
			x		Minimum Policed Unit
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-maximum_packet_size
			x		Maximum Packet Size
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_fast_reroute
			x		Enable Fast Reroute
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fast_reroute_setup_priority
			x		Setup Priority
			x	-fast_reroute_holding_priority
			x		Holding Priority
			x	-hop_limit
			x		Hop Limit
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-fast_reroute_bandwidth
			x		Bandwidth (bps)
			x	-fast_reroute_exclude_any
			x		Exclude Any
			x	-fast_reroute_include_any
			x		Include Any
			x	-fast_reroute_include_all
			x		Include All
			x	-one_to_one_backup_desired
			x		One To One Backup Desired
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-facility_backup_desired
			x		Facility Backup Desired
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-send_detour
			x		Send Detour
			x	-number_of_detour_sub_objects
			x		Number Of Detour Sub-Objects
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-backup_lsp_id
			x		Backup LSP Id Pool Start
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-backup_lsp_session_id
			x		This specifies the Backup LSP session Id.
			x		The default value is 30000.
			x		The minimum value is 0 and the maximum value is 65535.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_path_re_optimization
			x		Enable Path Re-Optimization
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_periodic_re_evaluation_request
			x		Enable Periodic Re-Evaluation Request
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-re_evaluation_request_interval
			x		Re-Evaluation Request Interval
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_ero
			x		Enable ERO
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-prepend_dut_to_ero
			x		Prepend DUT to ERO
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		dontprepend -
			x   		prependloose -
			x   		prependstrict -
			x	-ingress_p2p_prefix_length
			x		Prefix Length
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-number_of_ero_sub_objects
			x		Number Of ERO Sub-Objects
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-send_rro
			x		Send RRO
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ingress_number_of_rro_sub_objects
			x		Number Of RRO Sub-Objects
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2p_ingress_active
			x		Activate/Deactivate Configuration
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-plr_id
			x		PLR ID
			x	-avoid_node_id
			x		Avoid Node ID
			x	-ero_type
			x		Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		ip -
			x   		as -
			x	-ero_ip
			x		IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-prefix_length
			x		Prefix Length
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-as_number
			x		AS
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-loose_flag
			x		Loose Flag
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-rro_type
			x		Reservation Style
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		ip -
			x   		label -
			x	-rro_ip
			x		IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ingress_protection_available
			x		Protection Available
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ingress_protection_in_use
			x		Protection In Use
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ingress_label
			x		Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ingress_c_type
			x		C-Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ingress_global_label
			x		Global Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ingress_bandwidth_protection
			x		Bandwidth Protection
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ingress_node_protection
			x		Node Protection
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-egress_refresh_interval
			x		Refresh Interval (ms)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-egress_timeout_multiplier
			x		Timeout Multiplier
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-send_reservation_confirmation
			x		Send Reservation Confirmation
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_fixed_label_for_reservations
			x		Enable Fixed Label For Reservations
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-label_value
			x		Label Value
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-reservation_style
			x		Reservation Style
			x		Valid choices are:
			x   		se -
			x   		ff -
			x   		auto -
			x	-reflect_rro
			x		Reflect RRO
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-egress_number_of_rro_sub_objects
			x		Number Of RRO Sub-Objects
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-egress_active
			x		Activate/Deactivate Configuration
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-egress_type
			x		Reservation Style
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		ip -
			x   		label -
			x	-egress_ip
			x		IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-egress_protection_available
			x		Protection Available
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-egress_protection_in_use
			x		Protection In Use
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-egress_label
			x		Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-egress_c_type
			x		C-Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-egress_global_label
			x		Global Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-egress_bandwidth_protection
			x		Bandwidth Protection
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-egress_node_protection
			x		Node Protection
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-source_ipv6
			x		Source IPv6
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-insert_ipv6_explicit_null
			x		Insert IPv6 explicit NULL
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-end_point_ipv6
			x		Destination IPv6
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ingress_lsp_count
			x		Number of P2MP Ingress LSPs configured per IPv4 Loopback
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_egress_tunnel_count
			x		Number of P2MP Egress Tunnels configured per IPv4 Loopback
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_egress_active
			x		Activate/Deactivate Configuration
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-type_p2mp_id
			x		P2MP ID Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		iP -
			x   		p2MPId -
			x	-p2mp_id_as_number
			x		P2MP ID displayed in Integer format
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_id_ip
			x		P2MP ID displayed in IP Address format
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_egress_refresh_interval
			x		Refresh Interval (ms)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_egress_timeout_multiplier
			x		Timeout Multiplier
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_send_reservation_confirmation
			x		Send Reservation Confirmation
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_enable_fixed_label_for_reservations
			x		Enable Fixed Label For Reservations
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_label_value
			x		Label Value
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_reservation_style
			x		Reservation Style
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		se -
			x   		ff -
			x   		auto -
			x	-sub_lsps_down
			x		Sub LSPs Down
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_destination_ipv4_group_address
			x		Destination IPv4 Group Address
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_end_point_ipv6
			x		Destination IPv6
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_reflect_rro
			x		Reflect RRO
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_include_leaf_ip_at_bottom
			x		Include Leaf IP at bottom
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_include_connected_ip_on_top
			x		Include connected IP on top
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_send_as_rro
			x		Send As RRO
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_send_as_srro
			x		Send As SRRO
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_egress_number_of_rro_sub_objects
			x		Number Of RRO Sub-Objects
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_egress_rro_type
			x		Type: Label Or IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		ip -
			x   		label -
			x	-p2mp_egress_ip
			x		IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_egress_protection_available
			x		Protection Available
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_egress_protection_in_use
			x		Protection In Use
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_egress_label
			x		Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_egress_c_type
			x		C-Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_egress_global_label
			x		Global Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_egress_bandwidth_protection
			x		Bandwidth Protection
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_egress_node_protection
			x		Node Protection
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ingress_active
			x		Activate/Deactivate Configuration
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ingress_type_p2mp_id
			x		P2MP ID Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		iP -
			x   		p2MPId -
			x	-ingress_p2mp_id_as_number
			x		P2MP ID displayed in Integer format
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ingress_p2mp_id_ip
			x		P2MP ID displayed in IP Address format
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_tunnel_id
			x		Tunnel ID
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_lsp_id
			x		LSP Id
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ingress_refresh_interval
			x		Refresh Interval (ms)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ingress_timeout_multiplier
			x		Timeout Multiplier
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ingress_p2mp_sub_lsp_ranges
			x		Number of P2MP Ingress Sub LSPs configured per RSVP-TE P2MP Ingress LSP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_using_headend_ip
			x		Using Headend IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_source_ipv4
			x		Source IPv4
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_source_ipv6
			x		Source IPv6
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-insert_i_pv6_explicit_null
			x		Insert IPv6 explicit NULL
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_auto_generate_session_name
			x		Auto Generate Session Name
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_session_name
			x		Session Name
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_setup_priority
			x		Setup Priority
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_holding_priority
			x		Holding Priority
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_local_protection_desired
			x		Local Protection Desired
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_label_recording_desired
			x		Label Recording Desired
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_se_style_desired
			x		SE Style Desired
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_bandwidth_protection_desired
			x		Bandwidth Protection Desired
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_node_protection_desired
			x		Node Protection Desired
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_resource_affinities
			x		Resource Affinities
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_exclude_any
			x		Exclude Any
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_include_any
			x		Include Any
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_include_all
			x		Include All
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_token_bucket_rate
			x		Token Bucket Rate
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_token_bucket_size
			x		Token Bucket Size
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_peak_data_rate
			x		Peak Data Rate
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_minimum_policed_unit
			x		Minimum Policed Unit
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_maximum_packet_size
			x		Maximum Packet Size
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_enable_fast_reroute
			x		Enable Fast Reroute
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_fast_reroute_setup_priority
			x		Setup Priority
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_fast_reroute_holding_priority
			x		Holding Priority
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_hop_limit
			x		Hop Limit
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_fast_reroute_bandwidth
			x		Bandwidth (bps)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_fast_reroute_exclude_any
			x		Exclude Any
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_fast_reroute_include_any
			x		Include Any
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_fast_reroute_include_all
			x		Include All
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_one_to_one_backup_desired
			x		One To One Backup Desired
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_facility_backup_desired
			x		Facility Backup Desired
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_send_detour
			x		Send Detour
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_number_of_detour_sub_objects
			x		Number Of Detour Sub-Objects
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_backup_lsp_id
			x		Backup LSP Id Pool Start
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_enable_path_re_optimization
			x		Enable Path Re-Optimization
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_enable_periodic_re_evaluation_request
			x		Enable Periodic Re-Evaluation Request
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_re_evaluation_request_interval
			x		Re-Evaluation Request Interval
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_include_head_ip_at_bottom
			x		Include Head IP at bottom
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-include_connected_ip_on_top
			x		Include connected IP on top
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_number_of_rro_sub_objects
			x		Number Of RRO Sub-Objects
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_send_rro
			x		Send RRO
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ingress_rro_type
			x		Type: IP or Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		ip -
			x   		label -
			x	-p2mp_ingress_ip
			x		IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ingress_protection_available
			x		Protection Available
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ingress_protection_in_use
			x		Protection In Use
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ingress_label
			x		Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ingress_c_type
			x		C-Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ingress_global_label
			x		Global Label
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ingress_node_protection
			x		Node Protection
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ingress_bandwidth_protection
			x		Bandwidth Protection
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-sub_lsp_active
			x		Activate/Deactivate Configuration
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-leaf_ip
			x		Leaf IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-prepend_dut
			x		Prepend DUT
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		dontprepend -
			x   		prependloose -
			x   		prependstrict -
			x	-prefix_length_of_dut
			x		Prefix Length of DUT
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-append_leaf
			x		Append Leaf
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		dontappend -
			x   		appendloose -
			x   		appendstrict -
			x	-prefix_length_of_leaf
			x		Prefix Length of Leaf
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-send_as_ero
			x		Send As ERO
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-send_as_sero
			x		Send As SERO
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_enable_ero
			x		Enable ERO
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_number_of_ero_sub_objects
			x		Number Of ERO Sub-Objects
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ero_type
			x		Type: IP or AS
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		ip -
			x   		as -
			x	-p2mp_ero_ip
			x		IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ero_as_number
			x		AS
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ero_loose_flag
			x		Loose Flag
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_ero_prefix_length
			x		Prefix Length
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-t_spec_same_as_primary
			x		TSpec Same As Primary
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-backup_lsp_token_bucket_size
			x		Token Bucket Size
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-backup_lsp_token_bucket_rate
			x		Token Bucket Rate
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-backup_lsp_peak_data_rate
			x		Peak Data Rate
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-backup_lsp_minimum_policed_unit
			x		Minimum Policed Unit
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-backup_lsp_maximum_packet_size
			x		Maximum Packet Size
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ero_same_as_primary
			x		ERO Same As Primary
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-backup_lsp_enable_ero
			x		Enable ERO
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-backup_lsp_prepend_dut_to_ero
			x		Prepend DUT to ERO
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		dontprepend -
			x   		prependloose -
			x   		prependstrict -
			x	-backup_lsp_prefix_length
			x		Prefix Length
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-backup_lsp_number_of_ero_sub_objects
			x		Number Of ERO Sub-Objects
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-backuplsp_ero_ip
			x		IP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-backuplsp_ero_type
			x		Type
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		ip -
			x   		as -
			x	-backuplsp_ero_prefix_length
			x		Prefix Length
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-backuplsp_ero_as_number
			x		AS
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-backuplsp_ero_loose_flag
			x		Loose Flag
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-delay_lsp_switch_over
			x		Delay LSP switch over
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lsp_switch_over_delay_time
			x		LSP Switch Over Delay timer (sec)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_delay_lsp_switch_over
			x		Delay LSP switch over
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p2mp_lsp_switch_over_delay_time
			x		LSP Switch Over Delay timer (sec)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-symbolic_path_name
			x		This is used for generating the traffic for those LSPs from PCE for which the Symbolic Path Name is configured and matches the value.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_r_r_o
			x		Enable RRO
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pcep_expected_initiated_active
			x		Activate/Deactivate RSVP-TE PCEP Expected Initiated LSPs
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pcep_expected_initiated_number_of_rro_sub_objects
			x		Number Of RRO Sub-Objects
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pcep_expected_initiated_backup_lsp_id
			x		Backup LSP Id
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-expected_pce_initiated_lsps_count
			x		Number of Expected PCE Initiated RSVP-TE LSPs
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-initial_delegation
			x		Initial Delegation
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-redelegation_timeout_interval
			x		The period of time a PCC waits for, when a PCEP session is terminated, before revoking LSP delegation
			x		to a PCE and attempting to redelegate LSPs associated with the terminated PCEP session to PCE.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lsp_operative_mode
			x		The mode of LSP in which it is currently behaving.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		lspopeativemodesyncreport - Sync/Report.
			x   		lspopeativemoderequest - Request.
			x	-configure_sync_lsp_object
			x		Include Objects
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		elect_objects - Select Objects.
			x   		ppag - Association.
			x	-enable_bfd_mpls
			x		If selected, BFD MPLS is enabled.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_lsp_ping
			x		If set to True, LSP Ping is enabled for learned LSPs.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-include_association
			x		Indicates whether Association will be included in a RSVP Sync LSP. All other attributes in sub-tab-PPAG would be editable only if this checkbox is enabled.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-association_id
			x		The Association ID of this LSP.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-protection_lsp
			x		Indicates whether Protection LSP Bit is On.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-standby_mode
			x		Indicates whether Standby LSP Bit is On.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-disable_r_s_v_p_signal
			x		Disable RSVP Signaling For PCEP
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_lsp_self_ping
			x		If set to True, LSP Self Ping is turned on for RSVP Ingress.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lsp_self_ping_sessionId
			x		This specifies the session Id of the LSP Self Ping.
			x		The default value is 1.
			x		The minimum value is 1 and the maximum value is 2^64-1.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ip_ttl_of_lsp_self_ping
			x		This specifies the IP header TTL of the Self Ping packet.
			x		The default value is 255.
			x		The minimum value is 1 and the maximum value is 255.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ip_dscp_of_lsp_self_ping
			x		This specifies the IP header DSCP of the Self Ping packet.
			x		The default value is 48.
			x		The minimum value is 0 and the maximum value is 63.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lsp_self_ping_retry_count
			x		This specifies the number of times Ingress LSR should transmit the LSP Self Ping packet.
			x		The default value is 3.
			x		The minimum value is 1 and the maximum value is 2^32-1.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lsp_self_ping_retry_interval
			x		This is the time interval (in milliseconds) between two LSP Self Ping packet re-transmissions.
			x		The default value is 1000.
			x		The minimum value is 1000 and the maximum value is 30000.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-forward_lsp_self_ping
			x		If set to True, RSVP Egress forwards the LSP Self Ping packet to Ingress LSR.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ip_ttl_decrement_count
			x		This specifies the amount by which the IP header's TTL value is decremented, before forwarding LSP Self Ping Packet to Ingress LSR.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-retain_lsp_self_ping_dscp
			x		If set to True, Egress LSR keeps the IP header DSCP value of the forwarded LSP self ping packet as it is.
			x		If set to False, Egress LSR overwrites the IP header DSCP value with the value configured in LSP Self Ping IP DSCP field, before forwarding self ping packet to Ingress LSR.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lsp_self_ping_ip_dscp
			x		This specifies the value to be set in the IP header DSCP field of the forwarded Self Ping packet (when Retain LSP Self Ping DSCP is not selected).
			x		The default value is 48.
			x		The minimum value is 0 and the maximum value is 63.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-initial_lsp_self_ping_drop_count
			x		This specifies the number of times Egress LSR drops the Self Ping packet.
			x		The default value is 0.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-adspec
			 		If true (1), enable INTSERV ADSPEC object in PATH message.This option is always set to true.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-egress_ip_addr
			 		IP address of the tunnel's egress point.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-egress_ip_step
			 		This value is used to increment egress IP address when configuring multiple tunnels.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-ero
			 		If true (1), enable explicit route object.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-ero_dut_pfxlen
			 		If the DUTs address is to be prepended to the ERO list, this indicates what prefix length is to be used for the entry.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-ero_list_as_num
			 		List of Autonomous System numbers.Used by AS type only.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-ero_list_ipv4
			 		List of IPv4 prefixes (one for each entry)used by IPv4 type only.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-ero_list_loose
			 		Indicates whether the ERO item is to be considered a LOOSE item or a STRICT item.1 for LOOSE; 0 for STRICT
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-ero_list_pfxlen
			 		List of prefix length.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-ero_list_type
			 		Type of ERO entries. Note ipv6 is not supported. Valid options are:ipv4 (DEFAULT)as
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-ero_mode
			 		Indicates whether the DUTs address is to be prepended to the ERO list and whether it is a LOOSE or STRICT entry.Valid options are:loose (DEFAULT)strictnone
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-facility_backup
			 		For fast reroute, indicates that the use of the Facility Backup feature is enabled.This may be combined with one_to_one_backup option.fast_reroute option must be true for this option to have any effect.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-fast_reroute
			 		Enables the use of the fast reroute feature.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-fast_reroute_hop_limit
			 		An element of the FAST_REROUTE object that is the maximum number of extra hops the backup path is allowed to take from the current PLR node to a merge point.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-ingress_bandwidth
			 		The bandwidth requested for the connection, expressed in kbits/sec.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-ingress_ip_addr
			 		IP address of ingress node.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-ingress_ip_count
			 		Valid only with IxTclNetwork.The number of ingress IP addresses per tunnel.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-ingress_ip_step
			 		This value is used to increment ingress IP address when configuring multiple tunnels.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-ingress_enable_interface_creation
			x		If this parameter is set to 1, protocol interfaces will be created for each ingress tunnel using ingres_ip_addr.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-lsp_id_count
			 		The number of LSPs to create on a single tunnel handle.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-lsp_id_start
			 		Starting LSP ID, used in SENDER_TEMPLATE object.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-lsp_id_step
			 		The value to increment the LSP ID when configuring multiple LSPs ("-count" is greater than 1).
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-no_write
			 		If this option is present, the configuration is not written to the hardware. This option can be used to queue up multiple configurations before writing to the hardware.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-one_to_one_backup
			 		For fast reroute, indicates that the use of the Facility Backup feature is enabled.This may be combined with facility_backup option. fast_reroute option must be true for this option to have any effect.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-rro
			 		If true (1), enable record route.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-rro_list_ctype
			 		If the type field is IP, then this is the C_Type of the included Label Object.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-rro_list_flags
			 		0x1 - Local protection available.0x2 - Local protection in use.0x4 - Bandwidth protection0x8 - Node protection
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-rro_list_ipv4
			 		List of IPv4 prefixes (one for each entry) used by IPv4 type only.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-rro_list_label
			 		List of 32 bit label objects.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-rro_list_type
			 		Type of RRO entries.Note ipv6 is not supported. Valid options are:ipv4 (DEFAULT)label
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-rsvp_behavior
			 		Configures the node as an Ingress or Egress.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-sender_tspec_max_pkt_size
			 		The maximum packet size associated with the RSVP Senders Traffic Specification.Expressed in bytes.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-sender_tspec_min_policed_size
			 		The minimum policed unit size associated with the RSVP Senders Traffic Specification.Expressed in bytes.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-sender_tspec_peak_data_rate
			 		The peak data rate associated with the RSVP Senders Traffic Specification.Expressed in bytes per second.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-sender_tspec_token_bkt_rate
			 		The token bucket rate associated with the RSVP Senders Traffic Specification.Expressed in bytes per second.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-sender_tspec_token_bkt_size
			 		TThe token bucket size associated with the RSVP Senders Traffic Specification.Expressed in bytes.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr
			 		If true (1), enable SESSION_ATTRIBUTE object in PATH message.This option is always set to true.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr_bw_protect
			 		This indicates that bandwidth protection is desired from the PLRs along the backup protected LSP path.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr_flags
			 		Allows user to set the flags directly without using the prior session attribute options.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr_hold_priority
			 		This is the session priority with respect to holding resources, such as keeping a session during preemption. The valid range is from 0 to 255. The highest priority is indicated by 0.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr_label_record
			 		This indicates that label information is to be included when doing a record route operation.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr_local_protect
			 		This permits transit routers to use a local traffic rerouting repair mechanism in the event of a fault on an adjacent downstream link or node. This may result in a violation of the explicit route object.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr_name
			 		This is the name assigned to this Session.(DEFAULT = "")
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr_node_protect
			 		For Fast Reroute, if enabled, sets the Node Protection Desired Flag in the Session_Attribute object of the RRO message. It indicates to PLRs associated with the protected LSP path, that a backup path is desired that bypasses (avoids) at least the next node on the LSP.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr_ra_exclude_any
			 		Represents a set of attribute filters associated with a tunnel, any of which renders a link unacceptable.(DEFAULT = 00 00 00 00)
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr_ra_include_all
			 		Represents a set of attribute filters associated with a tunnel, all of which must be present for a link to be acceptable (with respect to this test). When all bits are set to 0 (null set), it automatically passes.(DEFAULT = 00 00 00 00)
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr_ra_include_any
			 		Represents a set of attribute filters associated with a tunnel, any of which makes a link acceptable (with respect to this test). When all bits are set to 0 (null set), it automatically passes.(DEFAULT = 00 00 00 00)
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr_reroute
			 		Enables the use of the fast reroute feature.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr_resource_affinities
			 		If true (1), enable resource affinities.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr_se_style
			 		This indicates that the tunnel ingress node may reroute this tunnel without tearing it down. A tunnel egress node should use the SE Style when responding with an RESV message.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_attr_setup_priority
			 		This is the session priority with respect to taking resources, such as preempting another session. The valid range is from 0 to 255. The highest priority is indicated by 0.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-tunnel_id_count
			 		The number of tunnels to create on a single tunnel handle.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-tunnel_id_start
			 		Starting tunnel ID.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-tunnel_id_step
			 		This value is used to increment the tunnel ID when configuring multiple tunnels ("-count" is greater than 1).
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-tunnel_pool_handle
			 		RSVP-TE tunnel pool handle. Used for mode other than create.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-writeFlag
			 		DEPRECATED - use -no_write instead.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-egress_behavior
			x		Available only with IxTclNetwork.Dictates the RSVP reservation style when the value of behavior is rsvpEgress. Possible values include:Always_use_configured_style = If used, egress LER will always use the reservation style which the user has configured.Use_se_when_indicated_in_session_attribute = If used, if the SE Style desired flag is set in the PATH message from the ingress LER, the egress LER will always use the SE style, no matter what reservation style was configured.Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-egress_ip_addr
			x		Available only with IxTclNetwork.This parameter exists in the implementation of RSVP-TE P2P but it has a new meaning in the implementation for P2MP. Parameters count, egress_ip, egress_ip_step, egress_leaf_range_count, egress_leaf_range_step, egress_leaf_ip_count configure how P2MP tunnel leaves are configured.The -count parameter configures the number of Egress P2MP tunnel tails.The -egress_ip parameter configures the IPv4 address of the first P2MP tunnel leaf of the first Egress P2MP Tunnel tail.The parameter -egress_ip_step configures the step which will increment the IPv4 address of the -egress_ip_addr when there are multiple Egress P2MP Tunnel Tails configured.The -egress_leaf_range_count parameter configures how many P2MP leaf ranges are configured per Egress P2MP Tunnel Tail.The -egress_leaf_range_step configures the IPv4 step used to increment egress_ip_addr when there are multiple leaf_ranges configured.The -egress_leaf_ip_count parameter configures how many P2MP leaves will be configured in an egress P2MP tunnel leaf range.Example: -count 3egress_ip_addr5.5.5.5egress_ip_addr_step1.0.0.0egress_leaf_range_count3egress_leaf_range_step0.1.0.0egress_leaf_ip_count15Configuration Result:Egress1Tunnel Leaf Range 1Leaf Start Ip Address5.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address5.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address5.7.5.5Leaf Count15Egress 2Tunnel Leaf Range 1Leaf Start Ip Address6.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address6.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address6.7.5.5Leaf Count15Egress 3Tunnel Leaf Range 1Leaf Start Ip Address7.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address7.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address7.7.5.5Leaf Count15(DEFAULT = N/A)Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-egress_ip_count
			x		Available only with IxTclNetwork.This parameter is valid only for P2P emulations.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-egress_ip_step
			x		Available only with IxTclNetwork.This parameter exists in the implementation of RSVP-TE P2P but it has a new meaning in the implementation for P2MP. Parameters count, egress_ip, egress_ip_step, egress_leaf_range_count, egress_leaf_range_step, egress_leaf_ip_count configure how P2MP tunnel leaves are configured.The -count parameter configures the number of Egress P2MP tunnel tails.The -egress_ip parameter configures the IPv4 address of the first P2MP tunnel leaf of the first Egress P2MP Tunnel tail.The parameter -egress_ip_step configures the step which will increment the IPv4 address of the -egress_ip_addr when there are multiple Egress P2MP Tunnel Tails configured.The -egress_leaf_range_count parameter configures how many P2MP leaf ranges are configured per Egress P2MP Tunnel Tail.The -egress_leaf_range_step configures the IPv4 step used to increment egress_ip_addr when there are multiple leaf_ranges configured.The -egress_leaf_ip_count parameter configures how many P2MP leaves will be configured in an egress P2MP tunnel leaf range.Example: -count 3egress_ip_addr5.5.5.5egress_ip_addr_step1.0.0.0egress_leaf_range_count3egress_leaf_range_step0.1.0.0egress_leaf_ip_count15Configuration Result:Egress1Tunnel Leaf Range 1Leaf Start Ip Address5.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address5.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address5.7.5.5Leaf Count15Egress 2Tunnel Leaf Range 1Leaf Start Ip Address6.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address6.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address6.7.5.5Leaf Count15Egress 3Tunnel Leaf Range 1Leaf Start Ip Address7.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address7.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address7.7.5.5Leaf Count15Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-egress_leaf_ip_count
			x		Available only with IxTclNetwork.Parameters count, egress_ip, egress_ip_step, egress_leaf_range_count, egress_leaf_range_step, egress_leaf_ip_count configure how P2MP tunnel leaves are configured.The -count parameter configures the number of Egress P2MP tunnel tails.The -egress_ip parameter configures the IPv4 address of the first P2MP tunnel leaf of the first Egress P2MP Tunnel tail.The parameter -egress_ip_step configures the step which will increment the IPv4 address of the -egress_ip_addr when there are multiple Egress P2MP Tunnel Tails configured.The -egress_leaf_range_count parameter configures how many P2MP leaf ranges are configured per Egress P2MP Tunnel Tail.The -egress_leaf_range_step configures the IPv4 step used to increment egress_ip_addr when there are multiple leaf_ranges configured.The -egress_leaf_ip_count parameter configures how many P2MP leaves will be configured in an egress P2MP tunnel leaf range.Example: -count 2egress_ip_addr5.5.5.5egress_ip_addr_step1.0.0.0egress_leaf_range_count3egress_leaf_range_step0.1.0.0egress_leaf_ip_count15Configuration Result:Egress1Tunnel Leaf Range 1Leaf Start Ip Address5.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address5.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address5.7.5.5Leaf Count15Egress 2Tunnel Leaf Range 1Leaf Start Ip Address6.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address6.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address6.7.5.5Leaf Count15Egress 3Tunnel Leaf Range 1Leaf Start Ip Address7.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address7.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address7.7.5.5Leaf Count15Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-egress_leaf_range_count
			x		Available only with IxTclNetwork.Parameters count, egress_ip, egress_ip_step, egress_leaf_range_count, egress_leaf_range_step, egress_leaf_ip_count configure how P2MP tunnel leaves are configured.The -count parameter configures the number of Egress P2MP tunnel tails.The -egress_ip parameter configures the IPv4 address of the first P2MP tunnel leaf of the first Egress P2MP Tunnel tail.The parameter -egress_ip_step configures the step which will increment the IPv4 address of the -egress_ip_addr when there are multiple Egress P2MP Tunnel Tails configured.The -egress_leaf_range_count parameter configures how many P2MP leaf ranges are configured per Egress P2MP Tunnel Tail.The -egress_leaf_range_step configures the IPv4 step used to increment egress_ip_addr when there are multiple leaf_ranges configured.The -egress_leaf_ip_count parameter configures how many P2MP leaves will be configured in an egress P2MP tunnel leaf range.Example: -count 3egress_ip_addr5.5.5.5egress_ip_addr_step1.0.0.0egress_leaf_range_count3egress_leaf_range_step0.1.0.0egress_leaf_ip_count15Configuration Result:Egress1Tunnel Leaf Range 1Leaf Start Ip Address5.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address5.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address5.7.5.5Leaf Count15Egress 2Tunnel Leaf Range 1Leaf Start Ip Address6.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address6.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address6.7.5.5Leaf Count15Egress 3Tunnel Leaf Range 1Leaf Start Ip Address7.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address7.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address7.7.5.5Leaf Count15Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-egress_leaf_range_param_type
			x		Available only with IxTclNetwork.list - the parameters egress_ip_addr, egress_ip_step, egress_leaf_ip_count must be provide as lists of values with length equal to the value specified by egress_leaf_range_count. This is used in order to create multiple tunnel leaf ranges per tunnel tail (P2MP).single_value - the parameters egress_ip_addr, egress_ip_step, egress_leaf_ip_count are provided as single values. The parameter egress_leaf_range_step is used to increment between the leaf range IP addreses.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-egress_leaf_range_step
			x		Available only with IxTclNetwork.Parameters count, egress_ip, egress_ip_step, egress_leaf_range_count, egress_leaf_range_step, egress_leaf_ip_count configure how P2MP tunnel leaves are configured.The -count parameter configures the number of Egress P2MP tunnel tails.The -egress_ip parameter configures the IPv4 address of the first P2MP tunnel leaf of the first Egress P2MP Tunnel tail.The parameter -egress_ip_step configures the step which will increment the IPv4 address of the -egress_ip_addr when there are multiple Egress P2MP Tunnel Tails configured.The -egress_leaf_range_count parameter configures how many P2MP leaf ranges are configured per Egress P2MP Tunnel Tail.The -egress_leaf_range_step configures the IPv4 step used to increment egress_ip_addr when there are multiple leaf_ranges configured.The -egress_leaf_ip_count parameter configures how many P2MP leaves will be configured in an egress P2MP tunnel leaf range.Example: -count 2egress_ip_addr5.5.5.5egress_ip_addr_step1.0.0.0egress_leaf_range_count3egress_leaf_range_step0.1.0.0egress_leaf_ip_count15Configuration Result:Egress1Tunnel Leaf Range 1Leaf Start Ip Address5.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address5.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address5.7.5.5Leaf Count15Egress 2Tunnel Leaf Range 1Leaf Start Ip Address6.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address6.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address6.7.5.5Leaf Count15Egress 3Tunnel Leaf Range 1Leaf Start Ip Address7.5.5.5Leaf Count15Tunnel Leaf Range 2Leaf Start Ip Address7.6.5.5Leaf Count15Tunnel Leaf Range 3Leaf Start Ip Address7.7.5.5Leaf Count15Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-emulation_type
			x		Available only with IxTclNetwork.Choices: rsvpte, rsvptep2mp.Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-enable_append_connected_ip
			x		Available only with IxTclNetwork.Append the connected IP as a RRO/SERO subobject at the end of the RRO / SERO list in the packet. Note that all flags will be set to 0 if this automatic inclusion option is used.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-enable_prepend_tunnel_leaf_ip
			x		Available only with IxTclNetwork.Prepend the tunnel leaf IP as a RRO/SERO subobject at the beginning of the RRO / SERO list in the packet. Note that no label will be automatically inserted and all flags will be set to 0 if this automatic inclusion option is used.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-enable_prepend_tunnel_head_ip
			x		Available only with IxTclNetwork.Prepend the tunnel head IP as a RRO/SERO subobject at the beginning of the RRO / SERO list in the packet. Note that all flags will be set to 0 if this automatic inclusion option is used.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-enable_send_as_rro
			x		Available only with IxTclNetwork.Send as a RRO.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-enable_send_as_srro
			x		Available only with IxTclNetwork.Send as a SRRO. Note that both enable_send_as_rro and enable_send_as_srro can be enabled at the same time if so required by the user.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-explicit_traffic_item
			x		Available only with IxTclNetworkInsert explicit traffic item for tunnel head if set to 1.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-h2l_info_dut_hop_type
			x		Available only with IxTclNetwork.Description:Based on the input, corresponding L bit in the packet will be set. This parameter configures the Tunnel Head To Leaf Info properties of a P2MP Tunnel. This parameter accepts a list of values.When a list of values is provided, multiple Tunnel Head To Leaf Info objects are configured on the current tunnel. If -count parameter is greater then 1 (multiple tunnels are configured at the same time), each tunnel will have the same Tunnel Head To Leaf Info objects. [RFC 3209].Choices -strict or -loose Dependencies: This parameter is valid only when -enable_prepend_dut is 1.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-h2l_info_dut_prefix_length
			x		Available only with IxTclNetwork.Prefix length of DUT. Range 1-32. This parameter configures the Tunnel Head To Leaf Info properties of a P2MP Tunnel. This parameter accepts a list of values. When a list of values is provided, multiple Tunnel Head To Leaf Info objects are configured on the current tunnel. If -count parameter is greater then 1 (multiple tunnels are configured at the same time), each tunnel will have the same Tunnel Head To Leaf Info objects.Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-h2l_info_enable_append_tunnel_leaf
			x		Available only with IxTclNetwork.Append the tunnel leaf at the end of the ERO / SERO list in the packet.This parameter configures the Tunnel Head To Leaf Info properties of a P2MP Tunnel. This parameter accepts a list of values. When a list of values is provided, multiple Tunnel Head To Leaf Info objects are configured on the current tunnel. If -count parameter is greater then 1 (multiple tunnels are configured at the same time), each tunnel will have the same Tunnel Head To Leaf Info objects.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-h2l_info_enable_prepend_dut
			x		Available only with IxTclNetwork.Prepend DUT to the ERO / SERO list. This parameter configures the Tunnel Head To Leaf Info properties of a P2MP Tunnel. This parameter accepts a list of values. When a list of values is provided, multiple Tunnel Head To Leaf Info objects are configured on the current tunnel.If -count parameter is greater then 1 (multiple tunnels are configured at the same time), each tunnel will have the same Tunnel Head To Leaf Info objects.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-h2l_info_ero_sero_list
			x		Available only with IxTclNetwork.This parameter configures a list of ero/sero objects on a Tunnel Head To Leaf Information object. ERO/SERO objects can be configured as either IP or AS. The following format must be used for IP type: ip,<ipv4 address/prefix>,<'s' for strict or 'l' for loose>ip = the 'ip' keywordipv4_address -- an IPv4 addressprefix -- the prefix length for the ip address (range 1-32)'l' - corresponding L bit in the packet will be set's' - corresponding L bit in the packet will not be setFor 'as' type the accepted format is as,<as number>,<'s' for strict or 'l' for loose> as -- 'as' keyword<as number> - number of the AS'l' - corresponding L bit in the packet will be set's' - corresponding L bit in the packet will not be setIn this way one ERO/SERO object is configured on all the Tunnel Head To Leaf Info objects. You can configure multiple ERO/SERO objects on all the Tunnel Head To Leaf Info objects by separating the format mentioned above with the ":" character.Example: "ip,1.0.1.0/32,s:ip,0.0.1.0/32,l"To configure a separate ERO/SERO object list on each Tunnel Head To Leaf you can pass this parameter on as a list.Example: count 2 h2l_info_tunnel_leaf_prefix_length [list 16 24]h2l_info_ero_sero_list [list ip,1.0.1.0/32,s:as,13,l ip,15.15.15.15/24,s:as,14,s] This will configure two P2MP tunnels. Each tunnel will have two Tunnel Head To Leaf Info objects. The first Head To Leaf Info object will have two ERO/SERO objects (ip 1010 and as 13), the second will also have two ERO/SERO objects (ip 15.15.15.15 and as 14).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-h2l_info_enable_send_as_ero
			x		Available only with IxTclNetwork.Entire configuration would go as ERO if 1. This parameter configures the Tunnel Head To Leaf Info properties of a P2MP Tunnel. This parameter accepts a list of values. When a list of values is provided, multiple Tunnel Head To Leaf Info objects are configured on the current tunnel. If -count parameter is greater then 1 (multiple tunnels are configured at the same time), each tunnel will have the same Tunnel Head To Leaf Info objects.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-h2l_info_enable_send_as_sero
			x		Available only with IxTclNetwork.Entire configuration would go as SERO if 1. If ERO and SERO both enabled then configuration would go both as ERO and SERO for that <head, leaf> tuple. This parameter configures the Tunnel Head To Leaf Info properties of a P2MP Tunnel. This parameter accepts a list of values. When a list of values is provided, multiple Tunnel Head To Leaf Info objects are configured on the current tunnel. If -count parameter is greater then 1 (multiple tunnels are configured at the same time), each tunnel will have the same Tunnel Head To Leaf Info objects.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-h2l_info_tunnel_leaf_count
			x		Available only with IxTclNetwork.Count of tunnel leaf. Range 1-4294967295. This parameter configures the Tunnel Head To Leaf Info properties of a P2MP Tunnel. This parameter accepts a list of values. When a list of values is provided, multiple Tunnel Head To Leaf Info objects are configured on the current tunnel. If -count parameter is greater then 1 (multiple tunnels are configured at the same time), each tunnel will have the same Tunnel Head To Leaf Info objects.Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-h2l_info_tunnel_leaf_hop_type
			x		Available only with IxTclNetwork.Choices: strict, loose. Based on the input, corresponding L bit in the packet will be set. [RFC 3209]. This parameter configures the Tunnel Head To Leaf Info properties of a P2MP Tunnel. This parameter accepts a list of values. When a list of values is provided, multiple Tunnel Head To Leaf Info objects are configured on the current tunnel. If -count parameter is greater then 1 (multiple tunnels are configured at the same time), each tunnel will have the same Tunnel Head To Leaf Info objects.Dependencies: -enable_append_tunnel_leaf 1.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-h2l_info_tunnel_leaf_ip_start
			x		Available only with IxTclNetwork.This will contain the start IP address of leaf for which the ERO / SERO is going to be configured. IP Address (IPv4 format only). This parameter configures the Tunnel Head To Leaf Info properties of a P2MP Tunnel. This parameter accepts a list of values. When a list of values is provided, multiple Tunnel Head To Leaf Info objects are configured on the current tunnel. If -count parameter is greater then 1 (multiple tunnels are configured at the same time), each tunnel will have the same Tunnel Head To Leaf Info objects.Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-h2l_info_tunnel_leaf_prefix_length
			x		Available only with IxTclNetwork.Prefix length of tunnel leaf. Range 1-32. This parameter configures the Tunnel Head To Leaf Info properties of a P2MP Tunnel. This parameter accepts a list of values. When a list of values is provided, multiple Tunnel Head To Leaf Info objects are configured on the current tunnel.If -count parameter is greater then 1 (multiple tunnels are configured at the same time), each tunnel will have the same Tunnel Head To Leaf Info objects.Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-head_traffic_inter_tunnel_ip_step
			x		Available only with IxTclNetwork.When -count parameter is greater then 1 this will be the step used to increment -head_traffic_start_ip IP address from one tunnel to the next.(DEFAULT = 0.0.1.0 or ::1:0)The parameters -head_traffic_inter_tunnel_ip_step,head_traffic_ip_count,- head_traffic_ip_type, -head_traffic_start_ip define the source IP addresses when an RSVP-TE P2MP handle is used as emulation_src_handle in ::<namespace>::traffic_config.Dependencies: -emulation_type rsvptep2mp; -rsvp_behavior ingress
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-head_traffic_ip_count
			x		Available only with IxTclNetwork.The number of routers in the sender range.RANGE1-4294967295The parameters -head_traffic_inter_tunnel_ip_step, head_traffic_ip_count,- head_traffic_ip_type, -head_traffic_start_ip define the source IP addresses when an RSVP-TE P2MP handle is used as emulation_src_handle in ::<namespace>::traffic_config.Dependencies: -emulation_type rsvptep2mp; -rsvp_behavior ingress
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-head_traffic_ip_type
			x		Available only with IxTclNetwork.Indicates the end point type. CHOICES ipv4 ipv6The parameters -head_traffic_inter_tunnel_ip_step,head_traffic_ip_count,- head_traffic_ip_type, -head_traffic_start_ip define the source IP addresses when an RSVP-TE P2MP handle is used as emulation_src_handle in ::<namespace>::traffic_config.Dependencies: -emulation_type rsvptep2mp; -rsvp_behavior ingress
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-head_traffic_start_ip
			x		Available only with IxTclNetwork.The starting IP address one of IPv4 or IPv6.The parameters -head_traffic_inter_tunnel_ip_step,head_traffic_ip_count,- head_traffic_ip_type, -head_traffic_start_ip define the source IP addresses when an RSVP-TE P2MP handle is used as emulation_src_handle in ::<namespace>::traffic_config.Dependencies: -emulation_type rsvptep2mp; -rsvp_behavior ingress
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-p2mp_id
			x		Available only with IxTclNetwork.: IP Address or number.(DEFAULT = 0.0.0.1; 1)Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-p2mp_id_step
			x		Available only with IxTclNetwork.: Step to increment p2mp_id when -count parameter > 1. IP Address or number .(DEFAULT = 0.0.0.0 or 0)Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-path_error_tlv
			x		Available only with IxTclNetwork.When signaling fails in the head-end area, a path error message is sent to the head-end. Struct of form class,cType,data:class,cType,data:.class = The class distinguisher of the TLV.cType = The C-Type distinguisher of the TLV.data = The data associated with the TLV. The length of the TLV will be calculated from the length of this data.(DEFAULT = "")Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-path_tear_tlv
			x		Available only with IxTclNetwork.A set of custom TLVs to be included in TEAR messages. Struct of form class,cType,data:class,cType,data:.class = The class distinguisher of the TLV.cType = The C-Type distinguisher of the TLV.data = The data associated with the TLV. The length of the TLV will be calculated from the length of this data.(DEFAULT = "")Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-path_tlv
			x		Available only with IxTclNetwork.A set of custom TLVs to be included in PATH messages. Struct of form class,cType,data:class,cType,data:.class = The class distinguisher of the TLV.cType = The C-Type distinguisher of the TLV.data = The data associated with the TLV. The length of the TLV will be calculated from the length of this data.(DEFAULT = "")Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-record_route
			x		If set to 1, includes the RECORD_ROUTE object in the Path message. If set to 0, does not include the RECORD_ROUTE object in the Path message.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-reservation_error_tlv
			x		Available only with IxTclNetwork.A set of custom TLVs to be included in RESV ERR messages. These may only be used for ingress routers. Struct of form class,cType,data:class,cType,data:.class = The class distinguisher of the TLV.cType = The C-Type distinguisher of the TLV.data = The data associated with the TLV. The length of the TLV will be calculated from the length of this data.(DEFAULT = "")Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-reservation_tear_tlv
			x		Available only with IxTclNetwork.A set of custom TLVs to be included in RESV TEAR messages. These may only be used for egress routers. Struct of form class,cType,data:class,cType,data:.class = The class distinguisher of the TLV.cType = The C-Type distinguisher of the TLV.data = The data associated with the TLV. The length of the TLV will be calculated from the length of this data.(DEFAULT = N/A)Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-reservation_tlv
			x		Available only with IxTclNetwork.A set of custom TLVs to be included in RESV messages. These may only be used for egress routers. Struct of form class,cType,data:class,cType,data:.class = The class distinguisher of the TLV.cType = The C-Type distinguisher of the TLV.data = The data associated with the TLV. The length of the TLV will be calculated from the length of this data.(DEFAULT = N/A)Dependencies: N/A.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-tail_traffic_inter_tunnel_ip_step
			x		Available only with IxTclNetwork.When -count parameter is greater then 1 this will be the step used to increment -tail_traffic_start_ip IP address from one tunnel to the next.(DEFAULT = 0.0.1.0 or ::1:0)The parameters -tail_traffic_inter_tunnel_ip_step,tail_traffic_ip_count,- tail_traffic_ip_type, - tail_traffic_start_ip define the destination IP addresses when an RSVP-TE P2MP handle is used as emulation_dst_handle in ::<namespace>::traffic_config.Dependencies: -emulation_type rsvptep2mp
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-tail_traffic_ip_count
			x		Available only with IxTclNetwork.The number of routers in the destination range.RANGE1-4294967295The parameters -tail_traffic_inter_tunnel_ip_step,tail_traffic_ip_count,- tail_traffic_ip_type, - tail_traffic_start_ip define the destination IP addresses when an RSVP-TE P2MP handle is used as emulation_dst_handle in ::<namespace>::traffic_config.Dependencies: -emulation_type rsvptep2mp.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-tail_traffic_ip_type
			x		Available only with IxTclNetwork.Indicates the end point type. CHOICES ipv4 ipv6The parameters -tail_traffic_inter_tunnel_ip_step,tail_traffic_ip_count,- tail_traffic_ip_type, - tail_traffic_start_ip define the destination IP addresses when an RSVP-TE P2MP handle is used as emulation_dst_handle in ::<namespace>::traffic_config.Dependencies: -emulation_type rsvptep2mp.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-tail_traffic_start_ip
			x		Available only with IxTclNetwork.The IP address of the first destination router.The parameters -tail_traffic_inter_tunnel_ip_step,tail_traffic_ip_count,- tail_traffic_ip_type, - tail_traffic_start_ip define the destination IP addresses when an RSVP-TE P2MP handle is used as emulation_dst_handle in ::<namespace>::traffic_config.Dependencies: -emulation_type rsvptep2mp.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			n	-extended_tunnel_id_type
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
		
		Return Values:
		A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
			xkey:ipv4_loopback_handle                      value:A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
		A list containing the ipv4 protocol stack handles that were added by the command (if any).
			xkey:ipv4_handle                               value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		A list containing the ethernet protocol stack handles that were added by the command (if any).
			xkey:ethernet_handle                           value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE
			 key:status                                    value:$::SUCCESS | $::FAILURE
		When status is $::FAILURE, contains more information
			 key:log                                       value:When status is $::FAILURE, contains more information
		Handle of RSVP TE LSP configured
			 key:rsvpte_lsp_handle                         value:Handle of RSVP TE LSP configured
		Handle of RSVP P2P Ingress configured Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:rsvpte_p2p_ingress_handle                 value:Handle of RSVP P2P Ingress configured Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		Handle of RSVP P2 Egress configured
			 key:rsvpte_p2p_egress_handle                  value:Handle of RSVP P2 Egress configured
		Handle of RSVP P2MP Ingress configured Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:rsvpte_p2mp_ingress_handle                value:Handle of RSVP P2MP Ingress configured Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		Handle of RSVP P2MP Egress configured
			 key:rsvpte_p2mp_egress_handle                 value:Handle of RSVP P2MP Egress configured
		Handle of RSVP P2MP Ingress SubLSP configured
			 key:rsvpte_p2mp_ingress_sublsp_handle         value:Handle of RSVP P2MP Ingress SubLSP configured
		Handle of RSVP-TE Expected PCE Initiated P2P LSPs configured
			 key:rsvp_pcep_expected_initiated_lsps_handle  value:Handle of RSVP-TE Expected PCE Initiated P2P LSPs configured
		When status is failure, contains more information
			 key:log                                       value:When status is failure, contains more information
		The handles for the RSVP TE Tunnel created
			 key:tunnel_handle                             value:The handles for the RSVP TE Tunnel created
		
		Examples:
		See files starting with RSVP_ in the Samples subdirectory.  Also see some of the MVPN sample files for further examples of the RSVP usage.
		See the RSVP example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  rsvpte_p2p_ingress_handle, rsvpte_p2mp_ingress_handle
		Coded versus functional specification.
		1. Current parser does not support hex. The following options have RANGE 0-0xFFFFFFFF.  It is changed to RANGE 0-2147483647 for now.2. Note:  2147483647 is the max number supported by the current tcl 8.0.session_attr_ra_exclude_anysession_attr_ra_include_anysession_attr_ra_include_all3. Parameters used when -mode is "modify" will apply to all handles provided for modification.The following parameters can not be modified:rsvp_behavioregress_ip_addrip_countemulation_typeenable_append_connected_ipenable_prepend_tunnel_head_ipenable_prepend_tunnel_leaf_ipenable_send_as_rroenable_send_as_srrop2mp_ideroero_list_typeero_list_as_numero_list_ipv4ero_list_looseero_dut_pfxlenrro_list_ctyperro_list_flagsrrorro_list_labelrro_list_ipv4rro_list_typeplr_idavoid_node_id4. All values that support decimal representation are subject to conversion according to IEEEFloat format convension (IEEE standards for floating point - single precision 32 bit).
		
		See Also:
		
		"""
		return self._run_keyword("emulation_rsvp_tunnel_config", kwargs)

	def emulation_rsvp_tunnel_info(self, **kwargs):
		""" For a test port running RSVP emulation, retrieves the RSVP tunnel information for both incoming and outgoing tunnels.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_rsvp_tunnel_info
			 	[-handle      ANY]
			 	[-port_handle ANY]
		
		Arguments:
			 	-handle
			 		The RSVP session handle or tunnel handle.
			 	-port_handle
			 		The port where the RSVP tunnel information is to be retrieved.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                              value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                                 value:If status is failure, detailed information provided.
		list of labels; At port/session level.
			 key:label                               value:list of labels; At port/session level.
		Port Name statistic.
			 key:port_name                           value:Port Name statistic.
		At port level only.
			 key:total_lsp_count                     value:At port level only.
		At port level only.Returns the Egress LSPs Up statistic
			 key:inbound_lsp_count                   value:At port level only.Returns the Egress LSPs Up statistic
		At port level only.Returns the Ingress LSPs Configured statistic
			 key:outbound_lsp_count                  value:At port level only.Returns the Ingress LSPs Configured statistic
		At port level only.Returns the Ingress LSPs Up statistic
			 key:outbound_up_count                   value:At port level only.Returns the Ingress LSPs Up statistic
		At port level only.
			 key:outbound_down_count                 value:At port level only.
		keyed list ingress_ip.$tunnel_handle; At session/tunnel level.
			 key:ingress_ip                          value:keyed list ingress_ip.$tunnel_handle; At session/tunnel level.
		keyed list egress_ip.$tunnel_handle; At session/tunnel level.
			 key:egress_ip                           value:keyed list egress_ip.$tunnel_handle; At session/tunnel level.
		keyed list tunnel_id.$tunnel_handle; At session/tunnel level.
			 key:tunnel_id                           value:keyed list tunnel_id.$tunnel_handle; At session/tunnel level.
		keyed list leaf_ip.$tunnel_handle; At session/tunnel level. List of leaves for the tunnel_handle.
			 key:leaf_ip                             value:keyed list leaf_ip.$tunnel_handle; At session/tunnel level. List of leaves for the tunnel_handle.
		keyed list lsp_id.$tunnel_handle; At session/tunnel level.
			 key:lsp_id                              value:keyed list lsp_id.$tunnel_handle; At session/tunnel level.
		keyed list graceful_restart_reservation_state.$tunnel_handle; At session/tunnel level.
			 key:graceful_restart_reservation_state  value:keyed list graceful_restart_reservation_state.$tunnel_handle; At session/tunnel level.
		Source
			 key:source                              value:Source
		Direction
			 key:direction                           value:Direction
		Outbound Connect Count
			 key:outbound_connect_count              value:Outbound Connect Count
		Outbound Lsps
			 key:outbound_lsps                       value:Outbound Lsps
		list of LSP info; No further support
			 key:inbound_lsps                        value:list of LSP info; No further support
		
		Examples:
		See files starting with RSVP_ in the Samples subdirectory.  Also see some of the MVPN sample files for further examples of the RSVP usage.
		See the RSVP example in Appendix A, "Examples APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.The following stat counts are per port only:total_lsp_countinbound_lsp_countoutbound_lsp_countoutbound_up_countoutbound_down_count
		
		See Also:
		
		"""
		return self._run_keyword("emulation_rsvp_tunnel_info", kwargs)

	def emulation_stp_bridge_config(self, **kwargs):
		""" This command is used to create/modify/delete/enable/disable a STP bridge. Each STP bridge can have multiple STP router interfaces. Each bridge interface is associated with a protocol interface.By specifying the intf_... parameters there will be created a number of interfaces equal to intf_count of directly connected interfaces per STP bridge.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_stp_bridge_config
			 	[-auto_pick_bridge_mac           ANY]
			 	[-auto_pick_port                 ANY]
			 	[-bridge_mac                     ANY]
			 	[-bridge_mac_step                ANY]
			 	[-bridge_mode                    ANY]
			 	[-bridge_msti_vlan               ANY]
			 	[-bridge_priority                ANY]
			 	[-bridge_system_id               ANY]
			 	[-cist_external_root_cost        ANY]
			 	[-cist_external_root_mac         ANY]
			 	[-cist_external_root_priority    ANY]
			 	[-cist_reg_root_cost             ANY]
			 	[-cist_reg_root_mac              ANY]
			 	[-cist_reg_root_priority         ANY]
			 	[-cist_remaining_hop             ANY]
			 	[-count                          ANY]
			 	[-cst_root_mac_address           ANY]
			 	[-cst_root_path_cost             ANY]
			 	[-cst_root_priority              ANY]
			 	[-cst_vlan_port_priority         ANY]
			 	[-enable_jitter                  ANY]
			 	[-forward_delay                  ANY]
			 	[-handle                         ANY]
			 	[-hello_interval                 ANY]
			 	[-inter_bdpu_gap                 ANY]
			 	[-interface_handle               ANY]
			 	[-intf_cost                      ANY]
			 	[-intf_count                     ANY]
			 	[-intf_gw_ip_addr                ANY]
			 	[-intf_gw_ip_addr_step           ANY]
			 	[-intf_gw_ip_addr_bridge_step    ANY]
			 	[-intf_ip_addr                   ANY]
			 	[-intf_ip_addr_bridge_step       ANY]
			 	[-intf_ip_addr_step              ANY]
			 	[-intf_ip_prefix_length          ANY]
			 	[-intf_ipv6_addr                 ANY]
			 	[-intf_ipv6_addr_step            ANY]
			 	[-intf_ipv6_addr_bridge_step     ANY]
			 	[-intf_ipv6_prefix_length        ANY]
			 	[-jitter_percentage              ANY]
			 	[-link_type                      ANY]
			 	[-mac_address_bridge_step        ANY]
			 	[-mac_address_init               ANY]
			 	[-mac_address_intf_step          ANY]
			 	[-max_age                        ANY]
			 	[-message_age                    ANY]
			 	[-mode                           ANY]
			 	[-mstc_name                      ANY]
			 	[-mstc_revision                  ANY]
			 	[-mtu                            ANY]
			 	[-override_existence_check       ANY]
			 	[-override_tracking              ANY]
			 	[-port_handle                    ANY]
			 	[-port_no                        ANY]
			 	[-port_no_bridge_step            ANY]
			 	[-port_no_intf_step              ANY]
			 	[-port_priority                  ANY]
			 	[-pvid                           ANY]
			 	[-reset                          ANY]
			 	[-root_cost                      ANY]
			 	[-root_mac                       ANY]
			 	[-root_priority                  ANY]
			 	[-root_system_id                 ANY]
			 	[-vlan                           ANY]
			 	[-vlan_id                        ANY]
			 	[-vlan_id_bridge_step            ANY]
			 	[-vlan_id_intf_step              ANY]
			 	[-vlan_user_priority             ANY]
			 	[-vlan_user_priority_bridge_step ANY]
		
		Arguments:
			 	-auto_pick_bridge_mac
			 		If enabled, the MAC address for one of the STP interfaces will be automatically assigned as the MAC address for this Bridge. If disabled, the user can assign a MAC address for this Bridge.This option is valid only when -mode is create or -mode is modify and -handle is provided.Valid options are: 0 - disabled, 1 - enabled.
			 	-auto_pick_port
			 		If enabled, each STP interface configured for the same bridge will be assigned a unique port number automatically. Additional port numbers for interfaces on the same bridge will be incremented by 1. This option is valid only when -mode is create or -mode modify and -handle is provided as a STP bridge interface handle or as an STP bridge handle (both handles are returned by emulation_stp_bridge_config). If the change is to be applied on an STP bridge handle it will be applied for all its interfaces.Valid options are: 0 - disabled, 1 - enabled.
			 	-bridge_mac
			 		The 6-byte MAC Address of this emulated Bridge. Part of the Bridge Identifier (Bridge ID). This option is valid only when -mode is create or -mode is modify and -handle is provided.
			 	-bridge_mac_step
			 		The 6-byte MAC Address of this emulated Bridge. Part of the Bridge Identifier (Bridge ID). This option is valid only when -mode is create or -mode is modify and -handle is provided.
			 	-bridge_mode
			 		The type of spanning tree protocol to be used for this emulated Bridge. All of the emulated bridges on a port should use the same version of the spanning tree protocol - STP, RSTP, MSTP, PVST+, RPVST+ or PVSTP. The DUT should also use the same version of the protocol.
			 		Valid choices are:
			    		stp - Spanning Tree Protocol
			    		rstp - Rapid Spanning Tree Protocol (the default)
			    		mstp - Multiple Spanning Tree Protocol
			    		pvst - Per-VLAN Spanning Tree Plus Protocol
			    		rpvst - Rapid Per-VLAN Spanning Tree Plus Protocol
			    		pvstp - Per-VLAN Spanning Tree
			 	-bridge_msti_vlan
			 		This parameter is valid only for bridge_mode mstp, pvst and rpvst. The parameter specifies the MSTI/VLAN to be used by the bridge. Valid options are:allnone<vlan or msti handle>This option is valid only when -mode is modify and -handle is provided as a STP bridge interface handle or as an STP bridge handle (both handles are returned by emulation_stp_bridge_config). If the change is to be applied on an STP bridge handle it will be applied for all its interfaces.
			 	-bridge_priority
			 		The unsigned integer value assigned as the Priority for the Root Bridge. Part of the Root Bridge Identifier (Root Bridge ID). Since MAC address reduction is used, only multiples of 4096 are used. Choose one of the following values from the list: 0 4096 8192 12288 16384 20480 24576 28672 32768 36864 40960 45056 49152 53248 57344 61440. This option is valid only when -mode is create or -mode is modify and -handle is provided.
			 	-bridge_system_id
			 		The unsigned integer value assigned as the System ID for this Bridge. Part of the Bridge Identifier (Bridge ID).This option is valid only when: -mode is create and -bridge_mode is stp/rstp, or -mode is modify and -handle is provided.
			 	-cist_external_root_cost
			 		Common and Internal Spanning Tree (CIST) regional (external) root path cost. A 4-byte unsigned integer. This option is valid only when: -mode is create and -bridge_mode is mstp, or -mode is modify and -handle is provided.
			 	-cist_external_root_mac
			 		Common and Internal Spanning Tree (CIST) Regional (external) MAC address. Part of the CIST External Root Identifier. A 6-byte MAC address. A 4-byte unsigned integer. This option is valid only when: -mode is create and -bridge_mode is mstp, or -mode is modify and -handle is provided.
			 	-cist_external_root_priority
			 		Common and Internal Spanning Tree (CIST) external root priority. Since MAC address reduction is used, only multiples of 4096 are used. Choose one of the following values from the list: 0 4096 8192 12288 16384 20480 24576 28672 32768 36864 40960 45056 49152 53248 57344 61440. This option is valid only when: -mode is create and -bridge_mode is mstp, or -mode is modify and -handle is provided.
			 	-cist_reg_root_cost
			 		For MSTP Common and Internal Spanning Tree (CIST) regional (external) root path cost.This option is valid only when: -mode is create and -bridge_mode is mstp, or -mode is modify and -handle is provided.
			 	-cist_reg_root_mac
			 		Common and Internal Spanning Tree (CIST) Regional (external) MAC address. Part of the CIST External Root Identifier. A 6-byte MAC address. This option is valid only when: -mode is create and -bridge_mode is mstp, or -mode is modify and -handle is provided.
			 	-cist_reg_root_priority
			 		Since MAC address reduction is used, only multiples of 4096 are used. For MSTP is the priority value of the root bridge for the Common and internal Spanning Tree (CIST)/MSTP region (external). Part of the CIST External Root Identifier. Since MAC address reduction is used, only multiples of 4096 are used. Choose one of the following values from the list 0 4096 8192 12288 16384 20480 24576 28672 32768 36864 40960 45056 49152 53248 57344 61440. This option is valid only when: -mode is create and -bridge_mode is mstp, or -mode is modify and -handle is provided.
			 	-cist_remaining_hop
			 		The number of additional bridge-to-bridge hops that will allowed for the MSTP BPDUs. The root sets the maximum hop count, and each subsequent bridge decrements this value by 1. This option is valid only when: -mode is create and -bridge_mode is mstp, or -mode is modify and -handle is provided.
			 	-count
			 		This parameter represents the number of emulated bridges to create. A number between 1 and 200 must be provided. This option is valid only in mode create.
			 	-cst_root_mac_address
			 		The CST root MAC address. A 6-byte MAC address. This option is valid only when: -mode is create and -bridge_mode is pvst/rpvst, or -mode is modify and -handle is provided.
			 	-cst_root_path_cost
			 		A 4-byte unsigned integer is administrative path cost to the root bridge. This option is valid only when: -mode is create and -bridge_mode is pvst/rpvst, or -mode is modify and -handle is provided.
			 	-cst_root_priority
			 		Is the priority value of the root bridge for the Common Spanning Tree (CST). Since MAC address reduction is used, only multiples of 4096 are used. Choose one of the following values from the list 0 4096 8192 12288 16384 20480 24576 28672 32768 36864 40960 45056 49152 53248 57344 61440. This option is valid only when: -mode is create and -bridge_mode is pvst/rpvst, or -mode is modify and -handle is provided.
			 	-cst_vlan_port_priority
			 		The Port Priority for the emulated port on this PVST+ or RPVST+ bridge that is connected to the VLAN. A 2-byte unsigned integer. The valid range is 0 to 63. This option is valid only when: -mode is create and -bridge_mode is pvst/rpvst, or -mode is modify and -handle is provided.
			 	-enable_jitter
			 		If checked, jitter is enabled in order to stagger the transmission of Hello BPDUs and avoid congestion on the link. This option is valid only when -mode is create or -mode modify and -handle is provided as a STP bridge interface handle or as an STP bridge handle (both handles are returned by emulation_stp_bridge_config). If the change is to be applied on an STP bridge handle it will be applied for all its interfaces.
			 	-forward_delay
			 		The Forward Delay Timer. The delay time used for a port's change to the Forwarding state. This value is set by the Root Bridge. This option is valid only when -mode is create or -mode is modify and -handle is provided.
			 	-handle
			 		This option represents a STP bridge handle for modify, enable, disable or delete.This option is valid when -mode is modify, delete, enable or disable.
			 	-hello_interval
			 		The period of time between transmissions of Hello Messages from the Root Bridge. This option is valid only when -mode is create or -mode is modify and -handle is provided.
			 	-inter_bdpu_gap
			 		The interval between transmissions of BPDUs (in msec). The valid range is 0 to 60,000 msec.This option is valid only when -mode is create or -mode modify and -handle is provided.
			 	-interface_handle
			 		This parameter represents a list of protocol interfaces (previously created with interface_config) that will be used by the STP bridges. This parameter is valid only when -mode is create.
			 	-intf_cost
			 		The cost assigned to this interface - to be added to the Root Path Cost for the path to the Root bridge. A 4-byte unsigned integer. This option is valid only when -mode is create or -mode modify and -handle is provided as a STP bridge interface handle or as an STP bridge handle (both handles are returned by emulation_stp_bridge_config). If the change is to be applied on an STP bridge handle it will be applied for all its interfaces.
			 	-intf_count
			 		Number of interfaces to be created for every emulated bridge. This option is valid only when -mode is create.
			 	-intf_gw_ip_addr
			 		The gateway IP address for the interface that is going to be created. This option is valid only when -mode is create or -mode modify and -handle is a STP router interface.
			 	-intf_gw_ip_addr_step
			 		The gateway IP address incrementing step for the interface that is going to be created. This option is valid only when -mode is create.
			 	-intf_gw_ip_addr_bridge_step
			 		The gateway IP address incrementing step for the interface that is going to be created. This option is valid only when -mode is create. This step is apply between interfaces.
			 	-intf_ip_addr
			 		The first IPv4 address of the first STP interface that will be configured. This option is valid only when -mode is create or -mode is modify and -handle is a STP router interface.
			 	-intf_ip_addr_bridge_step
			 		The IPv4 address incrementing step of the STP interfaces that will be configured. Step is between bridges. This option is valid only when -mode is create.
			 	-intf_ip_addr_step
			 		The IPv4 address incrementing step of the STP bridges that will be configured. This option is valid only when -mode is create.
			 	-intf_ip_prefix_length
			 		The IPv4 address prefix of the STP interfaces that will be configured. This option is valid only when -mode is create.
			 	-intf_ipv6_addr
			 		The first IPv6 address of the first STP interface that will be configured. This option is valid only when -mode is create or -mode is modify and -handle is a STP interface.
			 	-intf_ipv6_addr_step
			 		The IPv6 address incrementing step of the STP interfaces that will be configured. This option is valid only when -mode is create.
			 	-intf_ipv6_addr_bridge_step
			 		The IPv6 address incrementing step of the STP bridges that will be configured. This option is valid only when -mode is create.
			 	-intf_ipv6_prefix_length
			 		The IPv6 address prefix of the STP interfaces that will be configured. This option is valid only when -mode is create or -mode is modify and -handle is a STP interface.
			 	-jitter_percentage
			 		The maximum percentage of +/- variation (jitter) from the Hello message transmission interval. This option is valid only when -mode is createor -mode modify and -handle is provided as a STP bridge interface handleor as an STP bridge handle (both handles are returned by emulation_stp_bridge_config). If the change is to be applied on an STP bridge handle it will be applied for all its interfaces.
			 	-link_type
			 		The type of link attached to this interface. This field is configurable ONLY for use with RSTP/MSTP/RPVST+ mode. The link type may be either point_to_point or shared. This option is valid only when: mode is create and bridge_mode is mstp/rstp/rpvstor mode is modify and -handle is provided as a STP bridge interface handle or as an STP bridge handle (both handles are returned by emulation_stp_bridge_config). If the change is to be applied on an STP bridge handle it will be applied for all its interfaces.Valid options are:point_to_point (DEFAULT)shared
			 	-mac_address_bridge_step
			 		This is step between two consecutive emulated bridges. This option is valid only when -mode create is provided.
			 	-mac_address_init
			 		The first MAC address of the first directly connectedinterface that will be configured. This option is valid only when -mode is create or -mode ismodify and -handle is provided as a STP bridge interface handle or as an STP bridge handle (both handles are returned by emulation_stp_bridge_config). If the change is to be applied on an STP bridge handle it will be applied for all its interfaces.
			 	-mac_address_intf_step
			 		This parameter specifies step between interfaces of a single emulated bridge. This option is valid only when -mode is create.
			 	-max_age
			 		maximum message aging time (in ms). This value is set by the Root Bridge. This option is valid only when -mode is create or -mode is modify and -handle is provided.
			 	-message_age
			 		The message age time parameter in the BPDU. Should be less than Max. Age. This option is valid only when -mode is create or -mode is modify and -handle is provided.
			 	-mode
			 		The operation that will be executed. Valid options are:create (DEFAULT)modifyenabledisabledeleteThis option has the following dependencies:when mode is create, -port_handle is requiredwhen mode is modify/enable/disable/delete, -handle is required
			 	-mstc_name
			 		The name assigned to this Multiple Spanning Tree Configuration (MSTC). This option is valid only when: This option is valid only when: -mode is create and -bridge_mode is mstp, or -mode is modify and -handle is provided.(DEFAULT = MSTC-1 for first element, MSTC-2 for second, etc)
			 	-mstc_revision
			 		The revision number for this Multiple Spanning Tree Configuration (MSTC). A 2-byte unsigned integer.This option is valid only when: -mode is create and -bridge_mode is mstp/pvst/rpvst, or -mode is modify and -handle is provided.
			 	-mtu
			 		The mtu value for the directly connected interfaces. This option is valid only when -mode is create or -mode is modify and -handle is provided as a STP bridge interface handle or as an STP bridge handle (both handles are returned by emulation_stp_bridge_config).If the change is to be applied on an STP bridge handle it will be applied for all its interfaces.
			 	-override_existence_check
			 		If this option is enabled, the interface existence check is skipped but the list of interfaces is still created and maintained in order to keep track of existing interfaces if required. Using this option will speed up the creation of the interfaces.
			 	-override_tracking
			 		If this option is enabled, the list of interfaces will no longer be created and maintained, thus speeding up the creation of interfaces even more. Also, it will enable -override_existence_check in case it was not already enabled because checking for interface existence becomes impossible if the list of interfaces does not exist anymore.
			 	-port_handle
			 		The port where the action will take place.This option is mandatory when -mode is create.
			 	-port_no
			 		The port number associated with this STP interface. If Auto Pick Port No. is enabled, the port number will be grayed out and automatically assigned-not changeable by the user. If Auto Pick Port No. is not enabled, the user may enter a value for the port number. This option is valid only when -mode is create or -mode is modify and -handle is provided.
			 	-port_no_bridge_step
			 		The amount to increment port number from a bridge to another.This option is valid only when -mode is create or -mode is modify and -handle is provided and auto_pick_port is 0.
			 	-port_no_intf_step
			 		The amount to increment port number from an interface to another in an emulated bridge. This option is valid only when -mode is create or -mode is modify and -handle is provided and auto_pick_port is 0.
			 	-port_priority
			 		The port priority. Choose one of the following values from the list:0 16 32 48 64 80 96 112 128 144 160 176 192 208 224 240.This option is valid only when:This option is valid only when: -mode is create and -bridge_mode is stp/rst/mstp, or -mode is modify and -handle is provided.
			 	-pvid
			 		The Port VLAN ID. This must be the same for all ports participating in this protocol. This option is valid only when mode is create and -bridge_mode is mstp/pvst/rpvst or mode is modify and -handle is provided as a STP bridge interface handle or as an STP bridge handle (both handles are returned by emulation_stp_bridge_config). If the change is to be applied on an STP bridge handle it will be applied for all its interfaces.
			 	-reset
			 		If this flag is present all the STP configuration on that specific port is erased. This option is requires -mode create and -port_handle to be provided.
			 	-root_cost
			 		Root Path Cost. The administrative cost for the shortest path from this bridge to the Root bridge.This option is valid only when: -mode is create and -bridge_mode is stp/rstp, or -mode is modify and -handle is provided.
			 	-root_mac
			 		The 6-byte MAC Address of the emulated Root Bridge. Part of the Root This option is valid only when: -mode is create and -bridge_mode is stp/rstp, or -mode is modify and -handle is provided.
			 	-root_priority
			 		The unsigned integer value assigned as the Priority for the Root Bridge. Part of the Root Bridge Identifier (Root Bridge ID). Since MAC address reduction is used, only multiples of 4096 are used. Choose one of the following values from the list: 0 4096 8192 12288 16384 20480 24576 28672 32768 (the default) 36864 40960 45056 49152 53248 57344 61440. This option is valid only when: -mode is create and -bridge_mode is stp/rstp, or -mode is modify and -handle is provided.
			 	-root_system_id
			 		The unsigned integer value assigned as the System ID for the Root Bridge. Part of the Root Bridge Identifier (Root Bridge ID).This option is valid only when: -mode is create and -bridge_mode is stp/rstp, or -mode is modify and -handle is provided.
			 	-vlan
			 		Enables vlan on the directly connected STP bridge interface.Valid options are: 0 - disable, 1 - enable.If vlan_id is specified on -mode create, -vlan will be set to 1. Dependencies: This option is valid only when -mode is create or -mode is modify and -handle is provided as a STP bridge interface handle or as an STP bridge handle (both handles are returned by emulation_stp_bridge_config). If the change is to be applied on an STP bridge handle it will be applied for all its interfaces.
			 	-vlan_id
			 		Sets the vlan ID on the directly connected STP bridge interface. Range 0-4095.This option is valid only when -mode is create or -mode is modify and -handle is provided as a STP bridge interface handle or as an STP bridge handle (both handles are returned by emulation_stp_bridge_config). If the change is to be applied on an STP bridge handle it will be applied for all its interfaces.
			 	-vlan_id_bridge_step
			 		Set VLAN step between bridges. This option is valid only when -mode is create.
			 	-vlan_id_intf_step
			 		Set VLAN step between interfaces. This option is valid only when -mode is create.
			 	-vlan_user_priority
			 		Sets the vlan ID user priority on the directly connected STP bridge interfaces. Range 0-7. This option is valid only when -mode is create or -mode is modify and -handle is provided as a STP bridge interface handle or as an STP bridge handle (both handles are returned by emulation_stp_bridge_config). If the change is to be applied on an STP bridge handle it will be applied for all its interfaces.
			 	-vlan_user_priority_bridge_step
			 		Sets the vlan ID user priority step between emulated bridges. This option is valid only when -mode is create or -mode is modify.
		
		Return Values:
		$::SUCCESS or $::FAILURE
			 key:status                    value:$::SUCCESS or $::FAILURE
		When status is failure, contains more information
			 key:log                       value:When status is failure, contains more information
		The list of STP bridge handles
			 key:bridge_handles            value:The list of STP bridge handles
		the list of bridge interface values - handles for an STP bridge
			 key:bridge_interface_handles  value:the list of bridge interface values - handles for an STP bridge
		the list of protocol interface handles for a specific STP bridge
			 key:interface_handles.        value:the list of protocol interface handles for a specific STP bridge
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_stp_bridge_config", kwargs)

	def emulation_stp_control(self, **kwargs):
		""" Take action for current configured emulated bridges. Actions could be
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_stp_control
			 	[-handle ANY]
			 	[-mode   ANY]
		
		Arguments:
			 	-handle
			 		Bridge handle should be specified here. One of the two parameters is required: port_handle/handle. This option usage will cause start protocol for all bridge on port.
			 	-mode
			 		The action to take on the provided port_handle/handle: start/stop the protocol. For start, stop or restart, the protocol will be started stopped or restarted. handle or port_handle should be provided.For mode bridge_topology_change: After the STP protocol is running, the user can press this button to generate Topology Change BPDUs, so that MAC addresses are flushed from the DUT and from relevant nodes in the spanning tree. When used with an MSTP bridge, this topology change applies to all CISTs and MSTIs related to the bridge. Protocol should be running when this parameter is specified or protocol should be started in same call.For mode cist_topology_change: After MSTP is up and running, the user can press this button to generateMSTP BPDUs, to update the Common and Internal Spanning Tree (CIST). Protocol should be running when this parameter is specified or protocol should be started in same call. This option is allowed for MSTP bridge only.For mode update_parameters: After STP is started and running and the switching network has converged, the Root ID and root cost for the bridge may be changed on-the-fly by entering the new value and pressing this Update Parameters button, to emulate dynamic changes in topology.If bridge mode is MSTP and any of the following were changed (using using -mode modify of ::<namespace>::emulation_stp_bridge_config or ::<namespace>::emulation_stp_msti_config):1. ID / Cost parameters for CIST Regional Root and/or ID / Cost parameters for CIST External Root2. MSTC Name3. MSTC Revision No4. MSTIs associated with this bridgethen this value (at -mode"update_parameters") can be used to commit and trigger changes in the emulated topology.In addition, note that the Protocol should be running when this parameter is specified or the protocol should be started in the same call.
		
		Return Values:
		$::SUCCESS or $::FAILURE
			 key:status  value:$::SUCCESS or $::FAILURE
		When status is failure, contains more information
			 key:log     value:When status is failure, contains more information
		The list of bridges created
			 key:handle  value:The list of bridges created
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_stp_control", kwargs)

	def emulation_stp_info(self, **kwargs):
		""" Command to retrieve STP statistics
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_stp_info
			 	[-mode   ANY]
			 	[-handle ANY]
		
		Arguments:
			 	-mode
			 		The action that should be taken. One of the two parameters is required: port_handle/handle.
			 		Valid choices are:
			    		aggregate_stats - retrieve stats aggregated per port
			    		learned_info - retrieve learned information by the STP protocol
			    		clear_stats - clear stats
			 	-handle
			 		This parameter represents a STP bridge handle obtained through a previous call to emulation_stp_bridge_config.One of the two parameters is required: port_handle/handle.
		
		Return Values:
			 key:TclX keyed list  value:
		$::SUCCESS or $::FAILURE
			 key:status           value:$::SUCCESS or $::FAILURE
		When status is failure, contains more information
			 key:log              value:When status is failure, contains more information
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_stp_info", kwargs)

	def emulation_stp_lan_config(self, **kwargs):
		""" This command is used to create/modify/delete/enable/disable an emulated LAN for STP protocol.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_stp_lan_config
			 	[-count           ANY]
			 	[-mac_address     ANY]
			 	[-mac_incr_enable ANY]
			 	[-mode            ANY]
			 	[-port_handle     ANY]
			 	[-vlan_enable     ANY]
			 	[-vlan_id         ANY]
		
		Arguments:
			 	-count
			 		Number of mac/vlan to be emulated with current object.This option is valid only when -mode create is provided.
			 	-mac_address
			 		First mac address in the range. option is valid only when -mode create is provided or -mode modify and -handle is provided.
			 	-mac_incr_enable
			 		If this option is enable then will be emulated -count ofdistinct mac generated incrementing by one. Option is valid only when -mode create is provided or -mode modify and -handle is provided.
			 	-mode
			 		Select action to take with current call. Choices are create, modify, delete, enable and disable. For mode create port_handle shoud be specified. For others handle should be provided.
			 	-port_handle
			 		Select port on which to create emulated LAN. option is valid only when -mode create is provided.
			 	-vlan_enable
			 		Enable/disable VLAN for current LAN. This option is valid for create ormodify mode.
			 	-vlan_id
			 		First vlan to be generated in current range. option is valid only when -mode create and -bridge_handle is provided or -mode modify and -handle is provided.
		
		Return Values:
		$::SUCCESS or $::FAILURE
			 key:status  value:$::SUCCESS or $::FAILURE
		When status is failure, contains more information
			 key:log     value:When status is failure, contains more information
		The list of bridges created
			 key:handle  value:The list of bridges created
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_stp_lan_config", kwargs)

	def emulation_stp_msti_config(self, **kwargs):
		""" This command is used to create/modify/delete/enable/disable a STP MSTI object. This object can be created on a MSTP bridge object. After this object is created it should be assigned to bridge - with mode modify of ixia
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_stp_msti_config
			 	[-bridge_handle                ANY]
			 	[-count                        ANY]
			 	[-handle                       ANY]
			 	[-mode                         ANY]
			 	[-msti_hops                    ANY]
			 	[-msti_id                      ANY]
			 	[-msti_id_step                 ANY]
			 	[-msti_internal_root_path_cost ANY]
			 	[-msti_mac                     ANY]
			 	[-msti_mac_step                ANY]
			 	[-msti_name                    ANY]
			 	[-msti_port_priority           ANY]
			 	[-msti_priority                ANY]
			 	[-msti_vlan_start              ANY]
			 	[-msti_vlan_start_step         ANY]
			 	[-msti_vlan_stop               ANY]
			 	[-msti_vlan_stop_step          ANY]
			 	[-msti_wildcard_percent_enable ANY]
			 	[-msti_wildcard_percent_start  ANY]
		
		Arguments:
			 	-bridge_handle
			 		Bridge handle on which to create MSTI objects. This option is mandatory for create mode. Option is valid only when -mode create is provided.
			 	-count
			 		The number of MSTI objects to be created. This option is valid only when -mode create and -bridge_handle is provided.
			 	-handle
			 		Handle returned by this procedure for specified for modify purpose. This option is valid only when -mode is modify, delete, enable or disable.
			 	-mode
			 		Action to be taken for: create, modify, delete, enable or disable. For mode create port_handle should be specified. For others handle should be provided.
			 	-msti_hops
			 		The number of MSTI hops remaining. An unsigned integer. Valid range: 1 to 255. This option is valid only when: -mode is createor -mode is modify and -handle is provided.
			 	-msti_id
			 		The identifier for this MSTI. An unsigned integer. The valid range is 1 to 4094. This option is valid only when: -mode is createor -mode is modify and -handle is provided.(DEFAULT = 1 for first object, 2 for second, etc.)
			 	-msti_id_step
			 		The amount used to increment msti_id. This option is valid only when -mode create and -bridge_handle is provided.
			 	-msti_internal_root_path_cost
			 		The MSTI Internal Root Path Cost. A 4-byte unsigned integer. This option is valid only when: -mode is createor -mode is modify and -handle is provided.
			 	-msti_mac
			 		The 6-byte MAC address for the MSTI root. This is part of the MSTI Regional Root Identifier. This option is valid only when -mode create and -bridge_handle is provided or -mode modify and -handle is provided.
			 	-msti_mac_step
			 		The 6-byte MAC address step for the MSTI root. This is part of the MSTI Regional Root Identifier. This option is valid only when: -mode is createor -mode is modify and -handle is provided.
			 	-msti_name
			 		The name assigned to this MST Instance (MSTI). This option specifies the MSTI name. If the character '%' is present in the MSTI name and the parameter -msti_wildcard_percent_enable is set to 1, then the '%' character will be replaced with the value specifiedthrough -msti_wildcard_percent_start. The value specifiedthrough -msti_wildcard_percent_start, will be incremented with the amount specified by -msti_wildcard_percent_step, if -count is greater than 1.(DEFAULT = for first object MSTI ID-1, for second MSTI ID-2, etc.)
			 	-msti_port_priority
			 		MSTI Port Priority is part of the MSTI Port Identifier. Choose one of the following values from the list: 0 16 32 48 64 80 96 112 128 144 160 176 192 208 224 240.This option is valid only when: -mode is createor -mode is modify and -handle is provided.
			 	-msti_priority
			 		The MSTI Root Priority. This is part of the MSTI Regional Root Identifier. Since MAC address reduction is used, only multiples of 4096 are used. Choose one of the following values from the list: 0 4096 8192 12288 16384 20480 24576 28672 32768 36864 40960 45056 49152 53248 57344 61440This option is valid only when: -mode is createor -mode is modify and -handle is provided.
			 	-msti_vlan_start
			 		The ID for the first VLAN in the VLAN range to which the MSTI is mapped. This option is valid only when: -mode is createor -mode is modify and -handle is provided.
			 	-msti_vlan_start_step
			 		The step for the first VLAN in the VLAN range to which the MSTI is mapped. This option is valid only when: -mode is createor -mode is modify and -handle is provided.
			 	-msti_vlan_stop
			 		The ID for the last VLAN in the VLAN range to which the MSTI is mapped. An unsigned integer. This option is valid only when: -mode is createor -mode is modify and -handle is provided.
			 	-msti_vlan_stop_step
			 		The step for the last VLAN in the VLAN range to which the MSTI is mapped. An unsigned integer should be provided. This option is valid only when: -mode is createor -mode is modify and -handle is provided.
			 	-msti_wildcard_percent_enable
			 		This parameter enables the replacement of % character found in -msti_name parameter, with the value specified through msti_wilcard_percent_start. For the first MSTI object created, the % character will be replaced with -msti_wilcard_percent_start. When -count is greater than 1, the -msti_wildcard_percent_start value will be incrementedwith -msti_wildcard_percent_step.
			 	-msti_wildcard_percent_start
			 		This parameter represents the value that will replace the % character used inside the string provided by -msti_name parameter.
		
		Return Values:
		$::SUCCESS or $::FAILURE
			 key:status  value:$::SUCCESS or $::FAILURE
		When status is failure, contains more information
			 key:log     value:When status is failure, contains more information
		On mode create, list of bridge handles
			 key:handle  value:On mode create, list of bridge handles
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_stp_msti_config", kwargs)

	def emulation_stp_vlan_config(self, **kwargs):
		""" This command is used to create/modify/delete/enable/disable a STP VLAN object. This object can be created on a PVST or RPVST bridge object. After this object is created it should be assigned to bridge - with mode modify of ixia
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_stp_vlan_config
			 	[-bridge_handle           ANY]
			 	[-count                   ANY]
			 	[-handle                  ANY]
			 	[-internal_root_path_cost ANY]
			 	[-mode                    ANY]
			 	[-root_mac_address        ANY]
			 	[-root_mac_address_step   ANY]
			 	[-root_priority           ANY]
			 	[-vlan_port_priority      ANY]
			 	[-vlan_port_priority_step ANY]
			 	[-vlan_id                 ANY]
		
		Arguments:
			 	-bridge_handle
			 		Bridge handle on which to create VLAN object. This parameter must be specified in create mode. This parameter should be specified in create mode.
			 	-count
			 		Number of VLAN objects to create for bridge specified by handle. This parameter is valid when -mode is create.
			 	-handle
			 		VLAN component of bridge handle to be modified. One of the two parameters is required: port_handle/handle. This option is valid for every mode except create.
			 	-internal_root_path_cost
			 		The administrative cost for the shortest path from this bridge to the Root bridge. A 4-byte unsigned integer. This option is valid only when: -mode is createor -mode is modify and -handle is provided.
			 	-mode
			 		The action to take on the port_handle/handle provided. For mode create port_handle shoud be specified. For othershandle should be provided.
			 	-root_mac_address
			 		The 6-byte MAC address for the Root bridge. This option is valid only when -mode create and -bridge_handle is provided or -mode modify and -handle is provided.
			 	-root_mac_address_step
			 		Specify the step for root_mac_address between STP VLAN objects. This option is valid only when -mode create and -bridge_handle is provided.
			 	-root_priority
			 		The priority of the port. Since MAC address reduction is used, only multiples of 4096 are used. Choose one of the following values from the list:0 4096 8192 12288 1638420480 24576 28672 32768 36864 40960 45056 49152 53248 57344 61440 This option is valid only when -mode create and -bridge_handle is provided or -mode modify and -handle is provided.
			 	-vlan_port_priority
			 		The Port Priority for the emulated port on this PVST+ or RPVST+ bridge that is connected to the VLAN. A 2-byte unsigned integer. The valid range is 0 to 63. This option is valid only when -mode create and -bridge_handle is provided or -mode modify and -handle is provided.
			 	-vlan_port_priority_step
			 		The step for the Port Priority for the emulated port on this PVST+ or RPVST+ bridge that is connected to the VLAN. A 2-byte unsigned integer. The valid range is 0 to 63. This option is valid only whenThis option is valid only when: -mode is createor -mode is modify and -handle is provided.
			 	-vlan_id
			 		This option is valid only when -mode create and -bridge_handle is provided or -mode modify and -handle is provided. (DEFAULT = 2 for first item, 3 for second, etc.)
		
		Return Values:
		$::SUCCESS or $::FAILURE
			 key:status  value:$::SUCCESS or $::FAILURE
		When status is failure, contains more information
			 key:log     value:When status is failure, contains more information
		The list of bridges created
			 key:handle  value:The list of bridges created
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_stp_vlan_config", kwargs)

	def emulation_telnet_config(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_telnet_config
			 	[-handle                         ANY]
			 	[-target                         ANY]
			 	[-property                       ANY]
			 	-mode                            ANY
			 	[-port_handle                    ANY]
			 	[-mac_mapping_mode               ANY]
			 	[-source_port_from               ANY]
			 	[-source_port_to                 ANY]
			 	[-emulated_router_gateway        ANY]
			 	[-emulated_router_subnet         ANY]
			 	[-dns_cache_timeout              ANY]
			 	[-grat_arp_enable                ANY]
			 	[-congestion_notification_enable ANY]
			 	[-time_stamp_enable              ANY]
			 	[-rx_bandwidth_limit_enable      ANY]
			 	[-tx_bandwidth_limit_enable      ANY]
			 	[-fin_timeout                    ANY]
			 	[-keep_alive_interval            ANY]
			 	[-keep_alive_probes              ANY]
			 	[-keep_alive_time                ANY]
			 	[-receive_buffer_size            ANY]
			 	[-retransmit_retries             ANY]
			 	[-rx_bandwidth_limit             ANY]
			 	[-rx_bandwidth_limit_unit        ANY]
			 	[-syn_ack_retries                ANY]
			 	[-syn_retries                    ANY]
			 	[-transmit_buffer_size           ANY]
			 	[-tx_bandwidth_limit             ANY]
			 	[-tx_bandwidth_limit_unit        ANY]
			 	[-ip_address_start               ANY]
			 	[-mac_address_start              ANY]
			 	[-gateway                        ANY]
			 	[-ip_count                       ANY]
			 	[-ip_increment_step              ANY]
			 	[-mac_increment_step             ANY]
			 	[-mss                            ANY]
			 	[-mss_enable                     ANY]
			 	[-network_mask                   ANY]
			 	[-vlan_enable                    ANY]
			 	[-vlan_id                        ANY]
			 	[-dns_server                     ANY]
			 	[-dns_suffix                     ANY]
			 	[-pool_ip_address_start          ANY]
			 	[-pool_ip_count                  ANY]
			 	[-pool_mac_address_start         ANY]
			 	[-pool_network                   ANY]
			 	[-pool_vlan_enable               ANY]
		
		Arguments:
			 	-handle
			 	-target
			    	-property
			        	-mode
			            	-port_handle
			                	-mac_mapping_mode
			                    	-source_port_from
			                        	-source_port_to
			                            	-emulated_router_gateway
			                                	-emulated_router_subnet
			                                    	-dns_cache_timeout
			                                        	-grat_arp_enable
			                                            	-congestion_notification_enable
			                                                	-time_stamp_enable
			                                                    	-rx_bandwidth_limit_enable
			                                                        	-tx_bandwidth_limit_enable
			                                                            	-fin_timeout
			                                                                	-keep_alive_interval
			                                                                    	-keep_alive_probes
			                                                                        	-keep_alive_time
			                                                                            	-receive_buffer_size
			                                                                                	-retransmit_retries
			                                                                                    	-rx_bandwidth_limit
			                                                                                        	-rx_bandwidth_limit_unit
			                                                                                            	-syn_ack_retries
			                                                                                                	-syn_retries
			                                                                                                    	-transmit_buffer_size
			                                                                                                        	-tx_bandwidth_limit
			                                                                                                            	-tx_bandwidth_limit_unit
			                                                                                                                	-ip_address_start
			                                                                                                                    	-mac_address_start
			                                                                                                                        	-gateway
			                                                                                                                            	-ip_count
			                                                                                                                                	-ip_increment_step
			                                                                                                                                    	-mac_increment_step
			                                                                                                                                        	-mss
			                                                                                                                                            	-mss_enable
			                                                                                                                                                	-network_mask
			                                                                                                                                                    	-vlan_enable
			                                                                                                                                                        	-vlan_id
			                                                                                                                                                            	-dns_server
			                                                                                                                                                                	-dns_suffix
			                                                                                                                                                                    	-pool_ip_address_start
			                                                                                                                                                                        	-pool_ip_count
			                                                                                                                                                                            	-pool_mac_address_start
			                                                                                                                                                                                	-pool_network
			                                                                                                                                                                                    	-pool_vlan_enable
		                                                                                                                                                                                   
		                                                                                                                                                                                   Return Values:
		                                                                                                                                                                                       $::SUCCESS | $::FAILURE
			                                                                                                                                                                                        key:status   value:$::SUCCESS | $::FAILURE
		                                                                                                                                                                                       When status is $::FAILURE, contains more information
			                                                                                                                                                                                        key:log      value:When status is $::FAILURE, contains more information
		                                                                                                                                                                                       the handles of a TELNET configuration, network, router, pool, dns server
			                                                                                                                                                                                        key:handles  value:the handles of a TELNET configuration, network, router, pool, dns server
		                                                                                                                                                                                   
		                                                                                                                                                                                   Examples:
		                                                                                                                                                                                       See files starting with TELNET_ in the Samples subdirectory. Also see the TELNET example in Appendix A, "Example APIs."
		                                                                                                                                                                                   
		                                                                                                                                                                                   Sample Input:
		                                                                                                                                                                                   
		                                                                                                                                                                                   Sample Output:
		                                                                                                                                                                                   
		                                                                                                                                                                                   Notes:
		                                                                                                                                                                                       Coded versus functional specification.
		                                                                                                                                                                                   
		                                                                                                                                                                                   See Also:
		                                                                                                                                                                                   
		"""
		return self._run_keyword("emulation_telnet_config", kwargs)

	def emulation_telnet_control(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_telnet_control
			 	-mode                            ANY
			 	[-handle                         ANY]
			 	[-map_handle                     ANY]
			 	[-force_ownership_enable         ANY]
			 	[-release_config_afterrun_enable ANY]
			 	[-reset_ports_enable             ANY]
			 	[-results_dir_enable             ANY]
			 	[-results_dir                    ANY]
		
		Arguments:
			 	-mode
			 	-handle
			    	-map_handle
			        	-force_ownership_enable
			            	-release_config_afterrun_enable
			                	-reset_ports_enable
			                    	-results_dir_enable
			                        	-results_dir
		                       
		                       Return Values:
		                           $::SUCCESS | $::FAILURE
			                            key:status   value:$::SUCCESS | $::FAILURE
		                           When status is $::FAILURE, contains more information
			                            key:log      value:When status is $::FAILURE, contains more information
		                           the handles of a telnet traffic configuration,
			                            key:handles  value:the handles of a telnet traffic configuration,
		                       
		                       Examples:
		                           See files starting with telnet_ in the Samples subdirectory. Also see the TELNET section in Appendix A, "Example APIs."
		                       
		                       Sample Input:
		                       
		                       Sample Output:
		                       
		                       Notes:
		                           Coded versus functional specification.
		                       
		                       See Also:
		                       
		"""
		return self._run_keyword("emulation_telnet_control", kwargs)

	def emulation_telnet_control_config(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_telnet_control_config
			 	[-handle                      ANY]
			 	[-target                      ANY]
			 	[-property                    ANY]
			 	-mode                         ANY
			 	[-direct_server_return_enable ANY]
			 	[-ip_address                  ANY]
			 	[-server_telnet_handle        ANY]
			 	[-type                        ANY]
			 	[-client_iterations           ANY]
			 	[-client_telnet_handle        ANY]
			 	[-client_traffic_handle       ANY]
			 	[-objective_type              ANY]
			 	[-objective_value             ANY]
			 	[-client_offline_time         ANY]
			 	[-port_map_policy             ANY]
			 	[-ramp_down_time              ANY]
			 	[-ramp_up_type                ANY]
			 	[-ramp_up_value               ANY]
			 	[-client_standby_time         ANY]
			 	[-client_sustain_time         ANY]
			 	[-client_total_time           ANY]
			 	[-server_traffic_handle       ANY]
			 	[-match_client_totaltime      ANY]
			 	[-server_iterations           ANY]
			 	[-server_offline_time         ANY]
			 	[-server_standby_time         ANY]
			 	[-server_sustain_time         ANY]
		
		Arguments:
			 	-handle
			 	-target
			    	-property
			        	-mode
			            	-direct_server_return_enable
			                	-ip_address
			                    	-server_telnet_handle
			                        	-type
			                            	-client_iterations
			                                	-client_telnet_handle
			                                    	-client_traffic_handle
			                                        	-objective_type
			                                            	-objective_value
			                                                	-client_offline_time
			                                                    	-port_map_policy
			                                                        	-ramp_down_time
			                                                            	-ramp_up_type
			                                                                	-ramp_up_value
			                                                                    	-client_standby_time
			                                                                        	-client_sustain_time
			                                                                            	-client_total_time
			                                                                                	-server_traffic_handle
			                                                                                    	-match_client_totaltime
			                                                                                        	-server_iterations
			                                                                                            	-server_offline_time
			                                                                                                	-server_standby_time
			                                                                                                    	-server_sustain_time
		                                                                                                   
		                                                                                                   Return Values:
		                                                                                                       $::SUCCESS | $::FAILURE
			                                                                                                        key:status   value:$::SUCCESS | $::FAILURE
		                                                                                                       When status is $::FAILURE, contains more information
			                                                                                                        key:log      value:When status is $::FAILURE, contains more information
		                                                                                                       the handles of a TELNET traffic configuration,
			                                                                                                        key:handles  value:the handles of a TELNET traffic configuration,
		                                                                                                   
		                                                                                                   Examples:
		                                                                                                       See files starting with TELNET_ in the Samples subdirectory. Also see the TELNET section in Appendix A, "Example APIs."
		                                                                                                   
		                                                                                                   Sample Input:
		                                                                                                   
		                                                                                                   Sample Output:
		                                                                                                   
		                                                                                                   Notes:
		                                                                                                       Coded versus functional specification.
		                                                                                                   
		                                                                                                   See Also:
		                                                                                                   
		"""
		return self._run_keyword("emulation_telnet_control_config", kwargs)

	def emulation_telnet_stats(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_telnet_stats
			 	[-handle           ANY]
			 	-mode              ANY
			 	[-aggregation_type ANY]
			 	[-stat_name        ANY]
			 	[-stat_type        ANY]
			 	[-filter_type      ANY]
		
		Arguments:
			 	-handle
			 	-mode
			    	-aggregation_type
			        	-stat_name
			            	-stat_type
			                	-filter_type
		               
		               Return Values:
		                   $::SUCCESS | $::FAILURE
			                    key:status   value:$::SUCCESS | $::FAILURE
		                   When status is $::FAILURE, contains more information
			                    key:log      value:When status is $::FAILURE, contains more information
		                   the handles of a TELNET stats configuration.
			                    key:handles  value:the handles of a TELNET stats configuration.
		               
		               Examples:
		                   See files starting with TELNET_ in the Samples subdirectory. Also see the TELNET section in Appendix A, "Example APIs."
		               
		               Sample Input:
		               
		               Sample Output:
		               
		               Notes:
		                   Coded versus functional specification.
		               
		               See Also:
		               
		"""
		return self._run_keyword("emulation_telnet_stats", kwargs)

	def emulation_telnet_traffic_config(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_telnet_traffic_config
			 	[-handle                 ANY]
			 	[-target                 ANY]
			 	-property                ANY
			 	-mode                    ANY
			 	[-default_command_prompt ANY]
			 	[-options_enable         ANY]
			 	[-expect_timeout         ANY]
			 	[-esm_enable             ANY]
			 	[-esm                    ANY]
			 	[-command                ANY]
			 	[-expect                 ANY]
			 	[-send                   ANY]
			 	[-server_close_command   ANY]
			 	[-server_command_prompt  ANY]
			 	[-echo_enable            ANY]
			 	[-linemode_enable        ANY]
			 	[-port                   ANY]
		
		Arguments:
			 	-handle
			 	-target
			    	-property
			        	-mode
			            	-default_command_prompt
			                	-options_enable
			                    	-expect_timeout
			                        	-esm_enable
			                            	-esm
			                                	-command
			                                    	-expect
			                                        	-send
			                                            	-server_close_command
			                                                	-server_command_prompt
			                                                    	-echo_enable
			                                                        	-linemode_enable
			                                                            	-port
		                                                           
		                                                           Return Values:
		                                                               $::SUCCESS | $::FAILURE
			                                                                key:status   value:$::SUCCESS | $::FAILURE
		                                                               When status is $::FAILURE, contains more information
			                                                                key:log      value:When status is $::FAILURE, contains more information
		                                                               the handles of a TELNET traffic configuration, list of traffic, agent.
			                                                                key:handles  value:the handles of a TELNET traffic configuration, list of traffic, agent.
		                                                           
		                                                           Examples:
		                                                               See files starting with TELNET_ in the Samples subdirectory. Also see the TELNET example in Appendix A, "Example APIs."
		                                                           
		                                                           Sample Input:
		                                                           
		                                                           Sample Output:
		                                                           
		                                                           Notes:
		                                                               Coded versus functional specification.
		                                                           
		                                                           See Also:
		                                                           
		"""
		return self._run_keyword("emulation_telnet_traffic_config", kwargs)

	def emulation_twamp_config(self, **kwargs):
		""" Configures TWAMP emulation for the specified test port or handle.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_twamp_config
			 	[-error_estimate_multiplier ANY]
			 	[-error_estimate_scale      ANY]
			 	[-global_max_outstanding    ANY]
			 	[-global_setup_rate         ANY]
			 	[-global_teardown_rate      ANY]
			 	[-handle                    ANY]
			 	[-mode                      ANY]
			 	[-port_max_outstanding      ANY]
			 	[-port_override_globals     ANY]
			 	[-port_setup_rate           ANY]
			 	[-port_teardown_rate        ANY]
		
		Arguments:
			 	-error_estimate_multiplier
			 		Error estimate (scale + multiplier) as defined by RFC 4656, section 4.1.2, page 29+
			 	-error_estimate_scale
			 		Error estimate (scale + multiplier) as defined by RFC 4656, section 4.1.2, page 29+
			 	-global_max_outstanding
			 		Maximum outstanding sessions.
			 	-global_setup_rate
			 		Initiation rate.
			 	-global_teardown_rate
			 		Teardown rate.
			 	-handle
			 		For -mode create, parameter -handle specifies the IP endpoint where the TWAMP extension is to be configured. For -mode modify/enable/disable/remove, this is the TWAMP range handle to be modified/enabled/disabled/removed.
			 	-mode
			 		Action to perform.
			 	-port_max_outstanding
			 		Maximum outstanding sessions for this port.
			 	-port_override_globals
			 		If selected, all the rate settings defined at the global level will be overridden by the rate settings defined on this port.
			 	-port_setup_rate
			 		Initiation rate for this port.
			 	-port_teardown_rate
			 		Teardown rate for this port.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE 
		Error message if command returns {status 0}
			 key:log     value:Error message if command returns {status 0} 
		Port handle on which TWAMP emulation was configured
			 key:handle  value:Port handle on which TWAMP emulation was configured
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_twamp_config", kwargs)

	def emulation_twamp_control(self, **kwargs):
		""" Controls TWAMP sessions.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_twamp_control
			 	[-handle ANY]
		
		Arguments:
			 	-handle
			 		For -mode create, parameter -handle specifies the IP endpoint where the TWAMP extension is to be manipulated.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE 
		When status is failure, contains more information
			 key:log     value:When status is failure, contains more information
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_twamp_control", kwargs)

	def emulation_twamp_control_range_config(self, **kwargs):
		""" Configure a TWAMP control range on the specified IP endpoint range.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_twamp_control_range_config
			 	[-control_mode               ANY]
			 	[-count                      ANY]
			 	[-handle                     ANY]
			 	[-key_id                     ANY]
			 	[-mode                       ANY]
			 	[-server_ip                  ANY]
			 	[-server_ip_intra_range_step ANY]
			 	[-server_port                ANY]
		
		Arguments:
			 	-control_mode
			 		Unauthenticated (for phase1). Read-only field in GUI.
			 	-count
			 		Number of control sessions.
			 	-handle
			 		For -mode create, parameter -handle specifies the IP endpoint range (previously configured with interface_config) where the TWAMP control range is to be configured. For -mode modify/enable/disable/remove, this is the TWAMP control range handle to be modified/enabled/disabled/removed.
			 	-key_id
			 		The session key.
			 	-mode
			 		Action to perform.
			 	-server_ip
			 		IP from which the Server accepts a Control-Session
			 	-server_ip_intra_range_step
			 		The IP step for the server address within the current range.
			 	-server_port
			 		Port on which the Server listens for Control-Sessions
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE 
		When status is failure, contains more info
			 key:log     value:When status is failure, contains more info 
		Handle of the twamp control range that was configured or modified
			 key:handle  value:Handle of the twamp control range that was configured or modified
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_twamp_control_range_config", kwargs)

	def emulation_twamp_info(self, **kwargs):
		""" Provides TWAMP statistics.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_twamp_info
			 	[-action ANY]
			 	[-handle ANY]
		
		Arguments:
			 	-action
			 		clear - reset the statistics for the specified port.
			 	-handle
			 		Allows the user to optionally select the groups to which the specified action is to be applied. If this parameter is not specified, then the specified action is applied to all groups configured on the port specified by the -port_handle command.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE 
		When status is failure, contains more information
			 key:log     value:When status is failure, contains more information
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_twamp_info", kwargs)

	def emulation_twamp_server_range_config(self, **kwargs):
		""" Create a new TWAMP server range and associate it with the corresponding TWAMP test range using the -handle parameter.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_twamp_server_range_config
			 	[-control_port                  ANY]
			 	[-count                         ANY]
			 	[-enable_access_control         ANY]
			 	[-handle                        ANY]
			 	[-iteration_count               ANY]
			 	[-key_id                        ANY]
			 	[-mode                          ANY]
			 	[-permitted_ip                  ANY]
			 	[-permitted_ip_intra_range_step ANY]
			 	[-permitted_pkt_size            ANY]
			 	[-permitted_sender_port         ANY]
			 	[-permitted_timeout             ANY]
			 	[-reflector_port                ANY]
			 	[-server_mode                   ANY]
		
		Arguments:
			 	-control_port
			 		Port on which the Server listens for Control-Sessions.
			 	-count
			 		Number of server ranges.
			 	-enable_access_control
			 		Enables or disables access control for this server range.
			 	-handle
			 		For -mode create, parameter -handle specifies the TWAMP control range to which the TWAMP test range is related. For -mode modify/enable/disable/remove, this is the TWAMP test range handle to be modified/enabled/disabled/removed.
			 	-iteration_count
			 		The number of iterations for this range.
			 	-key_id
			 		The key used for this session.
			 	-mode
			 		Action to perform.
			 	-permitted_ip
			 		The permitted IP address used by the server.
			 	-permitted_ip_intra_range_step
			 		The IP step used by the permitted IP address for this range.
			 	-permitted_pkt_size
			 		The permitted packet size used by the server.
			 	-permitted_sender_port
			 		The permitted source port of the stream initiated by Session-Sender.
			 	-permitted_timeout
			 		The permitted timeout for receiving packets on Session-Reflector after Stop-Sessions is received.
			 	-reflector_port
			 		Port on which the reflector receives the packets from the stream initiated by Session-Sender.
			 	-server_mode
			 		Unauthenticated (for phase1). Read-only field in GUI. Tool tip should indicate that current version does not support changing it. This will hopefully forestall some questions by different users at our initial customer.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE 
		When status is failure, contains more info
			 key:log     value:When status is failure, contains more info 
		Handle of the twamp server range that was configured or modified
			 key:handle  value:Handle of the twamp server range that was configured or modified
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_twamp_server_range_config", kwargs)

	def emulation_twamp_test_range_config(self, **kwargs):
		""" Create a new TWAMP test range on the IP endpoint range specified with -handle and create an association with the corresponding TWAMP control range using the -control_range_handle parameter.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: emulation_twamp_test_range_config
			 	[-control_range_handle        ANY]
			 	[-handle                      ANY]
			 	[-mode                        ANY]
			 	[-num_pkts                    ANY]
			 	[-padding_with_zero           ANY]
			 	[-pkt_length                  ANY]
			 	[-pps                         ANY]
			 	[-session_reflector_port      ANY]
			 	[-session_reflector_port_step ANY]
			 	[-session_sender_port         ANY]
			 	[-session_sender_port_step    ANY]
			 	[-test_sessions_count         ANY]
			 	[-timeout                     ANY]
		
		Arguments:
			 	-control_range_handle
			 		For -mode create or modify, parameter -control_range_handle handle specifies the TWAMP control range to which the TWAMP test range is related.
			 	-handle
			 		For -mode create, parameter -handle specifies the IP endpoint range (previously configured with interface_config) where the TWAMP test range is to be configured. For -mode modify/enable/disable/remove, this is the TWAMP test range handle to be modified/enabled/disabled/removed.
			 	-mode
			 		Action to perform.
			 	-num_pkts
			 		Number of packets to be sent by the Session-Sender
			 	-padding_with_zero
			 		Per RFC465, data in the packets is random, unless it is configured to be zero.
			 	-pkt_length
			 		Packet length including padding length as defined by the RFC4656.
			 	-pps
			 		Rate at which packets will be sent
			 	-session_reflector_port
			 		Port on which the reflector receives the packets from the stream initiated by Session-Sender
			 	-session_reflector_port_step
			 		The port step used by the reflector port within this range.
			 	-session_sender_port
			 		Source Port of the stream initiated by Session-Sender
			 	-session_sender_port_step
			 		The port step used by the session sender port.
			 	-test_sessions_count
			 		Number of test sessions.
			 	-timeout
			 		Timeout for receiving packets on Session-Reflector after Stop-Sessions is received.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE 
		When status is failure, contains more info
			 key:log     value:When status is failure, contains more info 
		Handle of the twamp test range that was configured or modified
			 key:handle  value:Handle of the twamp test range that was configured or modified
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_twamp_test_range_config", kwargs)

	def emulation_vxlan_config(self, **kwargs):
		""" Configures VXLAN emulation for the specified test port or handle.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_vxlan_config
			 	[-mode                        CHOICES create modify delete
			                               DEFAULT create]
			 	-handle                       ANY]
			x	[-create_ig                   CHOICES 0 1
			x                              DEFAULT 0]
			x	[-session_type                CHOICES vxlan vxlanv6
			x                              DEFAULT vxlan]
			x	[-protocol_name               ALPHA]
			x	[-mac_address_init            MAC]
			x	[-mac_address_step            MAC
			x                              DEFAULT 0000.0000.0001]
			x	[-mac_mtu                     RANGE 500-9216
			x                              DEFAULT 1500]
			 	[-ip_num_sessions             RANGE 1-16000]
			x	[-sessions_per_vxlan          RANGE 1-1600
			x                              DEFAULT 1]
			 	[-vlan_id                     RANGE 0-4095
			                               DEFAULT 4094]
			 	[-vlan_id_step                RANGE 0-4095]
			x	[-vlan_user_priority          RANGE 0-7
			x                              DEFAULT 0]
			 	[-intf_ip_addr                IPV4
			                               DEFAULT 100.1.0.2]
			 	[-intf_ip_addr_step           IPV4
			                               DEFAULT 0.0.0.0]
			x	[-intf_ip_prefix_length       RANGE 1-32
			x                              DEFAULT 24]
			x	[-vni                         ANY]
			x	[-ipv4_multicast              ANY]
			x	[-ipv6_multicast              ANY]
			x	[-enable_static_info          CHOICES 0 1]
			x	[-static_info_count           NUMERIC]
			x	[-remote_vtep_ipv4            ANY
			x                              DEFAULT 0.0.0.0]
			x	[-remote_vtep_unicast_ipv6    ANY]
			x	[-suppress_arp                CHOICES 0 1]
			x	[-enable_manual_remote_vm_mac ANY]
			x	[-remote_vm_static_mac        ANY
			x                              DEFAULT 00:00:00:00:00:00]
			x	[-remote_vm_static_ipv4       ANY
			x                              DEFAULT 0.0.0.0]
			x	[-remote_info_active          CHOICES 0 1]
			x	[-ip_to_vxlan_multiplier      NUMERIC]
			x	[-start_rate_enabled          CHOICES 0 1]
			x	[-start_rate                  NUMERIC]
			x	[-start_rate_interval         NUMERIC]
			x	[-start_max_outstanding       NUMERIC]
			x	[-start_rate_scale_mode       CHOICES device_group port]
			x	[-stop_rate_enabled           CHOICES 0 1]
			x	[-stop_rate                   NUMERIC]
			x	[-stop_rate_interval          NUMERIC]
			x	[-stop_max_outstanding        NUMERIC]
			x	[-stop_rate_scale_mode        CHOICES device_group port]
			x	[-udp_dest                    NUMERIC]
			x	[-igmp_mode                   ANY]
			x	[-outer_ip_dest_mode          ANY]
			 	[-gateway                     IP
			                               DEFAULT 100.1.0.1]
			 	[-gateway_step                IP
			                               DEFAULT 0.0.0.0]
			x	[-ig_vlan_id                  RANGE 0-4095
			x                              DEFAULT 4094]
			x	[-ig_vlan_id_step             RANGE 0-4095]
			x	[-ig_vlan_user_priority       RANGE 0-7
			x                              DEFAULT 0]
			x	[-ig_intf_ip_addr             IPV4
			x                              DEFAULT 102.1.0.2]
			x	[-ig_intf_ip_prefix_length    RANGE 1-32
			x                              DEFAULT 24]
			x	[-ig_intf_ip_addr_step        IPV4
			x                              DEFAULT 0.0.0.0]
			x	[-ig_gateway                  IP
			x                              DEFAULT 102.1.0.1]
			x	[-ig_gateway_step             IP
			x                              DEFAULT 0.0.0.0]
			x	[-ig_mac_address_init         MAC]
			x	[-ig_mac_address_step         MAC
			x                              DEFAULT 0000.0000.0001]
			x	[-ig_mac_mtu                  RANGE 500-9216
			x                              DEFAULT 1500]
			x	[-enable_resolve_gateway      CHOICES 0 1
			x                              DEFAULT 1]
			x	[-manual_gateway_mac          MAC
			x                              DEFAULT 0010.0000.0001]
			x	[-manual_gateway_mac_step     MAC
			x                              DEFAULT 0000.0000.0000]
			x	[-ig_enable_resolve_gateway   CHOICES 0 1
			x                              DEFAULT 1]
			x	[-ig_manual_gateway_mac       MAC]
			x	[-ig_manual_gateway_mac_step  MAC
			x                              DEFAULT 0000.0000.0000]
			x	[-inner_frame_minimum_size    NUMERIC]
			x	[-running_mode                CHOICES none
			x                              CHOICES ovsdbControllerBfdStack
			x                              CHOICES ovsdbStack]
			x	[-ovsdb_connector_multiplier  NUMERIC]
			x	[-external_learning           CHOICES 0 1]
			x	[-intf_ipv6_addr              IPV6]
			x	[-intf_ipv6_addr_step         IPV6]
			x	[-ipv6_gateway_ip             IPV6]
			x	[-ipv6_gateway_ip_step        IPV6]
			x	[-intf_ipv6_prefix_length     RANGE 1-128
			x                              DEFAULT 64]
		
		Arguments:
			 	-mode
			 		Action to take on the port specified the handle argument.
			 		Valid choices are:
			    		create - Adds a new VXLAN configuration on the port.
			    		modify - Modifies an existing VXLAN configuration (specified by -handle).
			    		delete - Remove an existing VXLAN configuration (specified by -handle).
			 	-handle
			 		Specifies the port and group upon which emulation is configured.If
			 		the -mode is "modify", -handle specifies the group upon which
			 		emulation is configured, otherwise it specifies the session upon
			 		which emulation is configured
			x	-create_ig
			x		If enabled creates behind the VXLAN device group a chained device group with IPv4 and Ethernet stacks emulating the connected VMs. If not enabled only the VXLAN device group will be created. Valid options:
			x		0 - Disabled
			x		1 - Enabled
			x		This option is valid only when -handle is a port handle.
			x	-session_type
			x		The VXLAN version to be emulated. CHOICES: vxlan vxlanv6.
			x		Valid choices are:
			x   		vxlan -
			x   		vxlanv6 -
			x	-protocol_name
			x		This is the name of the protocol stack as it appears in the GUI.
			x	-mac_address_init
			x		The MAC address for the interface to be created.
			x	-mac_address_step
			x		The incrementing step for the MAC address of the interface to be
			x		created.
			x	-mac_mtu
			x		The maximum transmission unit for the interfaces created with this range.
			 	-ip_num_sessions
			 		Indicates the number of IP address clients emulated.
			x	-sessions_per_vxlan
			x		Indicates the multiplier per VXLAN entity for behind VM clients emulated.
			 	-vlan_id
			 		The first VLAN ID to be used for the outer VLAN tag.
			 	-vlan_id_step
			 		The value to be added to the outer VLAN ID for each new assignment.
			x	-vlan_user_priority
			x		The 802.1Q priority for the outer VLAN.
			 	-intf_ip_addr
			 		The IP address of the simulated VTEP. If -ip_num_sessions is > 1, this IP address will increment by value specified in -intf_ip_addr_step.
			 	-intf_ip_addr_step
			 		This value will be used for incrementing the IP address of
			 		simulated VTEP if -count is > 1.
			x	-intf_ip_prefix_length
			x		Defines the mask of the IP address used for the Ixia (-intf_ip_addr)
			x		and the DUT interface.
			x	-vni
			x		VXLAN Network Identifier.
			x	-ipv4_multicast
			x		IPv4 Multicast Address.
			x	-ipv6_multicast
			x		IPv6 Multicast Address.
			x	-enable_static_info
			x		Enable Unicast Info.
			x	-static_info_count
			x		Unicast Info Count.
			x	-remote_vtep_ipv4
			x		Remote VTEP Ipv4.
			x	-remote_vtep_unicast_ipv6
			x		Remote VTEP Unicast IPv6.
			x	-suppress_arp
			x		Suppress Arp for each Remote VM defined.
			x	-enable_manual_remote_vm_mac
			x		Statically configure the Remote Inner Mac address to Outer Vtep IPv6 mapping, used for traffic.
			x	-remote_vm_static_mac
			x		Remote VM MAC.
			x	-remote_vm_static_ipv4
			x		Remote VM Ipv4.
			x	-remote_info_active
			x		Activates the Unicast Info for each Remote VM.
			x	-ip_to_vxlan_multiplier
			x		Configures the custom multiplier between stack elements (IPv4 and VXLAN stacks)
			x	-start_rate_enabled
			x		Number of times an action is triggered per time interval
			x		This option configures a global protocol parameter and is available only with /globals handle.
			x	-start_rate
			x		Number of times an action is triggered per time interval.
			x		This option configures a global protocol parameter and is available only with /globals handle.
			x	-start_rate_interval
			x		Time interval used to calculate the rate for triggering an action.
			x		This option configures a global protocol parameter and is available only with /globals handle.
			x	-start_max_outstanding
			x		The number of triggered instances of an action that are still awaiting a response of completion.
			x		This option configures a global protocol parameter and is available only with /globals handle.
			x	-start_rate_scale_mode
			x		Indicates whether the control is specified per port or per device group.
			x		This option configures a global protocol parameter and is available only with /globals handle.
			x		Valid choices are:
			x   		device_group - The values regarding stop rate are mapped per device group
			x   		port - The values regarding stop rate are mapped per port
			x	-stop_rate_enabled
			x		Number of times an action is triggered per time interval.
			x		This option configures a global protocol parameter and is available only with /globals handle.
			x	-stop_rate
			x		Number of times an action is triggered per time interval.
			x		This option configures a global protocol parameter and is available only with /globals handle.
			x	-stop_rate_interval
			x		Time interval used to calculate the rate for triggering an action.
			x		This option configures a global protocol parameter and is available only with /globals handle.
			x	-stop_max_outstanding
			x		The number of triggered instances of an action that are still awaiting a response of completion.
			x		This option configures a global protocol parameter and is available only with /globals handle.
			x	-stop_rate_scale_mode
			x		Indicates whether the control is specified per port or per device group.
			x		This option configures a global protocol parameter and is available only with /globals handle.
			x		Valid choices are:
			x   		device_group - The values regarding stop rate are mapped per device group
			x   		port - The values regarding stop rate are mapped per port
			x	-udp_dest
			x		UDP Destination Port.
			x		This option configures a global protocol parameter and is available only with /globals handle.
			x	-igmp_mode
			x		Indicates the IGMP version used by VXLAN interfaces.
			x		This option configures a global protocol parameter and is available only with /globals handle.
			x	-outer_ip_dest_mode
			x		Indicates what is the outer destination IP in the generated fpga traffic.
			x		This option configures a global protocol parameter and is available only with /globals handle.
			 	-gateway
			 		The IP address of the Gateway for the Interface Interface.
			 	-gateway_step
			 		This parameter is not valid on mode modify when IxTclProtocol is used.
			 		What step will be use for incrementing the -gateway option.
			x	-ig_vlan_id
			x		The first VLAN ID to be used for the outer VLAN tag.
			x		Argument configures the Ethernet stack of the chained device group/VMs.
			x	-ig_vlan_id_step
			x		The value to be added to the outer VLAN ID for each new assignment. Argument configures the Ethernet stack of the chained device group/VMs.
			x	-ig_vlan_user_priority
			x		The 802.1Q priority for the outer VLAN.Argument configures the Ethernet stack of the chained device group/VMs.
			x	-ig_intf_ip_addr
			x		List of IP addresses that configure each of the traffic generation
			x		tool interfaces.If -sessions_per_vxlan is > 1,
			x		this IP address will increment by value specified
			x		in -ig_intf_ip_addr_step. Argument configures the IPv4 stack of the chained device group/VMs.
			x	-ig_intf_ip_prefix_length
			x		Defines the mask of the IP address used for the Ixia (-intf_ip_addr)
			x		and the DUT interface.The range of the value is 1-32. Argument configures the IPv4 stack of the chained device group/VMs.
			x	-ig_intf_ip_addr_step
			x		This value will be used for incrementing the IP address if -count is > 1.
			x		Argument configures the IPv4 stack of the chained device group/VMs.
			x	-ig_gateway
			x		The IP address of the Gateway.
			x		Argument configures the IPv4 stack of the chained device group/VMs.
			x	-ig_gateway_step
			x		What step will be use for incrementing the -ig_gateway option.
			x		Argument configures the IPv4 stack of the chained device group/VMs.
			x	-ig_mac_address_init
			x		The MAC address for the interface to be created.
			x		Argument configures the Ethernet stack of the chained device group/VMs.
			x	-ig_mac_address_step
			x		The incrementing step for the MAC address of the interface to be
			x		created.
			x		Argument configures the Ethernet stack of the chained device group/VMs.
			x	-ig_mac_mtu
			x		The maximum transmission unit for the interfaces created with this range.
			x		Argument configures the Ethernet stack of the chained device group/VMs.
			x	-enable_resolve_gateway
			x		Autoresolve gateway MAC addresses.
			x	-manual_gateway_mac
			x		The manual gateway MAC addresses.
			x		This option has no effect unless enable_resolve_gateway is set to 0.
			x	-manual_gateway_mac_step
			x		The step of the manual gateway MAC addresses.
			x		This option has no effect unless enable_resolve_gateway is set to 0.
			x	-ig_enable_resolve_gateway
			x		Autoresolve gateway MAC addresses.
			x		Argument configures the IPv4 stack of the chained device group/VMs.
			x	-ig_manual_gateway_mac
			x		The manual gateway MAC addresses.
			x		This option has no effect unless enable_resolve_gateway is set to 0.
			x		Argument configures the IPv4 stack of the chained device group/VMs.
			x	-ig_manual_gateway_mac_step
			x		The step of the manual gateway MAC addresses.
			x		This option has no effect unless enable_resolve_gateway is set to 0.
			x		Argument configures the IPv4 stack of the chained device group/VMs.
			x	-inner_frame_minimum_size
			x		Pad inner frame with 0 in order to have inner frame of minimum specified size.
			x	-running_mode
			x		There will be different behaviours based on role (normal=0, ovsdb controller stack=1, bfd stack=2.
			x		Valid choices are:
			x   		none -
			x   		ovsdbControllerBfdStack -
			x   		ovsdbStack -
			x	-ovsdb_connector_multiplier
			x		Ovsdb to Vxlan multiplier, when part of OVSDB Server stack.
			x	-external_learning
			x		If true, VXLAN will use information received from another protocol which will handle the learning mechanism.
			x	-intf_ipv6_addr
			x		IPv6 addresses of the layer.
			x	-intf_ipv6_addr_step
			x		IPv6 addresses step of the layer.
			x	-ipv6_gateway_ip
			x		Gateway's IPv6 address of the layer.
			x	-ipv6_gateway_ip_step
			x		Gateways IPv6 address step of the layer.
			x	-intf_ipv6_prefix_length
			x		Defines the mask of the IP address used for the Ixia (-intf_ipv6_addr)
			x		and the DUT interface. This parameter is not valid on mode modify when
			x		IxTclProtocol is used. RANGE 1-128.
		
		Return Values:
		A list containing the vxlan static info protocol stack handles that were added by the command (if any).
			xkey:vxlan_static_info    value:A list containing the vxlan static info protocol stack handles that were added by the command (if any).
		A list containing the vxlanv6 protocol stack handles that were added by the command (if any).
			xkey:vxlanv6_handle       value:A list containing the vxlanv6 protocol stack handles that were added by the command (if any).
		A list containing the vxlanv6 static info protocol stack handles that were added by the command (if any).
			xkey:vxlanv6_static_info  value:A list containing the vxlanv6 static info protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE
			 key:status               value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log                  value:Error message if command returns {status 0}
		Device handles of the VXLAN devices configured Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:handle               value:Device handles of the VXLAN devices configured Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		Stack handle of the VXLAN stack configured
			xkey:vxlan_handle         value:Stack handle of the VXLAN stack configured
		Handle for the configured VXLAN device group
			xkey:dg_handle            value:Handle for the configured VXLAN device group
		Ethernet handle for the VXLAN device group Ethernet stack
			xkey:ethernet_handle      value:Ethernet handle for the VXLAN device group Ethernet stack
		IPv4 handle for the VXLAN device group IPv4 stack
			xkey:ipv4_handle          value:IPv4 handle for the VXLAN device group IPv4 stack
		IPv6 handle for the VXLAN6 device group IPv6 stack.
			xkey:ipv6_handle          value:IPv6 handle for the VXLAN6 device group IPv6 stack.
		Ethernet handle for the chained device group Ethernet stack
			xkey:ig_ethernet_handle   value:Ethernet handle for the chained device group Ethernet stack
		IPv4 handle for the chained device group IPv4 stack
			xkey:ig_ipv4_handle       value:IPv4 handle for the chained device group IPv4 stack
		Handle for the chained device group
			xkey:ig_dg_handle         value:Handle for the chained device group
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		When -handle is provided with the /globals value the arguments that configure global protocol
		setting accept both multivalue handles and simple values.
		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
		that configure global settings will only accept simple values. In this situation, these arguments will
		configure only the settings of the parent device group or the ports associated with the parent topology.
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		
		See Also:
		
		"""
		return self._run_keyword("emulation_vxlan_config", kwargs)

	def emulation_vxlan_control(self, **kwargs):
		""" Controls VXLAN sessions.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_vxlan_control
			 	[-handle ANY]
			 	[-action CHOICES start
			          CHOICES stop
			          CHOICES abort
			          CHOICES abort_async
			          CHOICES restart_down
			          DEFAULT start]
		
		Arguments:
			 	-handle
			 		Allows the user to optionally select the groups to which the
			 		specified action is to be applied.
			 		If this parameter is not specified, then the specified action is
			 		applied to all groups configured on the port specified by
			 		the -port_handle command. The handle is obtained from the keyed list returned
			 		in the call to emulation_vxlan_config proc.
			 		The port handle parameter must have been initialized and vxlan group
			 		emulation must have been configured prior to calling this function.
			 	-action
			 		Action to take on the specified handle.
			 		The parameters specified in the emulation_vxlan_config proc
			 		are used to control the bind/renew/release rates.
			 		Valid choices are:
			    		start - Start the protocol for the specified handle.
			    		stop - Stop the protocol for the specified handle
			    		abort - Aborts the VXLAN sessions for a VXLAN emulation. 
The command returns when the operation is completed. This option is valid only using IxTclNetwork.
			    		abort_async - Aborts the VXLAN sessions for a VXLAN emulation. The command returns immediately and the operation is executed in the backgronud. 
This option is valid only using IxTclNetwork.
			    		restart_down - Restart the sessions that are down.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information
			 key:log     value:When status is failure, contains more information
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_vxlan_control", kwargs)

	def emulation_vxlan_stats(self, **kwargs):
		""" Controls VXLAN subscriber group activity.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: emulation_vxlan_stats
			 	[-port_handle       ANY]
			 	[-handle            ANY]
			 	-mode               CHOICES aggregate_stats
			                     CHOICES clear_stats
			                     CHOICES session
			                     CHOICES vni
			                     CHOICES learned_info]
			x	[-execution_timeout NUMERIC
			x                    DEFAULT 1800]
			x	[-session_type      CHOICES vxlan vxlanv6
			x                    DEFAULT vxlan]
		
		Arguments:
			 	-port_handle
			 		Specifies the port upon which emulation id configured.
			 		This parameter is returned from emulation_dhcp_config proc.
			 		Emulation must have been previously enabled on the specified port
			 		via a call to emulation_dhcp_group_config proc.
			 		When -version is ixnetwork, one of -port_handle or -handle parameters
			 		should be provided.
			 	-handle
			 		Allows the user to optionally select the groups to which the
			 		specified action is to be applied.
			 		If this parameter is not specified, then the specified action is
			 		applied to all groups configured on the port specified by
			 		the -port_handle command. The handle is obtained from the keyed list returned
			 		in the call to emulation_vxlan_group_config proc.
			 		The port handle parameter must have been initialized and vxlan group
			 		emulation must have been configured prior to calling this function.
			 		For IxTclNetwork the statistics will be aggregated at port level (the
			 		port on which this handle has been configured). The stats aggregate.<stat key>
			 		will represent the aggregated port stats for the first port if multiple
			 		handles are provided.
			 	-mode
			 		This is a mandatory argument. Used to select the task to perform.
			 		This parameter is supported using the following APIs: IxTclNetwork.Valid choices are: clear collect.
			    		aggregate_stats - retrieve stats aggregated per port/handle
			    		clear_stats - clear stats
			    		session - retrieves non-aggregated stats per handle
			    		vni - retrieves aggregated stats per vni per handle
			    		learned_info - retrieves learnedInfo
			x	-execution_timeout
			x		This is the timeout for the function.
			x		The setting is in seconds.
			x		Setting this setting to 60 it will mean that the command must complete in under 60 seconds.
			x		If the command will last more than 60 seconds the command will be terminated by force.
			x		This flag can be used to prevent dead locks occuring in IxNetwork.
			x	-session_type
			x		The VXLAN version to be emulated. CHOICES: vxlan vxlanv6.
			x		Valid choices are:
			x   		vxlan -
			x   		vxlanv6 -
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                    value:$::SUCCESS | $::FAILURE
		When status is failure, contains more information
			 key:log                                                       value:When status is failure, contains more information
		Port Name
			 key:<port_handle>.aggregate.port_name                         value:Port Name
		Bytes sent. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.bytes_tx                          value:Bytes sent. Supported with IxTclNetwork.
		Bytes received. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.bytes_rx                          value:Bytes received. Supported with IxTclNetwork.
		Packets sent. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.packets_tx                        value:Packets sent. Supported with IxTclNetwork.
		Packets received. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.packets_rx                        value:Packets received. Supported with IxTclNetwork.
		Number of up sessions. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.sessions_up                       value:Number of up sessions. Supported with IxTclNetwork.
		Number of down sessions. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.sessions_down                     value:Number of down sessions. Supported with IxTclNetwork.
		Number of not started sessions. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.sessions_not_started              value:Number of not started sessions. Supported with IxTclNetwork.
		Total number of sessions. Supported with IxTclNetwork.
			 key:<port_handle>.aggregate.sessions_total                    value:Total number of sessions. Supported with IxTclNetwork.
		Bytes sent. Supported with IxTclNetwork.
			 key:session.<session ID>.bytes_tx                             value:Bytes sent. Supported with IxTclNetwork.
		Bytes received. Supported with IxTclNetwork.
			 key:session.<session ID>.bytes_rx                             value:Bytes received. Supported with IxTclNetwork.
		Packets sent. Supported with IxTclNetwork.
			 key:session.<session ID>.packets_tx                           value:Packets sent. Supported with IxTclNetwork.
		Packets received. Supported with IxTclNetwork.
			 key:session.<session ID>.packets_rx                           value:Packets received. Supported with IxTclNetwork.
		Topology name. Supported with IxTclNetwork.
			 key:session.<session ID>.topology                             value:Topology name. Supported with IxTclNetwork.
		Device Group name. Supported with IxTclNetwork.
			 key:session.<session ID>.device_group                         value:Device Group name. Supported with IxTclNetwork.
		VXLAN stack name. Supported with IxTclNetwork.
			 key:session.<session ID>.protocol                             value:VXLAN stack name. Supported with IxTclNetwork.
		VXLAN device id. Supported with IxTclNetwork.
			 key:session.<session ID>.device_id                            value:VXLAN device id. Supported with IxTclNetwork.
		VXLAN Network Identifier. Supported with IxTclNetwork.
			 key:session.<session ID>.vni                                  value:VXLAN Network Identifier. Supported with IxTclNetwork.
		Session status. Supported with IxTclNetwork.
			 key:session.<session ID>.session_status                       value:Session status. Supported with IxTclNetwork.
		Bytes sent. Supported with IxTclNetwork.
			 key:vni.<VNI ID>.<session ID>.bytes_tx                        value:Bytes sent. Supported with IxTclNetwork.
		Bytes received. Supported with IxTclNetwork.
			 key:vni.<VNI ID>.<session ID>.bytes_rx                        value:Bytes received. Supported with IxTclNetwork.
		Packets sent. Supported with IxTclNetwork.
			 key:vni.<VNI ID>.<session ID>.packets_tx                      value:Packets sent. Supported with IxTclNetwork.
		Packets received. Supported with IxTclNetwork.
			 key:vni.<VNI ID>.<session ID>.packets_rx                      value:Packets received. Supported with IxTclNetwork.
		Topology name. Supported with IxTclNetwork.
			 key:vni.<VNI ID>.<session ID>.topology                        value:Topology name. Supported with IxTclNetwork.
		Device Group name. Supported with IxTclNetwork.
			 key:vni.<VNI ID>.<session ID>.device_group                    value:Device Group name. Supported with IxTclNetwork.
		VXLAN Stack name. Supported with IxTclNetwork.
			 key:vni.<VNI ID>.<session ID>.protocol                        value:VXLAN Stack name. Supported with IxTclNetwork.
		VXLAN Network Identifier. Supported with IxTclNetwork.
			 key:vni.<VNI ID>.<session ID>.vni                             value:VXLAN Network Identifier. Supported with IxTclNetwork.
		Remote VM id. Supported with IxTclNetwork.
			 key:learned_info.<VTEP ID>.ipv4_learnedinfo.deviceid          value:Remote VM id. Supported with IxTclNetwork.
		Remote VM MAC address. Supported with IxTclNetwork.
			 key:learned_info.<VTEP ID>.ipv4_learnedinfo.remote_vm_mac     value:Remote VM MAC address. Supported with IxTclNetwork.
		Remote VTEP IPv4 address. Supported with IxTclNetwork.
			 key:learned_info.<VTEP ID>.ipv4_learnedinfo.remote_vtep_ipv4  value:Remote VTEP IPv4 address. Supported with IxTclNetwork.
		Remote VM id. Supported with IxTclNetwork.
			 key:learned_info.<VTEP ID>.ipv6_learnedinfo.deviceid          value:Remote VM id. Supported with IxTclNetwork.
		Remote VM MAC address. Supported with IxTclNetwork.
			 key:learned_info.<VTEP ID>.ipv6_learnedinfo.remote_vm_mac     value:Remote VM MAC address. Supported with IxTclNetwork.
		Remote VTEP IPv6 address. Supported with IxTclNetwork.
			 key:learned_info.<VTEP ID>.ipv6_learnedinfo.remote_vtep_ipv6  value:Remote VTEP IPv6 address. Supported with IxTclNetwork.
		
		Examples:
		
		Sample Input:
		.
		
		Sample Output:
		.
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("emulation_vxlan_stats", kwargs)

	def esmc_config(self, **kwargs):
		""" Performs esmc configuration
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: esmc_config
			x	[-mode          ANY]
			x	[-parent_handle ANY]
			x	[-handle        ANY]
			x	[-style         ANY]
			x	[-enabled       ANY]
			x	[-flag_mode     ANY]
			x	[-name          ANY]
			x	[-ql            ANY]
			x	[-rate          ANY]
			x	[-wait_id       ANY]
		
		Arguments:
			x	-mode
			x		create - creates and configures a new object
			x		add - adds a child object to the one specified by the -handle param
			x		modify - modified attributes on the given object by the -handle param
			x		delete - this mode cannot be used.
			x		In order to delete ESMC ranges the ethernetrange_config command must be used
			x		with -mode delete on the parent handle of the ESMC range that has typepath:
			x		//vport/protocolStack/ethernetEndpoint/range/macRange
			x		Valid choices are:
			x   		create - creates and configures a new object
			x   		add - adds a child object to the one specified by the -handle param
			x   		modify - modified attributes on the given object by the -handle param
			x   		delete - deletes the object given by the -handle param
			x	-parent_handle
			x		The parent handle used for creating this object. Has the form: /vport/protocolStack/ethernetEndpoint/range/macRange
			x	-handle
			x		A handle returned via a ::<namespace>::esmc_config command. This is used for mode modify
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x	-enabled
			x		Disabled ranges won't be configured nor validated.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-flag_mode
			x		The operation of the SSM header Event flag.
			x		Valid choices are:
			x   		Auto - Auto
			x   		AlwaysOn - Always On
			x   		AlwaysOff - Always Off
			x	-name
			x		Name of range
			x	-ql
			x		The SSM clock quality level(QL) code.
			x		Valid choices are:
			x   		QL-STU - QL-STU/UNK
			x   		QL-PRS - QL-PRS
			x   		QL-PRC - QL-PRC
			x   		QL-INV3 - QL-INV3
			x   		QL-SSU-A/TNC - QL-SSU-A/TNC
			x   		QL-INV5 - QL-INV5
			x   		QL-INV6 - QL-INV6
			x   		QL-ST2 - QL-ST2
			x   		QL-SSU-B - QL-SSU-B
			x   		QL-INV9 - QL-INV9
			x   		QL-EEC2/ST3 - QL-EEC2/ST3
			x   		QL-EEC1/SEC - QL-EEC1/SEC
			x   		QL-SMC - QL-SMC
			x   		QL-ST3E - QL-ST3E
			x   		QL-PROV - QL-PROV
			x   		QL-DNU/DUS - QL-DNU/DUS
			x   		QL-RANDOM - QL-RANDOM
			x	-rate
			x		SSM message transmit rate.
			x	-wait_id
			x		This value is true if supplicant
			x		is waiting for RequestId from DUT part.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log      value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles  value:The returned handle(s) of the  config command.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("esmc_config", kwargs)

	def esmc_control(self, **kwargs):
		""" Perform control plane operations on an endpoint created by a ::<namespace>::esmc_config command
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: esmc_control
			x	[-handle ANY]
			x	[-action ANY]
		
		Arguments:
			x	-handle
			x		A handle returned via a ::<namespace>::esmc_config command. This is the object on which the action will take place.
			x	-action
			x		Action to be executed.
			x		Valid choices are:
			x   		abort - abort all sessions on the same port with the target endpoint designated by -handle. The control is returned when the operation is completed.
			x   		abort_async - abort all sessions on the same port with the target endpoint designated by -handle. The control is returned immediately. The operation is executed in the background.
			x   		start - start and/or negotiate session for the target endpoint designated by -handle.
			x   		connect - start and/or negotiate session for the target endpoint designated by -handle.
			x   		stop - stop and/or release session for the target endpoint designated by -handle.
			x   		disconnect - stop and/or release session for the target endpoint designated by -handle.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status         value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log            value:Error message if command returns {status 0}
		The result(s) of the  control action.
			 key:inner_results  value:The result(s) of the  control action.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("esmc_control", kwargs)

	def esmc_stats(self, **kwargs):
		""" Retrieve statistics plane on an endpoint created by a ::<namespace>::esmc_config command
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: esmc_stats
			x	[-port_handle ANY]
		
		Arguments:
			x	-port_handle
			x		The port handle for which the esmc stats need to be retrieved
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status           value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log              value:Error message if command returns {status 0}
		per-port aggregate stats for endpoints created via ::<namespace>::esmc_create
			 key:<port_handle>.*  value:per-port aggregate stats for endpoints created via ::<namespace>::esmc_create
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("esmc_stats", kwargs)

	def ethernetrange_config(self, **kwargs):
		""" Performs ethernetrange configuration
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: ethernetrange_config
			x	[-mode                            ANY]
			x	[-parent_handle                   ANY]
			x	[-handle                          ANY]
			x	[-style                           ANY]
			x	[-mac_range_count                 ANY]
			x	[-mac_range_enabled               ANY]
			x	[-mac_range_increment_by          ANY]
			x	[-mac_range_mac                   ANY]
			x	[-mac_range_mtu                   ANY]
			x	[-mac_range_name                  ANY]
			x	[-vlan_range_enabled              ANY]
			x	[-vlan_range_first_id             ANY]
			x	[-vlan_range_id_incr_mode         ANY]
			x	[-vlan_range_increment            ANY]
			x	[-vlan_range_increment_step       ANY]
			x	[-vlan_range_inner_enable         ANY]
			x	[-vlan_range_inner_first_id       ANY]
			x	[-vlan_range_inner_increment      ANY]
			x	[-vlan_range_inner_increment_step ANY]
			x	[-vlan_range_inner_priority       ANY]
			x	[-vlan_range_inner_tpid           ANY]
			x	[-vlan_range_inner_unique_count   ANY]
			x	[-vlan_range_name                 ANY]
			x	[-vlan_range_priority             ANY]
			x	[-vlan_range_tpid                 ANY]
			x	[-vlan_range_unique_count         ANY]
			x	[-vlan_range_vlan_id_info         ANY]
		
		Arguments:
			x	-mode
			x		The operation this command will execute
			x		Valid choices are:
			x   		create - creates and configures a new object
			x   		add - adds a child object to the one specified by the -handle param
			x   		modify - modified attributes on the given object by the -handle param
			x   		delete - deletes the object given by the -handle param
			x	-parent_handle
			x		The parent handle used for creating this object. Has the form: //vport
			x	-handle
			x		A handle returned via a ::<namespace>::ethernetrange_config command. This is used for mode modify
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x	-mac_range_count
			x		The total number of interfaces to be created for the range.
			x	-mac_range_enabled
			x		Disabled ranges won't be configured nor validated.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-mac_range_increment_by
			x		When a range of multiple MACs is created with this plugin, this value
			x		is the incrementor used to create the addresses in the range.
			x		This property is used in conjunction with 'MAC Address' as a base value.
			x		Incrementor used when the plugin creates a range of MACs.
			x	-mac_range_mac
			x		When a range of multiple MACs is created with this plugin, this value
			x		is the base value used to create the addresses in the range.
			x		This property is used in conjunction with 'Increment' as an incrementor.
			x		Base value used when the plugin creates a MAC address.
			x	-mac_range_mtu
			x		Maximum Transmission Unit.
			x		The largest packet that a given network medium can carry.
			x		Ethernet, for example, has a fixed MTU of 1500 bytes without and 9500 bytes with Jumbo frame support.
			x		ATM has a fixed MTU of 48 bytes and PPP has a negotiated MTU that is usually between 500 and 2000 bytes.
			x	-mac_range_name
			x		Name of range
			x	-vlan_range_enabled
			x		Disabled ranges won't be configured nor validated.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-vlan_range_first_id
			x		The first ID to be used for the first VLAN tag.
			x	-vlan_range_id_incr_mode
			x		Method used to increment VLAN IDs.
			x		May take the following values: 0 (First VLAN first), 1 (Last VLAN first), 2 (All).
			x		Valid choices are:
			x   		0 - Outer First
			x   		1 - Inner First
			x   		2 - All
			x	-vlan_range_increment
			x		Amount of increment per increment step for first VLAN. E.g. increment step = 10 and increment = 2 means increment VLAN ID by 2 for every 10 IPs
			x	-vlan_range_increment_step
			x		Frequency of first VLAN ID increment. E.g., value of 10 means increment VLAN ID once for every 10 IP addresses.
			x	-vlan_range_inner_enable
			x		Enable the inner VLAN.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-vlan_range_inner_first_id
			x		The first ID to be used for the inner VLAN tag.
			x	-vlan_range_inner_increment
			x		Amount of increment per increment step for Inner VLAN. E.g. increment step = 10 and increment = 2 means increment VLAN ID by 2 for every 10 IPs
			x	-vlan_range_inner_increment_step
			x		Frequency of inner VLAN ID increment. E.g., value of 10 means increment VLAN ID once for every 10 IP addresses.
			x	-vlan_range_inner_priority
			x		The 802.1Q priority to be used for the inner VLAN tag.
			x	-vlan_range_inner_tpid
			x		The TPID value in the inner VLAN Tag.
			x		Valid choices are:
			x   		0x8100 - 0x8100
			x   		0x88a8 - 0x88a8
			x   		0x9100 - 0x9100
			x   		0x9200 - 0x9200
			x   		0x9300 - 0x9300
			x	-vlan_range_inner_unique_count
			x		Number of unique inner VLAN IDs to use.
			x	-vlan_range_name
			x		Name of range
			x	-vlan_range_priority
			x		The 802.1Q priority to be used for the outer VLAN tag.
			x	-vlan_range_tpid
			x		The TPID value in the outer VLAN Tag.
			x		Valid choices are:
			x   		0x8100 - 0x8100
			x   		0x88a8 - 0x88a8
			x   		0x9100 - 0x9100
			x   		0x9200 - 0x9200
			x   		0x9300 - 0x9300
			x	-vlan_range_unique_count
			x		Number of unique first VLAN IDs to use.
			x	-vlan_range_vlan_id_info
			x		Contains extra VLANs
			x		Is a subelement of type: VlanIdInfo
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log      value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles  value:The returned handle(s) of the  config command.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("ethernetrange_config", kwargs)

	def fcoe_client_globals_config(self, **kwargs):
		""" Performs fcoe_client_globals configuration
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fcoe_client_globals_config
			x	[-mode                                  ANY]
			x	[-parent_handle                         ANY]
			x	[-handle                                ANY]
			x	[-style                                 ANY]
			x	[-accept_partial_config                 ANY]
			x	[-b2b_rx_size                           ANY]
			x	[-dcbx_timeout                          ANY]
			x	[-fip_advertisement_period              ANY]
			x	[-fip_fcf_mac_list_collection           ANY]
			x	[-fip_fcf_mac_list_collection_interval  ANY]
			x	[-fip_override_advertisement_period     ANY]
			x	[-fip_override_vnport_keep_alive_period ANY]
			x	[-fip_propose_mac_in_fpma               ANY]
			x	[-fip_reset_discovery                   ANY]
			x	[-fip_reset_num_retry                   ANY]
			x	[-fip_restart_on_session_down           ANY]
			x	[-fip_send_keep_alives                  ANY]
			x	[-fip_version                           ANY]
			x	[-fip_vlan_disc_with_name_id            ANY]
			x	[-fip_vnport_keep_alive_period          ANY]
			x	[-ignore_duplicate_mac_descriptors      ANY]
			x	[-max_fcoe_size                         ANY]
			x	[-max_packets_per_second                ANY]
			x	[-max_retries                           ANY]
			x	[-retry_interval                        ANY]
			x	[-setup_rate                            ANY]
			x	[-teardown_rate                         ANY]
		
		Arguments:
			x	-mode
			x		The operation this command will execute
			x		Valid choices are:
			x   		create - creates and configures a new object
			x   		add - adds a child object to the one specified by the -handle param
			x   		modify - modified attributes on the given object by the -handle param
			x   		delete - deletes the object given by the -handle param
			x	-parent_handle
			x		The parent handle used for creating this object. Has the form: //vport
			x	-handle
			x		A handle returned via a ::<namespace>::fcoe_client_globals_config command. This is used for mode modify
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x	-accept_partial_config
			x		This flag controls how the negotiation process reports success or failure.
			x		When is true the plugin reports success if at least one session is established.
			x		When is false the plugin reports success only if all sessions are established.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-b2b_rx_size
			x		The buffer-to-buffer receive data field size in bytes.
			x	-dcbx_timeout
			x		The number of seconds to wait for DCBX to negotiate.
			x	-fip_advertisement_period
			x		The interval in seconds between periodic Discovery Advertisements and ENode FIP Keep-Alive messages.
			x		The default value is 8. Valid values are in the range 1 to 90.
			x	-fip_fcf_mac_list_collection
			x		Allow Ixia emulated ENodes to collect FCF-MAC address info and show details at per-session stats.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fip_fcf_mac_list_collection_interval
			x		The amount of time in seconds given to the Ixia emulated ENodes to receive FIP Discovery Advertisements from different FCF-MACs.
			x	-fip_override_advertisement_period
			x		If enabled, the Discovery Advertisement period will be specified by the application.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fip_override_vnport_keep_alive_period
			x		If enabled, the VN_Port Keep-Alive period will be specified by the application.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fip_propose_mac_in_fpma
			x		Allow Ixia emulated ENodes to propose a non-zero valid MAC address in FPMA FLOGI request.
			x		If not enabled, Ixia encodes an all zero MAC address in FPMA FLOGI request.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fip_reset_discovery
			x		Allow FIP negotiation to be reinitialized after a specified number of retries has been attempted.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fip_reset_num_retry
			x		The number of normal retries to be attempted before resetting the state machine
			x		and continue retrying with alternate FIP VLAN Discovery and FIP Solicitation messages.
			x	-fip_restart_on_session_down
			x		If enabled, the port will restart FIP negotiation when the session goes down.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fip_send_keep_alives
			x		If enabled, the port will send ENode/VN_Port FIP Keep-Alive messages.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fip_version
			x		The FIP version to use. Auto mode will accept same version as the negotiating party.
			x		Valid choices are:
			x   		auto - Auto
			x   		0 - Version 0
			x   		1 - Version 1
			x	-fip_vlan_disc_with_name_id
			x		Include Name_Identifier Descriptor in FIP VLAN Request messages generated by Ixia emulated ENodes.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fip_vnport_keep_alive_period
			x		The interval in seconds between periodic VN_Port FIP Keep-Alive messages.
			x		The default value is 90. Valid values are in the range 1 to 3600.
			x	-ignore_duplicate_mac_descriptors
			x		Ignore duplicate MAC descriptors.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-max_fcoe_size
			x		The maximum FCoE frame size in bytes.
			x	-max_packets_per_second
			x		The maximum number of requests transmitted in each second.
			x	-max_retries
			x		The number of request retries for each negotiation stage in case of response timeout or error.
			x	-retry_interval
			x		The number of seconds to wait for a response before sending a new request.
			x	-setup_rate
			x		The number of interfaces scheduled to be configured in each second.
			x	-teardown_rate
			x		The number of interfaces scheduled to be deconfigured in each second.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log      value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles  value:The returned handle(s) of the  config command.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("fcoe_client_globals_config", kwargs)

	def fcoe_client_options_config(self, **kwargs):
		""" Performs fcoe_client_options configuration
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fcoe_client_options_config
			x	[-mode                   ANY]
			x	[-parent_handle          ANY]
			x	[-handle                 ANY]
			x	[-style                  ANY]
			x	[-associates             ANY]
			x	[-max_packets_per_second ANY]
			x	[-override_global_rate   ANY]
			x	[-setup_rate             ANY]
			x	[-teardown_rate          ANY]
		
		Arguments:
			x	-mode
			x		The operation this command will execute
			x		Valid choices are:
			x   		create - creates and configures a new object
			x   		add - adds a child object to the one specified by the -handle param
			x   		modify - modified attributes on the given object by the -handle param
			x   		delete - deletes the object given by the -handle param
			x	-parent_handle
			x		The parent handle used for creating this object. Has the form: //vport
			x	-handle
			x		A handle returned via a ::<namespace>::fcoe_client_options_config command. This is used for mode modify
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x	-associates
			x		The 'Associates' property applies only to 'client mode'
			x		endpoints (e.g. DHCP/L2TP/PPP). It describes a list
			x		of server endpoints that will:
			x		+ always be started before the client endpoint is started
			x		+ always be stopped after the client endpoint is stopped.
			x		This allows orderly, synchronized start and stop sequences
			x		to occur between associated client and server endpoints.
			x		This feature should be used when you have two or more IXIA
			x		DHCP/PPP/L2TP endpoints (client and server) in a network
			x		configuration. It prevents extraneous session negotiation
			x		timeouts that may occur due to:
			x		+ a server being started after a client was started
			x		+ a server being stopped before a client was stopped.
			x		Is a subelement of type: Associate
			x	-max_packets_per_second
			x		The maximum number of requests transmitted in each second, for this port group.
			x	-override_global_rate
			x		Global rate settings are automatically distributed to all port groups.
			x		If one port group has this field enabled, the distributed rate settings will be overridden with the following values.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-setup_rate
			x		The number of interfaces scheduled to be configured in each second, for this port group.
			x	-teardown_rate
			x		The number of interfaces scheduled to be deconfigured in each second, for this port group.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log      value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles  value:The returned handle(s) of the  config command.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("fcoe_client_options_config", kwargs)

	def fcoe_config(self, **kwargs):
		""" Performs fcoe configuration
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fcoe_config
			x	[-mode                                    ANY]
			x	[-parent_handle                           ANY]
			x	[-handle                                  ANY]
			x	[-style                                   ANY]
			x	[-fdisc_count                             ANY]
			x	[-fdisc_enabled                           ANY]
			x	[-fdisc_name                              ANY]
			x	[-fdisc_name_server_commands              ANY]
			x	[-fdisc_name_server_query                 ANY]
			x	[-fdisc_name_server_query_command         ANY]
			x	[-fdisc_name_server_query_parameter_type  ANY]
			x	[-fdisc_name_server_query_parameter_value ANY]
			x	[-fdisc_name_server_registration          ANY]
			x	[-fdisc_node_wwn_increment                ANY]
			x	[-fdisc_node_wwn_start                    ANY]
			x	[-fdisc_override_node_wwn                 ANY]
			x	[-fdisc_plogi_dest_id                     ANY]
			x	[-fdisc_plogi_enabled                     ANY]
			x	[-fdisc_plogi_mesh_mode                   ANY]
			x	[-fdisc_plogi_target_name                 ANY]
			x	[-fdisc_port_wwn_increment                ANY]
			x	[-fdisc_port_wwn_start                    ANY]
			x	[-fdisc_prli_enabled                      ANY]
			x	[-fdisc_source_oui                        ANY]
			x	[-fdisc_source_oui_increment              ANY]
			x	[-fdisc_state_change_registration         ANY]
			x	[-fdisc_state_change_registration_option  ANY]
			x	[-flogi_count                             ANY]
			x	[-flogi_enabled                           ANY]
			x	[-flogi_fip_addressing_mode               ANY]
			x	[-flogi_fip_destination_mac_address       ANY]
			x	[-flogi_fip_enabled                       ANY]
			x	[-flogi_fip_option_set_name               ANY]
			x	[-flogi_fip_solicit_timeout               ANY]
			x	[-flogi_fip_vendor_id                     ANY]
			x	[-flogi_fip_vlan_discovery                ANY]
			x	[-flogi_fip_vlan_discovery_untagged       ANY]
			x	[-flogi_name                              ANY]
			x	[-flogi_name_server_commands              ANY]
			x	[-flogi_name_server_query                 ANY]
			x	[-flogi_name_server_query_command         ANY]
			x	[-flogi_name_server_query_parameter_type  ANY]
			x	[-flogi_name_server_query_parameter_value ANY]
			x	[-flogi_name_server_registration          ANY]
			x	[-flogi_node_wwn_increment                ANY]
			x	[-flogi_node_wwn_start                    ANY]
			x	[-flogi_plogi_dest_id                     ANY]
			x	[-flogi_plogi_enabled                     ANY]
			x	[-flogi_plogi_mesh_mode                   ANY]
			x	[-flogi_plogi_target_name                 ANY]
			x	[-flogi_port_wwn_increment                ANY]
			x	[-flogi_port_wwn_start                    ANY]
			x	[-flogi_prli_enabled                      ANY]
			x	[-flogi_source_oui                        ANY]
			x	[-flogi_source_oui_increment              ANY]
			x	[-flogi_state_change_registration         ANY]
			x	[-flogi_state_change_registration_option  ANY]
			x	[-flogi_unicast_fip_solicit               ANY]
			x	[-mac_range_count                         ANY]
			x	[-mac_range_enabled                       ANY]
			x	[-mac_range_increment_by                  ANY]
			x	[-mac_range_mac                           ANY]
			x	[-mac_range_mtu                           ANY]
			x	[-mac_range_name                          ANY]
			x	[-vlan_range_enabled                      ANY]
			x	[-vlan_range_first_id                     ANY]
			x	[-vlan_range_id_incr_mode                 ANY]
			x	[-vlan_range_increment                    ANY]
			x	[-vlan_range_increment_step               ANY]
			x	[-vlan_range_inner_enable                 ANY]
			x	[-vlan_range_inner_first_id               ANY]
			x	[-vlan_range_inner_increment              ANY]
			x	[-vlan_range_inner_increment_step         ANY]
			x	[-vlan_range_inner_priority               ANY]
			x	[-vlan_range_inner_tpid                   ANY]
			x	[-vlan_range_inner_unique_count           ANY]
			x	[-vlan_range_name                         ANY]
			x	[-vlan_range_priority                     ANY]
			x	[-vlan_range_tpid                         ANY]
			x	[-vlan_range_unique_count                 ANY]
			x	[-vlan_range_vlan_id_info                 ANY]
		
		Arguments:
			x	-mode
			x		The operation this command will execute
			x		Valid choices are:
			x   		create - creates and configures a new object
			x   		add - adds a child object to the one specified by the -handle param
			x   		modify - modified attributes on the given object by the -handle param
			x   		delete - deletes the object given by the -handle param
			x	-parent_handle
			x		The parent handle used for creating this object. Has the form: //vport
			x	-handle
			x		A handle returned via a ::<namespace>::fcoe_config command. This is used for mode modify
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x	-fdisc_count
			x		The number of FDISC VN_Ports per FLOGI VN_Port to be created by this VN_Port range.
			x	-fdisc_enabled
			x		Disabled ranges won't be configured nor validated.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fdisc_name
			x		Name of range
			x	-fdisc_name_server_commands
			x		Signifies the Name Server Commands that will be sent by the client.
			x	-fdisc_name_server_query
			x		If set, the N_Port will attempt to query a Name Server.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fdisc_name_server_query_command
			x		Name Server request command codes.
			x		Valid choices are:
			x   		kGidA - GID_A
			x   		kGaNxt - GA_NXT
			x   		kGpnId - GPN_ID
			x   		kGnnId - GNN_ID
			x   		kGidPn - GID_PN
			x   		kGidPt - GID_PT
			x	-fdisc_name_server_query_parameter_type
			x		State Change Registration Parameter Type.
			x		Valid choices are:
			x   		kPortIdentifier - Port Identifier
			x   		kPortType - Port Type
			x   		kPortName - Port Name
			x	-fdisc_name_server_query_parameter_value
			x		State Change Registration Parameter Value.
			x	-fdisc_name_server_registration
			x		If set, the N_Port will attempt to register to a Name Server.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fdisc_node_wwn_increment
			x		The Node Name incrementing value for this N_Port range.
			x	-fdisc_node_wwn_start
			x		The Node Name starting value for this N_Port range.
			x	-fdisc_override_node_wwn
			x		If set, the GUI will allow overriding the Node WWN for FDISC VN_Ports.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fdisc_plogi_dest_id
			x		Indicates FCIDs and WWNs that can be used as destination for PLOGI requests.
			x	-fdisc_plogi_enabled
			x		Enables these N_Ports to attempt a PLOGI connection with specified destinations.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fdisc_plogi_mesh_mode
			x		The association mode between PLOGI initiators and targets.
			x		Valid choices are:
			x   		one-to-one - One - One
			x   		many-to-many - Many - Many
			x	-fdisc_plogi_target_name
			x		Indicates the N_Port range used as destination for PLOGI requests.
			x	-fdisc_port_wwn_increment
			x		The Port Name incrementing value for this N_Port range.
			x	-fdisc_port_wwn_start
			x		The Port Name starting value for this N_Port range.
			x	-fdisc_prli_enabled
			x		Process login.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fdisc_source_oui
			x		The OUI ID (3-byte) associated to all N_Ports in this range.
			x	-fdisc_source_oui_increment
			x		The OUI ID incrementing value for this N_Port range.
			x	-fdisc_state_change_registration
			x		If set, the N_Port will attempt to subscribe to State Change events.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fdisc_state_change_registration_option
			x		State Change Registration option.
			x		Valid choices are:
			x   		kFabricDetected - Fabric Detected
			x   		kNXPortDetected - NX Port Detected
			x   		kAll - All
			x	-flogi_count
			x		The number of FLOGI VN_Ports to be created by this VN_Port range.
			x	-flogi_enabled
			x		Disabled ranges won't be configured nor validated.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-flogi_fip_addressing_mode
			x		The addressing mode specified by FLOGI/FDISC requests.
			x		Valid choices are:
			x   		fabric-provided - FPMA
			x   		server-provided - SPMA
			x   		both - Both
			x	-flogi_fip_destination_mac_address
			x		Represents the address to which "FIP Solicit Unicast" is sent.
			x	-flogi_fip_enabled
			x		Enable FCoE Initialization Protocol (FIP).
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-flogi_fip_option_set_name
			x		The name of the Option Set used by this range.
			x	-flogi_fip_solicit_timeout
			x		Period of time (in seconds) that the client waits for a message of type "FIP Discovery Advertisement Multicast" before failing.
			x	-flogi_fip_vendor_id
			x		The Vendor Identifier value (8-byte).
			x	-flogi_fip_vlan_discovery
			x		Enable FIP VLAN Discovery.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-flogi_fip_vlan_discovery_untagged
			x		If enabled, VLAN Discovery will be performed using plain Ethernet frames, i.e. without any VLAN tags.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-flogi_name
			x		Name of range
			x	-flogi_name_server_commands
			x		Signifies the Name Server Commands that will be sent by the client.
			x	-flogi_name_server_query
			x		If set, the N_Port will attempt to query a Name Server.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-flogi_name_server_query_command
			x		Name Server request command codes.
			x		Valid choices are:
			x   		kGidA - GID_A
			x   		kGaNxt - GA_NXT
			x   		kGpnId - GPN_ID
			x   		kGnnId - GNN_ID
			x   		kGidPn - GID_PN
			x   		kGidPt - GID_PT
			x	-flogi_name_server_query_parameter_type
			x		State Change Registration Parameter Type.
			x		Valid choices are:
			x   		kPortIdentifier - Port Identifier
			x   		kPortType - Port Type
			x   		kPortName - Port Name
			x	-flogi_name_server_query_parameter_value
			x		State Change Registration Parameter Value.
			x	-flogi_name_server_registration
			x		If set, the N_Port will attempt to register to a Name Server.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-flogi_node_wwn_increment
			x		The Node Name incrementing value for this N_Port range.
			x	-flogi_node_wwn_start
			x		The Node Name starting value for this N_Port range.
			x	-flogi_plogi_dest_id
			x		Indicates FCIDs and WWNs that can be used as destination for PLOGI requests.
			x	-flogi_plogi_enabled
			x		Enables these N_Ports to attempt a PLOGI connection with specified destinations.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-flogi_plogi_mesh_mode
			x		The association mode between PLOGI initiators and targets.
			x		Valid choices are:
			x   		one-to-one - One - One
			x   		many-to-many - Many - Many
			x	-flogi_plogi_target_name
			x		Indicates the N_Port range used as destination for PLOGI requests.
			x	-flogi_port_wwn_increment
			x		The Port Name incrementing value for this N_Port range.
			x	-flogi_port_wwn_start
			x		The Port Name starting value for this N_Port range.
			x	-flogi_prli_enabled
			x		Process login.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-flogi_source_oui
			x		The OUI ID (3-byte) associated to all N_Ports in this range.
			x	-flogi_source_oui_increment
			x		The OUI ID incrementing value for this N_Port range.
			x	-flogi_state_change_registration
			x		If set, the N_Port will attempt to subscribe to State Change events.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-flogi_state_change_registration_option
			x		State Change Registration option.
			x		Valid choices are:
			x   		kFabricDetected - Fabric Detected
			x   		kNXPortDetected - NX Port Detected
			x   		kAll - All
			x	-flogi_unicast_fip_solicit
			x		None - Fip Solicit is made as multicast.
			x		Listen/Learn FIFO - The client waits a message of type "FIP Discovery Advertisement Multicast" and replies with "FIP Solicit Unicast" to the server.
			x		Listen/Learn PB - In this mode the FCoE Client listens for Unsolicited Advertisements from FCFs; when the waiting period is over, the FCF with the highest priority is chosen and a Discovery Solicitation unicast is sent to it.
			x		Explicit - The client sends directly a "FIP Solicit Unicast" to the address from "FIP Destination MAC Address" field.
			x		Valid choices are:
			x   		none - None
			x   		listenFifo - Listen/Learn Fifo
			x   		listenPb - Listen/Learn Priority Based
			x   		explicitMac - Explicit MAC
			x	-mac_range_count
			x		The total number of interfaces to be created for the range.
			x	-mac_range_enabled
			x		Disabled ranges won't be configured nor validated.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-mac_range_increment_by
			x		When a range of multiple MACs is created with this plugin, this value
			x		is the incrementor used to create the addresses in the range.
			x		This property is used in conjunction with 'MAC Address' as a base value.
			x		Incrementor used when the plugin creates a range of MACs.
			x	-mac_range_mac
			x		When a range of multiple MACs is created with this plugin, this value
			x		is the base value used to create the addresses in the range.
			x		This property is used in conjunction with 'Increment' as an incrementor.
			x		Base value used when the plugin creates a MAC address.
			x	-mac_range_mtu
			x		Maximum Transmission Unit.
			x		The largest packet that a given network medium can carry.
			x		Ethernet, for example, has a fixed MTU of 1500 bytes without and 9500 bytes with Jumbo frame support.
			x		ATM has a fixed MTU of 48 bytes and PPP has a negotiated MTU that is usually between 500 and 2000 bytes.
			x	-mac_range_name
			x		Name of range
			x	-vlan_range_enabled
			x		Disabled ranges won't be configured nor validated.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-vlan_range_first_id
			x		The first ID to be used for the first VLAN tag.
			x	-vlan_range_id_incr_mode
			x		Method used to increment VLAN IDs.
			x		May take the following values: 0 (First VLAN first), 1 (Last VLAN first), 2 (All).
			x		Valid choices are:
			x   		0 - Outer First
			x   		1 - Inner First
			x   		2 - All
			x	-vlan_range_increment
			x		Amount of increment per increment step for first VLAN. E.g. increment step = 10 and increment = 2 means increment VLAN ID by 2 for every 10 IPs
			x	-vlan_range_increment_step
			x		Frequency of first VLAN ID increment. E.g., value of 10 means increment VLAN ID once for every 10 IP addresses.
			x	-vlan_range_inner_enable
			x		Enable the inner VLAN.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-vlan_range_inner_first_id
			x		The first ID to be used for the inner VLAN tag.
			x	-vlan_range_inner_increment
			x		Amount of increment per increment step for Inner VLAN. E.g. increment step = 10 and increment = 2 means increment VLAN ID by 2 for every 10 IPs
			x	-vlan_range_inner_increment_step
			x		Frequency of inner VLAN ID increment. E.g., value of 10 means increment VLAN ID once for every 10 IP addresses.
			x	-vlan_range_inner_priority
			x		The 802.1Q priority to be used for the inner VLAN tag.
			x	-vlan_range_inner_tpid
			x		The TPID value in the inner VLAN Tag.
			x		Valid choices are:
			x   		0x8100 - 0x8100
			x   		0x88a8 - 0x88a8
			x   		0x9100 - 0x9100
			x   		0x9200 - 0x9200
			x   		0x9300 - 0x9300
			x	-vlan_range_inner_unique_count
			x		Number of unique inner VLAN IDs to use.
			x	-vlan_range_name
			x		Name of range
			x	-vlan_range_priority
			x		The 802.1Q priority to be used for the outer VLAN tag.
			x	-vlan_range_tpid
			x		The TPID value in the outer VLAN Tag.
			x		Valid choices are:
			x   		0x8100 - 0x8100
			x   		0x88a8 - 0x88a8
			x   		0x9100 - 0x9100
			x   		0x9200 - 0x9200
			x   		0x9300 - 0x9300
			x	-vlan_range_unique_count
			x		Number of unique first VLAN IDs to use.
			x	-vlan_range_vlan_id_info
			x		Contains extra VLANs
			x		Is a subelement of type: VlanIdInfo
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log      value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles  value:The returned handle(s) of the  config command.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("fcoe_config", kwargs)

	def fcoe_control(self, **kwargs):
		""" Perform control plane operations on an endpoint created by a ::<namespace>::fcoe_config command
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fcoe_control
			x	[-handle ANY]
			x	[-action ANY]
		
		Arguments:
			x	-handle
			x		A handle returned via a ::<namespace>::fcoe_config command. This is the object on which the action will take place.
			x	-action
			x		Action to be executed.
			x		Valid choices are:
			x   		abort - abort all sessions on the same port with the target endpoint designated by -handle. The control is returned when the operation is completed.
			x   		abort_async - abort all sessions on the same port with the target endpoint designated by -handle. The control is returned immediately. The operation is executed in the background.
			x   		start - start and/or negotiate session for the target endpoint designated by -handle.
			x   		connect - start and/or negotiate session for the target endpoint designated by -handle.
			x   		stop - stop and/or release session for the target endpoint designated by -handle.
			x   		disconnect - stop and/or release session for the target endpoint designated by -handle.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status         value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log            value:Error message if command returns {status 0}
		The result(s) of the  control action.
			 key:inner_results  value:The result(s) of the  control action.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("fcoe_control", kwargs)

	def fcoe_fwd_config(self, **kwargs):
		""" Performs fcoe_fwd configuration
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fcoe_fwd_config
			x	[-mode                            ANY]
			x	[-parent_handle                   ANY]
			x	[-handle                          ANY]
			x	[-style                           ANY]
			x	[-b2b_rx_size                     ANY]
			x	[-enabled                         ANY]
			x	[-fabric_name                     ANY]
			x	[-fc_map                          ANY]
			x	[-fdisc_reject_interval           ANY]
			x	[-fip_addressing_mode             ANY]
			x	[-fip_advertisement_period        ANY]
			x	[-fip_clear_vlink_on_expire       ANY]
			x	[-fip_clear_vlink_port_ids        ANY]
			x	[-fip_enabled                     ANY]
			x	[-fip_fka_dbit                    ANY]
			x	[-fip_priority                    ANY]
			x	[-fip_version                     ANY]
			x	[-fip_vlan_discovery              ANY]
			x	[-fip_vnport_keep_alive_period    ANY]
			x	[-flogi_reject_interval           ANY]
			x	[-logo_reject_interval            ANY]
			x	[-mac_range_count                 ANY]
			x	[-mac_range_enabled               ANY]
			x	[-mac_range_increment_by          ANY]
			x	[-mac_range_mac                   ANY]
			x	[-mac_range_mtu                   ANY]
			x	[-mac_range_name                  ANY]
			x	[-name                            ANY]
			x	[-name_server                     ANY]
			x	[-name_server_commands            ANY]
			x	[-operating_mode                  ANY]
			x	[-plogi_reject_interval           ANY]
			x	[-switch_name                     ANY]
			x	[-vlan_ids                        ANY]
			x	[-vlan_range_enabled              ANY]
			x	[-vlan_range_first_id             ANY]
			x	[-vlan_range_id_incr_mode         ANY]
			x	[-vlan_range_increment            ANY]
			x	[-vlan_range_increment_step       ANY]
			x	[-vlan_range_inner_enable         ANY]
			x	[-vlan_range_inner_first_id       ANY]
			x	[-vlan_range_inner_increment      ANY]
			x	[-vlan_range_inner_increment_step ANY]
			x	[-vlan_range_inner_priority       ANY]
			x	[-vlan_range_inner_tpid           ANY]
			x	[-vlan_range_inner_unique_count   ANY]
			x	[-vlan_range_name                 ANY]
			x	[-vlan_range_priority             ANY]
			x	[-vlan_range_tpid                 ANY]
			x	[-vlan_range_unique_count         ANY]
			x	[-vlan_range_vlan_id_info         ANY]
		
		Arguments:
			x	-mode
			x		The operation this command will execute
			x		Valid choices are:
			x   		create - creates and configures a new object
			x   		add - adds a child object to the one specified by the -handle param
			x   		modify - modified attributes on the given object by the -handle param
			x   		delete - deletes the object given by the -handle param
			x	-parent_handle
			x		The parent handle used for creating this object. Has the form: //vport
			x	-handle
			x		A handle returned via a ::<namespace>::fcoe_fwd_config command. This is used for mode modify
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x	-b2b_rx_size
			x		The buffer-to-buffer receive data field size in bytes.
			x	-enabled
			x		Disabled ranges won't be configured nor validated.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fabric_name
			x		The Fabric Name value assigned to this interface.
			x	-fc_map
			x		The MAC Address Prefix associated to local FC fabric.
			x	-fdisc_reject_interval
			x		When the user enters N, IxNetwork FCF will send out one LS_RJT for every N-th FDISC request.
			x		If N = 0, no FDISC request will be rejected.
			x		If N = 1, every FDISC request will be rejected.
			x		If N = 10, then the first 9 FDISC requests will be accepted, and the 10th will be rejected.
			x	-fip_addressing_mode
			x		The MAC Addressing Mode supported by this interface.
			x		Valid choices are:
			x   		fabric-provided - FPMA
			x   		server-provided - SPMA
			x   		both - Both
			x	-fip_advertisement_period
			x		The interval in milliseconds between periodic Discovery Advertisements.
			x		It is also used to monitor the interval between ENodes FIP Keep-Alive frames.
			x		A value of 0 milliseconds indicates that no Keep-Alive message is expected.
			x	-fip_clear_vlink_on_expire
			x		[no description available]
			x	-fip_clear_vlink_port_ids
			x		[no description available]
			x	-fip_enabled
			x		Select this option to respond to general FIP requests.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fip_fka_dbit
			x		When the D bit is set, the VF_Port will not verify periodic reception
			x		of ENode FIP Keep-Alive and VN_Port FIP Keep-Alive frames.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fip_priority
			x		The FIP Priority value sent with Discovery Advertisements.
			x	-fip_version
			x		The FIP version to use.
			x		Valid choices are:
			x   		0 - Version 0
			x   		1 - Version 1
			x	-fip_vlan_discovery
			x		Select this option to respond to FIP VLAN Discovery requests.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-fip_vnport_keep_alive_period
			x		The interval in milliseconds between periodic VN_Port FIP Keep-Alive frames.
			x		A value of 0 milliseconds indicates that no Keep-Alive message is expected.
			x	-flogi_reject_interval
			x		When the user enters N, IxNetwork FCF will send out one LS_RJT for every N-th FLOGI request.
			x		If N = 0, no FLOGI request will be rejected.
			x		If N = 1, every FLOGI request will be rejected.
			x		If N = 10, then the first 9 FLOGI requests will be accepted, and the 10th will be rejected.
			x	-logo_reject_interval
			x		When the user enters N, IxNetwork FCF will send out one LS_RJT for every N-th LOGO request.
			x		If N = 0, no LOGO request will be rejected.
			x		If N = 1, every LOGO request will be rejected.
			x		If N = 10, then the first 9 LOGO requests will be accepted, and the 10th will be rejected.
			x	-mac_range_count
			x		The total number of interfaces to be created for the range.
			x	-mac_range_enabled
			x		Disabled ranges won't be configured nor validated.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-mac_range_increment_by
			x		When a range of multiple MACs is created with this plugin, this value
			x		is the incrementor used to create the addresses in the range.
			x		This property is used in conjunction with 'MAC Address' as a base value.
			x		Incrementor used when the plugin creates a range of MACs.
			x	-mac_range_mac
			x		When a range of multiple MACs is created with this plugin, this value
			x		is the base value used to create the addresses in the range.
			x		This property is used in conjunction with 'Increment' as an incrementor.
			x		Base value used when the plugin creates a MAC address.
			x	-mac_range_mtu
			x		Maximum Transmission Unit.
			x		The largest packet that a given network medium can carry.
			x		Ethernet, for example, has a fixed MTU of 1500 bytes without and 9500 bytes with Jumbo frame support.
			x		ATM has a fixed MTU of 48 bytes and PPP has a negotiated MTU that is usually between 500 and 2000 bytes.
			x	-mac_range_name
			x		Name of range
			x	-name
			x		Name of range
			x	-name_server
			x		Select this option to respond to Name Service requests.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-name_server_commands
			x		Signifies the Name Server Commands that will be accepted by the forwarder.
			x	-operating_mode
			x		Describes the operating mode for this interface.
			x		Valid choices are:
			x   		VF_PORT - VF_PORT
			x   		F_PORT - F_PORT
			x	-plogi_reject_interval
			x		When the user enters N, IxNetwork FCF will send out one LS_RJT for every N-th PLOGI request.
			x		If N = 0, no PLOGI request will be rejected.
			x		If N = 1, every PLOGI request will be rejected.
			x		If N = 10, then the first 9 PLOGI requests will be accepted, and the 10th will be rejected.
			x	-switch_name
			x		The Switch Name value assigned to this interface.
			x	-vlan_ids
			x		The VLAN ID list sent with VLAN Notifications (e.g. 10,20).
			x		Discovery Advertisements will be periodically sent for each VLAN ID specified in this list.
			x	-vlan_range_enabled
			x		Disabled ranges won't be configured nor validated.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-vlan_range_first_id
			x		The first ID to be used for the first VLAN tag.
			x	-vlan_range_id_incr_mode
			x		Method used to increment VLAN IDs.
			x		May take the following values: 0 (First VLAN first), 1 (Last VLAN first), 2 (All).
			x		Valid choices are:
			x   		0 - Outer First
			x   		1 - Inner First
			x   		2 - All
			x	-vlan_range_increment
			x		Amount of increment per increment step for first VLAN. E.g. increment step = 10 and increment = 2 means increment VLAN ID by 2 for every 10 IPs
			x	-vlan_range_increment_step
			x		Frequency of first VLAN ID increment. E.g., value of 10 means increment VLAN ID once for every 10 IP addresses.
			x	-vlan_range_inner_enable
			x		Enable the inner VLAN.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-vlan_range_inner_first_id
			x		The first ID to be used for the inner VLAN tag.
			x	-vlan_range_inner_increment
			x		Amount of increment per increment step for Inner VLAN. E.g. increment step = 10 and increment = 2 means increment VLAN ID by 2 for every 10 IPs
			x	-vlan_range_inner_increment_step
			x		Frequency of inner VLAN ID increment. E.g., value of 10 means increment VLAN ID once for every 10 IP addresses.
			x	-vlan_range_inner_priority
			x		The 802.1Q priority to be used for the inner VLAN tag.
			x	-vlan_range_inner_tpid
			x		The TPID value in the inner VLAN Tag.
			x		Valid choices are:
			x   		0x8100 - 0x8100
			x   		0x88a8 - 0x88a8
			x   		0x9100 - 0x9100
			x   		0x9200 - 0x9200
			x   		0x9300 - 0x9300
			x	-vlan_range_inner_unique_count
			x		Number of unique inner VLAN IDs to use.
			x	-vlan_range_name
			x		Name of range
			x	-vlan_range_priority
			x		The 802.1Q priority to be used for the outer VLAN tag.
			x	-vlan_range_tpid
			x		The TPID value in the outer VLAN Tag.
			x		Valid choices are:
			x   		0x8100 - 0x8100
			x   		0x88a8 - 0x88a8
			x   		0x9100 - 0x9100
			x   		0x9200 - 0x9200
			x   		0x9300 - 0x9300
			x	-vlan_range_unique_count
			x		Number of unique first VLAN IDs to use.
			x	-vlan_range_vlan_id_info
			x		Contains extra VLANs
			x		Is a subelement of type: VlanIdInfo
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log      value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles  value:The returned handle(s) of the  config command.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("fcoe_fwd_config", kwargs)

	def fcoe_fwd_control(self, **kwargs):
		""" Perform control plane operations on an endpoint created by a ::<namespace>::fcoe_fwd_config command
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fcoe_fwd_control
			x	[-handle ANY]
			x	[-action ANY]
		
		Arguments:
			x	-handle
			x		A handle returned via a ::<namespace>::fcoe_fwd_config command. This is the object on which the action will take place.
			x	-action
			x		Action to be executed.
			x		Valid choices are:
			x   		abort - abort all sessions on the same port with the target endpoint designated by -handle. The control is returned when the operation is completed.
			x   		abort_async - abort all sessions on the same port with the target endpoint designated by -handle. The control is returned immediately. The operation is executed in the background.
			x   		start - start and/or negotiate session for the target endpoint designated by -handle.
			x   		connect - start and/or negotiate session for the target endpoint designated by -handle.
			x   		stop - stop and/or release session for the target endpoint designated by -handle.
			x   		disconnect - stop and/or release session for the target endpoint designated by -handle.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status         value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log            value:Error message if command returns {status 0}
		The result(s) of the  control action.
			 key:inner_results  value:The result(s) of the  control action.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("fcoe_fwd_control", kwargs)

	def fcoe_fwd_globals_config(self, **kwargs):
		""" Performs fcoe_fwd_globals configuration
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fcoe_fwd_globals_config
			x	[-mode                          ANY]
			x	[-parent_handle                 ANY]
			x	[-handle                        ANY]
			x	[-style                         ANY]
			x	[-accept_partial_config         ANY]
			x	[-dcbx_timeout                  ANY]
			x	[-fip_clear_vlink_with_port_ids ANY]
			x	[-max_packets_per_second        ANY]
			x	[-max_retries                   ANY]
			x	[-retry_interval                ANY]
		
		Arguments:
			x	-mode
			x		The operation this command will execute
			x		Valid choices are:
			x   		create - creates and configures a new object
			x   		add - adds a child object to the one specified by the -handle param
			x   		modify - modified attributes on the given object by the -handle param
			x   		delete - deletes the object given by the -handle param
			x	-parent_handle
			x		The parent handle used for creating this object. Has the form: //vport
			x	-handle
			x		A handle returned via a ::<namespace>::fcoe_fwd_globals_config command. This is used for mode modify
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x	-accept_partial_config
			x		This flag controls how the negotiation process reports success or failure.
			x		When is true the plugin reports success if at least one session is established.
			x		When is false the plugin reports success only if all sessions are established.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-dcbx_timeout
			x		The number of seconds to wait for DCBX to negotiate.
			x	-fip_clear_vlink_with_port_ids
			x		[no description available]
			x	-max_packets_per_second
			x		The maximum number of requests transmitted in each second.
			x	-max_retries
			x		The number of request retries for each negotiation stage in case of response timeout or error.
			x	-retry_interval
			x		The number of seconds to wait for a response before sending a new request.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log      value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles  value:The returned handle(s) of the  config command.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("fcoe_fwd_globals_config", kwargs)

	def fcoe_fwd_options_config(self, **kwargs):
		""" Performs fcoe_fwd_options configuration
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fcoe_fwd_options_config
			x	[-mode                   ANY]
			x	[-parent_handle          ANY]
			x	[-handle                 ANY]
			x	[-style                  ANY]
			x	[-max_packets_per_second ANY]
			x	[-override_global_rate   ANY]
			x	[-unsol_discovery_tpid   ANY]
		
		Arguments:
			x	-mode
			x		The operation this command will execute
			x		Valid choices are:
			x   		create - creates and configures a new object
			x   		add - adds a child object to the one specified by the -handle param
			x   		modify - modified attributes on the given object by the -handle param
			x   		delete - deletes the object given by the -handle param
			x	-parent_handle
			x		The parent handle used for creating this object. Has the form: //vport
			x	-handle
			x		A handle returned via a ::<namespace>::fcoe_fwd_options_config command. This is used for mode modify
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x	-max_packets_per_second
			x		The maximum number of PLOGI requests transmitted in each second.
			x	-override_global_rate
			x		Global rate settings are automatically distributed to all port groups.
			x		If one port group has this field enabled, the distributed rate settings will be overridden with the following values.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-unsol_discovery_tpid
			x		Server VLAN TPIDs.
			x		Valid choices are:
			x   		0x8100,0x88A8 - All
			x   		0x8100 - 0x8100
			x   		0x88A8 - 0x88A8
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log      value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles  value:The returned handle(s) of the  config command.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("fcoe_fwd_options_config", kwargs)

	def fcoe_fwd_stats(self, **kwargs):
		""" Retrieve statistics plane on an endpoint created by a ::<namespace>::fcoe_fwd_config command
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fcoe_fwd_stats
			x	[-port_handle ANY]
		
		Arguments:
			x	-port_handle
			x		The port handle for which the fcoe_fwd stats need to be retrieved
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                         value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log                                            value:Error message if command returns {status 0}
		Port Name
			 key:<port_handle>.gen.port_name                    value:Port Name
		VN_Ports Registered
			 key:<port_handle>.gen.vnports_registered           value:VN_Ports Registered
		NS Requests Rx
			 key:<port_handle>.gen.ns_requests_rx               value:NS Requests Rx
		NS Accepts Tx
			 key:<port_handle>.gen.ns_acceptstx                 value:NS Accepts Tx
		NS Rejects Tx
			 key:<port_handle>.gen.ns_rejects_tx                value:NS Rejects Tx
		SCR Requests Rx
			 key:<port_handle>.gen.scr_requests_x               value:SCR Requests Rx
		SCR Accepts Tx
			 key:<port_handle>.gen.scr_accepts_tx               value:SCR Accepts Tx
		SCR Rejects Tx
			 key:<port_handle>.gen.scr_rejects_tx               value:SCR Rejects Tx
		FLOGI Requests Rx
			 key:<port_handle>.gen.flogi_requests_rx            value:FLOGI Requests Rx
		FLOGI LS_ACC Tx
			 key:<port_handle>.gen.flogi_ls_acc_tx              value:FLOGI LS_ACC Tx
		FLOGI LS_RJT Tx
			 key:<port_handle>.gen.flogi_ls_rjt_tx              value:FLOGI LS_RJT Tx
		FDISC Requests Rx
			 key:<port_handle>.gen.fdisc_requests_rx            value:FDISC Requests Rx
		FDISC LS_ACC Tx
			 key:<port_handle>.gen.fdisc_ls_acc_tx              value:FDISC LS_ACC Tx
		FDISC LS_RJT Tx
			 key:<port_handle>.gen.fdisc_ls_rjt_tx              value:FDISC LS_RJT Tx
		FLOGO Requests Rx
			 key:<port_handle>.gen.flogo_requests_rx            value:FLOGO Requests Rx
		FLOGO LS_ACC Tx
			 key:<port_handle>.gen.flogo_ls_acc_tx              value:FLOGO LS_ACC Tx
		FLOGO LS_RJT Tx
			 key:<port_handle>.gen.flogo_ls_rjt_tx              value:FLOGO LS_RJT Tx
		PLOGI Requests Rx
			 key:<port_handle>.gen.plogi_requests_rx            value:PLOGI Requests Rx
		PLOGI LS_ACC Tx
			 key:<port_handle>.gen.plogi_ls_acc_tx              value:PLOGI LS_ACC Tx
		PLOGI LS_RJT Tx
			 key:<port_handle>.gen.plogi_ls_rjt_tx              value:PLOGI LS_RJT Tx
		PLOGO Requests Rx
			 key:<port_handle>.gen.plogo_requests_rx            value:PLOGO Requests Rx
		PLOGO LS_ACC Tx
			 key:<port_handle>.gen.plogo_ls_acc_tx              value:PLOGO LS_ACC Tx
		PLOGO LS_RJT Tx
			 key:<port_handle>.gen.plogo_ls_rjt_tx              value:PLOGO LS_RJT Tx
		PLOGI Requests Tx
			 key:<port_handle>.gen.plogi_requests_tx            value:PLOGI Requests Tx
		PLOGI LS_ACC Rx
			 key:<port_handle>.gen.plogi_ls_acc_rx              value:PLOGI LS_ACC Rx
		PLOGI LS_RJT Rx
			 key:<port_handle>.gen.plogi_ls_rjt_rx              value:PLOGI LS_RJT Rx
		PLOGO Requests Tx
			 key:<port_handle>.gen.plogo_requests_tx            value:PLOGO Requests Tx
		PLOGO LS_ACC Rx
			 key:<port_handle>.gen.plogo_ls_acc_rx              value:PLOGO LS_ACC Rx
		PLOGO LS_RJT Rx
			 key:<port_handle>.gen.plogo_ls_rjt_rx              value:PLOGO LS_RJT Rx
		Discovery Solicitations Rx
			 key:<port_handle>.gen.disc_solicits_rx             value:Discovery Solicitations Rx
		Discovery Advertisements Tx
			 key:<port_handle>.gen.disc_adverts_tx              value:Discovery Advertisements Tx
		VLAN Requests Rx
			 key:<port_handle>.gen.vlan_requests_rx             value:VLAN Requests Rx
		VLAN Notifications Tx
			 key:<port_handle>.gen.vlan_notifications_tx        value:VLAN Notifications Tx
		Unsolicited Discovery Advertisements Tx
			 key:<port_handle>.gen.unsol_disc_adverts_tx        value:Unsolicited Discovery Advertisements Tx
		ENode Keep-Alives Rx
			 key:<port_handle>.gen.enode_keep_alives_rx         value:ENode Keep-Alives Rx
		ENode Keep-Alives Miss
			 key:<port_handle>.gen.enode_keep_alives_miss       value:ENode Keep-Alives Miss
		Unexpected ENode Keep-Alives Rx
			 key:<port_handle>.gen.unexp_enode_keep_alives_rx   value:Unexpected ENode Keep-Alives Rx
		VN_Port Keep-Alives Rx
			 key:<port_handle>.gen.vnport_keep_alives_rx        value:VN_Port Keep-Alives Rx
		VN_Port Keep-Alives Miss
			 key:<port_handle>.gen.vnport_keepalives_miss       value:VN_Port Keep-Alives Miss
		Unexpected VN_Port Keep-Alives Rx
			 key:<port_handle>.gen.unexp_vnport_keep_alives_rx  value:Unexpected VN_Port Keep-Alives Rx
		Clear Virtual Links VN_Ports
			 key:<port_handle>.gen.clear_vlink_vnports          value:Clear Virtual Links VN_Ports
		Clear Virtual Links Tx
			 key:<port_handle>.gen.clear_vlink_tx               value:Clear Virtual Links Tx
		Clear Virtual Links Rx
			 key:<port_handle>.gen.clear_vlink_rx               value:Clear Virtual Links Rx
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("fcoe_fwd_stats", kwargs)

	def fcoe_fwd_vnport_config(self, **kwargs):
		""" Performs fcoe_fwd_vnport configuration
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fcoe_fwd_vnport_config
			x	[-mode               ANY]
			x	[-parent_handle      ANY]
			x	[-handle             ANY]
			x	[-style              ANY]
			x	[-b2b_rx_size        ANY]
			x	[-count              ANY]
			x	[-enabled            ANY]
			x	[-name               ANY]
			x	[-node_wwn_increment ANY]
			x	[-node_wwn_start     ANY]
			x	[-plogi_dest_id      ANY]
			x	[-plogi_enabled      ANY]
			x	[-plogi_mesh_mode    ANY]
			x	[-plogi_target_name  ANY]
			x	[-port_id_increment  ANY]
			x	[-port_id_start      ANY]
			x	[-port_wwn_increment ANY]
			x	[-port_wwn_start     ANY]
			x	[-simulated          ANY]
			x	[-vx_port_name       ANY]
		
		Arguments:
			x	-mode
			x		The operation this command will execute
			x		Valid choices are:
			x   		create - creates and configures a new object
			x   		add - adds a child object to the one specified by the -handle param
			x   		modify - modified attributes on the given object by the -handle param
			x   		delete - deletes the object given by the -handle param
			x	-parent_handle
			x		The parent handle used for creating this object. Has the form: /vport/protocolStack/ethernet/fcoeFwdEndpoint/range/fcoeFwdVxPort
			x	-handle
			x		A handle returned via a ::<namespace>::fcoe_fwd_vnport_config command. This is used for mode modify
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x	-b2b_rx_size
			x		The buffer-to-buffer receive data field size in bytes.
			x	-count
			x		The number of VN_Ports allocated by this range.
			x	-enabled
			x		Disabled ranges won't be configured nor validated.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-name
			x		Name of range
			x	-node_wwn_increment
			x		The Node Name incrementing value for this N_Port range.
			x	-node_wwn_start
			x		The Node Name starting value for this N_Port range.
			x	-plogi_dest_id
			x		Indicates FCIDs and WWNs that can be used as destination for PLOGI requests.
			x	-plogi_enabled
			x		Enables these N_Ports to attempt a PLOGI connection with specified destinations.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-plogi_mesh_mode
			x		The association mode between PLOGI initiators and targets.
			x		Valid choices are:
			x   		one-to-one - One - One
			x   		many-to-many - Many - Many
			x	-plogi_target_name
			x		Indicates the N_Port range used as destination for PLOGI requests.
			x	-port_id_increment
			x		The increment value used to generate new FC_ID values.
			x	-port_id_start
			x		The FC_ID value assigned to first VN_Port.
			x	-port_wwn_increment
			x		The Port Name incrementing value for this N_Port range.
			x	-port_wwn_start
			x		The Port Name starting value for this N_Port range.
			x	-simulated
			x		Enables these VN_Ports to be simulated behind FCoE Forwarder.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-vx_port_name
			x		The FCoE Forwarder interface associated with this range.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log      value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles  value:The returned handle(s) of the  config command.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("fcoe_fwd_vnport_config", kwargs)

	def fcoe_stats(self, **kwargs):
		""" Retrieve statistics plane on an endpoint created by a ::<namespace>::fcoe_config command
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fcoe_stats
			x	[-port_handle ANY]
		
		Arguments:
			x	-port_handle
			x		The port handle for which the fcoe stats need to be retrieved
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                             value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log                                                value:Error message if command returns {status 0}
		Port Name
			 key:<port_handle>.gen.port_name                        value:Port Name
		FLOGI Tx
			 key:<port_handle>.gen.flogi_tx                         value:FLOGI Tx
		FDISC Tx
			 key:<port_handle>.gen.fdisc_tx                         value:FDISC Tx
		FLOGI LS_ACC Rx
			 key:<port_handle>.gen.flogi_ls_acc_rx                  value:FLOGI LS_ACC Rx
		FLOGI LS_RJT Rx
			 key:<port_handle>.gen.flogi_ls_rjt_rx                  value:FLOGI LS_RJT Rx
		FDISC LS_ACC Rx
			 key:<port_handle>.gen.fdisc_ls_acc_rx                  value:FDISC LS_ACC Rx
		FDISC LS_RJT Rx
			 key:<port_handle>.gen.fdisc_ls_rjt_rx                  value:FDISC LS_RJT Rx
		F_BSY Rx
			 key:<port_handle>.gen.f_bsy_rx                         value:F_BSY Rx
		F_RJT Rx
			 key:<port_handle>.gen.f_rjt_rx                         value:F_RJT Rx
		FLOGO Tx
			 key:<port_handle>.gen.flogo_tx                         value:FLOGO Tx
		PLOGI Tx
			 key:<port_handle>.gen.plogi_tx                         value:PLOGI Tx
		PLOGI Requests Rx
			 key:<port_handle>.gen.plogi_requests_rx                value:PLOGI Requests Rx
		PLOGI LS_ACC Rx
			 key:<port_handle>.gen.plogi_ls_acc_rx                  value:PLOGI LS_ACC Rx
		PLOGI LS_RJT Rx
			 key:<port_handle>.gen.plogi_ls_rjt_rx                  value:PLOGI LS_RJT Rx
		PLOGO Tx
			 key:<port_handle>.gen.plogo_tx                         value:PLOGO Tx
		PLOGO Rx
			 key:<port_handle>.gen.plogo_rx                         value:PLOGO Rx
		NS Registration Tx
			 key:<port_handle>.gen.ns_registration_tx               value:NS Registration Tx
		NS Registration OK
			 key:<port_handle>.gen.ns_registration_ok               value:NS Registration OK
		NS Queries Tx
			 key:<port_handle>.gen.ns_queries_tx                    value:NS Queries Tx
		NS Queries OK
			 key:<port_handle>.gen.ns_queries_ok                    value:NS Queries OK
		SCR Tx
			 key:<port_handle>.gen.scr_tx                           value:SCR Tx
		SCR ACC Rx
			 key:<port_handle>.gen.scr_acc_rx                       value:SCR ACC Rx
		RSCN Rx
			 key:<port_handle>.gen.rscn_rx                          value:RSCN Rx
		RSCN ACC Tx
			 key:<port_handle>.gen.rscn_acc_tx                      value:RSCN ACC Tx
		FIP Discovery Solicitations Tx
			 key:<port_handle>.gen.fip_discovery_solicitations_tx   value:FIP Discovery Solicitations Tx
		FIP Discovery Advertisements Rx
			 key:<port_handle>.gen.fip_discovery_advertisements_rx  value:FIP Discovery Advertisements Rx
		FIP Keep-Alives Tx
			 key:<port_handle>.gen.fip_keep_alives_tx               value:FIP Keep-Alives Tx
		FIP Clear Virtual Links Rx
			 key:<port_handle>.gen.fip_clear_virtual_links_rx       value:FIP Clear Virtual Links Rx
		Interfaces Up
			 key:<port_handle>.gen.interfaces_up                    value:Interfaces Up
		Interfaces Down
			 key:<port_handle>.gen.interfaces_down                  value:Interfaces Down
		Interfaces Fail
			 key:<port_handle>.gen.interfaces_fail                  value:Interfaces Fail
		Interfaces Outstanding
			 key:<port_handle>.gen.interfaces_outstanding           value:Interfaces Outstanding
		Sessions Initiated
			 key:<port_handle>.gen.sessions_initiated               value:Sessions Initiated
		Sessions Succeeded
			 key:<port_handle>.gen.sessions_succeeded               value:Sessions Succeeded
		Sessions Failed
			 key:<port_handle>.gen.sessions_failed                  value:Sessions Failed
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("fcoe_stats", kwargs)

	def fc_client_config(self, **kwargs):
		""" Performs FC Client configuration. The configuration parameters for arange of FC Client.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fc_client_config
			 	[-fdisc_count                             ANY]
			 	[-fdisc_enabled                           ANY]
			 	[-fdisc_name                              ANY]
			 	[-fdisc_name_server_query                 ANY]
			 	[-fdisc_name_server_query_command         ANY]
			 	[-fdisc_name_server_query_parameter_type  ANY]
			 	[-fdisc_name_server_query_parameter_value ANY]
			 	[-fdisc_name_server_registration          ANY]
			 	[-fdisc_node_wwn_increment                ANY]
			 	[-fdisc_node_wwn_override                 ANY]
			 	[-fdisc_node_wwn_start                    ANY]
			 	[-fdisc_plogi_dest_id                     ANY]
			 	[-fdisc_plogi_enabled                     ANY]
			 	[-fdisc_plogi_mesh_mode                   ANY]
			 	[-fdisc_plogi_target_name                 ANY]
			 	[-fdisc_port_wwn_increment                ANY]
			 	[-fdisc_port_wwn_start                    ANY]
			 	[-fdisc_prli_enabled                      ANY]
			 	[-fdisc_source_oui_incre                  ANY]
			 	[-fdisc_state_change_registration         ANY]
			 	[-fdisc_state_change_registration_option  ANY]
			 	[-flogi_count                             ANY]
			 	[-flogi_name                              ANY]
			 	[-flogi_name_server_query                 ANY]
			 	[-flogi_name_server_query_command         ANY]
			 	[-flogi_name_server_query_parameter_type  ANY]
			 	[-flogi_name_server_query_parameter_value ANY]
			 	[-flogi_name_server_registration          ANY]
			 	[-flogi_node_wwn_start                    ANY]
			 	[-flogi_plogi_dest_id                     ANY]
			 	[-flogi_plogi_enabled                     ANY]
			 	[-flogi_plogi_mesh_mode                   ANY]
			 	[-flogi_plogi_target_name                 ANY]
			 	[-flogi_port_wwn_start                    ANY]
			 	[-flogi_prli_enabled                      ANY]
			 	[-flogi_source_oui_increment              ANY]
			 	[-flogi_state_change_registration         ANY]
			 	[-flogi_state_change_registration_option  ANY]
			 	[-handle                                  ANY]
			 	-mode                                     ANY
		
		Arguments:
			 	-fdisc_count
			 		The number of FDISC N_Ports per FLOGI N_Port to be created by thisN_Port range.
			 	-fdisc_enabled
			 		Disabled ranges won't be configured and validated.
			 	-fdisc_name
			 		Name of FDISC range.(DEFAULT = "NPORT-FDISC-R")
			 	-fdisc_name_server_query
			 		If set, the N_Port will attempt to query a Name Server.
			 	-fdisc_name_server_query_command
			 		Name Server request command codes.gid_a- GID_Aga_nxt - GA_NXTgpn_id - GPN_IDgid_pn - GID_PNgid_pt - GID_PT
			 	-fdisc_name_server_query_parameter_type
			 		State Change Registration Parameter Type.port_identifier- {Port Identifier}port_type- {Port Type}port_name- {Port Name}
			 	-fdisc_name_server_query_parameter_value
			 		State Change Registration Parameter Value.(DEFAULT = {})
			 	-fdisc_name_server_registration
			 		If set, the N_Port will attempt to register to a Name Server.
			 	-fdisc_node_wwn_increment
			 		The Node Name incrementing value for this N_Port range.
			 	-fdisc_node_wwn_override
			 		If set, the GUI will allow overri ding the Node WWN for FDISC N_Ports.
			 	-fdisc_node_wwn_start
			 		The Node Name starting value for this N_Port range.
			 	-fdisc_plogi_dest_id
			 		Indicates FCIDs and WWNs that can be used as destination for PLOGIrequest.
			 	-fdisc_plogi_enabled
			 		Enables these N_Ports to attempt a PLOGI connectionwith specifieddestinations.
			 	-fdisc_plogi_mesh_mode
			 		The association mode between PLOGI initiators and targets.one_to_one- {One - One}many_to_many- {Many - Many}
			 	-fdisc_plogi_target_name
			 		Indicates the N_Port range used asdestination for PLOGI requests.(DEFAULT = {})
			 	-fdisc_port_wwn_increment
			 		The Port Name incrementing va lue for this N_Port range.
			 	-fdisc_port_wwn_start
			 		The Port Name starting value for this N_Port range.
			 	-fdisc_prli_enabled
			 		Process login.
			 	-fdisc_source_oui_incre
			 		The OUI ID incrementing value for this N_Port range.
			 	-fdisc_state_change_registration
			 		If set, the N_Port will attempt to subscribe to State Change events.
			 	-fdisc_state_change_registration_option
			 		State Change Registration option.fabric_detected- {Fabric Detected}nxport_detected- {NX Port Detected}all- All(DEFAULT = fabric_detected )
			 	-flogi_count
			 		The number of FLOGI VN_Ports to becreated by this VN_Port range.
			 	-flogi_name
			 		(DEFAULT = "NPORT-FLOGI-R")
			 	-flogi_name_server_query
			 		If set, the N_Port will attempt to query a Name Server.
			 	-flogi_name_server_query_command
			 		Name Server request command codes.gid_a- GID_Aga_nxt - GA_NXTgpn_id - GPN_IDgid_pn - GID_PNgid_pt - GID_PT
			 	-flogi_name_server_query_parameter_type
			 		State Change Registra tion Parameter Type.port_identifier- {Port Identifier}port_type- {Port Type}port_name- {Port Name}
			 	-flogi_name_server_query_parameter_value
			 		State Change Registration Parameter Value.(DEFAULT = {})
			 	-flogi_name_server_registration
			 		If set, the N_Port will attempt to register to a Name Server.
			 	-flogi_node_wwn_start
			 		The Node Name starting value for this N_Port range.
			 	-flogi_plogi_dest_id
			 		Indicates FCIDs and WWNs that can be used as destination for PLOGI requests.
			 	-flogi_plogi_enabled
			 		Enables these N_Ports to attempt a PLOGI connectionwith specified destinations.
			 	-flogi_plogi_mesh_mode
			 		The association mode between PLOGI initiators and targets.one_to_one- {One- One}many_to_many- {Many - Many}
			 	-flogi_plogi_target_name
			 		Indicates the N_Port range used asdestination for PLOGI requests.(DEFAULT = {})
			 	-flogi_port_wwn_start
			 		The Port Name starting value for this N_Port range.
			 	-flogi_prli_enabled
			 		Process login.
			 	-flogi_source_oui_increment
			 		The OUI ID incrementing value for this N_Port range.
			 	-flogi_state_change_registration
			 		If set, the N_Port will attempt to subscribe to State Change events.
			 	-flogi_state_change_registration_option
			 		State Change Registration option.fabric_detected- {Fabric Detected}nxport_detected- {NX Port Detected}all- All(DEFAULT = fabric_detected )
			 	-handle
			 		FC handle of a configuration to be modified or removed.
			 	-mode
			 		add- add a new FC client configurationdisable - Disable an existing FC client configuration.(specified by -handle).enable- Enable an existing FC client configuration.(specified by -handle).modify- modify an existing FC client configuration.(specified by -handle).remove- Remove an existing FC client configuration.(specified by -handle).
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		FC client handles.
			 key:handles  value:FC client handles.
		When status is failure, contains more information.
			 key:log      value:When status is failure, contains more information.
		
		Examples:
		See the FC client examples under the Samples folder of the HLT installation for specific examples of usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("fc_client_config", kwargs)

	def fc_client_global_config(self, **kwargs):
		""" This command performs FC Client global configuration.The parameters below are valid for the entire test.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fc_client_global_config
			 	[-accept_partial_config  ANY]
			 	[-max_packets_per_second ANY]
			 	[-max_retries            ANY]
			 	-mode                    ANY
			 	[-retry_interval         ANY]
			 	[-setup_rate             ANY]
		
		Arguments:
			 	-accept_partial_config
			 		This flag controls how the negotiation process reports success orfailure. When 1, the plugin reports success if at least one sessionis established. When 0, the plugin reports success only if allsessions are established.
			 	-max_packets_per_second
			 		The maximum number of requeststransmitted in each second.
			 	-max_retries
			 		The number of request retries for eachnegotiation stage incase ofresponse timeout or error.
			 	-mode
			 		add- add a new FC Client global configuaration.modify- modify an existing FC Client global configuaration.remove- remove an existing FC Client global configuaration.
			 	-retry_interval
			 		The number of seconds to wait for a response before sending a newrequest.
			 	-setup_rate
			 		The number of interfaces scheduled to be configured ineach second, for this port group.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		FC Client handles
			 key:handles  value:FC Client handles
		When status is failure, contains more information
			 key:log      value:When status is failure, contains more information
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("fc_client_global_config", kwargs)

	def fc_client_options_config(self, **kwargs):
		""" Performs fc_client_options configuration.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fc_client_options_config
			 	[-associates             ANY]
			 	[-b2b_credit             ANY]
			 	[-b2b_rx_size            ANY]
			 	[-ed_tov                 ANY]
			 	[-ed_tov_mode            ANY]
			 	[-max_packets_per_second ANY]
			 	-mode                    ANY
			 	[-override_global_rate   ANY]
			 	-port_handle             ANY
			 	[-rt_tov                 ANY]
			 	[-rt_tov_mode            ANY]
			 	[-setup_rate             ANY]
		
		Arguments:
			 	-associates
			 		The 'Associates' property applies only to 'client mode'endpoints. It describes a list of server endpoints that will:+ always be started before the client endpoint is started+ always be stopped after the client endpoint is stopped.This allows orderly, synchronized start and stop sequencesto occur between associated client and server endpoints.This feature should be used when you have two or more IXIAin a network configuration. It prevents extraneous session negotiation timeouts that may occur due to:+ a server being started after a client was started+ a server being stopped before a client was stopped.(DEFAULT = {})
			 	-b2b_credit
			 		The buffer-to-buffer credit.
			 	-b2b_rx_size
			 		The buffer-to-buffer receive data field size in bytes.
			 	-ed_tov
			 		The user-provided error detect timeout value, can be editedby override ed_tov mode.
			 	-ed_tov_mode
			 		Allows the user to provide the error detect timeout value orhave the Ixia port obtain it from login.
			 	-max_packets_per_second
			 		The maximum number of requests transmittedin each second, for this port group.
			 	-mode
			 		modify remove.
			 	-override_global_rate
			 		Global rate settings are automaticallydistributed to all port groups.If one port group has this field enabled, the distributedrate settings will be overridden with the following values.
			 	-port_handle
			 		The port on which the FC client range .
			 	-rt_tov
			 		The user-provided receiver - transmitter timeout value, can beedited by override rt_tov mode.
			 	-rt_tov_mode
			 		Allows the user to provide receiver - transmitter timeoutvalue or have the Ixia port obtain it from login.
			 	-setup_rate
			 		The number of interfaces scheduled to be configured ineach second, for this port group.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		See the FC examples in Appendix A, "Example APIs," for specific examplesof usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("fc_client_options_config", kwargs)

	def fc_client_stats(self, **kwargs):
		""" Retrieve statistics plane on an endpoint created by a ixia
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fc_client_stats
			 	[-handle      ANY]
			x	[-mode        ANY]
			x	[-port_handle ANY]
		
		Arguments:
			 	-handle
			 		The handle for which the fcClient stats need to be retrieved.
			x	-mode
			x		Specifies statistics retrieval mode as either aggregate for all configured sessions, on a per session basis or on a per range basis.
			x		Valid choices are:
			x   		aggregate - Retrieve all statistics.
			x   		session - Retrieve statistics for each individual session.
			x   		range - Retrieve statistics for each individual range
			x	-port_handle
			x		The port for which the FC Client sessions statistics needs to be retrieved. Only available when using IxNetwork to retrieve statistics.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                   value: $::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                                      value: If status is failure, detailed information provided.
		The FC Client global statistics are generated for each port, and aggregated for all ports, for a test run.
			 key:AGGREGATE STATS                          value: The FC Client global statistics are generated for each port, and aggregated for all ports, for a test run.
		If -handle is specified, the aggregate.* keys that are not prefixed are the
			 key:PER RANGE STATS                          value: If -handle is specified, the aggregate.* keys that are not prefixed are the
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.port_name               value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.e_d_tov                 value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.f_bsy_rx                value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.f_rjt_rx                value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.flogi_tx                value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.fdisc_tx                value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.fdisc_ls_acc_rx         value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.fdisc_ls_rjt_rx         value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.flogi_ls_acc_rx         value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.flogi_ls_rjt_rx         value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.flogo_tx                value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.ns_queries_ok           value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.ns_queries_tx           value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.ns_registration_ok      value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.ns_registration_tx      value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogi_ls_acc_rx         value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogi_ls_rjt_rx         value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogi_requests_rx       value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogi_tx                value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogo_rx                value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogo_tx                value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.prli_ls_acc_rx          value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.prli_ls_rjt_rx          value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.prli_requests_rx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.prli_tx                 value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.range_id                value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.range_name              value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.remote_bb_credit        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.rscn_acc_tx             value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.rscn_rx                 value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.scr_acc_rx              value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.scr_tx                  value: Available with IxNetwork. Only for per range statistics
		The per-session statistics are collected for each FC Client session created from a specific range.
			 key:PER SESSION STATS                        value: The per-session statistics are collected for each FC Client session created from a specific range.
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.port_name           value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.e_d_tov             value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.f_bsy_rx            value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.f_rjt_rx            value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.failure_reason      value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.fdisc_ls_acc_rx     value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.fdisc_ls_rjt_rx     value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.fdisc_tx            value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.flogi_ls_acc_rx     value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.flogi_ls_rjt_rx     value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.flogi_tx            value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.flogo_tx            value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.interface_id        value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.interface_status    value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.ns_queries_ok       value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.ns_queries_tx       value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.ns_registration_ok  value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.ns_registration_tx  value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.plogi_dest_id       value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.plogi_ls_acc_rx     value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.plogi_ls_rjt_rx     value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.plogi_requests_rx   value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.plogi_tx            value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.plogo_rx            value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.plogo_tx            value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.port_name           value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.prli_ls_acc_rx      value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.prli_ls_rjt_rx      value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.prli_requests_rx    value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.prli_tx             value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.remote_bb_credit    value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.rscn_acc_tx         value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.rscn_rx             value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.scr_acc_rx          value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.scr_tx              value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.session_name        value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.source_id           value: Available with IxNetwork. Only for per session statistics
		
		Examples:
		See the FC examples in Appendix A, "Example APIs," for specific examples of usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("fc_client_stats", kwargs)

	def fc_control(self, **kwargs):
		""" Perform control plane operations on an endpoint created by the following HLT API commands
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fc_control
			 	-action       ANY
			 	[-action_mode ANY]
			 	[-handle      ANY]
			 	[-port_handle ANY]
		
		Arguments:
			 	-action
			 		abort- abort all sessions on the same port with the targetendpoint designated by handle. The control is returnedwhen the operation is completed. This actionaccepts both -handle and -port_handle parameter.Supported for both Client and Fport.clear_stats- clear stats. Please provide only port_handle for thisaction. Supported for both Client and Fport at port_handle.fc_client_fdisc- enable process Fdisc of FC Client. This actionaccepts both -handle and -port_handle parameter.fc_client_fdisc_plogi- enable process Plogi for Fc Client Fdisc Range. This actionaccepts -handle parameter only.fc_client_fdisc_plogo- enable process Plogo for Fc Client Fdisc Range. This actionaccepts -handle parameter only.fc_client_flogi- enable process of FC FabricLogin from FlogiRange of FC Client to Fabric.This action accepts both -handle and-port_handle parameter.fc_client_flogo- enable process of FC FabricLogout from FlogiRange of FC Client to Fabric.This action accepts both -handle and-port_handle parameter.fc_client_npiv_flogo- enable N_Port ID Virtualization.This actionaccept both -handle and -port_handle parameter.fc_client_plogi- enable process of FC Port Login fromFlogiRange /FdiscRange of FC Client to Fabric.Thisaction accepts both -handle and -port_handle parameter.fc_client_plogo- enable process of FC Port Logout from FlogiRange /FdiscRange of FC Client to Fabric.Thisaction accepts both -handle and -port_handle parameter.is_done- Check if -result parameter is done.pause- pause a FC connection . This action accepts both-handle and -port_handle parameter. Supported for both Client and Fport.resume- resume a FCconnection which had been paused.This action accepts both-handle and -port_handle parameter.Supported for both Client and Fport.start- start and/or negotiate session for the target endpointdesignated by handle. This action accepts both-handle and -port_handle parameter and supported for both Client and Fport.stop- stop and/or release session for the target endpointdesignated by handle.This action accepts both-handle and -port_handle parameter andsupported for both Client and Fport.
			 	-action_mode
			 		sync- action works synchronouslyasync- action works asynchronously
			 	-handle
			 		A handle returned via a ::<namespace>::fc_fport_config command.The action specified by -action parameter will be executed for thespecified FC FPORT handles (ranges).
			 	-port_handle
			 		The port on which the FC F_PORT_Fwd range is to be created.The action specified by -action parameter will be executed for thespecified port handles.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		Result value of an async action.
			 key:result  value:Result value of an async action.
		
		Examples:
		See the FC F_Port examples under the Samples folder of the HLTinstallation for specific examples of usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("fc_control", kwargs)

	def fc_fport_config(self, **kwargs):
		""" Performs FC F_Port configuration. The configuration parameters for arange of FC Fport_Fwd.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fc_fport_config
			 	[-b2b_rx_size           ANY]
			 	[-fabric_name           ANY]
			 	[-fdisc_reject_interval ANY]
			 	[-flogi_reject_interval ANY]
			 	[-handle                ANY]
			 	[-logo_reject_interval  ANY]
			 	-mode                   ANY
			 	[-name                  ANY]
			 	[-name_server           ANY]
			 	[-operating_mode        ANY]
			 	[-plogi_reject_interval ANY]
			 	[-port_handle           ANY]
		
		Arguments:
			 	-b2b_rx_size
			 		The buffer to buffer receive data field size in byte.
			 	-fabric_name
			 		The Fabric Name value assigned to this interface.
			 	-fdisc_reject_interval
			 		When the user enters N, IxNetwork F_Port will send out one LS_RJT forevery N-th FDISC request.If N=0, no FDISC request will be rejected.If N=1, every FDISC request will be rejected.If N=10, then first 9 FDISC request will be accepted, and the 10th
			 	-flogi_reject_interval
			 		When the user enters N, IxNetwork F_Port will send out one LS_RJT forevery N-th FLOGI request.If N=0, no FLOGI request will be rejected.If N=1, every FLOGI request will be rejected.If N=10, then first 9 FLOGI request will be accepted, and the 10th
			 	-handle
			 		FC handle of a configuration to be added, enabled, disabled, modifiedor removed.
			 	-logo_reject_interval
			 		When the user enters N, IxNetwork F_Port will send out one LS_RJT forevery N-th LOGO request.If N=0, no LOGO request will be rejected.If N=1, every LOGO request will be rejected.If N=10, then first 9 LOGO request will be accepted, and the 10th
			 	-mode
			 		add- add a new FC F_PORT configuration.enable- enable an existing FC F_PORT configuration.(specified by -handle)disable - disable an existing FC F_PORT configuration.(specified by -handle)modify- modify an existing FC F_PORT configuration.(specified by -handle)remove- remove an existing FC F_FORT configuration.(specified by -handle)
			 	-name
			 		Range name of F_PORT.(DEFAULT = F_PORT-FCFP-R)
			 	-name_server
			 	-operating_mode
			 	-plogi_reject_interval
			 		When the user enters N, IxNetwork F_Port will send out one LS_RJT forevery N-th PLOGI request.If N=0, no PLOGI request will be rejected.If N=1, every PLOGI request will be rejected.If N=10, then first 9 PLOGI request will be accepted, and the 10th
			 	-port_handle
			 		The port on which the FC F_PORT_Fwd range is to be created.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		FC F_Port range handles
			 key:handles  value:FC F_Port range handles
		When status is failure, contains more information
			 key:log      value:When status is failure, contains more information
		
		Examples:
		See the FC F_Port examples under the Samples folder of the HLTinstallation for specific examples of usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("fc_fport_config", kwargs)

	def fc_fport_global_config(self, **kwargs):
		""" This command performs FC FPORT global configuration.The parameters below are valid for the entire test
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fc_fport_global_config
			 	[-accept_partial_config  ANY]
			 	[-max_packets_per_second ANY]
			 	[-max_retries            ANY]
			 	-mode                    ANY
		
		Arguments:
			 	-accept_partial_config
			 		This flag controls how the negotiation process reports success orfailure. When 1, the plugin reports success if at least one sessionis established. When 0, the plugin reports success only if all
			 	-max_packets_per_second
			 		The maximum number of requeststransmitted in each second.
			 	-max_retries
			 		The number of request retries for eachnegotiation stage incase of
			 	-mode
			 		add- add a new FC F_Port global configuration.remove- remove an existing FC F_Port global configuration.modify- modify an existing FC F_Port global configuration.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		FC F_Port handles
			 key:handles  value:FC F_Port handles
		When status is failure, contains more information
			 key:log      value:When status is failure, contains more information
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("fc_fport_global_config", kwargs)

	def fc_fport_options_config(self, **kwargs):
		""" Performs fc_fport_options configuration.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fc_fport_options_config
			 	[-b2b_credit             ANY]
			 	[-ed_tov                 ANY]
			 	[-max_packets_per_second ANY]
			 	-mode                    ANY
			 	[-override_global_rate   ANY]
			 	-port_handle             ANY
		
		Arguments:
			 	-b2b_credit
			 		The buffer-to-buffer credit. A Buffer Credit specifies the number of
			 	-ed_tov
			 	-max_packets_per_second
			 		The maximum number of requeststransmitted in each second.
			 	-mode
			 		add- add a new FC F_Port option configuration.remove- remove an existing FC F_Port option configuration.modify- modify an existing FC F_Port option configuration.
			 	-override_global_rate
			 		If not selected, the global setup and teardown rate values will beequally divided among the ports. If selected, the setup and teardownparameters defined at the port level will override those defined at the
			 	-port_handle
			 		The port on which the FC F_PORT_Fwd range is to be created.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		FC F_Port handles
			 key:handles  value:FC F_Port handles
		When status is failure, contains more information
			 key:log      value:When status is failure, contains more information
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("fc_fport_options_config", kwargs)

	def fc_fport_stats(self, **kwargs):
		""" Retrieve statistics plane on an endpoi nt created by a ixia
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fc_fport_stats
			 	[-handle ANY]
			 	-mode    ANY
		
		Arguments:
			 	-handle
			 		The FC F_Port range or secondaryrange handle for which the FC F_Portsessions statistics needs to be retrieved.When using IxNetwork the statistics will be retrievedfor the port where that handle belongs.
			 	-mode
			 		Specifies statistics retrieval mode as either aggregate for allaggregate- Retrieve statistics for all ports.session- Retrieve statistics for each FC F_Port session.range- Retrieve statistics for per Fabric range.
		
		Return Values:
		The stats can be used with or without <port_handle>
			 key:AGGREGATE STATS                         value: The stats can be used with or without <port_handle>
		If -handle is specified, the aggregate.* keys that are not prefixed are the fc fport per range statistics
			 key:PER RANGE STATS                         value: If -handle is specified, the aggregate.* keys that are not prefixed are the fc fport per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.port_name              value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.fdisc_ls_acc_tx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.fdisc_ls_rjt_tx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.fdisc_requests_rx      value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.flogi_ls_acc_tx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.flogi_ls_rjt_tx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.flogi_requests_rx      value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.flogo_ls_acc_tx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.flogo_ls_rjt_tx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.flogo_requests_rx      value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.nports_registered      value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.ns_accepts_tx          value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.ns_rejects_tx          value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.ns_requests_rx         value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogi_ls_acc_rx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogi_ls_acc_tx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogi_ls_rjt_rx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogi_ls_rjt_tx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogi_requests_rx      value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogi_requests_tx      value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogo_ls_acc_rx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogo_ls_acc_tx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogo_ls_rjt_rx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogo_ls_rjt_tx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogo_requests_rx      value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.plogo_requests_tx      value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.range_name             value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.scr_requests_rx        value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.scr_accepts_tx         value: Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:range.<range ID>.scr_rejects_tx         value: Available with IxNetwork. Only for per range statistics
		The per-session statistics are collected for each FC Client session created from a specific range
			 key:PER SESSION STATS                       value: The per-session statistics are collected for each FC Client session created from a specific range
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.port_name          value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.fdisc_ls_acc_tx    value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.fdisc_ls_rjt_tx    value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.fdisc_requests_rx  value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.flogi_ls_acc_tx    value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.flogi_ls_rjt_tx    value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.flogi_requests_rx  value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.flogo_ls_acc_tx    value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.flogo_ls_rjt_tx    value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.flogo_requests_rx  value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.node_name          value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.ns_accepts_tx      value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.ns_rejects_tx      value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.ns_requests_rx     value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.plogi_ls_acc_tx    value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.plogi_ls_rjt_tx    value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.plogi_requests_rx  value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.plogo_ls_acc_tx    value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.plogo_ls_rjt_tx    value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.plogo_requests_rx  value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.port_name          value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.scr_accepts_tx     value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.scr_rejects_tx     value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.scr_requests_rx    value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.session_name       value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.session_status     value: Available with IxNetwork. Only for per session statistics
		Available with IxNetwork. Only for per session statistics
			 key:session.<session ID>.source_id          value: Available with IxNetwork. Only for per session statistics
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("fc_fport_stats", kwargs)

	def fc_fport_vnport_config(self, **kwargs):
		""" Performs FC N_Port configuration. The configuration parameters for asecondaryrange of FC Fport_Fwd.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: fc_fport_vnport_config
			 	[-b2b_rx_size       ANY]
			 	[-count             ANY]
			 	[-handle            ANY]
			 	-mode               ANY
			 	[-name              ANY]
			 	[-node_wwn_incr     ANY]
			 	[-node_wwn_start    ANY]
			 	[-plogi_dest_id     ANY]
			 	[-plogi_enable      ANY]
			 	[-plogi_mesh_mode   ANY]
			 	[-plogi_target_name ANY]
			 	[-port_id_incr      ANY]
			 	[-port_id_start     ANY]
			 	[-port_wwn_incr     ANY]
			 	[-port_wwn_start    ANY]
			 	[-simulated         ANY]
		
		Arguments:
			 	-b2b_rx_size
			 		The buffer to buffer receive data field size in byte.
			 	-count
			 	-handle
			 		FC handle of a configuration to be added, enabled, disabled, modifiedor removed.For -mode add: the handle is an FC FPORT range, previously createdusing ::<namespace>::fc_fport_config command.For -mode other than add: the handle is an FC FPORT VNPORT range, previously created using ::<namespace>::fc_fport_vnport_config
			 	-mode
			 		add- add a new FC F_PORT configuration.enable- enable an existing FC F_PORT configuration. (specified by -handle)disable- disable an existing FC F_PORT configuration.(specified by -handle)modify- modify an existing FC F_PORT configuration.(specified by -handle)remove- remove an existing FC F_FORT configuration. (specified by -handle)
			 	-name
			 		Range name of N_Port. (DEFAULT = N_PORT-FCFP-R)
			 	-node_wwn_incr
			 		The Node Name incrementing value for this N_Port range.
			 	-node_wwn_start
			 		The Node Name starting value for this N_Port range.
			 	-plogi_dest_id
			 		Indicates FCIDs and WWNs that can be used as destination for
			 	-plogi_enable
			 		Enables these N_Ports to attempt a PLOGI connection with
			 	-plogi_mesh_mode
			 		The association mode between PLOGI initiators and targets.
			 	-plogi_target_name
			 		Indicates the N_Ports range used as destination for PLOGI requests.
			 	-port_id_incr
			 		The increment value used to generate new FC_ID values.
			 	-port_id_start
			 	-port_wwn_incr
			 		The Port Name incrementing value for this N_Port range.
			 	-port_wwn_start
			 		The Port Name starting value for this N_Port range.
			 	-simulated
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		FC F_Port secondaryrange handles
			 key:handles  value:FC F_Port secondaryrange handles
		When status is failure, contains more information
			 key:log      value:When status is failure, contains more information
		
		Examples:
		See the FC F_Port examples under the Samples folder of the HLTinstallation for specific examples of usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("fc_fport_vnport_config", kwargs)

	def find_in_csv(self, **kwargs):
		""" The procedure is used to filter the flows from the file_name that matched the following condition
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: find_in_csv
			 	-file_name  ANY
			 	[-column1   ANY]
			 	[-column2   ANY]
		
		Arguments:
			 	-file_name
			 		The statistics .csv file to be parsed in order to return the statistic values.
			 	-column1
			 		The name of the column that will be looked-up in the .csv file and its valuewill be compared to the value in the -column2 parameter. Only the rows that meet the condition will be returned in this case. If no condition is provided all rows will be returned.
			 	-column2
			 		The name of the column in the .csv file that we willretrieve the value for from the .csv file for each row or a particular value (integer, string etc). This parameter value will be compared with -column1 parameter value based on the condition -condition. If the condition is met, then we will return only the row values to match the condition. If no condition is provided all rows will be returned.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                  value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                     value:On status of failure, gives detailed information.
		The value that corresponds to the column_name in the current flow.
			 key:<row_id>.<column_name>  value:The value that corresponds to the column_name in the current flow.
		The number of rows that are returned by the procedure.
			 key:row_count               value:The number of rows that are returned by the procedure.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("find_in_csv", kwargs)

	def get_execution_log(self, **kwargs):
		""" this method returns the current hl execution log file path     The result key is "execution_log"
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: get_execution_log
		
		Arguments:
		
		Return Values:
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("get_execution_log", kwargs)

	def get_nodrop_rate(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: get_nodrop_rate
			 	-stream_id         ANY
			 	-max_rate          ANY
			 	-tx_port_handle    ANY
			 	-rx_port_handle    ANY
			 	[-stream_mode      ANY]
			 	[-min_percent      ANY]
			 	[-run_time_sec     ANY]
			 	[-tolerance        ANY]
			 	[-poll_timeout_sec ANY]
		
		Arguments:
			 	-stream_id
			 	-max_rate
			    	-tx_port_handle
			        	-rx_port_handle
			            	-stream_mode
			                	-min_percent
			                    	-run_time_sec
			                        	-tolerance
			                            	-poll_timeout_sec
		                           
		                           Return Values:
		                               $::SUCCESS | $::FAILURE
			                                key:status                      value:$::SUCCESS | $::FAILURE
		                               If status is failure, contains more information
			                                key:log                         value:If status is failure, contains more information
		                               Nodrop rate in percentage for even mode
			                                key:nodrop_percent              value:Nodrop rate in percentage for even mode
		                               Nodrop rate in percentage for uneven mode, for that stream
			                                key:<stream_id>.nodrop_percent  value:Nodrop rate in percentage for uneven mode, for that stream
		                               Nodrop rate in packet per second
			                                key:<stream_id>.nodrop_pps      value:Nodrop rate in packet per second
		                           
		                           Examples:
		                           
		                           Sample Input:
		                           
		                           Sample Output:
		                           
		                           Notes:
		                           
		                           See Also:
		                           
		"""
		return self._run_keyword("get_nodrop_rate", kwargs)

	def get_packet_content(self, **kwargs):
		""" This command gets a certain packet slice from the content of a packet. From a list of packets passed by the user, the procedure extracts slices from the packets and returns a list. The offset and slice_size are decimal values that define the number of bytes.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: get_packet_content
			x	-offset       ANY
			x	-slice_size   ANY
			x	[-packet_list ANY]
		
		Arguments:
			x	-offset
			x		Decimal, number of bytes. Specifes where to start slicing the packets. Valid choices start with 0.
			x	-slice_size
			x		Decimal, number of bytes to extract. Specifies the number of bytes to extract from packet and return.
			x	-packet_list
			x		List of packets passed by the user to the procedure get_packet_content.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status          value:$::SUCCESS | $::FAILURE
		List of packet slices.
			 key:packet_content  value:List of packet slices.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("get_packet_content", kwargs)

	def get_port_list_from_connect(self, **kwargs):
		""" After calling the
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: get_port_list_from_connect
			 	[-connect_status ANY]
			 	[-devices        ANY]
			 	[-port_list      ANY]
		
		Arguments:
			 	-connect_status
			 		A key list containing the result of the call to the ::<namespace>::connect
			 	-devices
			 		A list of devices given to the connect call
			 	-port_list
			 		A list of ports given to the connect call
		
		Return Values:
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("get_port_list_from_connect", kwargs)

	def interface_config(self, **kwargs):
		""" This command configures an interface on an Ixia Load Module. It  provides the means for managing the Ixia Chassis Test Interface options.  Depending on whether the port is a SONET, Ethernet or ATM type, you have  access to the appropriate protocol properties. This command accommodates  addressing schemes such as like IPv4, IPv6, MAC and VLAN. You also have  access to the SONET properties for a PoS port, and if the port is  configured for PPP, you have access to the PPP configuration options.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: interface_config
			 	[-port_handle                                       REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-protocol_name                                     ALPHA]
			x	[-protocol_handle                                   ANY]
			x	[-enable_loopback                                   CHOICES 0 1
			x                                                    DEFAULT 0]
			x	[-connected_to_handle                               ANY]
			x	[-ipv4_multiplier                                   NUMERIC]
			x	[-ipv4_loopback_multiplier                          NUMERIC]
			x	[-ipv6_multiplier                                   NUMERIC]
			x	[-ipv6_loopback_multiplier                          NUMERIC]
			x	[-ipv4_resolve_gateway                              CHOICES 0 1
			x                                                    DEFAULT 1]
			x	[-ipv4_manual_gateway_mac                           MAC
			x                                                    DEFAULT 0000.0000.0001]
			x	[-ipv4_manual_gateway_mac_step                      MAC
			x                                                    DEFAULT 0000.0000.0001]
			x	[-ipv4_enable_gratarprarp                           CHOICES 0 1
			x                                                    DEFAULT 0]
			x	[-ipv4_gratarprarp                                  CHOICES gratarp rarp]
			x	[-ipv6_resolve_gateway                              CHOICES 0 1
			x                                                    DEFAULT 1]
			x	[-ipv6_manual_gateway_mac                           MAC]
			x	[-ipv6_manual_gateway_mac_step                      MAC
			x                                                    DEFAULT 0000.0000.0001]
			x	[-send_ping                                         CHOICES 0 1
			x                                                    DEFAULT 0]
			x	[-ping_dst                                          ANY]
			x	[-addresses_per_svlan                               RANGE 1-1000000000
			x                                                    DEFAULT 1]
			x	[-addresses_per_vci                                 ANY]
			x	[-addresses_per_vlan                                RANGE 1-1000000000
			x                                                    DEFAULT 1]
			x	[-addresses_per_vpi                                 ANY]
			x	[-arp                                               CHOICES 0 1
			x                                                    DEFAULT 1]
			x	[-arp_on_linkup                                     CHOICES 0 1
			x                                                    DEFAULT 1]
			x	[-arp_req_retries                                   NUMERIC
			x                                                    DEFAULT 2]
			x	[-arp_req_timer                                     ANY]
			 	[-arp_send_req                                      CHOICES 0 1]
			x	[-atm_enable_coset                                  CHOICES 0 1]
			x	[-atm_enable_pattern_matching                       CHOICES 0 1]
			x	[-arp_refresh_interval                              RANGE 30-6000
			x                                                    DEFAULT 60]
			x	[-atm_encapsulation                                 ANY]
			x	[-atm_filler_cell                                   CHOICES idle unassigned]
			x	[-atm_interface_type                                CHOICES uni nni]
			x	[-atm_packet_decode_mode                            CHOICES frame cell]
			x	[-atm_reassembly_timeout                            NUMERIC]
			 	[-autonegotiation                                   CHOICES 0 1]
			x	[-auto_detect_instrumentation_type                  CHOICES end_of_frame floating
			x                                                    DEFAULT floating]
			x	[-bad_blocks_number                                 NUMERIC]
			x	[-good_blocks_number                                NUMERIC]
			x	[-loop_count_number                                 NUMERIC]
			x	[-start_error_insertion                             NUMERIC]
			x	[-bert_configuration                                ANY]
			x	[-bert_error_insertion                              ANY]
			x	[-type_a_ordered_sets                               CHOICES local_fault remote_fault]
			x	[-type_b_ordered_sets                               CHOICES local_fault remote_fault]
			x	[-send_sets_mode                                    CHOICES alternate
			x                                                    CHOICES type_a_only
			x                                                    CHOICES type_b_only]
			 	[-clocksource                                       CHOICES internal loop external]
			x	[-connected_count                                   NUMERIC
			x                                                    DEFAULT 1]
			x	[-data_integrity                                    CHOICES 0 1]
			 	[-duplex                                            CHOICES half full auto]
			 	[-framing                                           CHOICES sonet sdh]
			 	[-gateway                                           IPV4]
			x	[-gateway_incr_mode                                 CHOICES every_subnet every_interface
			x                                                    DEFAULT every_subnet]
			x	[-gateway_step                                      IPV4
			x                                                    DEFAULT 0.0.0.1]
			x	[-gre_checksum_enable                               CHOICES 0 1]
			x	[-gre_count                                         NUMERIC
			x                                                    DEFAULT 1]
			x	[-gre_dst_ip_addr                                   IP]
			x	[-gre_dst_ip_addr_step                              IP
			x                                                    DEFAULT 0.0.0.1]
			x	[-gre_ip_addr                                       ANY]
			x	[-gre_ip_addr_step                                  ANY]
			x	[-gre_ip_prefix_length                              ANY]
			x	[-gre_ipv6_addr                                     ANY]
			x	[-gre_ipv6_addr_step                                ANY]
			x	[-gre_ipv6_prefix_length                            ANY]
			x	[-gre_key_enable                                    CHOICES 0 1]
			x	[-gre_key_in                                        RANGE 0-4294967295]
			x	[-gre_key_out                                       RANGE 0-4294967295]
			x	[-gre_seq_enable                                    CHOICES 0 1]
			 	[-ignore_link                                       CHOICES 0 1
			                                                     DEFAULT 0]
			x	[-integrity_signature                               REGEXP ^[0-9a-fA-F]{2}([.: ]{0,1}){0,11}[0-9a-fA-F]{2}$]
			x	[-integrity_signature_offset                        RANGE 24-64000]
			 	[-interface_handle                                  ANY]
			 	[-internal_ppm_adjust                               RANGE -100-100]
			 	[-intf_ip_addr                                      IPV4]
			x	[-intf_ip_addr_step                                 IPV4
			x                                                    DEFAULT 0.0.0.1]
			 	[-intf_mode                                         CHOICES atm
			                                                     CHOICES pos_hdlc
			                                                     CHOICES pos_ppp
			                                                     CHOICES ethernet
			                                                     CHOICES ethernet_vm
			                                                     CHOICES multis
			                                                     CHOICES multis_fcoe
			                                                     CHOICES rame_relay1490
			                                                     CHOICES novus_10g
			                                                     CHOICES novus_10g_fcoe
			                                                     CHOICES k400g
			                                                     CHOICES k400g_fcoe
			                                                     CHOICES bert
			                                                     CHOICES frame_relay2427
			                                                     CHOICES frame_relay_cisco
			                                                     CHOICES srp
			                                                     CHOICES srp_cisco
			                                                     CHOICES rpr
			                                                     CHOICES gfp
			                                                     CHOICES ethernet_fcoe
			                                                     CHOICES fc]
			 	[-intrinsic_latency_adjustment                      CHOICES 0 1]
			 	[-ipv6_gateway                                      IPV6]
			x	[-ipv6_gateway_step                                 IPV6
			x                                                    DEFAULT 0000:0000:0000:0000:0000:0000:0000:0001]
			 	[-ipv6_intf_addr                                    IPV6]
			x	[-ipv6_intf_addr_step                               IPV6
			x                                                    DEFAULT 0000:0000:0000:0000:0000:0000:0000:0001]
			 	[-ipv6_prefix_length                                ANY]
			x	[-ipv6_addr_mode                                    CHOICES static autoconfig]
			x	[-l23_config_type                                   CHOICES protocol_interface
			x                                                    CHOICES static_endpoint
			x                                                    DEFAULT protocol_interface]
			 	[-mode                                              CHOICES config modify destroy
			                                                     DEFAULT config]
			x	[-mss                                               ANY]
			x	[-mtu                                               RANGE 68-9216
			x                                                    DEFAULT 1500]
			 	[-netmask                                           MASK]
			x	[-ndp_send_req                                      CHOICES 0 1]
			x	[-no_write                                          FLAG]
			x	[-ns_on_linkup                                      CHOICES 0 1
			x                                                    DEFAULT 0]
			 	[-op_mode                                           CHOICES loopback
			                                                     CHOICES normal
			                                                     CHOICES monitor
			                                                     CHOICES sim_disconnect]
			x	[-override_existence_check                          CHOICES 0 1
			x                                                    DEFAULT 0]
			x	[-override_tracking                                 CHOICES 0 1
			x                                                    DEFAULT 0]
			x	[-check_gateway_exists                              CHOICES 0 1
			x                                                    DEFAULT 0]
			 	[-check_opposite_ip_version                         CHOICES 0 1
			                                                     DEFAULT 1]
			x	[-pcs_period                                        NUMERIC]
			x	[-pcs_count                                         NUMERIC]
			x	[-pcs_repeat                                        NUMERIC]
			x	[-pcs_period_type                                   NUMERIC]
			x	[-pcs_lane                                          NUMERIC]
			x	[-pcs_enabled_continuous                            CHOICES 0 1]
			x	[-pcs_sync_bits                                     ANY]
			x	[-pcs_marker_fields                                 ANY]
			x	[-pgid_128k_bin_enable                              CHOICES 0 1]
			x	[-pgid_mask                                         ANY]
			x	[-pgid_offset                                       RANGE 4-32677]
			x	[-pgid_mode                                         CHOICES custom
			x                                                    CHOICES dscp
			x                                                    CHOICES ipv6TC
			x                                                    CHOICES mplsExp
			x                                                    CHOICES split
			x                                                    CHOICES outer_vlan_priority
			x                                                    CHOICES outer_vlan_id_4
			x                                                    CHOICES outer_vlan_id_6
			x                                                    CHOICES outer_vlan_id_8
			x                                                    CHOICES outer_vlan_id_10
			x                                                    CHOICES outer_vlan_id_12
			x                                                    CHOICES inner_vlan_priority
			x                                                    CHOICES inner_vlan_id_4
			x                                                    CHOICES inner_vlan_id_6
			x                                                    CHOICES inner_vlan_id_8
			x                                                    CHOICES inner_vlan_id_10
			x                                                    CHOICES inner_vlan_id_12
			x                                                    CHOICES tos_precedence
			x                                                    CHOICES ipv6TC_bits_0_2
			x                                                    CHOICES ipv6TC_bits_0_5]
			x	[-pgid_encap                                        CHOICES LLCRoutedCLIP
			x                                                    CHOICES LLCPPPoA
			x                                                    CHOICES LLCBridgedEthernetFCS
			x                                                    CHOICES LLCBridgedEthernetNoFCS
			x                                                    CHOICES VccMuxPPPoA
			x                                                    CHOICES VccMuxIPV4Routed
			x                                                    CHOICES VccMuxBridgedEthernetFCS
			x                                                    CHOICES VccMuxBridgedEthernetNoFCS]
			x	[-pgid_split1_mask                                  ANY]
			x	[-pgid_split1_offset                                NUMERIC]
			x	[-pgid_split1_offset_from                           CHOICES start_of_frame]
			x	[-pgid_split2_mask                                  ANY]
			x	[-pgid_split2_offset                                NUMERIC]
			x	[-pgid_split2_offset_from                           CHOICES start_of_frame]
			x	[-pgid_split2_width                                 RANGE 0-4]
			x	[-pgid_split3_mask                                  ANY]
			x	[-pgid_split3_offset                                NUMERIC]
			x	[-pgid_split3_offset_from                           CHOICES start_of_frame]
			x	[-pgid_split3_width                                 RANGE 0-4]
			 	[-phy_mode                                          CHOICES copper fiber sgmii]
			x	[-master_slave_mode                                 CHOICES auto master slave
			x                                                    DEFAULT auto]
			x	[-port_rx_mode                                      REGEXP ^( *{{0,1} *(capture_and_measure|capture|echo|packet_group|data_integrity|sequence_checking|wide_packet_group|auto_detect_instrumentation) *}{0,1} *)+$
			x                                                    CHOICES capture
			x                                                    CHOICES packet_group
			x                                                    CHOICES data_integrity
			x                                                    CHOICES sequence_checking
			x                                                    CHOICES wide_packet_group
			x                                                    CHOICES echo
			x                                                    CHOICES auto_detect_instrumentation
			x                                                    CHOICES capture_and_measure]
			x	[-ppp_ipv4_address                                  IPV4]
			x	[-ppp_ipv4_negotiation                              CHOICES 0 1]
			x	[-ppp_ipv6_negotiation                              CHOICES 0 1]
			x	[-ppp_mpls_negotiation                              CHOICES 0 1]
			x	[-ppp_osi_negotiation                               CHOICES 0 1]
			x	[-pvc_incr_mode                                     ANY]
			x	[-qinq_incr_mode                                    CHOICES inner outer both
			x                                                    DEFAULT both]
			x	[-qos_byte_offset                                   RANGE 0-63]
			x	[-qos_packet_type                                   CHOICES ethernet
			x                                                    CHOICES ip_snap
			x                                                    CHOICES vlan
			x                                                    CHOICES custom
			x                                                    CHOICES ip_ppp
			x                                                    CHOICES ip_cisco_hdlc
			x                                                    CHOICES ip_atm]
			x	[-qos_pattern_mask                                  ANY]
			x	[-qos_pattern_match                                 ANY]
			x	[-qos_pattern_offset                                RANGE 0-65535]
			x	[-qos_stats                                         CHOICES 0 1]
			x	[-router_solicitation_retries                       RANGE 1-100
			x                                                    DEFAULT 2]
			x	[-rpr_hec_seed                                      CHOICES 0 1]
			 	[-rx_c2                                             ANY]
			 	[-rx_fcs                                            CHOICES 16 32]
			 	[-rx_scrambling                                     CHOICES 0 1]
			x	[-send_router_solicitation                          CHOICES 0 1]
			x	[-sequence_checking                                 CHOICES 0 1]
			x	[-sequence_num_offset                               RANGE 24-64000]
			x	[-signature                                         REGEXP ^[0-9a-fA-F]{2}([.: ]{0,1}){0,11}[0-9a-fA-F]{2}$]
			x	[-signature_mask                                    REGEXP ^[0-9a-fA-F]{2}([.: ]{0,1}){0,11}[0-9a-fA-F]{2}$]
			x	[-signature_offset                                  RANGE 24-64000]
			x	[-signature_start_offset                            RANGE 0-64000]
			x	[-single_arp_per_gateway                            CHOICES 0 1
			x                                                    DEFAULT 1]
			x	[-single_ns_per_gateway                             CHOICES 0 1
			x                                                    DEFAULT 1]
			x	[-speed_autonegotiation                             CHOICES ether100
			x                                                    CHOICES ether1000
			x                                                    CHOICES ether2.5Gig
			x                                                    CHOICES ether5Gig
			x                                                    CHOICES ether10Gig
			x                                                    CHOICES ether10000lan]
			 	[-speed                                             CHOICES ether10
			                                                     CHOICES ether100
			                                                     CHOICES ether1000
			                                                     CHOICES oc3
			                                                     CHOICES oc12
			                                                     CHOICES oc48
			                                                     CHOICES oc192
			                                                     CHOICES auto
			                                                     CHOICES ether10000wan
			                                                     CHOICES ether10000lan
			                                                     CHOICES ether40000lan
			                                                     CHOICES ether100000lan
			                                                     CHOICES ether2.5Gig
			                                                     CHOICES ether5Gig
			                                                     CHOICES ether10Gig
			                                                     CHOICES ether25Gig
			                                                     CHOICES ether40Gig
			                                                     CHOICES ether50Gig
			                                                     CHOICES ether100Gig
			                                                     CHOICES ether200Gig
			                                                     CHOICES ether400Gig
			                                                     CHOICES fc2000
			                                                     CHOICES fc4000
			                                                     CHOICES fc8000
			                                                     CHOICES ether100vm
			                                                     CHOICES ether1000vm
			                                                     CHOICES ether2000vm
			                                                     CHOICES ether3000vm
			                                                     CHOICES ether4000vm
			                                                     CHOICES ether5000vm
			                                                     CHOICES ether6000vm
			                                                     CHOICES ether7000vm
			                                                     CHOICES ether8000vm
			                                                     CHOICES ether9000vm
			                                                     CHOICES ether10000vm]
			 	[-src_mac_addr                                      MAC]
			x	[-src_mac_addr_step                                 MAC
			x                                                    DEFAULT 0000.0000.0001]
			x	[-target_link_layer_address                         ANY]
			 	[-transmit_clock_source                             CHOICES internal
			                                                     CHOICES bits
			                                                     CHOICES loop
			                                                     CHOICES external
			                                                     CHOICES internal_ppm_adj]
			x	[-transmit_mode                                     CHOICES advanced
			x                                                    CHOICES stream
			x                                                    CHOICES advanced_coarse
			x                                                    CHOICES stream_coarse]
			 	[-tx_c2                                             ANY]
			 	[-tx_fcs                                            CHOICES 16 32]
			 	[-tx_rx_sync_stats_enable                           CHOICES 0 1]
			 	[-tx_rx_sync_stats_interval                         NUMERIC]
			 	[-tx_scrambling                                     CHOICES 0 1]
			x	[-vci                                               ANY]
			x	[-vci_count                                         ANY]
			x	[-vci_step                                          ANY]
			 	[-vlan                                              CHOICES 0 1]
			x	[-vlan_id                                           REGEXP ^[0-9]{1,4}(,[0-9]{1,4}){0,5}$
			x                                                    RANGE 0-4096]
			x	[-vlan_id_step                                      REGEXP ^[0-9]{1,4}(,[0-9]{1,4}){0,5}$
			x                                                    RANGE 0-4096
			x                                                    DEFAULT 1]
			x	[-vlan_id_count                                     REGEXP ^[0-9]{1,4}(,[0-9]{1,4}){0,5}$
			x                                                    RANGE 1-4094
			x                                                    DEFAULT 4094]
			x	[-vlan_tpid                                         CHOICES 0x8100
			x                                                    CHOICES 0x88a8
			x                                                    CHOICES 0x88A8
			x                                                    CHOICES 0x9100
			x                                                    CHOICES 0x9200
			x                                                    CHOICES 0x9300
			x                                                    DEFAULT 0x8100]
			x	[-vlan_user_priority                                REGEXP ^[0-7](,[0-7]){0,5}$
			x                                                    RANGE 0-7
			x                                                    DEFAULT 0]
			x	[-vlan_user_priority_step                           REGEXP ^[0-7](,[0-7]){0,5}$
			x                                                    RANGE 0-7
			x                                                    DEFAULT 1]
			x	[-vlan_id_list                                      REGEXP ^[0-9]{1,4}(,[0-9]{1,4}){0,5}$
			x                                                    RANGE 0-4096]
			x	[-vlan_id_mode                                      CHOICES fixed increment]
			x	[-vlan_protocol_id                                  CHOICES 0x8100
			x                                                    CHOICES 0x88a8
			x                                                    CHOICES 0x88A8
			x                                                    CHOICES 0x9100
			x                                                    CHOICES 0x9200
			x                                                    CHOICES 0x9300]
			x	[-vlan_id_inner                                     REGEXP ^[0-9]{1,4}(,[0-9]{1,4}){0,5}$
			x                                                    RANGE 0-4096]
			x	[-vlan_id_inner_mode                                CHOICES fixed increment]
			x	[-vlan_id_inner_count                               RANGE 1-4096]
			x	[-vlan_id_inner_step                                RANGE 0-4096
			x                                                    DEFAULT 1]
			x	[-use_vpn_parameters                                CHOICES 0 1]
			x	[-site_id                                           NUMERIC]
			x	[-vpi                                               ANY]
			x	[-vpi_count                                         ANY]
			x	[-vpi_step                                          ANY]
			x	[-enable_rs_fec                                     CHOICES 0 1
			x                                                    CHOICES 0 1]
			x	[-enable_rs_fec_statistics                          CHOICES 0 1
			x                                                    CHOICES 0 1]
			x	[-firecode_request                                  CHOICES 0 1
			x                                                    CHOICES 0 1]
			x	[-firecode_advertise                                CHOICES 0 1
			x                                                    CHOICES 0 1]
			x	[-firecode_force_on                                 CHOICES 0 1
			x                                                    CHOICES 0 1]
			x	[-firecode_force_off                                CHOICES 0 1
			x                                                    CHOICES 0 1]
			x	[-request_rs_fec                                    CHOICES 0 1
			x                                                    CHOICES 0 1]
			x	[-advertise_rs_fec                                  CHOICES 0 1
			x                                                    CHOICES 0 1]
			x	[-force_enable_rs_fec                               CHOICES 0 1
			x                                                    CHOICES 0 1]
			x	[-use_an_results                                    CHOICES 0 1
			x                                                    CHOICES 0 1]
			x	[-force_disable_fec                                 CHOICES 0 1
			x                                                    CHOICES 0 1]
			x	[-link_training                                     CHOICES 0 1
			x                                                    CHOICES 0 1]
			x	[-ieee_media_defaults                               CHOICES 0 1
			x                                                    CHOICES 0 1]
			x	[-loop_continuously                                 CHOICES 0 1
			x                                                    CHOICES 0 1]
			x	[-enable_flow_control                               CHOICES 0 1
			x                                                    CHOICES 0 1
			x                                                    DEFAULT 1]
			x	[-enable_ndp                                        CHOICES 0 1
			x                                                    DEFAULT 1]
			x	[-flow_control_directed_addr                        ANY]
			x	[-fcoe_priority_groups                              ANY]
			 	[-fcoe_support_data_center_mode                     CHOICES 0 1]
			x	[-fcoe_priority_group_size                          CHOICES 4 8]
			x	[-fcoe_flow_control_type                            CHOICES ieee802.3x ieee802.1Qbb]
			x	[-fc_credit_starvation_value                        NUMERIC
			x                                                    DEFAULT 0]
			x	[-fc_no_rrdy_after                                  NUMERIC
			x                                                    DEFAULT 100]
			x	[-fc_tx_ignore_rx_link_faults                       ANY]
			x	[-tx_ignore_rx_link_faults                          CHOICES 0 1]
			x	[-clause73_autonegotiation                          CHOICES 0 1]
			x	[-laser_on                                          CHOICES 0 1]
			x	[-fc_max_delay_for_random_value                     RANGE 0-1000000
			x                                                    DEFAULT 0]
			x	[-fc_tx_ignore_available_credits                    CHOICES 0 1
			x                                                    DEFAULT 0]
			x	[-fc_min_delay_for_random_value                     NUMERIC
			x                                                    DEFAULT 0]
			x	[-fc_rrdy_response_delays                           CHOICES credit_starvation
			x                                                    CHOICES fixed_delay
			x                                                    CHOICES no_delay
			x                                                    CHOICES random_delay
			x                                                    DEFAULT no_delay]
			x	[-fc_fixed_delay_value                              RANGE 0-20000
			x                                                    DEFAULT 1]
			x	[-fc_force_errors                                   CHOICES no_errors
			x                                                    CHOICES no_rrdy
			x                                                    CHOICES no_rrdy_every
			x                                                    DEFAULT no_errors]
			x	[-enable_data_center_shared_stats                   CHOICES 0 1]
			x	[-additional_fcoe_stat_1                            CHOICES fcoe_invalid_delimiter
			x                                                    CHOICES fcoe_invalid_frames
			x                                                    CHOICES fcoe_invalid_size
			x                                                    CHOICES fcoe_normal_size_bad_fc_crc
			x                                                    CHOICES fcoe_normal_size_good_fc_crc
			x                                                    CHOICES fcoe_undersize_bad_fc_crc
			x                                                    CHOICES fcoe_undersize_good_fc_crc
			x                                                    CHOICES fcoe_valid_frames]
			x	[-additional_fcoe_stat_2                            CHOICES fcoe_invalid_delimiter
			x                                                    CHOICES fcoe_invalid_frames
			x                                                    CHOICES fcoe_invalid_size
			x                                                    CHOICES fcoe_normal_size_bad_fc_crc
			x                                                    CHOICES fcoe_normal_size_good_fc_crc
			x                                                    CHOICES fcoe_undersize_bad_fc_crc
			x                                                    CHOICES fcoe_undersize_good_fc_crc
			x                                                    CHOICES fcoe_valid_frames]
			x	[-tx_gap_control_mode                               CHOICES fixed average]
			x	[-tx_lanes                                          ANY]
			 	[-static_enable                                     CHOICES 0 1
			                                                     DEFAULT 0]
			 	[-static_atm_header_encapsulation                   ANY]
			 	[-static_atm_range_count                            ANY]
			 	[-static_vci                                        ANY]
			 	[-static_vci_increment                              ANY]
			 	[-static_vci_increment_step                         ANY]
			 	[-static_vci_step                                   ANY]
			 	[-static_pvc_count                                  ANY]
			 	[-static_pvc_count_step                             ANY]
			 	[-static_vpi                                        ANY]
			 	[-static_vpi_increment                              ANY]
			 	[-static_vpi_increment_step                         ANY]
			 	[-static_vpi_step                                   ANY]
			 	[-static_dlci_count_mode                            ANY]
			 	[-static_dlci_repeat_count                          ANY]
			 	[-static_dlci_repeat_count_step                     ANY]
			 	[-static_dlci_value                                 ANY]
			 	[-static_dlci_value_step                            ANY]
			 	[-static_fr_range_count                             ANY]
			 	[-static_intf_handle                                ANY]
			 	[-static_ip_dst_count                               RANGE 1-4294967295
			                                                     DEFAULT 1]
			 	[-static_ip_dst_count_step                          NUMERIC
			                                                     DEFAULT 0]
			 	[-static_ip_dst_addr                                IP
			                                                     DEFAULT 0.0.0.0]
			 	[-static_ip_dst_increment                           IP
			                                                     DEFAULT 0.0.0.1]
			 	[-static_ip_dst_increment_step                      IP
			                                                     DEFAULT 0.0.0.0]
			 	[-static_ip_dst_range_step                          IP
			                                                     DEFAULT 0.0.0.0]
			 	[-static_ip_dst_prefix_len                          RANGE 0-128
			                                                     DEFAULT 24]
			 	[-static_ip_dst_prefix_len_step                     NUMERIC
			                                                     DEFAULT 0]
			 	[-static_ip_range_count                             NUMERIC
			                                                     DEFAULT 0]
			 	[-static_l3_protocol                                CHOICES ipv4 ipv6
			                                                     DEFAULT ipv4]
			 	[-static_indirect                                   ANY]
			 	[-static_range_per_spoke                            ANY]
			x	[-static_lan_intermediate_objref                    ANY]
			 	[-static_lan_range_count                            NUMERIC
			                                                     DEFAULT 0]
			 	[-static_mac_dst                                    MAC
			                                                     DEFAULT 0000.0000.0000]
			 	[-static_mac_dst_count                              RANGE 1-4294967295
			                                                     DEFAULT 1]
			 	[-static_mac_dst_count_step                         NUMERIC
			                                                     DEFAULT 0]
			 	[-static_mac_dst_mode                               CHOICES fixed increment
			                                                     DEFAULT increment]
			 	[-static_mac_dst_step                               NUMERIC
			                                                     DEFAULT 0]
			 	[-static_site_id                                    RANGE 0-4294967295
			                                                     DEFAULT 0]
			 	[-static_site_id_enable                             CHOICES 0 1
			                                                     DEFAULT 0]
			 	[-static_site_id_step                               NUMERIC
			                                                     DEFAULT 0]
			 	[-static_vlan_enable                                ANY
			                                                     DEFAULT 0]
			 	[-static_vlan_id                                    RANGE 1-4095
			                                                     DEFAULT 1]
			 	[-static_vlan_id_mode                               CHOICES fixed increment inner outer
			                                                     DEFAULT fixed]
			 	[-static_vlan_id_step                               ANY
			                                                     DEFAULT 0]
			x	[-static_lan_count_per_vc                           NUMERIC
			x                                                    DEFAULT 1]
			x	[-static_lan_incr_per_vc_vlan_mode                  CHOICES fixed increment inner outer
			x                                                    DEFAULT fixed]
			x	[-static_lan_mac_range_mode                         CHOICES normal bundled
			x                                                    DEFAULT normal]
			x	[-static_lan_number_of_vcs                          NUMERIC
			x                                                    DEFAULT 1]
			x	[-static_lan_skip_vlan_id_zero                      CHOICES 0 1
			x                                                    DEFAULT 1]
			x	[-static_lan_tpid                                   CHOICES 0x8100
			x                                                    CHOICES 0x88a8
			x                                                    CHOICES 0x88A8
			x                                                    CHOICES 0x9100
			x                                                    CHOICES 0x9200
			x                                                    DEFAULT 0x8100]
			x	[-static_lan_vlan_priority                          RANGE 0-7
			x                                                    DEFAULT 0]
			x	[-static_lan_vlan_stack_count                       NUMERIC
			x                                                    DEFAULT 1]
			x	[-static_ig_atm_encap                               ANY]
			x	[-static_ig_vlan_enable                             ANY]
			x	[-static_ig_ip_type                                 ANY]
			x	[-static_ig_interface_enable_list                   ANY]
			x	[-static_ig_interface_handle_list                   ANY]
			x	[-static_ig_range_count                             ANY]
			x	[-pgid_split1_width                                 RANGE 0-4]
			n	[-aps                                               ANY]
			n	[-aps_arch                                          ANY]
			n	[-aps_channel                                       ANY]
			n	[-aps_request_1_1                                   ANY]
			n	[-aps_request_1_n                                   ANY]
			n	[-aps_switch_mode                                   ANY]
			n	[-auto_line_rdi                                     ANY]
			n	[-auto_line_rei                                     ANY]
			n	[-auto_path_rdi                                     ANY]
			n	[-auto_path_rei                                     ANY]
			n	[-crlf_path_trace                                   ANY]
			n	[-control_plane_mtu                                 ANY]
			n	[-dst_mac_addr                                      ANY]
			n	[-ignore_pause_frames                               ANY]
			n	[-interpacket_gap                                   ANY]
			n	[-long_lof_wait                                     ANY]
			n	[-output_enable                                     ANY]
			n	[-pause_length                                      ANY]
			n	[-rx_enhanced_prdi                                  ANY]
			n	[-rx_equalization                                   ANY]
			n	[-rx_hec                                            ANY]
			n	[-section_unequip                                   ANY]
			n	[-signal_fail_ber                                   ANY]
			n	[-ss_bits_pointer_interp                            ANY]
			n	[-tx_enhanced_prdi                                  ANY]
			n	[-tx_k2                                             ANY]
			n	[-tx_preemphasis_main_tap                           ANY]
			n	[-tx_preemphasis_post_tap                           ANY]
			n	[-tx_s1                                             ANY]
			x	[-ethernet_attempt_enabled                          CHOICES 0 1]
			x	[-ethernet_attempt_rate                             RANGE 1-1000]
			x	[-ethernet_attempt_interval                         NUMERIC]
			x	[-ethernet_attempt_scale_mode                       CHOICES port device_group
			x                                                    DEFAULT port]
			x	[-ethernet_diconnect_enabled                        CHOICES 0 1]
			x	[-ethernet_disconnect_rate                          RANGE 1-1000]
			x	[-ethernet_disconnect_interval                      NUMERIC]
			x	[-ethernet_disconnect_scale_mode                    CHOICES port device_group
			x                                                    DEFAULT port]
			x	[-ipv4_send_arp_rate                                RANGE 1-1000]
			x	[-ipv4_send_arp_interval                            NUMERIC]
			x	[-ipv4_send_arp_max_outstanding                     RANGE 1-1000]
			x	[-ipv4_send_arp_scale_mode                          CHOICES port device_group
			x                                                    DEFAULT port]
			x	[-ipv4_attempt_enabled                              CHOICES 0 1]
			x	[-ipv4_attempt_rate                                 RANGE 1-1000]
			x	[-ipv4_attempt_interval                             NUMERIC]
			x	[-ipv4_attempt_scale_mode                           CHOICES port device_group
			x                                                    DEFAULT port]
			x	[-ipv4_diconnect_enabled                            CHOICES 0 1]
			x	[-ipv4_disconnect_rate                              RANGE 1-1000]
			x	[-ipv4_disconnect_interval                          NUMERIC]
			x	[-ipv4_disconnect_scale_mode                        CHOICES port device_group
			x                                                    DEFAULT port]
			x	[-ipv6_send_ns_rate                                 RANGE 1-1000]
			x	[-ipv6_send_ns_interval                             NUMERIC]
			x	[-ipv6_send_ns_max_outstanding                      RANGE 1-1000]
			x	[-ipv6_send_ns_scale_mode                           CHOICES port device_group
			x                                                    DEFAULT port]
			x	[-ipv6_attempt_enabled                              CHOICES 0 1]
			x	[-ipv6_attempt_rate                                 RANGE 1-1000]
			x	[-ipv6_attempt_interval                             NUMERIC]
			x	[-ipv6_attempt_scale_mode                           CHOICES port device_group
			x                                                    DEFAULT port]
			x	[-ipv6_diconnect_enabled                            CHOICES 0 1]
			x	[-ipv6_disconnect_rate                              RANGE 1-1000]
			x	[-ipv6_disconnect_interval                          NUMERIC]
			x	[-ipv6_disconnect_scale_mode                        CHOICES port device_group
			x                                                    DEFAULT port]
			x	[-ipv6_autoconfiguration_send_ns_enabled            CHOICES 0 1]
			x	[-ipv6_autoconfiguration_send_ns_rate               RANGE 1-1000]
			x	[-ipv6_autoconfiguration_send_ns_interval           NUMERIC]
			x	[-ipv6_autoconfiguration_send_ns_max_outstanding    RANGE 1-1000]
			x	[-ipv6_autoconfiguration_send_ns_scale_mode         CHOICES port device_group
			x                                                    DEFAULT port]
			x	[-ipv6_autoconfiguration_send_rs_enabled            CHOICES 0 1]
			x	[-ipv6_autoconfiguration_send_rs_rate               RANGE 1-1000]
			x	[-ipv6_autoconfiguration_send_rs_interval           NUMERIC]
			x	[-ipv6_autoconfiguration_send_rs_max_outstanding    RANGE 1-1000]
			x	[-ipv6_autoconfiguration_send_rs_scale_mode         CHOICES port device_group
			x                                                    DEFAULT port]
			x	[-ipv6_autoconfiguration_attempt_enabled            CHOICES 0 1]
			x	[-ipv6_autoconfiguration_attempt_rate               RANGE 1-1000]
			x	[-ipv6_autoconfiguration_attempt_interval           NUMERIC]
			x	[-ipv6_autoconfiguration_attempt_max_outstanding    RANGE 1-1000]
			x	[-ipv6_autoconfiguration_attempt_scale_mode         CHOICES port device_group
			x                                                    DEFAULT port]
			x	[-ipv6_autoconfiguration_disconnect_enabled         CHOICES 0 1]
			x	[-ipv6_autoconfiguration_disconnect_rate            RANGE 1-1000]
			x	[-ipv6_autoconfiguration_disconnect_interval        NUMERIC]
			x	[-ipv6_autoconfiguration_disconnect_max_outstanding RANGE 1-1000]
			x	[-ipv6_autoconfiguration_disconnect_scale_mode      CHOICES port device_group
			x                                                    DEFAULT port]
			x	[-notify_mac_move                                   CHOICES 0 1]
			x	[-ipv4_re_send_arp_on_link_up                       ANY]
			x	[-ipv4_permanent_mac_for_gateway                    ANY]
			x	[-ipv4_gratarp_transmit_count                       ANY]
			x	[-ipv4_gratarp_transmit_interval                    ANY]
			x	[-ipv4_rarp_transmit_count                          ANY]
			x	[-ipv4_rarp_transmit_interval                       ANY]
			x	[-ipv6_re_send_ns_on_link_up                        ANY]
			x	[-ipv6_permanent_mac_for_gateway                    ANY]
		
		Arguments:
			 	-port_handle
			 		List of ports of which to take ownership and perform configuration.
			 		This option takes a list of port handles.
			x	-protocol_name
			x		This is the name of the protocol stack as it appears in the GUI.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-protocol_handle
			x		Handle for the stack that the user wants to modify or delete.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_loopback
			x		This argument can be used to trigger the addition of loopback
			x		IPv4 or IPv6 protocols instead of the usual ones.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-connected_to_handle
			x		A handle to another ethernet or loopback stack through which the current
			x		protocol stack will be connected.
			x		This argument will be ignored if the current protocol stack does not support
			x		connectors.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_multiplier
			x		This is the multiplier for the IPv4 stack as its used in the custom ratios.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_loopback_multiplier
			x		This is the multiplier for the IPv4 loopback stack as its used in the custom ratios.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_multiplier
			x		This is the multiplier for the IPv6 stack as its used in the custom ratios.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_loopback_multiplier
			x		This is the multiplier for the IPv6 loopback stack as its used in the custom ratios.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_resolve_gateway
			x		Autoresolve gateway MAC addresses.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_manual_gateway_mac
			x		The manual gateway MAC addresses.
			x		This option has no effect unless ipv4_autoresolve_gateway_mac is set to 0.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_manual_gateway_mac_step
			x		The step of the manual gateway MAC addresses.
			x		This option has no effect unless ipv4_autoresolve_gateway_mac is set to 0.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_enable_gratarprarp
			x		Enable GRATARP or RARP.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_gratarprarp
			x		Indicates the type of packet to be transmitted - GRATARP or RARP.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		gratarp - Indicates GRATARP packet is going to be transmitted.
			x   		rarp - Indicates RARP packet is going to be transmitted.
			x	-ipv6_resolve_gateway
			x		Autoresolve gateway MAC addresses.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_manual_gateway_mac
			x		The manual gateway MAC addresses.
			x		This option has no effect unless ipv6_resolve_gateway is set to 0.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_manual_gateway_mac_step
			x		The step of the manual gateway MAC addresses.
			x		This option has no effect unless ipv6_resolve_gateway is set to 0.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-send_ping
			x		Sends ping from the specified interfaces or protocol handles
			x		to the destination specified in ping_dst.
			x		This argument will have no effect if no ping_dst is specified.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ping_dst
			x		Specifies what destination to ping.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-addresses_per_svlan
			x		How often a new outer VLAN ID is generated.
			x		This parameter is valid only when l23_config_type is static_endpoint (new API).
			x	-addresses_per_vci
			x		How often a new VCI value is generated. This parameter is valid only when l23_config_type is static_endpoint (new API).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-addresses_per_vlan
			x		How often a new VLAN ID/inner VLAN ID is generated.
			x		This parameter is valid only when l23_config_type is static_endpoint (new API).
			x	-addresses_per_vpi
			x		How often a new VPI value is generated. This parameter is valid only when l23_config_type is static_endpoint (new API).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-arp
			x		Enables or disables the -arp_send_req parameter. If this is 0 -arp_send_req will be ignored.
			x	-arp_on_linkup
			x		Send ARP for the IPv4 interfaces when the port link becomes up.
			x		The option is global, for all ports and interfaces.
			x		This is valid only for the new API.
			x	-arp_req_retries
			x		The number of times the arp request will be attempted.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x	-arp_req_timer
			x		(deprecated) The value has no effect on the code.It was left in so as not to break existing scripts that attempt to use it.This option takes a list of values when -port_handle is a list of port handles.This option is valid for the old and the new APIs.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-arp_send_req
			 		Whether sending an ARP request to the DUT is enabled. You can use this
			 		basic function to ensure correct addressing of the interfaces. By
			 		default, the ARP is sent on the Ethernet port.
			 		For IPv4 interfaces the arp request is sent to the gateway.
			 		For IPv6 interfaces a router solicitation is sent to 'all routers'
			 		multicast address.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid options are:
			 		0 - Disable (DEFAULT).
			 		1 - Enable.
			x	-atm_enable_coset
			x		If 1, enables the Coset algorithm to be used with the Header Error
			x		Control (HEC) byte.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x	-atm_enable_pattern_matching
			x		If 1, then the use of capture and filter based on ATM patterns is
			x		enabled and the maximum number of VCCs is reduced to 12,288.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x	-arp_refresh_interval
			x		A user configurable ARP refresh timer
			x	-atm_encapsulation
			x		Sets atm encapsulation type for ports that support ATM feature. This option takes a list of values when -port_handle is a list of port handles.This option is valid for the old and the new APIs.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-atm_filler_cell
			x		SONET frame transmission is continuous even when data or control
			x		messages are not being transmitted.This option allows the cell
			x		type that is transmitted during these intervals.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		Valid choices are:
			x   		idle - (default) idle cells are transmitted with VPI/VCI = 0/0 and CLP = 0.
			x   		unassigned - unassigned cells are transmitted with VPI/VCI = 0/0 and CLP = 0.
			x	-atm_interface_type
			x		The type of interface to emulate.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles. Valid choices are:
			x		uni - (default) user to network interface
			x		nni - network to network interface
			x		Valid choices are:
			x   		uni -
			x   		nni -
			x	-atm_packet_decode_mode
			x		This setting controls the interpretation of received packets when
			x		they are decoded.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		Valid choices are:
			x   		frame - (default) Decode the packet as a frame.
			x   		cell - Decode the packet as an ATM cell.
			x	-atm_reassembly_timeout
			x		Sets the value for the Reassembly Timeout, which is the period of time
			x		(expressed in seconds) that the receive side will wait for another cell
			x		on that channel - for reassembly of cells into a CPCS PDU (packet).If
			x		no cell is received within that period, the timer will expire.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			 	-autonegotiation
			 		Whether to enable auto-negotiation on each interface.
			 		When the new IxNetwork TCL API is used and the autonegotiation is
			 		enabled, the autonegotiation is performed using all the existing
			 		Ethernet speed/duplex combinations: 1000, 100full, 100half, 10full
			 		and 10half. The feature from HLTAPI 2.90, which allowed the user to
			 		select only a subset of speed/duplex combinations to be used in the
			 		autonegotiation process, is not supported by IxNetwork at this moment.
			 		If the autonegotition is enabled, the speed and duplex options are
			 		ignored.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid options are:
			 		0 - Disable
			 		1 - Enable (DEFAULT)
			x	-auto_detect_instrumentation_type
			x		How to insert the instrumentation signature. Valid only is port_rx_mode is auto_detect_instrumentation.
			x		Valid only for the new API (IxTclNetwork).
			x		Valid choices are:
			x   		end_of_frame - the timestamp and data integrity CRC will be inserted at the end of the frame before the CRC
			x   		floating - (default) the timestamp is part of an automatic instrumentation header.
This mode should be used when the packet may get truncated or has padding. This is the IxTclProtocol equivalent.
			x	-bad_blocks_number
			x		The number of contiguous 66-bit blocks with errors to insert between bad blocks.
			x	-good_blocks_number
			x		The number of contiguous 66-bit blocks without errors to insert between bad blocks.
			x	-loop_count_number
			x		L1 config parameter that counts the number of times the series will loop.
			x	-start_error_insertion
			x		L1 config parameter that starts/stops the error insertion for the contiguous 66-bit blocks.
			x	-bert_configuration
			x		This option takes a list of physical lanes . This parameter is valid only with IxTclHal api.It has the following structure:
			x		<phy_lane>:<tx_pattern>,<tx_invert>,<rx_pattern>,<rx_invert>,<enable_stats>|....
			x		phy_lane - physical lane, it can take values from 0A-9A,0B-9B for 100Gig ports, and 0A-3A for 40Gig ports.
			x		tx_pattern - If set, indicates that the transmitted pattern is to be inverted. Valid options are:
			x		PRBS-31 - the 2^31 pattern as specified in ITU-T0151 is expected
			x		PRBS-23 - the 2^23 pattern as specified in ITU-T0151 is expected
			x		PRBS-20 - the 2^20 pattern as specified in ITU-T0151 is expected
			x		PRBS-15 - the 2^15 pattern as specified in ITU-T0151 is expected
			x		PRBS-11 - the 2^11 pattern as specified in ITU-T0151 is expected
			x		PRBS-9 - the 2^9 pattern as specified in ITU-T0151 is expected
			x		PRBS-7 - the 2^7 pattern as specified in ITU-T0151 is expected
			x		lane_detection - used to detect the lane pattern and how the lanes are connected between ports
			x		alternating - alternating ones and zeroes are expected
			x		all1 - all ones are expected
			x		tx_invert - If set, indicates that the transmitted pattern is to be inverted. Valid options are:
			x		0 - disable
			x		1- enable
			x		(default = disable)
			x		rx_pattern - If set, indicates the expected receive pattern. Valid options are:
			x		PRBS-31 - the 2^31 pattern as specified in ITU-T0151 is expected
			x		PRBS-23 - the 2^23 pattern as specified in ITU-T0151 is expected
			x		PRBS-20 - the 2^20 pattern as specified in ITU-T0151 is expected
			x		PRBS-15 - the 2^15 pattern as specified in ITU-T0151 is expected
			x		PRBS-11 - the 2^11 pattern as specified in ITU-T0151 is expected
			x		PRBS-9 - the 2^9 pattern as specified in ITU-T0151 is expected
			x		PRBS-7 - the 2^7 pattern as specified in ITU-T0151 is expected
			x		auto_detect - the pattern is automatically detected by the receiver.
			x		alternating - alternating ones and zeroes are expected.
			x		all1 - all ones are expected.
			x		rx_invert -If txRxPatternMode is set to independent, this indicates that the expected receive
			x		pattern is to be inverted. Valid options are:
			x		0 - disable
			x		1 - enable
			x		(default = disable)
			x		enable_stats - Only applicable when bert mode is active. If set, enables BERT lane
			x		statistics to be collected. Valid options are:
			x		0 - disable
			x		1 - enable
			x		(default = disable)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-bert_error_insertion
			x		This command is used to configure the insertion of deliberate errors on a port. It takes
			x		a list of physical lanes for the error insertion. This parameter is valid only with IxTclHal api. It has the following structure:
			x		<phy_lane>:<single_error>,<error_bit_rate>,<error_bit_rate_unit>,<insert>|....
			x		phy_lane - physical lane, it can take values from 0A-9A,0B-9B for 100Gig ports, and 0A-3A for 40Gig ports.
			x		single_error - insert single error value
			x		error_bit_rate - a 32-bit mask, expressed as a list of four one-byte
			x		elements, which indicates which bit in a 32-bit word is to be errored.
			x		(default = 1)
			x		error_bit_rate_unit - During continuous burst rate situations, this is the error rate. Valid options are:
			x		e-2 - An error is inserted every 2^2 (4) bits.
			x		e-3 - An error is inserted every 2^3 (8) bits.
			x		e-4 - An error is inserted every 2^4 (16) bits.
			x		e-5 - An error is inserted every 2^5 (32) bits.
			x		e-6 - An error is inserted every 2^6 (64) bits.
			x		e-7 - An error is inserted every 2^7 (128) bits.
			x		e-8 - An error is inserted every 2^8 (256) bits.
			x		e-9 - An error is inserted every 2^9 (512) bits.
			x		e-10 - An error is inserted every 2^10 (1024) bits.
			x		e-11 - An error is inserted every 2^11 (2048) bits.
			x		insert - choose whether to insert the error or not
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-type_a_ordered_sets
			x		L1 config parameter that indicates whether the type should insert a local error, a remote error or a custom ordered set.
			x		Valid choices are:
			x   		local_fault -
			x   		remote_fault -
			x	-type_b_ordered_sets
			x		L1 config parameter that indicates whether the type should insert a local error, a remote error or a custom ordered set.
			x		Valid choices are:
			x   		local_fault -
			x   		remote_fault -
			x	-send_sets_mode
			x		Specifies whether ordered set A and/or B is used in the error insertion.
			x		Valid choices are:
			x   		alternate -
			x   		type_a_only -
			x   		type_b_only -
			 	-clocksource
			 		Clock source for SONET interfaces at which each interface is
			 		configured.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid choices are:
			    		internal - Transmit Clocking Internal
			    		loop - Transmit Clocking Recovered
			    		external - Transmit Clocking External (77.76MHz)
			x	-connected_count
			x		The number of connected interfaces to be created, when trying to create
			x		multiple interfaces with a single interface_config call.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when static_enable is 0 and l23_config_type
			x		is static_endpoint or protocol_interface(new API).
			x	-data_integrity
			x		Whether to enable the data integrity checking capability on the port.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		Valid options are:
			x		0 - Disable (DEFAULT)
			x		1 - Enable
			 	-duplex
			 		Whether duplex is full or half.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid choices are:
			    		half - half duplex
			    		full - full duplex
			    		auto - selects both full and half duplex
			 	-framing
			 		POS interface type.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles. Valid options are:
			 		sonet
			 		sdh
			 		Valid choices are:
			    		sonet -
			    		sdh -
			 	-gateway
			 		List of IP addresses that configure the addresses of the gateway (that
			 		is, the DUT interface IP addresses).
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			x	-gateway_incr_mode
			x		Determines when the gateway addresses are incremented.
			x		This option is valid only when l23_config_type is static_endpoint (new API).
			x		Valid choices are:
			x   		every_subnet - (default) - A new gateway address is created for each subnet defined in the port group.
With this mode, the increment operation is triggered when a range IP increment operation creates an IP address that is in a new subnet.
			x   		every_interface - A new gateway address is created for each interface, whether or not the next address is from the same subnet.
			x	-gateway_step
			x		The incrementing step for the gateway address of the interface, when
			x		connected_count is greater than 1.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when l23_config_type is static_endpoint.
			x	-gre_checksum_enable
			x		Enable/disable checksum on a GRE interface.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when l23_config_type is protocol_interface.
			x	-gre_count
			x		The number of GRE interfaces to be created for each connected
			x		interface.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when l23_config_type is protocol_interface.
			x	-gre_dst_ip_addr
			x		GRE tunnel destination IP address.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when l23_config_type is protocol_interface.
			x	-gre_dst_ip_addr_step
			x		The incrementing step for the GRE Destination IP address of the
			x		interface, when connected_count is greater than 1.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when l23_config_type is protocol_interface.
			x	-gre_ip_addr
			x		GRE tunnel IPv4 address. This option takes a list of values when -port_handle is a list of port handles.This option is valid only when l23_config_type is protocol_interface (old and new API).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-gre_ip_addr_step
			x		The incrementing step for the GRE IPv4 address of the interface, when connected_count is greater than 1. This option takes a list of values when -port_handle is a list of port handles.This option is valid only when l23_config_type is protocol_interface (old and new API).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-gre_ip_prefix_length
			x		The IPv4 prefix length for the GRE interface that needs to be created. This option takes a list of values when -port_handle is a list of port handles.This option is valid only when l23_config_type is protocol_interface (old and new API).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-gre_ipv6_addr
			x		GRE tunnel IPv6 address. This option takes a list of values when -port_handle is a list of port handles.This option is valid only when l23_config_type is protocol_interface (old and new API).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-gre_ipv6_addr_step
			x		The incrementing step for the GRE IPv6 address of the interface, when connected_count is greater than 1. This option takes a list of values when -port_handle is a list of port handles.This option is valid only when l23_config_type is protocol_interface (old and new API).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-gre_ipv6_prefix_length
			x		The IPv6 prefix length for the GRE interface that needs to be created. This option takes a list of values when -port_handle is a list of port handles.This option is valid only when l23_config_type is protocol_interface (old and new API).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-gre_key_enable
			x		Enable/disable key on a GRE interface.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when l23_config_type is protocol_interface.
			x	-gre_key_in
			x		Value of the IN key on a GRE interface.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when l23_config_type is protocol_interface.
			x	-gre_key_out
			x		Value of the OUT key on a GRE interface.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when l23_config_type is protocol_interface.
			x	-gre_seq_enable
			x		Enable/disable sequencing on a GRE interface.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when l23_config_type is protocol_interface.
			 	-ignore_link
			 		Transmit ignores the link status on Ethernet, POS or ATM port if set to
			 		true.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			x	-integrity_signature
			x		Signature used in the packet for data integrity checking. When the
			x		Receive Mode for a port is configured to check for data integrity,
			x		received packets are matched for the data integrity signature value.
			x		This signature is a 4-byte value.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-integrity_signature_offset
			x		The offset of the data integrity signature in the packet.
			x		If -port_rx_mode is set to auto_detect_instrumentation then this
			x		offset will be ignored, only the -integrity_signature is needed.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-interface_handle
			 		This parameter takes a list of interface handles. It is used
			 		with -mode modify in order to modify L2-3 settings
			 		when -l23_config_type is protocol_interface.
			 		Parameter valid only with IxTclNetwork.
			 		If the interface handle represents a routed interface,
			 		the interface cannot be modified into a connected interface
			 		(it can only be routed to another connected interface).
			 	-internal_ppm_adjust
			 		Parameter valid only when transmit_clock_source is set on internal_ppm_adj.
			 		Specifies the PPM value to adjust the IEEE clock frequency tolerance.
			 		This parameter can have values between -100,100
			 	-intf_ip_addr
			 		List of IP addresses that configure each of the traffic generation
			 		tool interfaces.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			x	-intf_ip_addr_step
			x		The incrementing step for the IPv4 address of the interface, when
			x		connected_count is greater than 1.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This is valid only for the new API.
			 	-intf_mode
			 		SONET header type.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Please check Ixia Hardware and Reference Manual for the list of cards that support
			 		this feature.
			 		Valid choices are:
			    		atm -
			    		pos_hdlc -
			    		pos_ppp - The default value for cards that support ATM and POS is pos_ppp.
			    		ethernet_vm - This is specific for IxVM cards.
			    		ethernet -
			    		ethernet_fcoe - If speed is configured to ether10000lan the port mode will be tenGigLanFcoe.
If speed is configured to ether10000wan tenGigWanFcoe.
Otherwise the port mode will be ethernetFcoe. Valid only with ixnetwork API.
			    		multis - This is specific for Multis cards (10G/40G/100G).Valid only with ixnetwork new API.
			    		multis_fcoe - FCoE for Multis cards (10G/40G/100G).Valid only with ixnetwork new API.
			    		novus - This is specific for Novus cards.Valid only with ixnetwork new API.
			    		novus_fcoe - FCoE for Novus cards.Valid only with ixnetwork new API.
			    		novus_10g - This is specific for Novus 10G cards.Valid only with ixnetwork new API.
			    		novus_10g_fcoe - FCoE for Novus 10G cards.Valid only with ixnetwork new API.
			    		k400g - This is specific for K400G/Titan400G cards.Valid only with ixnetwork new API.
			    		k400g_fcoe - FCoE for Novus K400G/Titan400G cards.Valid only with ixnetwork new API.
			    		rame_relay1490 -
			    		frame_relay2427 -
			    		frame_relay_cisco -
			    		srp -
			    		srp_cisco -
			    		rpr -
			    		fc - Fiber Channel
			    		gfp -
			    		bert - The bert option is valid only for 40Gig/100Gig cards.
			 	-intrinsic_latency_adjustment
			 		This option enables the Intrinsic Latency Adjustment for poets that support
			 		this feature. Valid values are:
			 		0 - Not enabled (DEFAULT)
			 		1 - Enabled
			 	-ipv6_gateway
			 		List of IPV6 addresses that configure the addresses of the gateway (that
			 		is, the DUT interface IP addresses).
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			x	-ipv6_gateway_step
			x		The incrementing step for the IPv6 gateway of the interface, when
			x		connected_count is greater than 1.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			 	-ipv6_intf_addr
			 		List of IPv6 addresses that configure each of the traffic generation
			 		tool interfaces.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			x	-ipv6_intf_addr_step
			x		The incrementing step for the IPv6 address of the interface, when
			x		connected_count is greater than 1.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when l23_config_type is static_endpoint.
			 	-ipv6_prefix_length
			 		The mask width of the IPv6 address in an interface.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			x	-ipv6_addr_mode
			x		The address mode for Static ipv6 endpoints. May be static or autoconfig.
			x		This option is valid only when l23_config_type is static_endpoint.
			x		Valid choices are:
			x   		static -
			x   		autoconfig -
			x	-l23_config_type
			x		The type of IP interface that will be configured. This argument is only supported for legacy compatibility with the ixia namespace.
			x		Valid choices are:
			x   		protocol_interface - (default) - the interface will be configured in the
Routing/Switching/Interfaces section
			x   		static_endpoint - the interface will be configured as an IP endpoint in the
Auth/Access Hosts/DCB section
			 	-mode
			 		Action to be taken on the interface selected.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid choices are:
			    		config -
			    		modify - Valid only when using IxTclNetwork.
When ::ixia::interface_config is provided with -port_handle
parameter, -mode modify and other supported parameters,
except -interface_handle, the modification is supported
for L1 parameters only.
When ::ixia::interface_config is provided with -port_handle
parameter, -mode modify and other supported parameters,
including -interface_handle, the modification is supported
for L2-L3 parameters also, but only for protocol
interfaces (-l23_config_type protocol_interface).
			    		destroy - clear all interfaces before configuring new ones.
			x	-mss
			x		The Maximum Segment Size. The MSS is the largest amount of data, specified in bytes, that the IP device can transmit as a single, unfragmented unit. The TCP MSS equals the MTU minus the TCP header size, minus the IP header size. Stack Manager supports jumbo frames. Therefore the maximum value is 9460. This option is valid only when l23_config_type is static_endpoint (new API). This option takes a list of values when -port_handle is a list of port handles.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-mtu
			x		This option configure Maximum Trasmision Unit for created interfaces.
			x		This parameter can be an interfaces - one MTU value for each interface
			x		to be created.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			 	-netmask
			 		Network mask used for IP address configuration of the traffic
			 		generation tool interfaces.
			x	-ndp_send_req
			x		See -send_router_solicitation parameter.
			x		If both -ndp_send_req and -send_router_solicitation are present, -ndp_send_req takes precedence.
			x	-no_write
			x		If this option is present, the configuration is not written to the
			x		hardware. This option can be used to queue up multiple configurations
			x		before writing to the hardware.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ns_on_linkup
			x		Send Neighbor Solicitation for the IPv6 interfaces when the port link becomes up.
			x		The option is global, for all ports and interfaces.
			 	-op_mode
			 		Operational mode on the interface.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid options are:
			 		loopback
			 		normal
			 		monitor
			 		sim_disconnect
			 		Valid choices are:
			    		loopback -
			    		normal -
			    		monitor -
			    		sim_disconnect -
			x	-override_existence_check
			x		If this option is enabled, the interface existence check is skipped but
			x		the list of interfaces is still created and maintained in order to keep
			x		track of existing interfaces if required. Using this option will speed
			x		up the interfaces' creation.
			x		Valid only for -l23_config_type protocol_interface.
			x	-override_tracking
			x		If this option is enabled, the list of interfaces wont be created and
			x		maintained anymore, thus, speeding up the interfaces' creation even
			x		more. Also, it will enable -override_existence_check in case it wasnt
			x		already enabled because checking for interface existence becomes
			x		impossible if the the list of interfaces doesnt exist anymore.
			x		Valid only for -l23_config_type protocol_interface.
			x	-check_gateway_exists
			x		If 0, this check offers the possibility of creating routed/unconnected
			x		interfaces as connected interfaces.
			x		If 1, the command will check if the provided gateway address can be
			x		found on an existing interface. If an interface with the gateway IP
			x		address exists, the interface required will be configured as unconnected.
			 	-check_opposite_ip_version
			 		This parameter is used when trying to configure dual stack interfaces.
			 		For example, if an interface_config with ipv4 parameters is called,
			 		the procedure will search for an existing interface with the same MAC
			 		address and ipv6 settings. If such an interface is found and check_opposite_ip_version
			 		is set to 1 this interface will have the ipv4 settings created or modified if ipv4
			 		settings already exists. In case check_opposite_ip_version is set to 0, an error
			 		specifying that the MAC address is unique per port will be thrown.
			x	-pcs_period
			x		Periodicity of transmitted errors. The unit of period differs based on the type of
			x		error (pcs_period_type) selected.
			x		Type = lane markers, period = lane markers
			x		Type = lane markers and payload, period = 64/66 bit words
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pcs_count
			x		Consecutive errors to transmit.
			x	-pcs_repeat
			x		Total number of errors to transmit. This is value ignored if pcs_enabled_continuous is
			x		set to 1 (true).
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pcs_period_type
			x		Use to configure the PCS Error Period Type.
			x		Valid values are:
			x		0 - pcsLaneErrorPeriodTypeLaneMarkers - Lane Markers period type (only)
			x		1 - pcsLaneErrorPeriodTypeLaneMarkersAndPayload - both Lane Markers
			x		and Payload period types
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pcs_lane
			x		Specifies which lane to insert errors into.
			x		Valid values range:
			x		019 for 100G load modules;
			x		03 for 40G load modules.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pcs_enabled_continuous
			x		If set to true, will transmit errors continuously at the given period and count. If
			x		false, see repeat, below. Valid choices are:
			x		0 - false
			x		1 - true
			x	-pcs_sync_bits
			x		Hex field for entering the error bits for the sync field.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pcs_marker_fields
			x		Hex field for entering the lane marker fields.
			x		Valid formats are: 00.00.00.00.00.00.00.02 , 00:00:00:00:00:00:00:02
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pgid_128k_bin_enable
			x		Enables the 128k bin mode so that the wide packet group receive
			x		mode will be larger.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pgid_mask
			x		The mask value to use when the -port_rx_mode is set to
			x		wide_packet_group.Value is by default a two byte value, in hex form,
			x		without any spaces (e.g., AAAA).
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pgid_offset
			x		The group ID offset value.
			x		If -port_rx_mode is set to auto_detect_instrumentation then this
			x		offset will be ignored, only the pgid value is needed.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pgid_mode
			x		This option can be used to specify the PGID mode in the filter
			x		section, on specified RX port.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		The predifined split pgid offsets used for egress tracking with IxNetwork TCL API
			x		are fixed. They do not adjust if the offsets monitored in the received packets are shifted.
			x		Valid choices are:
			x   		custom - this option is not available with IxNetwork TclAPI
			x   		dscp - When IxNetwork Tcl API is used, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predefined IPv4 DSCP (6 bits) offset.
			x   		ipv6TC - When IxNetwork Tcl API is used, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined IPv6 Traffic Class (8 bits) offset.
			x   		mplsExp - When IxNetwork Tcl API is used, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined MPLS Exp (3 bits) offset.
			x   		split - When IxNetwork Tcl API is used, this option enables egress tracking
on this port using split pgids. The egress tracking offset and width
will be configured manually with the parameters -pgid_split1_offset and
pgid_split1_width.
			x   		outer_vlan_priority - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined Outer VLAN Priority (3 bits) offset.
This choice is supported only on Ethernet, 10 gig lan and 10 gig wan cards.
			x   		outer_vlan_id_4 - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined Outer VLAN ID (4 bits) offset.
This choice is supported only on Ethernet, 10 gig lan and 10 gig wan cards.
			x   		outer_vlan_id_6 - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined Outer VLAN ID (6 bits) offset.
This choice is supported only on Ethernet, 10 gig lan and 10 gig wan cards.
			x   		outer_vlan_id_8 - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined Outer VLAN ID (8 bits) offset.
This choice is supported only on Ethernet, 10 gig lan and 10 gig wan cards.
			x   		outer_vlan_id_10 - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined Outer VLAN ID (10 bits) offset.
This choice is supported only on Ethernet, 10 gig lan and 10 gig wan cards.
			x   		outer_vlan_id_12 - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined Outer VLAN ID (12 bits) offset.
This choice is supported only on Ethernet, 10 gig lan and 10 gig wan cards.
			x   		inner_vlan_priority - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined Inner VLAN Priority (3 bits) offset.
This choice is supported only on Ethernet, 10 gig lan and 10 gig wan cards.
			x   		inner_vlan_id_4 - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined Inner VLAN ID (4 bits) offset.
This choice is supported only on Ethernet, 10 gig lan and 10 gig wan cards.
			x   		inner_vlan_id_6 - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined Inner VLAN ID (6 bits) offset.
This choice is supported only on Ethernet, 10 gig lan and 10 gig wan cards.
			x   		inner_vlan_id_8 - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined Inner VLAN ID (8 bits) offset.
This choice is supported only on Ethernet, 10 gig lan and 10 gig wan cards.
			x   		inner_vlan_id_10 - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined Inner VLAN ID (10 bits) offset.
This choice is supported only on Ethernet, 10 gig lan and 10 gig wan cards.
			x   		inner_vlan_id_12 - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined Inner VLAN ID (12 bits) offset.
This choice is supported only on Ethernet, 10 gig lan and 10 gig wan cards.
			x   		tos_precedence - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined IPv4 TOS Precedence (3 bits) offset.
			x   		ipv6TC_bits_0_2 - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined IPv6 Traffic Class Bits 0-2 (3 bits) offset.
			x   		ipv6TC_bits_0_5 - Available only with IxNetwork TCL API, this option enables egress tracking
on this port using split pgids. The egress tracking offset will
configured to the predifined IPv6 Traffic Class Bits 0-5 (6 bits) offset.
			x	-pgid_encap
			x		Available only with IxNetwork TCL API. When -pgid_mode is configured to
			x		'ipv6TC', 'dscp', 'mplsExp', 'tos_precedence', 'ipv6TC_bits_0_2' or 'ipv6TC_bits_0_2'
			x		and the port is ATM, this option configures the encapsulation used for
			x		egress tracking. Valid options are:
			x		LLCRoutedCLIP - default
			x		LLCPPPoA
			x		LLCBridgedEthernetFCS
			x		LLCBridgedEthernetNoFCS
			x		VccMuxPPPoA
			x		VccMuxIPV4Routed
			x		VccMuxBridgedEthernetFCS
			x		VccMuxBridgedEthernetNoFCS
			x		Valid choices are:
			x   		LLCRoutedCLIP -
			x   		LLCPPPoA -
			x   		LLCBridgedEthernetFCS -
			x   		LLCBridgedEthernetNoFCS -
			x   		VccMuxPPPoA -
			x   		VccMuxIPV4Routed -
			x   		VccMuxBridgedEthernetFCS -
			x   		VccMuxBridgedEthernetNoFCS -
			x	-pgid_split1_mask
			x		The PGID mask bits for the first split PGID. It is a hexadecimal value
			x		in the 0x<HEX_VALUE> format. This option is available only for
			x		traffic_generator ixos. This option has any meaning only if
			x		the -pgid_mode option is set to split.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pgid_split1_offset
			x		The offset in bytes from pgid_split1_offset_from.
			x		This option has any meaning only if the -pgid_mode option is set to split.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x	-pgid_split1_offset_from
			x		The frame location from which the pgid_split1_offset value is
			x		computed. This option is available only for traffic_generator ixos.
			x		This option has any meaning only if the -pgid_mode option is set to
			x		split.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		start_of_frame -
			x	-pgid_split2_mask
			x		The PGID mask bits for the second split PGID. It is a hexadecimal
			x		value in the 0x<HEX_VALUE> format. This option is available only for
			x		traffic_generator ixos. This option has any meaning only if
			x		the -pgid_mode option is set to split.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pgid_split2_offset
			x		The offset in bytes from pgid_split2_offset_from. This option is
			x		available only for traffic_generator ixos. This option has any meaning
			x		only if the -pgid_mode option is set to split.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pgid_split2_offset_from
			x		The frame location from which the pgid_split2_offset value is
			x		computed. This option is available only for traffic_generator ixos.
			x		This option has any meaning only if the -pgid_mode option is set to
			x		split.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		start_of_frame -
			x	-pgid_split2_width
			x		The width, in bytes, of the split PGID. This option is available only
			x		for traffic_generator ixos. This option has any meaning only if
			x		the -pgid_mode option is set to split.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pgid_split3_mask
			x		The PGID mask bits for the third split PGID. It is a hexadecimal value
			x		in the 0x<HEX_VALUE> format. This option is available only for
			x		traffic_generator ixos. This option has any meaning only if
			x		the -pgid_mode option is set to split.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pgid_split3_offset
			x		The offset in bytes from pgid_split_offsetX_from. This option is
			x		available only for traffic_generator ixos. This option has any meaning
			x		only if the -pgid_mode option is set to split.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-pgid_split3_offset_from
			x		The frame location from which the pgid_split3_offset value is
			x		computed. This option is available only for traffic_generator ixos.
			x		This option has any meaning only if the -pgid_mode option is set to
			x		split.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		start_of_frame -
			x	-pgid_split3_width
			x		The width, in bytes, of the split PGID. This option is available only
			x		for traffic_generator ixos. This option has any meaning only if
			x		the -pgid_mode option is set to split.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-phy_mode
			 		For dual mode ethernet interfaces only.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid options are:
			 		copper
			 		fiber
			 		sgmii (valid only for IxNetwork)
			 		Valid choices are:
			    		copper -
			    		fiber -
			    		sgmii -
			x	-master_slave_mode
			x		Valid only for IxNetwork for interfaces that support media-independent master/slave negotiation.
			x		Valid options are:
			x		auto
			x		master
			x		slave
			x		Valid choices are:
			x   		auto -
			x   		master -
			x   		slave -
			x	-port_rx_mode
			x		Configure the Receive Engine of the Ixia port.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		Valid choices are:
			x   		capture - Capture packets.
			x   		packet_group - Compile statistics for specified
packet group. PGID is 2 bytes.
			x   		data_integrity - Check data integrity.
			x   		sequence_checking - Check data sequencing.
			x   		wide_packet_group - Compile statistics for specified packet group. PGID is 4 bytes,but only the low order 17 bits are active.
			x   		echo - Gigabit echo mode.
			x   		auto_detect_instrumentation - Automatic instrumentation detection. This option includes wide_packet_group mode also.
If this option is set then, for PGID, data integrity checking and
sequence checking there will be no need for specifying signature offset, only signature value will be provided.
			x   		capture_and_measure - This is valid only for new API (IxTclNetwork)
			x	-ppp_ipv4_address
			x		IPv4 address for which to enable or disable PPP IPv4 negotiation.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x	-ppp_ipv4_negotiation
			x		Whether to enable PPP IPv4 negotiation on this port.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		Valid options are:
			x		0 - Disable
			x		1 - (default) Enable
			x	-ppp_ipv6_negotiation
			x		Whether to enable PPP IPv6 negotiation on this port.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		Valid options are:
			x		0 - Disable
			x		1 - (default) Enable
			x	-ppp_mpls_negotiation
			x		Whether to enable PPP MPLS negotiation on this port.
			x		Valid options
			x		are:
			x		0 - Disable
			x		1 - (default) Enable
			x	-ppp_osi_negotiation
			x		Whether to enable OSI Network Control protocol on the Ixia PoS port.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		Valid options are:
			x		0 - Disable
			x		1 - (default) Enable
			x	-pvc_incr_mode
			x		The Method used to increment PVCs. This parameter is valid only vci - The VCI is incremented first. When the Unique Count (vci_count) is reached the number of times specified by the addresses_per_vpi parameter, the VPI is incremented.vpi - The VPI is incremented first. When the Unique Count (vpi_count) is reached the number of times specified by the addresses_per_vci parameter, the VCI is incremented.both (default) - Both VCI and VPI are incremented at the same time.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-qinq_incr_mode
			x		The Method used to increment VLAN IDs. This parameter is valid only
			x		when l23_config_type is static_endpoint (new API).
			x		Valid choices are:
			x   		inner - The inner VLAN ID is incremented first. When the Unique Count
(vlan_id_count) is reached the number of times specified by the addresses_per_svlan parameter, the outer VLAN ID is incremented.
			x   		outer - The outer VLAN ID is incremented first. When the Unique Count
(vlan_id_count) is reached the number of times specified by the addresses_per_vlan parameter, the inner VLAN ID is incremented.
			x   		both - Both VLAN IDs are incremented at the same time.
			x	-qos_byte_offset
			x		The byte offset from the beginning of the packet for the byte which
			x		contains the QoS level for the packet.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-qos_packet_type
			x		The type of packet that the QoS counters are looking for priority
			x		bits within. Choices are: ethernet, ip_snap, vlan, custom, ip_ppp,
			x		ip_cisco_hdlc, ip_atm.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		ethernet -
			x   		ip_snap -
			x   		vlan -
			x   		custom -
			x   		ip_ppp -
			x   		ip_cisco_hdlc -
			x   		ip_atm -
			x	-qos_pattern_mask
			x		The mask to be applied to the pattern match. Value of 1 indicate that
			x		the corresponding bit is not to be matched.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-qos_pattern_match
			x		The value to be matched for at the Pattern Match Offset, subject to
			x		the Pattern Match Mask. The value is in hex.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-qos_pattern_offset
			x		The byte offset from the beginning of the packet for the byte(s) that
			x		contains a value to be matched. If the pattern is matched, then the
			x		packet is deemed to contain a QoS level.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-qos_stats
			x		Whether to have access to the QOS (IP TOS PRECEDENCE) statistics on
			x		this port.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles. Valid options are:
			x		0 - Disable
			x		1 - (default) Enable
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-router_solicitation_retries
			x		The number of times the router solicitation request will be attempted.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-rpr_hec_seed
			x		The initial setting of the CRC for the 16 byte header. This option is
			x		used only when intf_mode is set to rpr.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		Valid options are:
			x		0 - (default) 0x0000
			x		1 - 0xFFFF
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-rx_c2
			 		Receive Path Signal Label for the Ixia interface.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 	-rx_fcs
			 		FCS value (16 or 32) for the receiving side of each interfaces.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid options are:
			 		16
			 		32
			 		Valid choices are:
			    		16 -
			    		32 -
			 	-rx_scrambling
			 		Whether to enable data scrambling in the SONET framer of the Ixia
			 		interface. (SPE Scrambling = X^43+1).
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid options are:
			 		0 - Disable
			 		1 - Enable (DEFAULT)
			x	-send_router_solicitation
			x		If is option is present and has value 1 then interfaces on specified
			x		port will sent IPv6 router solicitation ICMP message to the DUT.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x	-sequence_checking
			x		Whether to enable the frame sequence capability on this port.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		Valid options are:
			x		0 - (default) Disable
			x		1 - Enable
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-sequence_num_offset
			x		The offset of the sequence number in the packet.
			x		If -port_rx_mode is set to auto_detect_instrumentation then this
			x		offset will be ignored.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-signature
			x		Signature used in the packet for Packet Group Statistics when packet
			x		groups or wide packet groups are enable.
			x		This signature will be searched into the received packets at offset
			x		represented by -signature_offset.
			x		If -port_rx_mode is set to auto_detect_instrumentation then this
			x		option will represent the a signature value of 12 hex bytes.
			x		This signature will be searched into the received packets starting
			x		with offset -signature_start_offset.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-signature_mask
			x		Sets the signature mask when -port_rx_mode is set to
			x		auto_detect_instrumentation.
			x		Value 1 means don't care and value 0 means that that bit should
			x		correspond to the signature.
			x		If -signature is "00 00 00 00 00 00 00 00 23 45 67 89" and
			x		the -signature_mask is "FF FF FF FF FF FF FF FF 00 00 00 00",
			x		then only last 4 bytes will be searched in the packet.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-signature_offset
			x		The offset of the signature in the packet. You can configure a fully
			x		customized signature in the packet for advanced testing. The
			x		signature of the packet is a 4-byte value, "DE AD BE EF". This
			x		signature is used for ease of readability when capturing packets.
			x		If -port_rx_mode is set to auto_detect_instrumentation then this
			x		offset will be ignored.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-signature_start_offset
			x		If -port_rx_mode is set to auto_detect_instrumentation then this will
			x		be the offset start to search into the received packets for -signature
			x		<signature> option.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-single_arp_per_gateway
			x		Send single ARP per gateway for the IPv4 interfaces when the port link becomes up.
			x		The option is global, for all ports and interfaces.
			x		This is valid only for the new API.
			x	-single_ns_per_gateway
			x		Send single Neighbor Solicitation per gateway for the IPv6 interfaces when the port link becomes up.
			x		The option is global, for all ports and interfaces.
			x		This is valid only for the new API.
			x	-speed_autonegotiation
			x		Autonegociation Speed at which each interface is configured. This option takes a value or list of values when -port_handle is a single of port handles. Example v1 or {v1 v2}. This option takes a list of values for each interface when -port_handle is a list of port handles. Example {{v1 v2} {v3 v4}}
			x		Valid choices are:
			x   		ether100 - 100M speed for HW ports
			x   		ether1000 - 1G speed for HW ports
			x   		ether2.5Gig - 2.5G speed for HW ports
			x   		ether5Gig - 5G speed for HW ports
			x   		ether10Gig - 10G speed for HW ports
			x   		ether10000lan - 10G speed for HW ports
			 	-speed
			 		Speed at which each interface is configured. This option takes a list of values when -port_handle is a list of port handles.
			 		Valid choices are:
			    		ether10 - 10M speed for HW ports
			    		ether100 - 100M speed for HW ports
			    		ether1000 - 1G speed for HW ports
			    		oc3 -
			    		oc12 -
			    		oc48 -
			    		oc192 -
			    		auto -
			    		ether10000wan - 10G speed for HW ports
			    		ether10000lan - 10G speed for HW ports
			    		ether40000lan - 40G speed for HW ports
			    		ether100000lan - 40G speed for HW ports
			    		ether2.5Gig - 2.5G speed for HW ports
			    		ether5Gig - 5G speed for HW ports
			    		ether10Gig - 10G speed for HW ports
			    		ether25Gig - 25G speed for HW ports
			    		ether40Gig - 40G speed for HW ports
			    		ether50Gig - 50G speed for HW ports
			    		ether100Gig - 100G speed for HW ports
			    		ether200Gig - 100G speed for HW ports
			    		ether400Gig - 400G speed for HW ports
			    		fc2000 -
			    		fc4000 -
			    		fc8000 -
			    		ether100vm - 100M speed for IxVM ports
			    		ether1000vm - 1G speed for IxVM ports
			    		ether2000vm - 2G speed for IxVM ports
			    		ether3000vm - 3G speed for IxVM ports
			    		ether4000vm - 4G speed for IxVM ports
			    		ether5000vm - 5G speed for IxVM ports
			    		ether6000vm - 6G speed for IxVM ports
			    		ether7000vm - 7G speed for IxVM ports
			    		ether8000vm - 8G speed for IxVM ports
			    		ether9000vm - 9G speed for IxVM ports
			    		ether10000vm - 10G speed for IxVM ports
			 	-src_mac_addr
			 		MAC address of the port.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid formats are:
			 		{00 00 00 00 00 00}, 00:00:00:00:00:00, 0000.0000.0000,
			 		00.00.00.00.00.00, {0000 0000 0000}
			x	-src_mac_addr_step
			x		The incrementing step for the MAC address of the connected interface,
			x		when connected_count is greater than 1.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This is valid for the new API.
			x	-target_link_layer_address
			x		Enable target the link layer address for an IPv6 interface.This is valid when l23_config_type is protocol_interface (new API).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-transmit_clock_source
			 		Specifies the clock source for synchronous transmissions. You can set the
			 		transmit clock source for Ethernet 10/100/1000/100Gig interfaces.
			 		Options internal, bits, loop, external are not supported.
			 		Valid choices are:
			    		internal - Specifies that a crystal on the interface provides the transmit clock
			    		bits - Specifies that a Building Integrated Timing Supply is used as the transmit
clock. You can only use this option for Ethernet 1000 Fiber interface.
			    		loop - Specifies that a clock recovered from the received data is used as the transmit clock
			    		external - Specifies that the transmit clock signals are provided by external reference sources such as GPS and CDMA.
			    		internal_ppm_adj - Adjust the clock PPM within the IEEE clock frequency.
			x	-transmit_mode
			x		Type of stream for this port. This option takes a list of values when -port_handle is a list of port handles.
			x		Valid choices are:
			x   		advanced - (default) Sets up the hardware to use the advanced stream
scheduler, which involves the ability to interleave differing streams within one stream definition.
			x   		stream - Sets up the hardware to use normal streams.
			x   		advanced_coarse - Sets up the hardware to use the advanced stream scheduler, but with less precision and CPU utilization.
This option is specific to virtual ports and is valid only for intf_mode = ethernet_vm.
			x   		stream_coarse - Sets up the hardware to use less precision and CPU utilization with normal streams.
This option is specific to virtual ports and is valid only for intf_mode = ethernet_vm.
			 	-tx_c2
			 		Transmit Path Signal Label for the Ixia interface.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 	-tx_fcs
			 		FCS value (16 or 32) for the transmitting side of each interfaces.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid options are:
			 		16
			 		32
			 		Valid choices are:
			    		16 -
			    		32 -
			 	-tx_rx_sync_stats_enable
			 		This option starts / stops collecting Tx/Rx Sync stats.
			 		Valid options are:
			 		0 - stop collecting Sync stats (DEFAULT)
			 		1 - start collecting Sync stats
			 	-tx_rx_sync_stats_interval
			 		This option represents the interval (ms) at which to synchronously
			 		freeze TX and RX PGID stats.
			 	-tx_scrambling
			 		Whether to enable data scrambling in the SONET framer of the Ixia
			 		interface. (SPE Scrambling = X^43+1).
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid options are:
			 		0 - Disable
			 		1 - Enable (DEFAULT)
			x	-vci
			x		The VCI value when configuring ATM interfaces. This option takes a list of values when -port_handle is a list of port handles. This is valid for the old and new API.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vci_count
			x		The number of unique VCI values. This parameter is valid when l23_config_type is static_endpoint (new API).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vci_step
			x		The incrementing step for the VCI of the interface, when connected_count is greater than 1. The vci will be incremented modulo 65536, when the maximum value is reached, the counting starts again from 32. This option is valid only when l23_config_type is static_endpoint (new API). This option takes a list of values when -port_handle is a list of port handles.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-vlan
			 		Whether to enable VLAN on the traffic generation tool interfaces.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		Valid options are:
			 		1 - Enable
			 		0 - Disable (DEFAULT)
			x	-vlan_id
			x		VLAN ID of each interface where VLAN is enabled. This parameter
			x		accepts a list of numbers separated by ',' - the vlan id for each
			x		encapsulation 802.1q. This is how stacked vlan is configured.
			x		Each value should be between 0 and 4095, inclusive, for l23_config_type protocol_interfaces.
			x		Each value should be between 0 and 4094, inclusive, for l23_config_type static_endpoint.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x	-vlan_id_step
			x		The incrementing step for the VLAN ID of the interface, when
			x		connected_count is greater than 1.
			x		The vlan_id will be incremented modulo 4096, when the maximum value
			x		is reached, the counting starts again from 0.
			x		The vlan_id will be incremented modulo 4094 (by default), when the maximum value
			x		is reached, the counting starts again from 0, for l23_config_type static_endpoint,
			x		but the number of unique values can be modified by using vlan_id_count.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x	-vlan_id_count
			x		The number of unique outer VLAN IDs that will be created. This parameter
			x		accepts a list of numbers separated by ',' - the vlan id count for each
			x		encapsulation 802.1q. This is how stacked vlan is configured.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when l23_config_type is static_endpoint (new API).
			x	-vlan_tpid
			x		Tag Protocol Identifier / TPID (hex). The EtherType that identifies
			x		the protocol header that follows the VLAN header (tag).
			x		Available TPIDs: 0x8100 (the default), 0x88a8, 0x9100, 0x9200.
			x		If the VLAN Count is greater than 1 (for stacked VLANs),
			x		this field also accepts comma-separated values so that different TPID
			x		values can be assigned to different VLANs. For example, to assign TPID
			x		0x8100, 0x9100, 0x9200, and 0x9200 to the first four created VLANs,
			x		enter: 0x8100,0x9100,0x9200,0x9200.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x		This option is valid only when l23_config_type is protocol_interface.
			x		Valid choices are:
			x   		0x8100 -
			x   		0x88a8 -
			x   		0x88A8 -
			x   		0x9100 -
			x   		0x9200 -
			x   		0x9300 -
			x	-vlan_user_priority
			x		If VLAN is enabled on the interface, the priority of the VLAN. For each interface,
			x		the user priority list should be given as a list of integers separated by commas.
			x		This parameter accepts a list of user priority for each 802.1 encapsulation used.
			x		Valid choices for each element in the list are between 0 and 7, inclusive.
			x		This option takes a list of values when -port_handle is a list of port handles.
			x		For example, if we have 2 interfaces with 3 vlans each, the user priority could be: [list 1,2,7 1,3,4]
			x	-vlan_user_priority_step
			x		The incrementing step for the VLAN user priority of the interface, when
			x		connected_count is greater than 1. The vlan_user_priority will be
			x		incremented modulo 8, when the maximum value is reached, the counting
			x		starts again from 0.
			x		This option is valid only when l23_config_type is static_endpoint.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles.
			x	-vlan_id_list
			x		See description for -vlan_id parameter. If both vlan_id and vlan_id_list are present, vlan_id_List
			x		takes precedence. If vlan_id_list is present vlan_id_inner will be ignored.
			x	-vlan_id_mode
			x		Used to specify whether VLAN ID is the same, or incremented, for multiple addresses.
			x		Valid choices are:
			x   		fixed -
			x   		increment -
			x	-vlan_protocol_id
			x		See -vlan_tpid parameter
			x		Valid choices are:
			x   		0x8100 -
			x   		0x88a8 -
			x   		0x88A8 -
			x   		0x9100 -
			x   		0x9200 -
			x   		0x9300 -
			x	-vlan_id_inner
			x		Set the VLAN ID 2 associated with the address pool.
			x		Only works if VLAN is enabled and vlan_id provided.
			x		Each value should be between 0 and 4095, inclusive.
			x	-vlan_id_inner_mode
			x		Used to specify whether VLAN ID is the same, or incremented, for multiple addresses.
			x		This parameter is ignored if -vlan_id_inner is not specified in the same command.
			x		This option is valid only when l23_config_type is static_endpoint (new API).
			x		Valid choices are:
			x   		fixed -
			x   		increment -
			x	-vlan_id_inner_count
			x		Count value of inner VLAN ID per outer VLAN. Depending on this value outer and inner VLANs
			x		are incremented in QinQ. If not specified outer and inner VLANs are incremented independently.
			x		This parameter is ignored if -vlan_id_inner is not specified in the same command.
			x		This option is valid only when l23_config_type is static_endpoint (new API).
			x	-vlan_id_inner_step
			x		Used to specify how much the VLAN ID 2 is incremented when vlan_id_inner_mode is increment.
			x		This parameter is ignored if -vlan_id_inner is not specified in the same command.
			x		This option is valid only when l23_config_type is static_endpoint (new API).
			x	-use_vpn_parameters
			x		Flag to determine whether optional VPN parameters are provided.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-site_id
			x		VPN Site Identifier
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-vpi
			x		The VPI value when configuring ATM interfaces. This option takes a list of values when -port_handle is a list of port handles. This is valid for the old and new API.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vpi_count
			x		The number of unique VPI values. This parameter is valid when l23_config_type is static_endpoint (new API).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-vpi_step
			x		The incrementing step for the VPI of the interface, when connected_count is greater than 1. The vpi will be incremented modulo 256, when the maximum value is reached, the counting starts again from 0. This option is valid only when l23_config_type is static_endpoint (new API). This option takes a list of values when -port_handle is a list of port handles.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-enable_rs_fec
			x		Enable RS-FEC (Reed Solomon - Forward Error Correction). RS-FEC is a encoding mechanism to improve Bit Error Rate across a channel.
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-enable_rs_fec_statistics
			x		Enable RS-FEC Statistics.
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-firecode_request
			x		Request FC-FEC
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-firecode_advertise
			x		Advertise FC-FEC
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-firecode_force_on
			x		Force Enable FC-FEC
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-firecode_force_off
			x		Force Disable FC-FEC
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-request_rs_fec
			x		Request RS-FEC
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-advertise_rs_fec
			x		Advertise RS-FEC
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-force_enable_rs_fec
			x		Force Enable RS-FEC
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-use_an_results
			x		Use AN Results
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-force_disable_fec
			x		Force Disable FEC
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-link_training
			x		Link training.
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-ieee_media_defaults
			x		IEEE Media Defaults.
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-loop_continuously
			x		L1 config parameter that enables continuous looping. Valid only for Multis cards.
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-enable_flow_control
			x		If 1, enables the port's MAC flow control and mechanisms to listen for a directed address pause message. Valid only with ixnetwork api.
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-enable_ndp
			x		Enables or disables the -send_router_solicitation and -ndp_send_req parameters.
			x		If this is 0 both -send_router_solicitation and -ndp_send_req will be ignored.
			x	-flow_control_directed_addr
			x		The 48-bit MAC address that the port listens on for a directed pause.
			x		Valid only with ixnetwork api.
			x	-fcoe_priority_groups
			x		Valid only with ixnetwork api and when intf_mode is ethernet_fcoe and speed is
			x		ether10000wan or ether10000lan. If 802.3Qbb is selected as the fcoe_flow_control_type,
			x		the PFC/Priority settings is used to map each of the eight PFC priorities to one
			x		of the four Priority Groups (or to none). The Priority Groups are numbered 0 through 3.
			x		This parameter takes a list of values, with a length of maximum 8 elements 0,1,2,3 or none.
			x		Example: {0 3 1 2 none 3} will configure:
			x		PFC 0 - Priority Group 0
			x		PFC 1 - Priority Group 3
			x		PFC 2 - Priority Group 1
			x		PFC 3 - Priority Group 2
			x		PFC 4 - Priority Group None
			x		PFC 5 - Priority Group 3
			x		PFC 6 - Priority Group None
			x		PFC 7 - Priority Group None
			 	-fcoe_support_data_center_mode
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-fcoe_priority_group_size
			x		Valid only with ixnetwork api and when intf_mode is ethernet_fcoe and speed is
			x		ether10000wan or ether10000lan. Configure the size of a priority group. Valid choices are:
			x		4 - 4
			x		8 (default) - 8
			x		Valid choices are:
			x   		4 -
			x   		8 -
			x	-fcoe_flow_control_type
			x		Valid only with ixnetwork api. Selects and configures a flow control protocol for the FCoE Client port.
			x		Valid only when intf_mode is ethernet_fcoe and speed is ether10000wan or ether10000lan.
			x		Valid choices are:
			x		ieee802.3x - ieee802.3x
			x		ieee802.1Qbb (default) - ieee802.1Qbb
			x		Valid choices are:
			x   		ieee802.3x -
			x   		ieee802.1Qbb -
			x	-fc_credit_starvation_value
			x		Valid only with ixnetwork api. If selected, the programs encounter a delay value
			x		specified in the Hold R_RDY field. The counter starts counting down after it
			x		receives the first frame. The port holds R_RDY for all frames received until counter
			x		reaches to 0.
			x		Valid only when intf_mode is fc.
			x	-fc_no_rrdy_after
			x		Valid only with ixnetwork api. Send R_RDY signals without any delay.
			x		Valid only when intf_mode is fc.
			x	-fc_tx_ignore_rx_link_faults
			x		DEPRECATED - Please use tx_ignore_rx_link_faults instead.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-tx_ignore_rx_link_faults
			x		Enable to send trafic even if the receive link is down.
			x	-clause73_autonegotiation
			x		This argument is deprecated. Please use autonegotiation instead.
			x	-laser_on
			x		Enable "laser on" option for Multis/Novus cards.
			x	-fc_max_delay_for_random_value
			x		Valid only with ixnetwork api. The maximum random delay value for the R_RDY primitives.
			x		Valid only when intf_mode is fc.
			x	-fc_tx_ignore_available_credits
			x		Valid only with ixnetwork api.
			x		Valid only when intf_mode is fc. Valid choices are:
			x		0 (default) - disable
			x		1 - enable
			x	-fc_min_delay_for_random_value
			x		Valid only with ixnetwork api. The minimum random delay value for the R_RDY primitives.
			x		Valid only when intf_mode is fc.
			x	-fc_rrdy_response_delays
			x		Valid only with ixnetwork api. The internal delays for the transmission of R_RDY Primitive Signal
			x		Valid only when intf_mode is fc. Valid choices are:
			x		credit_starvation
			x		fixed_delay
			x		no_delay (default)
			x		random_delay
			x		Valid choices are:
			x   		credit_starvation -
			x   		fixed_delay -
			x   		no_delay -
			x   		random_delay -
			x	-fc_fixed_delay_value
			x		Valid only with ixnetwork api. Internal delays the R_RDY primitive signals.
			x		Valid only when intf_mode is fc.
			x	-fc_force_errors
			x		Valid only with ixnetwork api. Configure the port to introduce errors in the transmission of R_RDYPrimitives Signals.
			x		Valid only when intf_mode is fc. Valid choices are:
			x		no_errors (default)
			x		no_rrdy
			x		no_rrdy_every
			x		Valid choices are:
			x   		no_errors -
			x   		no_rrdy -
			x   		no_rrdy_every -
			x	-enable_data_center_shared_stats
			x		Valid only with ixnetwork api. Globally enable Data Center Shared Statistics.
			x		Valid choices are:
			x		0 (default) - disabled
			x		1 - enabled
			x	-additional_fcoe_stat_1
			x		Valid only with ixnetwork api and when enable_data_center_shared_stats is 1.
			x		Valid choices are:
			x   		fcoe_invalid_delimiter - (default) - FCoE invalid delimiter
			x   		fcoe_invalid_frames - FCoE invalid frames
			x   		fcoe_invalid_size - FCoE invalid size
			x   		fcoe_normal_size_bad_fc_crc - FCoE normal size, bad FC-CRC
			x   		fcoe_normal_size_good_fc_crc - FCoE normal size, good FC-CRC
			x   		fcoe_undersize_bad_fc_crc - FCoE undersize, bad FC-CRC
			x   		fcoe_undersize_good_fc_crc - FCoE undersize, good FC-CRC
			x   		fcoe_valid_frames - FCoE valid frames
			x	-additional_fcoe_stat_2
			x		Valid only with ixnetwork api and when enable_data_center_shared_stats is 1.
			x		Valid choices are:
			x   		fcoe_invalid_delimiter - FCoE invalid delimiter
			x   		fcoe_invalid_frames - FCoE invalid frames
			x   		fcoe_invalid_size - FCoE invalid size
			x   		fcoe_normal_size_bad_fc_crc - FCoE normal size, bad FC-CRC
			x   		fcoe_normal_size_good_fc_crc - FCoE normal size, good FC-CRC
			x   		fcoe_undersize_bad_fc_crc - FCoE undersize, bad FC-CRC
			x   		fcoe_undersize_good_fc_crc - FCoE undersize, good FC-CRC
			x   		fcoe_valid_frames - FCoE valid frames
			x	-tx_gap_control_mode
			x		Valid only for new API when speed is ether10000wan or ether10000lan
			x		and intf_mode is ethernet | ethernet_fcoe.
			x		Valid choices are:
			x   		fixed - Sets gap control to fixed mode
			x   		average - Sets gap control to average mode
			x	-tx_lanes
			x		This option takes a list of txLanes. This parameter is valid only with IxTclHal api.
			x		<phy_lane>:<pcs_lane>,<skew>|<phy_lane>:<pcs_lane>,<skew>|....
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-static_enable
			 		Enables creation of IxNetwork static endpoints. If this parameter is 1,
			 		only IxNetwork static endpoints will be created. All other parameters
			 		that configure protocol interfaces (-l23_config_type protocol_interface)
			 		and SM static endpoints (-l23_config_type static_endpoint) will be ignored.
			 		Valid choices are:
			 		0 - disable (DEFAULT)
			 		1 - enable
			 	-static_atm_header_encapsulation
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_atm_range_count > 0.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 		Valid choices are:
			    		-
			 	-static_atm_range_count
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_atm_range_count > 0. Configure the number of ATM static endpoints to create.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_vci
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_atm_range_count > 0. The value for the first ATM Virtual Circuit Identifier (VCI). The VCI value is used with a VPI value - a VPI/VCI pair - to identify a specific ATM link.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_vci_increment
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_atm_range_count > 0. Increment step used inside an ATM range for vci.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_vci_increment_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_atm_range_count > 0. Step to increment -static_vci_increment between ATM static endpoint ranges.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_vci_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_atm_range_count > 0. Step of vci between ATM ranges.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_pvc_count
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_atm_range_count > 0. Number of ATM PVC to create in a range.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_pvc_count_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_atm_range_count > 0. Step of Permanent Virtual Circuits count (-static_pvc_count) between ATM ranges.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_vpi
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_atm_range_count > 0. The value for the first ATM Virtual Port Identifier (VPI). The VPI value is used with a VCI value - a VPI/VCI pair - to identify a specific ATM virtual link.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_vpi_increment
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_atm_range_count > 0. Increment step used inside an ATM range for vpi.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_vpi_increment_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_atm_range_count > 0. Step to increment -static_vpi_increment between ATM static endpoint ranges.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_vpi_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_atm_range_count > 0. Step of vpi between ATM static endpoint ranges.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_dlci_count_mode
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 		Valid choices are:
			    		-
			 	-static_dlci_repeat_count
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_fr_range_count > 0. Number of DLCI to advertise per Frame Relay range.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_dlci_repeat_count_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_fr_range_count > 0. Step of dlci_repeat_count betweenranges.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_dlci_value
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_fr_range_count > 0. The Data Link Connection Identifier (DLCI) value.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_dlci_value_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_fr_range_count > 0. Step of dlci values between ranges.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_fr_range_count
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1. Number of Frame Relay static endpoint ranges to be created.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-static_intf_handle
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_ip_range_count > 0. Interface handles to be used by IP type.
			 		These handles are returned by interface_config when - l23_config_type is
			 		protocol_interface and -static_enable is 0. In order for an interface to be
			 		a valid handle it must have the same encapsulations as the static endpoint ip
			 		range (same IP type, number of vlans if any).
			 	-static_ip_dst_count
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_ip_range_count > 0. Number of IPs to be generated on an IP range.
			 	-static_ip_dst_count_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_ip_range_count > 0. Step to increment - static_ip_dst_count between ranges.
			 	-static_ip_dst_addr
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_ip_range_count > 0. The first IP address in the range.
			 	-static_ip_dst_increment
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_ip_range_count > 0. IP step used between IP on same IP range.
			 	-static_ip_dst_increment_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_ip_range_count > 0. Step to increment -static_ip_dst_increment between ranges.
			 	-static_ip_dst_range_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_ip_range_count > 0. IP step between IP ranges.
			 	-static_ip_dst_prefix_len
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_ip_range_count > 0. The numbers of bits in the network mask
			 		to be used with the IP address.
			 	-static_ip_dst_prefix_len_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_ip_range_count > 0. Step to increment the number of bits in
			 		the network masks to be used with the IP address between ranges.
			 	-static_ip_range_count
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_ip_range_count > 0. Number of IP static endpoint ranges to be created.
			 	-static_l3_protocol
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_ip_range_count > 0. The IP version number. Valid choices are:
			 		ipv4 (DEFAULT)
			 		ipv6
			 		Valid choices are:
			    		ipv4 -
			    		ipv6 -
			 	-static_indirect
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_lan_range_count > 0. Enables/Disables creation atm/fr ranges that will be mapped to the lan static endpoint. The atm_range_count /fr_range_count parameter will must be at least equal to $static_lan_range_count divided by $static_range_per_spoke . If -static_lan_intermediate_objref is specified, the atm/fr ranges specified in static_lan_intermediate_objref will be used.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 		Valid choices are:
			    		0 - disable
			    		1 - enable (DEFAULT)
			 	-static_range_per_spoke
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_lan_range_count > 0. Configure how many lan ranges will use the same atm/fr range. For example: if this parameter is 3, lan ranges 1, 2 and 3 will use atm range 1, lan ranges 4,5 and 6 will use atm range 2 and so on. The atm/fr ranges are taken from static_lan_intermediate_objref if it is specified or created if static_indirect is 1.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-static_lan_intermediate_objref
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_lan_range_count > 0. It is used to create a LAN object on ATM/POS interface related to a specific ATM/FR object. This parameter accepts static ATM/FR range handles (returned by interface_config with -static_enabled 1 and -static_atm_range_count/static_fr_range_count >=1). This parameter will be a list of elements separated by commas (,) that must be >= $static_lan_range_count divided by $static_range_per_spoke. ATM static endpoints can be used to create LAN objects only when -static_atm_header_encapsulation is one of: LLCBridgedEthernetFCS, LLCBridgedEthernetNoFCS, VccMuxBridgedEthernetFCS, VccMuxBridgedEthernetNoFCS. FR static endpoints can be used to create LAN objects only if layer 1 configuration of the port is Frame Relay (interface_config -intf_mode frame_relay2427).
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-static_lan_range_count
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1.
			 		Number of LAN static endpoint ranges to be created.
			 		If any of the following parameters -static_mac_dst, -static_mac_dst_count, -static_mac_dst_mode, -static_site_id, -static_site_id_enable, -static_vlan_enable, -static_vlan_id or -static_vlan_id_mode is present the default value is set to 1.
			 	-static_mac_dst
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_lan_range_count > 0. MAC address used in LAN ranges.
			 	-static_mac_dst_count
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_lan_range_count > 0. Number of MAC addresses to be generated by an LAN range.
			 	-static_mac_dst_count_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_lan_range_count > 0. The step to increment static_mac_dst_count between ranges.
			 	-static_mac_dst_mode
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_lan_range_count > 0. Valid choices are:
			 		increment (DEFAULT)
			 		fixed
			 		For increment MAC address from LAN range will be incremented.
			 		Valid choices are:
			    		fixed -
			    		increment -
			 	-static_mac_dst_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_lan_range_count > 0. MAC step between LAN ranges.
			 	-static_site_id
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_lan_range_count > 0 and -static_site_id_enable 0 and -static_lan_mac_range_mode normal.
			 		The Site ID is implemented for static (and dynamic) routes, including the Static Lan
			 		end point. Users can configure traffic streams by grouping routes
			 		belonging to the same Site ID.
			 	-static_site_id_enable
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_lan_range_count > 0 and -static_lan_mac_range_mode normal.
			 		Enable site id value for LAN range(s). Valid choices are:
			 		0 (DEFAULT)
			 		1
			 	-static_site_id_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_lan_range_count > 0 and -static_site_id_enable 0 and -static_lan_mac_range_mode normal.
			 		Step of site_id between LAN ranges.
			 	-static_vlan_enable
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_lan_range_count > 0. Enable VLAN for LAN ranges. Valid choices are:
			 		1 - enable
			 		0 - disable (DEFAULT)
			 	-static_vlan_id
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_lan_range_count > 0. Configure first VLAN ID.
			 		If stacked vlans need to be created, a list of values separated by the colon(:) character
			 		must be provided to this parameter.
			 	-static_vlan_id_mode
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_lan_range_count > 0 and -static_vlan_enable 1 and -static_lan_mac_range_mode normal.
			 		Select increment or fixed mode for vlan_id value.
			 		Valid choices are:
			    		fixed - not increment (DEFAULT)
			    		increment - increment inner and outer
			    		inner - increment inner
			    		outer - increment outer
			 	-static_vlan_id_step
			 		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			 		and -static_lan_range_count > 0 and -static_vlan_enable 1. Step of start
			 		VLAN ID between LAN ranges.
			 		If stacked vlans need to be created then this parameter must be a list of values separated through
			 		the colon(:) character. Each vlan ID will be incremented with coresponding values in this parameter.
			 		Example:
			 		If static_vlan_id is 1:2:3, static_lan_range_count is 4 and static_vlan_id_step is 2:4:6, four LAN ranges
			 		will be created with the following VLAN IDs: "1,2,3", "3,6,9", "5,10,15", "7,14,21".
			x	-static_lan_count_per_vc
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			x		and -static_lan_range_count > 0 and -static_lan_mac_range_mode bundled.
			x		The total count per VC in this bundled mode.
			x	-static_lan_incr_per_vc_vlan_mode
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			x		and -static_lan_range_count > 0 and -static_lan_mac_range_mode bundled.
			x		Enable the use of multiple VLANs, which are incremented for each additional
			x		VLAN per VC. Valid choices are:
			x		fixed (DEFAULT)
			x		increment
			x		inner
			x		outer
			x		Valid choices are:
			x   		fixed -
			x   		increment -
			x   		inner -
			x   		outer -
			x	-static_lan_mac_range_mode
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			x		and -static_lan_range_count > 0. Configure available MAC Range Mode. Valid choices are:
			x		normal -
			x		bundled -
			x		Valid choices are:
			x   		normal - This mode supports only a single MAC Id for all the VCs. Existing Static MAC Range fields are exposed in this mode.
Parameters -static_lan_count_per_vc and -static_lan_number_of_vcs are ignored in this case.
			x   		bundled - This mode supports Multiple MAC ids for each VC. Bundled mode is also
useful to create MAC ranges for testing L2 devices when L2/VPN is not being used. This is intended for L2VPN/VPLS application where there is a need to
simulate many MAC hosts behind each VC. The number of MAC Ids are dependent on the Number of VCs and Count Per VC that is configured.
			x	-static_lan_number_of_vcs
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			x		and -static_lan_range_count > 0 and -static_lan_mac_range_mode bundled.
			x		The total number of VCs.
			x	-static_lan_skip_vlan_id_zero
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			x		and -static_lan_range_count > 0. Enable skip vlan id 0.
			x	-static_lan_tpid
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			x		and -static_lan_range_count > 0 and -static_vlan_enable 1. Tag Protocol Identifier / TPID (hex). The
			x		EtherType that identifies the protocol header that follows the VLAN header (tag).
			x		If stacked vlans need to be created, a list of values separated by the colon(:) character
			x		must be provided to this parameter.
			x		Valid choices are:
			x		0x8100 (DEFAULT)
			x		0x88a8
			x		0x9100
			x		0x9200
			x		Valid choices are:
			x   		0x8100 -
			x   		0x88a8 -
			x   		0x88A8 -
			x   		0x9100 -
			x   		0x9200 -
			x	-static_lan_vlan_priority
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			x		and -static_lan_range_count > 0 and -static_vlan_enable 1.
			x		The user priority of the VLAN tag: a value from 0 through 7. The use and interpretation
			x		of this field is defined in ISO/IEC 15802-3.
			x		If stacked vlans need to be created, a list of values separated by the colon(:) character
			x		must be provided to this parameter.
			x	-static_lan_vlan_stack_count
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1
			x		and -static_lan_range_count > 0 and -static_vlan_enable 1.
			x		The number of VLANs configured for stacked VLANs/QinQ.
			x	-static_ig_atm_encap
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_ig_range_count > 0. The type of ATM encapsulation used for
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		-
			x	-static_ig_vlan_enable
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_ig_range_count > 0. Associate VLANs with the protocol interfaces. Vlan must already be enabled on the interfaces that will be specified with -static_ig_interface_handle_list.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-static_ig_ip_type
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_ig_range_count > 0. The IP version being used for the Protocol
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		-
			x	-static_ig_interface_enable_list
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_ig_range_count > 0. Specify whether to enable the corresponding protocol interface entry. This parameter must be a list of values separated by semicolons having the same length as -static_ig_interface_handle_list.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-static_ig_interface_handle_list
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1 and -static_ig_range_count > 0. A list of protocol interface handles (returned by interface_config with -l23_config_type protocol_interface) separated by semicolons ":". Only protocol interfaces with matching IP version and VLAN setting must be used.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-static_ig_range_count
			x		Parameter valid only for IxNetwork static endpoints when -static_enable 1. Specify the number of Interface Groups static endpoints to configure.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-pgid_split1_width
			x		The width, in bytes/bits, of the split PGID for IxOs/IxNetwork.
			x		This option has any meaning only if the -pgid_mode option is set to split.
			x		This option takes a list of values when -port_handle is a list of
			x		port handles. For IxOS the range accepted is 0-4 bytes.
			x		When IxNetwork TclAPI is used the range accepted is0-12 bits.
			n	-aps
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-aps_arch
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-aps_channel
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-aps_request_1_1
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-aps_request_1_n
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-aps_switch_mode
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-auto_line_rdi
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-auto_line_rei
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-auto_path_rdi
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-auto_path_rei
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-crlf_path_trace
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-control_plane_mtu
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-dst_mac_addr
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-ignore_pause_frames
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-interpacket_gap
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-long_lof_wait
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-output_enable
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-pause_length
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-rx_enhanced_prdi
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-rx_equalization
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-rx_hec
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-section_unequip
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-signal_fail_ber
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-ss_bits_pointer_interp
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-tx_enhanced_prdi
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-tx_k2
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-tx_preemphasis_main_tap
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-tx_preemphasis_post_tap
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-tx_s1
			x	-ethernet_attempt_enabled
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ethernet_attempt_rate
			x   		Specifies the rate in attempts/second at which attempts are made to
			x   		bring up sessions.
			x   		When using IxNetwork this parameter can take values from the 1-1000 range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ethernet_attempt_interval
			x   		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ethernet_attempt_scale_mode
			x   		Indicates whether the control is specified per port or per device group.
			x   		This setting is global for all the ethernet protocols configured in the ixncfg
			x   		and can be configured just when handle is /globals meaning that the user wants
			x   		to configure only global protocol settings.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		port -
			x       		device_group -
			x	-ethernet_diconnect_enabled
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ethernet_disconnect_rate
			x   		Specifies the rate in attempts/second at which attempts are made to
			x   		disconnect sessions.
			x   		When using IxNetwork this parameter can take values from the 1-1000 range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ethernet_disconnect_interval
			x   		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ethernet_disconnect_scale_mode
			x   		Indicates whether the control is specified per port or per device group.
			x   		This setting is global for all the ethernet protocols configured in the ixncfg
			x   		and can be configured just when handle is /globals meaning that the user wants
			x   		to configure only global protocol settings.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		port -
			x       		device_group -
			x	-ipv4_send_arp_rate
			x   		Specifies the rate in attempts/second at which attempts are made to
			x   		send ARP requests on sessions.
			x   		When using IxNetwork this parameter can take values from the 1-1000 range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_send_arp_interval
			x   		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_send_arp_max_outstanding
			x   		The maximum number of triggered instances of an action that is still awaiting a response or completion
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_send_arp_scale_mode
			x   		Indicates whether the control is specified per port or per device group.
			x   		This setting is global for all the IPv4 protocols configured in the ixncfg
			x   		and can be configured just when handle is /globals meaning that the user wants
			x   		to configure only global protocol settings.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		port -
			x       		device_group -
			x	-ipv4_attempt_enabled
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_attempt_rate
			x   		Specifies the rate in attempts/second at which attempts are made to
			x   		bring up sessions.
			x   		When using IxNetwork this parameter can take values from the 1-1000 range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_attempt_interval
			x   		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_attempt_scale_mode
			x   		Indicates whether the control is specified per port or per device group.
			x   		This setting is global for all the IPv4 protocols configured in the ixncfg
			x   		and can be configured just when handle is /globals meaning that the user wants
			x   		to configure only global protocol settings.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		port -
			x       		device_group -
			x	-ipv4_diconnect_enabled
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_disconnect_rate
			x   		Specifies the rate in attempts/second at which attempts are made to
			x   		disconnect sessions.
			x   		When using IxNetwork this parameter can take values from the 1-1000 range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_disconnect_interval
			x   		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_disconnect_scale_mode
			x   		Indicates whether the control is specified per port or per device group.
			x   		This setting is global for all the IPv4 protocols configured in the ixncfg
			x   		and can be configured just when handle is /globals meaning that the user wants
			x   		to configure only global protocol settings.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		port -
			x       		device_group -
			x	-ipv6_send_ns_rate
			x   		Specifies the rate in attempts/second at which attempts are made to
			x   		send NS requests on sessions.
			x   		When using IxNetwork this parameter can take values from the 1-1000 range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_send_ns_interval
			x   		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_send_ns_max_outstanding
			x   		The maximum number of triggered instances of an action that is still awaiting a response or completion
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_send_ns_scale_mode
			x   		Indicates whether the control is specified per port or per device group.
			x   		This setting is global for all the IPv6 protocols configured in the ixncfg
			x   		and can be configured just when handle is /globals meaning that the user wants
			x   		to configure only global protocol settings.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		port -
			x       		device_group -
			x	-ipv6_attempt_enabled
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_attempt_rate
			x   		Specifies the rate in attempts/second at which attempts are made to
			x   		bring up sessions.
			x   		When using IxNetwork this parameter can take values from the 1-1000 range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_attempt_interval
			x   		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_attempt_scale_mode
			x   		Indicates whether the control is specified per port or per device group.
			x   		This setting is global for all the IPv6 protocols configured in the ixncfg
			x   		and can be configured just when handle is /globals meaning that the user wants
			x   		to configure only global protocol settings.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		port -
			x       		device_group -
			x	-ipv6_diconnect_enabled
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_disconnect_rate
			x   		Specifies the rate in attempts/second at which attempts are made to
			x   		disconnect sessions.
			x   		When using IxNetwork this parameter can take values from the 1-1000 range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_disconnect_interval
			x   		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_disconnect_scale_mode
			x   		Indicates whether the control is specified per port or per device group.
			x   		This setting is global for all the IPv6 protocols configured in the ixncfg
			x   		and can be configured just when handle is /globals meaning that the user wants
			x   		to configure only global protocol settings.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		port -
			x       		device_group -
			x	-ipv6_autoconfiguration_send_ns_enabled
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_send_ns_rate
			x   		Specifies the rate in attempts/second at which attempts are made to
			x   		send NS requests on sessions.
			x   		When using IxNetwork this parameter can take values from the 1-1000 range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_send_ns_interval
			x   		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_send_ns_max_outstanding
			x   		The maximum number of triggered instances of an action that is still awaiting a response or completion
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_send_ns_scale_mode
			x   		Indicates whether the control is specified per port or per device group.
			x   		This setting is global for all the IPv6 Autoconfiguration protocols configured
			x   		in the ixncfg and can be configured just when handle is /globals meaning that
			x   		the user wants to configure only global protocol settings.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		port -
			x       		device_group -
			x	-ipv6_autoconfiguration_send_rs_enabled
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_send_rs_rate
			x   		Specifies the rate in attempts/second at which attempts are made to
			x   		send RS requests on sessions.
			x   		When using IxNetwork this parameter can take values from the 1-1000 range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_send_rs_interval
			x   		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_send_rs_max_outstanding
			x   		The maximum number of triggered instances of an action that is still awaiting a response or completion
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_send_rs_scale_mode
			x   		Indicates whether the control is specified per port or per device group.
			x   		This setting is global for all the IPv6 Autoconfiguration protocols configured
			x   		in the ixncfg and can be configured just when handle is /globals meaning that
			x   		the user wants to configure only global protocol settings.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		port -
			x       		device_group -
			x	-ipv6_autoconfiguration_attempt_enabled
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_attempt_rate
			x   		Specifies the rate in attempts/second at which attempts are made to
			x   		bring up sessions.
			x   		When using IxNetwork this parameter can take values from the 1-1000 range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_attempt_interval
			x   		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_attempt_max_outstanding
			x   		The maximum number of triggered instances of an action that is still awaiting a response or completion
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_attempt_scale_mode
			x   		Indicates whether the control is specified per port or per device group.
			x   		This setting is global for all the IPv6 Autoconfiguration protocols configured
			x   		in the ixncfg and can be configured just when handle is /globals meaning that
			x   		the user wants to configure only global protocol settings.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		port -
			x       		device_group -
			x	-ipv6_autoconfiguration_disconnect_enabled
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_disconnect_rate
			x   		Specifies the rate in attempts/second at which attempts are made to
			x   		disconnect sessions.
			x   		When using IxNetwork this parameter can take values from the 1-1000 range.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_disconnect_interval
			x   		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_disconnect_max_outstanding
			x   		The maximum number of triggered instances of an action that is still awaiting a response or completion
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_autoconfiguration_disconnect_scale_mode
			x   		Indicates whether the control is specified per port or per device group.
			x   		This setting is global for all the IPv6 Autoconfiguration protocols configured
			x   		in the ixncfg and can be configured just when handle is /globals meaning that
			x   		the user wants to configure only global protocol settings.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		port -
			x       		device_group -
			x	-notify_mac_move
			x   		Flag to determine if MAC move notifications should be sent
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_re_send_arp_on_link_up
			x   		Resends ARP after link up.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_permanent_mac_for_gateway
			x   		When enabled, adds permanent entries for Gateways with manual MAC.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_gratarp_transmit_count
			x   		Number of times GRATARP packet is sent per per source IPv4 address.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_gratarp_transmit_interval
			x   		Time interval to calculate next GRATARP packet transmission for each source IPv4 address.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_rarp_transmit_count
			x   		Number of times RARP packet is sent per per source IPv4 address.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv4_rarp_transmit_interval
			x   		Time interval to calculate next RARP packet transmission for each source IPv4 address.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_re_send_ns_on_link_up
			x   		Resends neighbor solicitation after link up.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_permanent_mac_for_gateway
			x   		When enabled, adds permanent entries for Gateways with manual MAC.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		A list containing the ethernet protocol stack handles that were added by the command (if any).
			xkey:ethernet_handle                               value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		A list containing the ipv4 protocol stack handles that were added by the command (if any).
			xkey:ipv4_handle                                   value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		A list containing the ipv6 protocol stack handles that were added by the command (if any).
			xkey:ipv6_handle                                   value:A list containing the ipv6 protocol stack handles that were added by the command (if any).
		A list containing the ipv6autoconfiguration protocol stack handles that were added by the command (if any).
			xkey:ipv6autoconfiguration_handle                  value:A list containing the ipv6autoconfiguration protocol stack handles that were added by the command (if any).
		A list containing the ipv6 loopback protocol stack handles that were added by the command (if any).
			xkey:ipv6_loopback_handle                          value:A list containing the ipv6 loopback protocol stack handles that were added by the command (if any).
		A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
			xkey:ipv4_loopback_handle                          value:A list containing the ipv4 loopback protocol stack handles that were added by the command (if any).
		A list containing the greoipv4 protocol stack handles that were added by the command (if any).
			xkey:greoipv4_handle                               value:A list containing the greoipv4 protocol stack handles that were added by the command (if any).
		A list containing the greoipv6 protocol stack handles that were added by the command (if any).
			xkey:greoipv6_handle                               value:A list containing the greoipv6 protocol stack handles that were added by the command (if any).
		$::SUCCESS | $::FAILURE
			 key:status                                        value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                           value:On status of failure, gives detailed information.
		A handle that can be used in router configs to designate an existing protocol interface. All static endpoints created with -static_enable 1 are returned on this key Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:interface_handle                              value:A handle that can be used in router configs to designate an existing protocol interface. All static endpoints created with -static_enable 1 are returned on this key Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		handles to the unconnected interfaces created in this call Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:routed_interface_handle                       value:handles to the unconnected interfaces created in this call Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		handle to the gre interfaces created in this call Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			 key:gre_interface_handle                          value:handle to the gre interfaces created in this call Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		ATM static endpoints configured when -static_enable 1
			 key:atm_endpoints                                 value:ATM static endpoints configured when -static_enable 1
		FR static endpoints configured when -static_enable 1
			 key:fr_endpoints                                  value:FR static endpoints configured when -static_enable 1
		IP static endpoints configured when -static_enable 1
			 key:ip_endpoints                                  value:IP static endpoints configured when -static_enable 1
		LAN static endpoints configured when -static_enable 1
			 key:lan_endpoints                                 value:LAN static endpoints configured when -static_enable 1
		Interface Group static endpoints configured when -static_enable 1
			 key:ig_endpoints                                  value:Interface Group static endpoints configured when -static_enable 1
		0 if arp table empty or 1 when arp table not empty. Available when -arp_send_req is 1.
			 key:<port_handle>.arp_request_success             value:0 if arp table empty or 1 when arp table not empty. Available when -arp_send_req is 1.
		0 if neighbor discover table empty or 1 when neighbor discover table not empty. Available when -arp_send_req is 1 or -send_router_solicitation is 1.
			 key:<port_handle>.router_solicitation_success     value:0 if neighbor discover table empty or 1 when neighbor discover table not empty. Available when -arp_send_req is 1 or -send_router_solicitation is 1.
		list of interface handles that failed to resolve their gateways ip addresses. Available when arp_request_success is 0.
			 key:<port_handle>.arp_ipv4_interfaces_failed      value:list of interface handles that failed to resolve their gateways ip addresses. Available when arp_request_success is 0.
		list of interface handles that didn't get any response to the router solicitation. Available when arp_request_success is 0.
			 key:<port_handle>.arp_ipv6_interfaces_failed      value:list of interface handles that didn't get any response to the router solicitation. Available when arp_request_success is 0.
		list of interface handles that failed to resolve their gateway. Available when arp_request_success is 0.
			 key:<protocol_handle>.arp_failed_item_handles     value:list of interface handles that failed to resolve their gateway. Available when arp_request_success is 0.
		list of interface handles that are not started. Available when arp_request_success is 0 and at least one of the sessions on which arp was sent is not started.
			 key:<protocol_handle>.arp_interfaces_not_started  value:list of interface handles that are not started. Available when arp_request_success is 0 and at least one of the sessions on which arp was sent is not started.
		0 if the ping request failed on any of the interfaces. Available only when -send_ping is 1 and -ping_dst is specified.
			 key:<port_handle>.ping_success                    value:0 if the ping request failed on any of the interfaces. Available only when -send_ping is 1 and -ping_dst is specified.
		Detailed status of the ping request on the specified port. Available only when -send_ping is 1 and -ping_dst is specified.
			 key:<port_handle>.ping_details                    value:Detailed status of the ping request on the specified port. Available only when -send_ping is 1 and -ping_dst is specified.
		A handle that can be used in router configs to designate an existing protocol interface. All static endpoints created with -static_enable 1 are returned on this key
			 key:interface_handle                              value:A handle that can be used in router configs to designate an existing protocol interface. All static endpoints created with -static_enable 1 are returned on this key
		handles to the unconnected interfaces created in this call
			 key:routed_interface_handle                       value: handles to the unconnected interfaces created in this call
		handle to the gre interfaces created in this call
			 key:gre_interface_handle                          value: handle to the gre interfaces created in this call
		ATM static endpoints configured when -static_enable 1
			 key:atm_endpoints                                 value: ATM static endpoints configured when -static_enable 1
		FR static endpoints configured when -static_enable 1
			 key:fr_endpoints                                  value: FR static endpoints configured when -static_enable 1
		IP static endpoints configured when -static_enable 1
			 key:ip_endpoints                                  value: IP static endpoints configured when -static_enable 1
		LAN static endpoints configured when -static_enable 1
			 key:lan_endpoints                                 value: LAN static endpoints configured when -static_enable 1
		Interface Group static endpoints configured when -static_enable 1
			 key:ig_endpoints                                  value: Interface Group static endpoints configured when -static_enable 1
		
		Examples:
		See files starting with Interface_ in the Samples subdirectory.  Also see most of the other sample files for further examples of the usage.  See Appendix A, "Example APIs," for further examples of the interface_config usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		1) You can configure multiple interfaces on the same Ixia port.
		2) If autonegotiation is explicitly set to 0, the valid speed/duplex
		combinations are:
		speed: ether10   duplex: half
		speed: ether10   duplex: full
		speed: ether100  duplex: half
		speed: ether100  duplex: full
		speed: ether1000 duplex: ignored, because it is always set to full
		Any other combination will return an error.
		If speed is set to ether10 or ether100 and the duplex parameter is missing the duplex will
		be set to full.
		3) Static endpoint parameters (active when -static_enable 1) that can have a separate value
		for each static  endpoint range should be specified as comma separated lists. If a comma
		separated parameter value accepts a list, the list will be separated by
		semicolons (:). -static_vlan_id is such a parameter. When  static_lan_vlan_stack_count
		is > 1, -static_vlan id will be a list separated with :, each value corresponding to
		a stack from the stacked vlans.
		4) When -handle is provided with the /globals value the arguments that configure global protocol
		setting accept both multivalue handles and simple values.
		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
		that configure global settings will only accept simple values. In this situation, these arguments will
		configure only the settings of the parent device group or the ports associated with the parent topology.
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  interface_handle, routed_interface_handle, gre_interface_handle
		Coded versus functional specification.1) You can configure multiple interfaces on the same Ixia port.
		2) If autonegotiation is explicitly set to 0, the valid speed/duplex combinations are:speed: ether10   duplex: halfspeed: ether10   duplex: fullspeed: ether100  duplex: halfspeed: ether100  duplex: fullspeed: ether1000 duplex: ignored, because it is always set to fullAny other combination will return an error.If speed is set to ether10 or ether100 and the duplex parameter is missing the duplex willbe set to full.
		3) Static endpoint parameters (active when -static_enable 1) that can have a separate value for each static  endpoint range should be specified as comma separated lists. If a comma separated parameter value accepts a list, the list will be separated by semicolons (:). -static_vlan_id is such a parameter. When - static_lan_vlan_stack_count is > 1, -static_vlan id will be a list separated with ":", each value corresponding to a stack from the stacked vlans
		
		See Also:
		
		"""
		return self._run_keyword("interface_config", kwargs)

	def interface_control(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: interface_control
			 	[-port_handle ANY]
			 	[-action      ANY]
		
		Arguments:
			 	-port_handle
			 	-action
		
		Return Values:
		   $::SUCCESS | $::FAILURE
			    key:status  value:$::SUCCESS | $::FAILURE
		   On status of failure, gives detailed information.
			    key:log     value:On status of failure, gives detailed information.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("interface_control", kwargs)

	def interface_stats(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: interface_stats
			 	[-port_handle ANY]
		
		Arguments:
			 	-port_handle
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:<port_handle>.<status>                                 value: $::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:<port_handle>.<log>                                    value: On status of failure, gives detailed information.
		same info as intf_mode of interface_config
			 key:<port_handle>.<intf_type>                              value: same info as intf_mode of interface_config
		SONET or SDH, if applicable
			 key:<port_handle>.<framing>                                value: SONET or SDH, if applicable
		official card name
			 key:<port_handle>.<card_name>                              value: official card name
		official port name
			 key:<port_handle>.<port_name>                              value: official port name
		same info as speed in interface_config
			 key:<port_handle>.<intf_speed>                             value: same info as speed in interface_config
		frames sent
			 key:<port_handle>.<tx_frames>                              value: frames sent
		frames received
			 key:<port_handle>.<rx_frames>                              value: frames received
		transmit duration
			 key:<port_handle>.<elapsed_time>                           value: transmit duration
		collision frames received
			 key:<port_handle>.<rx_collisions>                          value: collision frames received
		total collisions
			 key:<port_handle>.<total_collisions>                       value: total collisions
		duplex value, full or half
			 key:<port_handle>.<duplex>                                 value: duplex value, full or half
		number of fcs errors
			 key:<port_handle>.<fcs_errors>                             value: number of fcs errors
		number of late collisions
			 key:<port_handle>.<late_collisions>                        value: number of late collisions
		link value representative of an IxTclHal enum
			 key:<port_handle>.<link>                                   value: link value representative of an IxTclHal enum
		Indicates if the received PCS lane achieved sync-bit lock, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.sync_header_lock              value: Indicates if the received PCS lane achieved sync-bit lock, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		Indicates if the received PCS lane has achieved alignment marker lock, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.pcs_lane_marker_lock          value: Indicates if the received PCS lane has achieved alignment marker lock, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		The PCS lane number identified by the alignment marker, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.pcs_lane_marker_map           value: The PCS lane number identified by the alignment marker, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		Shows the actual skew in nanoseconds, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.relative_lane_skew            value: Shows the actual skew in nanoseconds, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		The number of synchronization bit errors received, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.synk_header_error_count       value: The number of synchronization bit errors received, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		The number of incorrect PCS lane markers received while in PCS lane lock state, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.pcs_lane_error_marker_count   value: The number of incorrect PCS lane markers received while in PCS lane lock state, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		The number of BIP-8 errors for a PCS lane, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.bip8_error_count              value: The number of BIP-8 errors for a PCS lane, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		Indicates the loss of sync header lock since the last statistic was read, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.lost_sync_header_lock         value: Indicates the loss of sync header lock since the last statistic was read, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		Indicates the loss of PCS lane marker lock since the last statistic was read, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.lost_pcs_lane_marker_lock     value: Indicates the loss of PCS lane marker lock since the last statistic was read, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		For 40/100Gig PCS error generation.
			 key:<port_handle>.pcs_sync_errors_received                 value: For 40/100Gig PCS error generation.
		For 40/100Gig PCS error generation.
			 key:<port_handle>.pcs_illegal_codes_received               value: For 40/100Gig PCS error generation.
		For 40/100Gig PCS error generation.
			 key:<port_handle>.pcs_remote_faults_received               value: For 40/100Gig PCS error generation.
		For 40/100Gig PCS error generation.
			 key:<port_handle>.pcs_local_faults_received                value: For 40/100Gig PCS error generation.
		For 40/100Gig PCS error generation.
			 key:<port_handle>.pcs_illegal_ordered_set_received         value: For 40/100Gig PCS error generation.
		For 40/100Gig PCS error generation.
			 key:<port_handle>.pcs_illegal_idle_received                value: For 40/100Gig PCS error generation.
		For 40/100Gig PCS error generation.
			 key:<port_handle>.pcs_illegal_sof_received                 value: For 40/100Gig PCS error generation.
		For 40/100Gig PCS error generation.
			 key:<port_handle>.pcs_out_of_order_sof_received            value: For 40/100Gig PCS error generation.
		For 40/100Gig PCS error generation.
			 key:<port_handle>.pcs_out_of_order_eof_received            value: For 40/100Gig PCS error generation.
		For 40/100Gig PCS error generation.
			 key:<port_handle>.pcs_out_of_order_data_received           value: For 40/100Gig PCS error generation.
		For 40/100Gig PCS error generation.
			 key:<port_handle>.pcs_out_of_order_ordered                 value: For 40/100Gig PCS error generation.
		For BERT, indicates the total number of bits sent, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.bert_bits_sent                value: For BERT, indicates the total number of bits sent, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		IFor BERT, indicates the total number of bits received, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.bert_bits_received            value: IFor BERT, indicates the total number of bits received, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		For BERT, indicates the total number of bit errors sent., where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.bert_bit_errors_sent          value: For BERT, indicates the total number of bit errors sent., where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		For BERT,indicates the total number of bit errors received, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.bert_bit_error_received       value: For BERT,indicates the total number of bit errors received, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		Indicates if the pattern is locked where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.bert_pattern_lock             value: Indicates if the pattern is locked where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		Indicates the Pattern Lock Lost value, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.bert_pattern_lock_lost        value: Indicates the Pattern Lock Lost value, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		Indicates if the received PCS lane achieved sync-bit lock, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.bert_bit_error_ratio          value: Indicates if the received PCS lane achieved sync-bit lock, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		For BERT, indicates the ratio of the number of errored bits compared to the total number of bits transmitted, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.bert_number_mismatched_ones   value: For BERT, indicates the ratio of the number of errored bits compared to the total number of bits transmitted, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		Indicates the number of expected ones that where received as zeroes, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.bert_mismatched_ones_ratio    value: Indicates the number of expected ones that where received as zeroes, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		Indicates the ratio of mismatched zeroes to the total number of bits, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.bert_number_mismatched_zeros  value: Indicates the ratio of mismatched zeroes to the total number of bits, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		Indicates the ratio of mismatched ones to the total number of bits, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
			 key:<port_handle>.<phy_lane>.bert_mismatched_zeros_ratio   value: Indicates the ratio of mismatched ones to the total number of bits, where phy_lane is 0A-3A for ether40Gig ports or 0A-9A,0B-9B for ether100Gig ports
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		All keys that are not listed in this documentation are not supported in the current implementation of this command.
		
		See Also:
		
		"""
		return self._run_keyword("interface_stats", kwargs)

	def ixvm_config(self, **kwargs):
		""" This command can be used to create and delete IxVM virtual cards on an IxVM virtual chassis.     Please note that no operation can be performed if the cards is owned by any user. Ownership needs to be cleared before making any configuration changes.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: ixvm_config
			x	-mode                     CHOICES create
			x                          CHOICES modify
			x                          CHOICES delete
			x                          CHOICES delete_all]
			x	[-port_action             CHOICES add delete]
			x	-virtual_chassis          ANY]
			x	[-card_no                 RANGE 1-32]
			x	[-port_no                 RANGE 1-9]
			x	[-management_ip           IP]
			x	[-keep_alive              RANGE 1-2147483647
			x                          DEFAULT 300]
			x	[-virtual_interface_list  REGEXP ^\w[0-9]+$]
			x	[-virtual_interface_count RANGE 1-9]
			x	[-mtu                     RANGE 1500-9000
			x                          DEFAULT 1500]
			x	[-promiscuous_mode        CHOICES 0 1
			x                          DEFAULT 0]
			x	[-break_locks             CHOICES 0 1]
			x	[-rebuild_from_discovery  CHOICES 0 1]
			x	[-rediscover              CHOICES 0 1]
			x	[-max_wait_timer          RANGE 0-300
			x                          DEFAULT 30]
		
		Arguments:
			x	-mode
			x   		create - Create virtual card(s) of the specified virtual chassis.
			x   		modify - Modify virtual card(s) properties (including adding/removing virtual ports).
			x   		delete - Delete virtual card(s) or delete virtual ports from a virtual card if port_no argument is specified.
			x   		delete_all - Delete all virtual cards from the specified virtual chassis.
			x	-port_action
			x		Valid only for mode modify.
			x		When specified will allow adding/deleting port(s) to existing cards.
			x		Without specifying this parameter only existing port(s) can be modified.
			x		Please note that in this mode the existing port setting will not be modified (mtu, promiscuous. arguments supplied will only refer to the new ports being added).
			x		Valid choices are:
			x   		add - This action will allow adding new ports to existing cards. Please note than a maximum of 9 ports can be added to a card (if the card has 10 virtual interfaces - 9 interfaces + 1 management).
This mode is similar with mode create, but instead of adding a new card will append to existing cards.
			x   		delete - This is similar with mode delete when port_no is present. Will delete the ports specified in the port_no from the card specified by management_ip or card_no.
			x	-virtual_chassis
			x		The ip or hostname of the virtual chassis. If a DNS name is provided, please make sure the name can be resolved using the dns provider from the ixnetwork_tcl_server machine.
			x	-card_no
			x		The number of the card affected by the chosen action. Valid only for mode modify or delete.
			x		If management_ip is provided the card_no is ignored.
			x	-port_no
			x		The number of the port affected by the chosen action. Valid only for mode modify or delete_port.
			x	-management_ip
			x		The management IPv4 address of the virtual card.
			x	-keep_alive
			x		The interval in seconds in which the keep alive is being sent to the virtual chassis.
			x	-virtual_interface_list
			x		The list of interface names that the virtual ports will use.
			x		This argument is only valid when mode is create or modify. For mode modify this argument is only valid when port_action is add.
			x		Example: providing a list of eth1, eth2, eth3 will result in 3 virtual ports using eth1, eth2 and respectively eth3 virtual network interface names.
			x	-virtual_interface_count
			x		The number of ports to create. Using this argument the interface names are automatically calculated.
			x		Can be used instead of virtual_interface_list.
			x		This argument is only valid when mode is create or modify. For mode modify this argument is only valid when port_action is add.
			x		When both virtual_interface_list and virtual_interface_count are present, virtual_interface_list will take precedence over virtual_interface_count and virtual_interface_count will be ignored.
			x		Example:virtual_interface_count 5 will result in eth1 eth2 eth3 eth4 and eth5 as the 5 created virtual interfaces
			x	-mtu
			x		The MTU of the virtual port created.
			x		When a single value is provided, the value will be applied to all ports given by the virtual_interface_list.
			x		When providing a list, the list length needs to match the length of the one provided for virtual_interface_list.
			x	-promiscuous_mode
			x		This argument specifies if the virtual port will use promiscuous mode. For more info on this setting please consult IxVM documentation.
			x		When providing a single value, the value will be applied to all ports given by the virtual_interface_list.
			x		When providing a list, the list length needs to match the length of the one provided for virtual_interface_list.
			x	-break_locks
			x		This argument, if specified, will force clear ownership if the virtual card is in use (has ownership taken by any user).
			x		This will allow modify/delete operations to be performed forcefully. Please note that forcefully clearing port ownership
			x		will disconnect any existing user from the port causing current running script failure.
			x		Valid only when mode is modify, delete. delete_all.
			x		For mode create, the ownership cannot be cleared using break_locks since the ports do not exist in order to clear ownership.
			x		If the ports are in use by other IxOS Virtual chassis you need to first delete/modify them from that chassis (and here you can use
			x		the break_locks and then add them to the current chassis).
			x	-rebuild_from_discovery
			x		This argument, if specified, will rebuild entire topology using discovered appliances.
			x		This argument is only valid for mode create.
			x		When this argument is used only the following arguments are valid: virtual_chassis, rediscover andpromiscuous_mode (only one value
			x		can be specified in this mode and this value will apply to all ports from all discovered appliances).
			x		Any other arguments will be ignored.
			x	-rediscover
			x		If this argument is specified, a rediscovery will be done prior to rebuilding from discovered appliances.
			x		Valid only when mode is rebuild_from_discovery is used.
			x	-max_wait_timer
			x		The maximum number of seconds to wait for the IxVM card/port to become ready when adding a new card/port.
			x		Giving a 0 value will cause the command to return without waiting.
			x		This argument is only valid when mode is create or modify.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		The ID of the card created from the virtual chassis.
			xkey:card_no  value:The ID of the card created from the virtual chassis.
		If status is failure, detailed information provided.
			 key:log      value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("ixvm_config", kwargs)

	def ixvm_control(self, **kwargs):
		""" This command enables the user to control the cards on IxVM virtual chassis.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: ixvm_control
			x	-action           CHOICES connect disconnect ]
			x	-virtual_chassis  ANY]
			x	[-card_no         NUMERIC]
			x	[-management_ip   IP]
			x	[-break_locks     CHOICES 0 1]
		
		Arguments:
			x	-action
			x   		connect - Connect (enable) virtual card. This operation needs to be executed on disconnected cards before they are available for usage.
			x   		disconnect - Disconnect (disable) virtual card. Disconnect (disable) the card from the current virtual chassis. This will prevent the card from being used, but will not delete it./
			x	-virtual_chassis
			x		The ip or hostname of the virtual chassis. If a DNS name is provided, please make sure the name can be resolved using the dns provider from the ixnetwork_tcl_server machine.
			x	-card_no
			x		The number of the card affected by the chosen action. If management_ip is provided this argument is ignored.
			x	-management_ip
			x		The management IPv4 adress of the virtual card affected by the choosen action. Card_no can also be provided insted of management ip. If both are provided, management_ip will take precedence and card_no will be ignored.
			x	-break_locks
			x		This argument, if specified, will force clear ownership if the virtual card is in use (has ownership taken by any user).
			x		Please note that forcefully clearing port ownership will disconnect any existing user from the port causing current running script failure.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("ixvm_control", kwargs)

	def ixvm_info(self, **kwargs):
		""" This command enables user to retrive all card and port data from an IxVM virtual chassis.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: ixvm_info
			x	[-mode            CHOICES current_configuration
			x                  CHOICES discovered_appliances
			x                  DEFAULT current_configuration]
			x	-virtual_chassis  ANY]
			x	[-rediscover      CHOICES 0 1]
		
		Arguments:
			x	-mode
			x   		current_configuration - Returns the current configuration of the cards and ports form the virtual chassis.
			x   		discovered_appliances - Returns the discovered appliances.
			x	-virtual_chassis
			x		The ip or hostname of the virtual chassis. If a DNS name is provided, please make sure the name can be resolved using the dns provider from the ixnetwork_tcl_server machine.
			x	-rediscover
			x		If this argument is specified, a rediscovery will be done prior to returning discovered appliances.
			x		Valid only when mode is discovered_appliances.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("ixvm_info", kwargs)

	def l2tp_config(self, **kwargs):
		""" Configures L2TPoE and L2TPoA sessions and tunnels for the specified test port. Each port can have upto 32000 sessions and 32000 tunnels.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: l2tp_config
			x	[-return_detailed_handles                        CHOICES 0 1
			x                                                 DEFAULT 0]
			 	[-l2_encap                                       CHOICES atm_vc_mux
			                                                  CHOICES atm_snap
			                                                  CHOICES atm_vc_mux_ethernet_ii
			                                                  CHOICES atm_snap_ethernet_ii
			                                                  CHOICES atm_vc_mux_ppp
			                                                  CHOICES atm_snap_ppp
			                                                  CHOICES ethernet_ii
			                                                  CHOICES ethernet_ii_vlan
			                                                  CHOICES ethernet_ii_qinq]
			 	[-l2tp_dst_addr                                  IP]
			 	[-l2tp_src_addr                                  IP]
			 	-mode                                            CHOICES lac lns
			 	[-handle                                         ANY]
			 	[-port_handle                                    REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-num_tunnels                                    RANGE 0-1024000]
			x	[-delete_attached_ppp                            CHOICES 0 1
			x                                                 DEFAULT 0]
			x	[-protocol_name                                  ALPHA]
			 	[-attempt_rate                                   RANGE 1-1000]
			 	[-auth_mode                                      CHOICES none pap chap pap_or_chap]
			 	[-action                                         CHOICES create modify remove
			                                                  DEFAULT create]
			 	[-auth_req_timeout                               RANGE 1-65535]
			 	[-avp_hide                                       FLAG]
			 	[-avp_rx_connect_speed                           ANY]
			 	[-avp_tx_connect_speed                           ANY]
			 	[-config_req_timeout                             RANGE 1-120]
			 	[-ctrl_chksum                                    FLAG]
			 	[-ctrl_retries                                   RANGE 1-100]
			 	[-data_chksum                                    FLAG]
			 	[-disconnect_rate                                RANGE 1-1000]
			 	[-domain_group_map                               ANY]
			 	[-echo_req                                       CHOICES 0 1]
			 	[-echo_req_interval                              RANGE 1-65535]
			 	[-echo_rsp                                       CHOICES 0 1
			                                                  DEFAULT 1]
			 	[-enable_magic                                   ANY]
			 	[-hello_interval                                 RANGE 1-180]
			 	[-hello_req                                      FLAG]
			 	[-hostname                                       ANY]
			 	[-hostname_wc                                    FLAG]
			 	[-init_ctrl_timeout                              RANGE 1-20]
			 	[-ip_cp                                          CHOICES ipv4_cp ipv6_cp dual_stack
			                                                  DEFAULT ipv4_cp]
			 	[-ipcp_req_timeout                               RANGE 1-120]
			 	[-l2tp_dst_step                                  IP]
			 	[-l2tp_src_count                                 RANGE 1-1024
			                                                  DEFAULT 1]
			 	[-l2tp_src_step                                  IP]
			 	[-length_bit                                     FLAG]
			 	[-max_auth_req                                   RANGE 1-65535]
			 	[-max_ctrl_timeout                               RANGE 1-20]
			 	[-max_ipcp_req                                   RANGE 1-255
			                                                  DEFAULT 10]
			 	[-max_outstanding                                ANY]
			 	[-max_terminate_req                              RANGE 0-1000
			                                                  DEFAULT 10]
			 	[-no_call_timeout                                RANGE 1-180
			                                                  DEFAULT 5]
			 	[-offset_bit                                     FLAG]
			 	[-offset_byte                                    RANGE 0-255]
			 	[-offset_len                                     RANGE 0-255]
			 	[-password                                       ALPHA]
			 	[-password_wc                                    FLAG]
			 	[-ppp_client_ip                                  IP]
			 	[-ppp_client_step                                IP]
			 	[-ppp_server_ip                                  IP]
			 	[-pvc_incr_mode                                  ANY]
			 	[-redial                                         FLAG]
			 	[-redial_max                                     RANGE 1-65535]
			 	[-redial_timeout                                 RANGE 1-20]
			 	[-rws                                            RANGE 1-2048]
			 	[-secret                                         ANY]
			 	[-secret_wc                                      FLAG]
			 	[-sequence_bit                                   FLAG]
			 	[-sess_distribution                              ANY]
			 	[-session_id_start                               ANY]
			 	[-sessions_per_tunnel                            RANGE 1-64000
			                                                  DEFAULT 1]
			 	[-terminate_req_timeout                          ANY]
			 	[-l2tp_credentials_count                         RANGE 1-1024
			                                                  DEFAULT 1]
			 	[-tun_auth                                       CHOICES authenticate_hostname
			                                                  CHOICES tunnel_authentication_disabled]
			 	[-tun_distribution                               ANY]
			 	[-tunnel_id_start                                ANY]
			 	[-udp_dst_port                                   RANGE 1-65535]
			 	[-udp_src_port                                   RANGE 1-65535]
			 	[-username                                       ALPHA]
			 	[-username_wc                                    FLAG]
			 	[-vci                                            ANY]
			 	[-vci_count                                      ANY]
			 	[-vci_step                                       ANY]
			 	[-vlan_count                                     RANGE 1-4094
			                                                  DEFAULT 4094]
			 	[-vlan_id                                        RANGE 0-4095
			                                                  DEFAULT 1]
			 	[-vlan_id_step                                   RANGE 0-4093
			                                                  DEFAULT 1]
			 	[-vlan_user_priority                             RANGE 0-7
			                                                  DEFAULT 0]
			 	[-vpi                                            ANY]
			 	[-vpi_count                                      ANY]
			 	[-vpi_step                                       ANY]
			 	[-wildcard_bang_end                              RANGE 0-65535]
			 	[-wildcard_bang_start                            RANGE 0-65535]
			 	[-wildcard_dollar_end                            RANGE 0-65535]
			 	[-wildcard_dollar_start                          RANGE 0-65535]
			 	[-wildcard_pound_end                             RANGE 0-65535]
			 	[-wildcard_pound_start                           RANGE 0-65535]
			 	[-wildcard_question_end                          RANGE 0-65535]
			 	[-wildcard_question_start                        RANGE 0-65535]
			x	[-addr_count_per_vci                             ANY]
			x	[-addr_count_per_vpi                             ANY]
			x	[-address_per_vlan                               RANGE 1-1000000000
			x                                                 DEFAULT 1]
			x	[-bearer_capability                              CHOICES digital analog both]
			x	[-bearer_type                                    CHOICES digital analog]
			x	[-dhcpv6_hosts_enable                            CHOICES 0 1
			x                                                 DEFAULT 0]
			x	[-dhcp6_pd_client_range_duid_enterprise_id       RANGE 1-2147483647
			x                                                 DEFAULT 10]
			x	[-dhcp6_pd_client_range_duid_type                CHOICES duid_en duid_llt duid_ll
			x                                                 DEFAULT duid_llt]
			x	[-dhcp6_pd_client_range_duid_vendor_id           RANGE 1-2147483647
			x                                                 DEFAULT 10]
			x	[-dhcp6_pd_client_range_duid_vendor_id_increment RANGE 1-2147483647
			x                                                 DEFAULT 1]
			x	[-dhcp6_pd_client_range_ia_id                    RANGE 1-2147483647
			x                                                 DEFAULT 10]
			x	[-dhcp6_pd_client_range_ia_id_increment          RANGE 1-2147483647
			x                                                 DEFAULT 1]
			x	[-dhcp6_pd_client_range_ia_t1                    RANGE 0-2147483647
			x                                                 DEFAULT 302400]
			x	[-dhcp6_pd_client_range_ia_t2                    RANGE 0-2147483647
			x                                                 DEFAULT 483840]
			x	[-dhcp6_pd_client_range_ia_type                  CHOICES iapd iana iata iana_iapd
			x                                                 DEFAULT iapd]
			x	[-dhcp6_pd_client_range_param_request_list       ANY]
			x	[-dhcp6_pd_client_range_renew_timer              RANGE 0-1000000000
			x                                                 DEFAULT 0]
			x	[-dhcp6_pd_client_range_use_vendor_class_id      ANY]
			x	[-dhcp6_pd_client_range_vendor_class_id          ANY]
			x	[-dhcp6_pgdata_max_outstanding_releases          RANGE 1-100000
			x                                                 DEFAULT 500]
			x	[-dhcp6_pgdata_max_outstanding_requests          RANGE 1-100000
			x                                                 DEFAULT 20]
			x	[-dhcp6_pgdata_override_global_setup_rate        CHOICES 0 1
			x                                                 DEFAULT 0]
			x	[-dhcp6_pgdata_override_global_teardown_rate     CHOICES 0 1
			x                                                 DEFAULT 0]
			x	[-dhcp6_pgdata_setup_rate_increment              ANY]
			x	[-dhcp6_pgdata_setup_rate_initial                RANGE 1-100000
			x                                                 DEFAULT 10]
			x	[-dhcp6_pgdata_setup_rate_max                    ANY]
			x	[-dhcp6_pgdata_teardown_rate_increment           ANY]
			x	[-dhcp6_pgdata_teardown_rate_initial             RANGE 1-100000
			x                                                 DEFAULT 50]
			x	[-dhcp6_pgdata_teardown_rate_max                 ANY]
			x	[-dhcp6_global_echo_ia_info                      CHOICES 0 1
			x                                                 DEFAULT 0]
			x	[-dhcp6_global_max_outstanding_releases          RANGE 1-100000
			x                                                 DEFAULT 500]
			x	[-dhcp6_global_max_outstanding_requests          RANGE 1-100000
			x                                                 DEFAULT 20]
			x	[-dhcp6_global_reb_max_rt                        RANGE 1-10000
			x                                                 DEFAULT 500]
			x	[-dhcp6_global_reb_timeout                       RANGE 1-100
			x                                                 DEFAULT 10]
			x	[-dhcp6_global_rel_max_rc                        RANGE 1-100
			x                                                 DEFAULT 5]
			x	[-dhcp6_global_rel_timeout                       RANGE 1-100
			x                                                 DEFAULT 1]
			x	[-dhcp6_global_ren_max_rt                        RANGE 1-10000
			x                                                 DEFAULT 600]
			x	[-dhcp6_global_ren_timeout                       RANGE 1-100
			x                                                 DEFAULT 10]
			x	[-dhcp6_global_req_max_rc                        RANGE 1-100
			x                                                 DEFAULT 10]
			x	[-dhcp6_global_req_max_rt                        RANGE 1-10000
			x                                                 DEFAULT 30]
			x	[-dhcp6_global_req_timeout                       RANGE 1-100
			x                                                 DEFAULT 1]
			x	[-dhcp6_global_setup_rate_increment              ANY]
			x	[-dhcp6_global_setup_rate_initial                RANGE 1-100000
			x                                                 DEFAULT 10]
			x	[-dhcp6_global_setup_rate_max                    ANY]
			x	[-dhcp6_global_sol_max_rc                        RANGE 1-100
			x                                                 DEFAULT 3]
			x	[-dhcp6_global_sol_max_rt                        RANGE 1-10000
			x                                                 DEFAULT 120]
			x	[-dhcp6_global_sol_timeout                       RANGE 1-100
			x                                                 DEFAULT 4]
			x	[-dhcp6_global_teardown_rate_increment           ANY]
			x	[-dhcp6_global_teardown_rate_initial             RANGE 1-100000
			x                                                 DEFAULT 50]
			x	[-dhcp6_global_teardown_rate_max                 ANY]
			x	[-dhcp6_global_wait_for_completion               ANY]
			x	[-hosts_range_count                              ANY]
			x	[-hosts_range_eui_increment                      ANY]
			x	[-hosts_range_first_eui                          ANY]
			x	[-hosts_range_ip_prefix                          ANY]
			x	[-hosts_range_subnet_count                       ANY]
			x	[-dhcp6_pd_server_range_dns_domain_search_list   ANY]
			x	[-dhcp6_pd_server_range_first_dns_server         IP]
			x	[-hosts_range_ip_outer_prefix                    ANY]
			x	[-hosts_range_ip_prefix_addr                     ANY]
			x	[-dhcp6_pd_server_range_second_dns_server        IP]
			x	[-dhcp6_pd_server_range_subnet_prefix            NUMERIC]
			x	[-dhcp6_pd_server_range_start_pool_address       IP
			x                                                 DEFAULT ::0]
			x	[-lease_time_max                                 ANY]
			 	[-lease_time                                     RANGE 300-30000000
			                                                  DEFAULT 3600]
			x	[-framing_capability                             CHOICES sync async both]
			x	[-inner_address_per_vlan                         RANGE 1-1000000000
			x                                                 DEFAULT 1]
			x	[-inner_vlan_count                               RANGE 1-4094
			x                                                 DEFAULT 4094]
			x	[-inner_vlan_id                                  RANGE 0-4095
			x                                                 DEFAULT 1]
			x	[-inner_vlan_id_step                             RANGE 0-4093
			x                                                 DEFAULT 1]
			x	[-inner_vlan_user_priority                       RANGE 0-7
			x                                                 DEFAULT 0]
			x	[-ipv6_pool_addr_prefix_len                      RANGE 0-128
			x                                                 DEFAULT 64]
			x	[-ipv6_pool_prefix                               ANY]
			x	[-ipv6_pool_prefix_len                           RANGE 1-127
			x                                                 DEFAULT 48]
			x	[-max_configure_req                              RANGE 1-255
			x                                                 DEFAULT 10]
			x	[-number_of_sessions                             RANGE 1-9216000]
			x	[-ppp_client_iid                                 IPV6
			x                                                 DEFAULT 00:11:11:11:00:00:00:01]
			x	[-ppp_client_iid_step                            IPV6
			x                                                 DEFAULT 00:00:00:00:00:00:00:01]
			x	[-ppp_server_iid                                 IPV6
			x                                                 DEFAULT 00:11:22:11:00:00:00:01]
			x	[-proxy                                          ANY]
			x	[-enable_term_req_timeout                        ANY]
			x	[-src_mac_addr                                   MAC]
			x	[-src_mac_addr_auto                              ANY]
			x	[-l2tp_src_gw                                    IP]
			x	[-l2tp_src_gw_step                               IP]
			x	[-l2tp_src_gw_incr_mode                          CHOICES per_subnet per_interface
			x                                                 DEFAULT per_subnet]
			x	[-l2tp_src_prefix_len                            RANGE 0-32
			x                                                 DEFAULT 16]
			n	[-avp_framing_type                               ANY]
			n	[-ppp_server_step                                ANY]
			n	[-vlan_user_priority_count                       ANY]
			n	[-vlan_user_priority_step                        ANY]
			n	[-avp_hide_list                                  ANY]
			n	[-l2tp_dst_count                                 ANY]
			x	[-lns_host_name                                  ANY]
			x	[-accept_any_auth_value                          CHOICES 0 1]
			x	[-dns_server_list                                ANY]
			x	[-send_dns_options                               CHOICES 0 1]
			x	[-lcp_accm                                       NUMERIC]
			x	[-lcp_enable_accm                                CHOICES 0 1]
			x	[-enable_mru_negotiation                         CHOICES 0 1]
			x	[-desired_mru_rate                               RANGE 64-10000]
			x	[-server_dns_options                             CHOICES accept_requested_addresses
			x                                                 CHOICES accept_only_requested_primary_address
			x                                                 CHOICES supply_primary_and_secondary
			x                                                 CHOICES supply_primary_only
			x                                                 CHOICES disable_extension]
			x	[-ppp_local_iid_step                             NUMERIC]
			x	[-ppp_local_ip_step                              IPV4]
			x	[-server_ipv4_ncp_configuration                  CHOICES serveronly clientmay]
			x	[-server_netmask                                 IPV4]
			x	[-server_netmask_options                         CHOICES accept_requested_netmask
			x                                                 CHOICES supply_netmask
			x                                                 CHOICES disable_extension]
			x	[-server_primary_dns_address                     IPV4]
			x	[-server_secondary_dns_address                   IPV4]
			x	[-enable_server_signal_iwf                       CHOICES 0 1]
			x	[-enable_server_signal_loop_char                 CHOICES 0 1]
			x	[-enable_server_signal_loop_encap                CHOICES 0 1]
			x	[-enable_server_signal_loop_id                   CHOICES 0 1]
			x	[-server_ipv6_ncp_configuration                  CHOICES serveronly clientmay]
			x	[-server_wins_options                            CHOICES accept_requested_addresses
			x                                                 CHOICES accept_only_requested_primary_address
			x                                                 CHOICES supply_primary_and_secondary
			x                                                 CHOICES supply_primary_only
			x                                                 CHOICES disable_extension]
			x	[-server_wins_primary_address                    IPV4]
			x	[-server_wins_secondary_address                  IPV4]
			x	[-enable_domain_groups                           CHOICES 0 1]
			x	[-chap_name                                      ALPHA]
			x	[-chap_secret                                    ALPHA]
			x	[-client_dns_options                             CHOICES request_primary_and_secondary
			x                                                 CHOICES request_primary_only
			x                                                 CHOICES accept_addresses_from_server
			x                                                 CHOICES accept_only_primary_address_from_server
			x                                                 CHOICES disable_extension]
			x	[-client_ipv4_ncp_configuration                  CHOICES learned request]
			x	[-client_netmask                                 IPV4]
			x	[-client_netmask_options                         CHOICES request_specific_netmask
			x                                                 CHOICES accept_netmask_from_server
			x                                                 CHOICES disable_extension]
			x	[-client_primary_dns_address                     IPV4]
			x	[-client_secondary_dns_address                   IPV4]
			x	[-client_ipv6_ncp_configuration                  CHOICES learned request]
			x	[-client_wins_options                            CHOICES request_primaryandsecondary_wins
			x                                                 CHOICES request_primaryonly_wins
			x                                                 CHOICES accept_addresses_from_server
			x                                                 CHOICES accept_only_primary_address_from_server
			x                                                 CHOICES disable_extension]
			x	[-client_wins_primary_address                    IPV4]
			x	[-client_wins_secondary_address                  IPV4]
			x	[-manual_gateway_mac                             MAC]
			x	[-resolve_gateway                                CHOICES 0 1]
			x	[-enable_exclude_hdlc                            CHOICES 0 1]
		
		Arguments:
			x	-return_detailed_handles
			x		This argument determines if individual interface, session or router handles are returned by the current command.
			x		This applies only to the command on which it is specified.
			x		Setting this to 0 means that only NGPF-specific protocol stack handles will be returned. This will significantly
			x		decrease the size of command results and speed up script execution.
			x		The default is 0, meaning only protocol stack handles will be returned.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-l2_encap
			 		Encapsulation type for the ATM and ethernet.Valid options are:
			 		atm_vc_mux
			 		atm_snap
			 		atm_vc_mux_ethernet_ii
			 		atm_snap_ethernet_ii
			 		atm_vc_mux_ppp
			 		atm_snap_ppp
			 		ethernet_ii
			 		ethernet_ii_vlan
			 		ethernet_ii_qinq
			 		Valid choices are:
			    		atm_vc_mux -
			    		atm_snap -
			    		atm_vc_mux_ethernet_ii -
			    		atm_snap_ethernet_ii -
			    		atm_vc_mux_ppp -
			    		atm_snap_ppp -
			    		ethernet_ii -
			    		ethernet_ii_vlan -
			    		ethernet_ii_qinq -
			 	-l2tp_dst_addr
			 		Base Destination IPv4 address to be used for setting up tunnel.
			 	-l2tp_src_addr
			 		Base IPv4 address to be used for the local IP interface on the port.
			 	-mode
			 		Whether port will be acting as a LAC or LNS.
			 		Valid choices are:
			    		lac -
			    		lns -
			 	-handle
			 		L2tp handle of a configuration to be modified or removed.
			 		Dependencies: only available when IxNetwork is used for the L2tp configuration.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-port_handle
			 		The port on which the L2TP sessions and tunnels are to be created.
			 	-num_tunnels
			 		Number of tunnels to be configured on the port.
			x	-delete_attached_ppp
			x		If 1, remove the attached device group (pppoxclient) for the LAC.This parameter is available only for -action remove.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-protocol_name
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-attempt_rate
			 		Specifies the rate in attempts/second at which attempts are made to
			 		bring up sessions.
			 	-auth_mode
			 		Authentication mode.Valid choices are:
			 		none
			 		pap
			 		chap
			 		pap_or_chap - Accept both pap and chap offered by DUT. This parameter is available only for -action create.
			 		Valid choices are:
			    		none -
			    		pap -
			    		chap -
			    		pap_or_chap -
			 	-action
			 		The action mode for configuring L2tp. Valid choices are:
			 		create
			 		modify
			 		remove
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		create -
			    		modify -
			    		remove -
			 	-auth_req_timeout
			 		Specifies the timeout value in seconds for acknowledgement of an
			 		authentication Request. This parameter is available only for -action create.
			 	-avp_hide
			 		Enable hiding of the AVPs in the L2TP control messages.
			 	-avp_rx_connect_speed
			 		This parameter is deprecated. It is accepted as procedure parameter but the functionality for it does not exist anymore.The Rx Connect Speed AVP values sent in the ICCN message. Any integer value may be used.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-avp_tx_connect_speed
			 		This parameter is deprecated. It is accepted as procedure parameter but the functionality for it does not exist anymore.AVP value to be sent as tx connect speed
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-config_req_timeout
			 		Specifies the timeout value in seconds for acknowledgement of a
			 		Configure Request or Terminate Request. This parameter is available only for -action create.
			 	-ctrl_chksum
			 		Enable sending the valid UDP checksum in the L2TP control messages.
			 	-ctrl_retries
			 		Number of times to retry a L2TP control message.
			 	-data_chksum
			 		Enable sending the valid UDP checksum in the L2TP data messages.
			 	-disconnect_rate
			 		Specifies the rate in disconnects/s at which sessions are
			 		disconnected.
			 	-domain_group_map
			 		List of domain group to LNS IP mapping.
			 		Each domain group can have thousands of domains.
			 		With the help of domain group it is very easy to map thousands of
			 		domains to one or more LNS IP addresses.
			 		When using IxNetwork:
			 		The domain group list is defined as:
			 		{ { IP_list_definition } { { domain_name } { lnsIP1index lnsIP2index
			 		... } } }.
			 		Where:
			 		IP_list_definition is defined as:
			 		{ ip_count starting_ip increment_step incremented_byte }
			 		ip_count <1-65535> : the number of LNS IPs.
			 		starting_ip <IPv4> : base LNS IP.
			 		increment_step <NUMERIC> : the step used to increment the LNS IP.
			 		incremented_byte <1-4> : the byte of the LNS IP to be incremented.
			 		domain_name is defined as:
			 		{ base_name wc wc_width wc_count wc_repeat trailing_name}
			 		base_name <STRING> : name to be used for the domain(s).
			 		wc {1|0} : enables wildcard substitution in the name field. If this
			 		is set to 0, the rest of the following values
			 		are ignored.
			 		wc_width <0-65535> : defines the number of digits in the generated portion of
			 		the domain name, and the first value to use in the
			 		generated portion of the domain name. For example,
			 		a wc_width of 001 will cause the generated portion
			 		of the domain name to be three digits wide, with
			 		the first value being 001. If the Base Name is mycompany,
			 		the first generated domain name will be mycompany001.
			 		The width of the generated portion is preserved when
			 		values are incremented, so the next domains generated
			 		will be mycompany002, mycompany003, and so forth.
			 		wc_count <1-32000> : the number of iterations of the numerical field -
			 		used for the name substitution
			 		wc_repeat <1-32000> : the number of times the id is repreated before
			 		passing to the next value - used for the name
			 		substitution
			 		trailing_name <STRING> : the string appended after the numerical
			 		substitution part of the domain name.
			 		lnsIPindex : The index of the LNS IP address from the IP list defined
			 		in the IP_list_definition section.
			 	-echo_req
			 		When set to 1, enables Echo Requests, when set to 0, disables Echo
			 		Requests.
			 	-echo_req_interval
			 		Specifies the time interval in seconds for sending LCP echo
			 		requests. Valid only if -echo_req is set to 1. This parameter is available only for -action create.
			 	-echo_rsp
			 		When set to 0, disabled sending of the echo Responses, when set to
			 		1, enables Echo Replies. Default enabled. This can be used to do
			 		some negative testing. This parameter is available only for -action create.
			 	-enable_magic
			 		Enables or disables negotiaton of magic numbers.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-hello_interval
			 		Time interval between sending of the hello request. Only applicable
			 		if the -hello_req is set to 1.
			 	-hello_req
			 		Enable sending of the hello request.
			 	-hostname
			 		The LAC Hostname to be used during the tunnel setup. Note that a range of
			 		hostname can be setup using the autoincrement feature. See
			 		option -hostname_wc.
			 	-hostname_wc
			 		Enables wildcard substitution in the hostname field.
			 	-init_ctrl_timeout
			 		Initial timeout for L2TP control message.
			 	-ip_cp
			 		Valid choices are:
			 		ipv4_cp -
			 		ipv6_cp -
			 		dual_stack -
			 		Valid choices are:
			    		ipv4_cp - IPv4 Control Protocol. When dhcpv6_hosts_enable is 1 a IPv4
range will be created that can coexist with other ranges from the same port created with dhcpv6_hosts_enable 1. An error will be issued if
dhcpv6_hosts_enable is 0 and other ranges created with dhcpv6_hosts_enable 1 exist on the same port.
			    		ipv6_cp - IPv6 Control Protocol. When dhcpv6_hosts_enable is 1 a DHCPv6 behind
l2tp range will be created. An error will be issued if dhcpv6_hosts_enable is 0 and other ranges created with dhcpv6_hosts_enable 1 exist on the same port.
			    		dual_stack - Valid only when dhcpv6_hosts_enable is 1. A dual stack DHCPv6 behind
l2tp range will be created. An error will be issued if other ranges created with dhcpv6_hosts_enable 0 exist on the same port.
			 	-ipcp_req_timeout
			 		Specifies the timeout value in seconds for acknowledgement of an
			 		IPCP configure request. This parameter is available only for -action create.
			 	-l2tp_dst_step
			 		The modifier for the l2tp destination address for multiple destination
			 		addresses.
			 	-l2tp_src_count
			 		Number of source IP addresses to simulate on the port.
			 	-l2tp_src_step
			 		The modifier for the l2tp source address for multiple source addresses.
			 	-length_bit
			 		Enable sending of the length field in the L2TP data messages.
			 	-max_auth_req
			 		Specifies the maximum number of authentication requests that can be
			 		sent without getting an authentication response from the DUT or if
			 		getting a negative authentication response. This parameter is available only for -action create.
			 	-max_ctrl_timeout
			 		Maximum timeout for L2TP control message.
			 	-max_ipcp_req
			 		Specifies the maximum number of IPCP configure requests that can be
			 		sent without getting an ack from the DUT.
			 		The range is 1-255. This parameter is available only for -action create.
			 	-max_outstanding
			 		Specifies the maximum number of sessions in progress, which includes the sessions in the process of either coming up or disconnecting, at one time.The range is 1-1000.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-max_terminate_req
			 		Specifies the maximum number of Terminate Requests that can be sent
			 		without acknowledgement. This parameter is available only for -action create.
			 		The range is 0-1000.
			 	-no_call_timeout
			 		Number of seconds to wait before tearing down the tunnels when
			 		the last sesision on the tunnel goes down.
			 		The range is 1-180.
			 	-offset_bit
			 		Enable sending of the offset field in the L2TP data messages.
			 	-offset_byte
			 		This is the value inserted in the offset field, if enabled
			 		by -offset_bit and -offset_len option.
			 	-offset_len
			 		If the -offset_bit is set to 1, this option controls number of
			 		bytes (specified by the -offset_byte option) to be inserted in after
			 		the L2TP data message header.
			 	-password
			 		Password, PAP, and CHAP only.
			 	-password_wc
			 		Enables wildcard substituation in the password field.
			 	-ppp_client_ip
			 		Base IP address of the client IP pool allocated by the LNS. Only
			 		valid if the mode option is set lns. For IPv6 this is the client IID.
			 		The value will be the formed from the least significant 64 bits of the
			 		IPv6 address provided. This parameter is available only for -action create.
			 	-ppp_client_step
			 		Step size to use for allocating client IP addresses. Only
			 		valid if the mode option is set lns. This parameter is available only for -action create.
			 	-ppp_server_ip
			 		Local IP address of the PPP server. Only valid if the mode is lns.
			 		For IPv6 this is the server IID.
			 		The value will be the formed from the least significant 64 bits of the
			 		IPv6 address provided. This parameter is available only for -action create.
			 	-pvc_incr_mode
			 		vpi- Increment VPI first then VCI (all based on the info configured).vci- Increment first VCI then VPI.both- Increment both VPI and VCI at the same time.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-redial
			 		Enable redialling of the session if the session drops after
			 		establishment due to any reason other than operator initiated
			 		teardown.
			 	-redial_max
			 		Number of times to redial before declaring it failure.
			 	-redial_timeout
			 		Number of seconds to wait between successive redial attempts.
			 	-rws
			 		Receive window size.
			 	-secret
			 		Secret to be used during the tunnel setup. Note that a range of
			 		secret can be setup using the autoincrement feature. See
			 		option -secret_wc.
			 	-secret_wc
			 		Enables wildcard substitution in the secret field.
			 	-sequence_bit
			 		Enable sequence numbering for the L2TP data messages.
			 	-sess_distribution
			 		Sessions are distributed by first filling one tunnel with sessions per tunnel (or one session per tunnel), then with a round robin between next - Sessions are filled in round robin fashion for all tunnelsfill - First sessions are allocated to single tunnel
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-session_id_start
			 		This parameter is deprecated. It is accepted as procedure parameter but the functionality for it does not exist anymore.Starting session ID to be used as local call ID.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-sessions_per_tunnel
			 		Number of sessions per tunnel.
			 		The range is 1-16000.
			 	-terminate_req_timeout
			 		Specifies the timeout value in seconds for acknowledgement of a Terminate Request.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-l2tp_credentials_count
			 		Number of L2TP Authentication credentials the LNS accepts.
			 		The range is 1-1024.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-tun_auth
			 		Enable tunnel authentication during the tunnel setup.
			 		Valid choices are:
			    		authenticate_hostname - Enable tunnel authentication.
			    		tunnel_authentication_disabled- Disable tunnel authentication.
			 	-tun_distribution
			 		Tunnel allocation algorithm. Tunnels can be allocated using two mechanisms at this time (this may be extended in the future by adding new options, or vendors can have their own allocation algorithms).next_tunnelfill_tunnel - In the mode, l2tp_dst_ip specified above is used as the tunnel destination point. e.g.: l2tp_src_addr= 10.1.1.1, l2tp_dst_addr= 10.1.1.2, l2tp_src_count= 4, l2tp_src_step= 0.0.1.0, l2tp_dst_step= 0.0.1.0. The tunnels will be created with src/dest as: 10.1.1.1 / 10.1.1.2, 10.1.2.1 / 10.1.2.2, 10.1.3.1 / 10.1.3.2, 10.1.4.1 / 10.1.4.2.domain_group_map - In this mode tunnel allocation algorithm depends on the domain group to LNS IP mapping described as a part of the -domain_group_map option and please see the example there.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-tunnel_id_start
			 		This parameter is deprecated. It is accepted as procedure parameter but the functionality for it does not exist anymore.Starting tunnel ID to be used as local tunnel ID.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-udp_dst_port
			 		Destination UDP port to be used for tunnels setup.
			 	-udp_src_port
			 		Source UDP port to be used for tunnels setup.
			 	-username
			 		Username, PAP, and CHAP only.
			 	-username_wc
			 		Enables wildcard substitution in the username field.
			 	-vci
			 		Starting VCI for PPPoA and PPPoEoA.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vci_count
			 		Number of VCIs.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vci_step
			 		Step value applied to VCI, PPPoA and PPPoEoA only.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vlan_count
			 		Number of VLAN IDs, applies to L2TPoE only and if -l2_encap is set to
			 		ethernet_ii_vlan.
			 	-vlan_id
			 		Starting VLAN ID, applies to L2TPoE only and if -l2_encap is set to
			 		ethernet_ii_vlan.
			 	-vlan_id_step
			 		Step value applied to VLAN ID, applies to L2TPo only and if -l2_encap
			 		is set to ethernet_ii_vlan.
			 	-vlan_user_priority
			 		VLAN user priority, applies to L2TPoE only and if -l2_encap is set to
			 		ethernet_ii_vlan.
			 	-vpi
			 		Starting VPI for PPPoA and PPPoEoA.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vpi_count
			 		Number of VPIs.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vpi_step
			 		Step value applied to VPI, PPPoA and PPPoEoA only.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-wildcard_bang_end
			 		Ending value for wildcard symbol 1 (!) substitution.
			 	-wildcard_bang_start
			 		Starting value for wildcard symbol 1 (!) substitution.
			 	-wildcard_dollar_end
			 		Ending value for wildcard symbol 2 ($) substitution.
			 	-wildcard_dollar_start
			 		Starting value for wildcard symbol 2 ($) substitution.
			 	-wildcard_pound_end
			 		Ending value for wildcard symbol 1 (\) substitution. It is also
			 		valid to useas the substitution symbol.
			 	-wildcard_pound_start
			 		Starting value for wildcard symbol 1 (\) substitution. It is also
			 		valid to useas the substitution symbol.
			 	-wildcard_question_end
			 		Ending value for wildcard symbol 2 (?) substitution.
			 	-wildcard_question_start
			 		Starting value for wildcard symbol 2 (?) substitution.
			x	-addr_count_per_vci
			x		Specifies the number of addresses assigned to one VCI value. When this number is reached, an increment operation is initiated. This parameter is valid only when using IxTclNetwork API.Valid values: 1 - 65535.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-addr_count_per_vpi
			x		Specifies the number of addresses assigned to one VPI value. 	When this number is reached, an increment operation is initiated. This parameter is valid only when using IxTclNetwork API.Valid values: 1- 65535.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-address_per_vlan
			x		How often a new outer VLAN ID is generated. For example, a value of 10
			x		will cause a new VLAN ID to be used in blocks of 10 IP addresses.
			x	-bearer_capability
			x		Indicates to the DUT the bearer device types for which HLT can
			x		accept incoming calls.
			x		Valid choices are:
			x   		digital - Digital only.
			x   		analog - Analog only.
			x   		both - Either analog or digital (the two enums are or'd together).
			x	-bearer_type
			x		The device type requested by HLT for outgoing calls.
			x		Valid choices are:
			x   		digital - Request digital device capability.
			x   		analog - Request analog device capability.
			x	-dhcpv6_hosts_enable
			x		Valid choices are:
			x		0Configure standard PPPoE
			x		1Enable using DHCPv6 hosts behind PPP CPE feature.
			x	-dhcp6_pd_client_range_duid_enterprise_id
			x		Define the vendors registered Private Enterprise Number as maintained by IANA.
			x		Available starting with HLT API 3.90. Valid when port_role is access;
			x		dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack;
			x		dhcp6_pd_client_range_duid_type is duid_en.
			x	-dhcp6_pd_client_range_duid_type
			x		Define the DHCP unique identifier type.
			x		Available starting with HLT API 3.90. Valid when port_role is access;
			x		dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x		Valid choices are:
			x   		duid_en - duid_en
			x   		duid_llt - (DEFAULT) duid_llt
			x   		duid_ll - duid_ll
			x	-dhcp6_pd_client_range_duid_vendor_id
			x		Define the vendor-assigned unique ID for this range. This ID is incremented
			x		automatically for each DHCP client.
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x		is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or
			x		dual_stack; dhcp6_pd_client_range_duid_type is duid_en.
			x	-dhcp6_pd_client_range_duid_vendor_id_increment
			x		Define the step to increment the vendor ID for each DHCP client.
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x		is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack;
			x		dhcp6_pd_client_range_duid_type is duid_en.
			x	-dhcp6_pd_client_range_ia_id
			x		Define the identity association unique ID for this range. This ID is incremented
			x		automatically for each DHCP client.
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role is
			x		access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_pd_client_range_ia_id_increment
			x		Define the step used to increment dhcp6_pd_client_range_ia_id for each
			x		DHCP client.
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x		is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_pd_client_range_ia_t1
			x		Define the suggested time at which the client contacts the server from which
			x		the addresses were obtained to extend the lifetimes of the addresses assigned.
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x		is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_pd_client_range_ia_t2
			x		Define the suggested time at which the client contacts any available
			x		server to extend the lifetimes of the addresses assigned.
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x		is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_pd_client_range_ia_type
			x		Define Identity Association Type.
			x		Valid choices are:IAPD, IANA, IATA, IANA_IAPD
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role is
			x		access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x		Valid choices are:
			x   		iapd -
			x   		iana -
			x   		iata -
			x   		iana_iapd -
			x	-dhcp6_pd_client_range_param_request_list
			x		Accepts list of values. Define the list of options in a message between a client and a server. (DEFAULT = {2 7 23 24})Dependencies: Available starting with HLT API 3.90. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pd_client_range_renew_timer
			x		Define the user-defined lease renewal timer. The value is estimated in seconds
			x		and will override the lease renewal timer if it is not zero and is smaller than the server-defined value.
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role is
			x		'access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_pd_client_range_use_vendor_class_id
			x		Enable using vendor class id.Dependencies: Available starting with HLT API 3.90. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-dhcp6_pd_client_range_vendor_class_id
			x		This option is used by a client to identify the vendor that manufactured the hardware on which the client is running. (DEFAULT = Ixia DHCP Client')Dependencies: Available starting with HLT API 3.90. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'; dhcp6_pd_client_range_use_vendor_class_id is 1
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_max_outstanding_releases
			x		The maximum number of requests to be sent by all DHCP clients during session
			x		teardown. This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or
			x		dual_stack.
			x	-dhcp6_pgdata_max_outstanding_requests
			x		The maximum number of requests to be sent by all DHCP clients during session
			x		startup. This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or
			x		dual_stack.
			x	-dhcp6_pgdata_override_global_setup_rate
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter
			x		applies at the port level.
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role is
			x		access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_pgdata_override_global_teardown_rate
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter
			x		applies at the port level.
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x		is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack
			x	-dhcp6_pgdata_setup_rate_increment
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'. Parameter dhcp6_pgdata_override_global_setup_rate is 1'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_setup_rate_initial
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter
			x		applies at the port level.
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x		is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x		Parameter dhcp6_pgdata_override_global_setup_rate is 1
			x	-dhcp6_pgdata_setup_rate_max
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'. Parameter dhcp6_pgdata_override_global_setup_rate is 1'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_teardown_rate_increment
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'. Parameter dhcp6_pgdata_override_global_teardown_rate is 1'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pgdata_teardown_rate_initial
			x		Description This parameter refers to the DHCPv6 Client Port Group Data.
			x		This parameter applies at the port level.
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x		is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x		Parameter dhcp6_pgdata_override_global_teardown_rate is 1
			x	-dhcp6_pgdata_teardown_rate_max
			x		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'. Parameter dhcp6_pgdata_override_global_teardown_rate is 1'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_global_echo_ia_info
			x		If 1 the DHCPv6 client will request the exact address as advertised by the server.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x		Valid choices are:
			x		0 - (DEFAULT) Disabled
			x		1 - Enabled
			x	-dhcp6_global_max_outstanding_releases
			x		The maximum number of requests to be sent by all DHCP clients during session
			x		teardown.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_max_outstanding_requests
			x		The maximum number of requests to be sent by all DHCP clients during session
			x		startup.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_reb_max_rt
			x		RFC 3315 max rebind timeout value in seconds.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_reb_timeout
			x		RFC 3315 initial rebind timeout value in seconds.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_rel_max_rc
			x		RFC 3315 release attempts.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_rel_timeout
			x		RFC 3315 initial release timeout in seconds.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_ren_max_rt
			x		RFC 3315 max renew timeout in secons.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_ren_timeout
			x		RFC 3315 initial renew timeout in secons.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_req_max_rc
			x		RFC 3315 max request retry attempts.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_req_max_rt
			x		RFC 3315 max request timeout value in secons.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_req_timeout
			x		RFC 3315 initial request timeout value in secons.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_setup_rate_increment
			x		This value represents the increment value for setup rate. This value is applied every second and can be negative. This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_global_setup_rate_initial
			x		Setup rate is the number of clients to start in each second. This value
			x		represents the initial value for setup rate.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_setup_rate_max
			x		This value represents the final value for setup rate. The setup rate will not change after this value is reached. This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_global_sol_max_rc
			x		RFC 3315 max solicit retry attempts.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_sol_max_rt
			x		RFC 3315 max solicit timeout value in seconds.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_sol_timeout
			x		RFC 3315 initial solicit timeout value in seconds.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_teardown_rate_increment
			x		This value represents the increment value for teardown rate. This value is applied every second and can be negative. This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_global_teardown_rate_initial
			x		Setup rate is the number of clients to stop in each second. This value
			x		represents the initial value for teardown rate.
			x		This parameter applies globally for all the ports in the configuration.
			x		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x		Valid when port_role is access; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp or dual_stack.
			x	-dhcp6_global_teardown_rate_max
			x		This value represents the final value for teardown rate. The teardown rate will not change after this value is reached. This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_global_wait_for_completion
			x		This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		0 - (DEFAULT)Disabled
			x   		1 - Enabled
			x	-hosts_range_count
			x		Configures the DHCP Hosts Range count property. Dependencies: Available starting with HLT API 3.90. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-hosts_range_eui_increment
			x		This parameter configures the EUI step to increment hosts_range_first_euifrom the DHCP Hosts Range. Dependencies: Available starting with HLT API 3.90. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'. Parameter hosts_range_count greater than 1
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-hosts_range_first_eui
			x		Configures the first EUI value of the DHCP Hosts Range. Dependencies: Available starting with HLT API 3.90. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-hosts_range_ip_prefix
			x		Defines the network prefix length associated with the address pool for the DHCP Hosts Range. Dependencies: Available starting with HLT API 3.90. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-hosts_range_subnet_count
			x		It defines the number of subnets for the DHCP Hosts Range. Dependencies: Available starting with HLT API 3.90. Valid when port_role is access'; dhcpv6_hosts_enable is 1; ip_cp is ipv6_cp' or dual_stack'.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pd_server_range_dns_domain_search_list
			x		Specifies the domain that the client will use when resolving host names with DNS.
			x	-dhcp6_pd_server_range_first_dns_server
			x		The first DNS server associated with this address pool. This is the first DNS
			x		address that will be assigned to any client that is allocated an IP address from this
			x		pool.
			x	-hosts_range_ip_outer_prefix
			x		This parameter represents the address prefix allocated to the hosts in all of the subnets behind the CPE interface. The default prefix is 64, the minimum is 0, and the maximum is 128.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-hosts_range_ip_prefix_addr
			x		The IPv6 prefix to be used for the static host addresses. The default prefix is 3001.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-dhcp6_pd_server_range_second_dns_server
			x		The second DNS server associated with this address pool. This is the second (of
			x		two) DNS addresses that will be assigned to any client that is allocated an IP
			x		address from this pool.
			x	-dhcp6_pd_server_range_subnet_prefix
			x		The prefix value used to subnet the addresses specified in the address pool. This
			x		is the subnet prefix length advertised in DHCPv6PD Offer and Reply messages.
			x	-dhcp6_pd_server_range_start_pool_address
			x		The starting IPv6 address for this DHCPv6 address pool.
			x	-lease_time_max
			x		The maximum lease duration, in seconds. The default value is 86,400; the minimum is 300; and the maximum is 30,000,000.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-lease_time
			 		The duration of an address lease, in seconds, if the client requesting the lease
			 		does not ask for a specific expiration time. The default value is 3600; the
			 		minimum is 300; and the maximum is 30,000,000.
			x	-framing_capability
			x		Indicates to the DUT the framing types for which HLT can accept
			x		incoming calls.
			x		Valid choices are:
			x   		sync - Synchronous (DEFAULT).
			x   		async - Asynchronous.
			x   		both - Either synchronous or asynchronous (the two enums are or'd together). This option is not supported with IxNetwork.
			x	-inner_address_per_vlan
			x		How often a new inner VLAN ID is generated. For example, a value of 10
			x		will cause a new VLAN ID to be used in blocks of 10 IP addresses, applies to L2TPoE only and if -l2_encap is set to
			x		ethernet_ii_qinq.
			x	-inner_vlan_count
			x		Number of inner VLAN IDs, applies to L2TPoE only and if -l2_encap is set to
			x		ethernet_ii_qinq.
			x	-inner_vlan_id
			x		Starting inner VLAN ID, applies to L2TPoE only and if -l2_encap is set to
			x		ethernet_ii_qinq.
			x	-inner_vlan_id_step
			x		Step value applied to inner VLAN ID, applies to L2TP only and if -l2_encap
			x		is set to ethernet_ii_qinq.
			x	-inner_vlan_user_priority
			x		Inner VLAN user priority, applies to L2TPoE only and if -l2_encap is set to
			x		ethernet_ii_qinq.
			x	-ipv6_pool_addr_prefix_len
			x		The IPv6 address prefix length. This parameter is available only for -action create.
			x	-ipv6_pool_prefix
			x		The IPv6 pool prefix.
			x	-ipv6_pool_prefix_len
			x		The IPv6 pool prefix length. Subtracting this from the address prefix
			x		length provides the size of the PPP IP pool. This parameter is available only for -action create.
			x		The range is 1-127.
			x	-max_configure_req
			x		The number of retries to be used for LCP negotiation.
			x		Any integer value may be used. This parameter is available only for -action create.
			x		The range is 1-255.
			x	-number_of_sessions
			x		Valid only for IxNetwork. If this parameter is specified, then the
			x		num_tunnels parameter will be ignored. This allows to specify then
			x		number of sessions to be created(usefull if sessions_per_tunnel
			x		number is not diving exaclty with the number of sessions).
			x	-ppp_client_iid
			x		Base IP address of the client IP pool allocated by the LNS. Only
			x		valid if the mode option is set lns. For DualStack this is the client IID.
			x		The value will be the formed from the least significant 64 bits of the
			x		IPv6 address provided. This parameter is available only for -action create.
			x	-ppp_client_iid_step
			x		Step size to use for allocating client IP addresses. Only
			x		valid if the mode option is set lns. This parameter is available only for -action create.
			x	-ppp_server_iid
			x		Local IP address of the PPP server. Only valid if the mode is lns.
			x		For DualStack this is the server IID.
			x		The value will be the formed from the least significant 64 bits of the
			x		IPv6 address provided. This parameter is available only for -action create.
			x	-proxy
			x		This parameter is deprecated. It is accepted as procedure parameter but the functionality for it does not exist anymore.If true, enables processing of the PROXY related AVPs for LNS operating mode.0 = false1 = true (DEFAULT)
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-enable_term_req_timeout
			x		This is used to enable/disable the action completion timeout.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-src_mac_addr
			x		This is used to specify the MAC address on the access endpoints. If it
			x		is missing, if an interface with the same IP as the one on the access
			x		endpoint exists, its MAC address will be used, if not the MAC address
			x		will be generated by the following rule:
			x		00:chassis:card:port:endpoint:01
			x	-src_mac_addr_auto
			x		This is used to specify if the MAC address is generated automatically or not.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-l2tp_src_gw
			x		This is used to specify the endpoint's gateway address, which can be
			x		different from the tunnel destination. If this attribute is not
			x		specified, the tunnel destination's IP will be used as gateway.
			x	-l2tp_src_gw_step
			x		This is used to specify the step of the endpoint's gateway address.
			x		Valid only for IxTclNetwork API.
			x	-l2tp_src_gw_incr_mode
			x		This is used to specify the mode of incrementing the gateway address.
			x		Valid only for IxTclNetwork API.
			x		Valid choices are:
			x   		per_subnet -
			x   		per_interface -
			x	-l2tp_src_prefix_len
			x		This is used to specify the endpoint's IP address prefix length.
			n	-avp_framing_type
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-ppp_server_step
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-vlan_user_priority_count
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-vlan_user_priority_step
			n	-avp_hide_list
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-l2tp_dst_count
			n   		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-lns_host_name
			x   		L2TP hostname sent by Ixia port when acting as LNS.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-accept_any_auth_value
			x   		Configures a PAP/CHAP authenticator to accept all offered usernames, passwords, and base domain names. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dns_server_list
			x   		DNS server list separacted by semicolon. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-send_dns_options
			x   		Enable RDNSS routing advertisments. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lcp_accm
			x   		Async-Control-Character-Map. Valid only when lcp_enable_accm is enabled. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lcp_enable_accm
			x   		Enable Async-Control-Character-Map. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_mru_negotiation
			x   		Enable MRU Negotiation. This parameter is available only for -action create.
			x	-desired_mru_rate
			x   		Max Transmit Unit for PPP. This parameter is available only for -action create.
			x	-server_dns_options
			x   		The server DNS options. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		accept_requested_addresses -
			x       		accept_only_requested_primary_address -
			x       		supply_primary_and_secondary -
			x       		supply_primary_only -
			x       		disable_extension -
			x	-ppp_local_iid_step
			x   		Server IPv6CP interface identifier increment, used in conjuction with the base identifier. This parameter is available only for -action create
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ppp_local_ip_step
			x   		**For internal use only**.
			x   		For PPP/IP v4 server plugins, exactly one server address is used.
			x   		As a result, 0.0.0.0 is the only legal value for this property. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-server_ipv4_ncp_configuration
			x   		The server ipv4 ncp configuration. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		serveronly -
			x       		clientmay -
			x	-server_netmask
			x   		The server netmask. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-server_netmask_options
			x   		Server netmask options. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		accept_requested_netmask -
			x       		supply_netmask -
			x       		disable_extension -
			x	-server_primary_dns_address
			x   		The server primary dns address. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-server_secondary_dns_address
			x   		The server secondary dns address. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_server_signal_iwf
			x   		This parameter enables the server signal iwf. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_server_signal_loop_char
			x   		This parameter enables the server signal loop char. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_server_signal_loop_encap
			x   		This parameter enables the server signal loop encapsulation. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_server_signal_loop_id
			x   		This parameter enables the server signal loop id. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-server_ipv6_ncp_configuration
			x   		The server ipv6 ncp configuration. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		serveronly -
			x       		clientmay -
			x	-server_wins_options
			x   		Server wins options for the primary and secondary addresses. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		Valid choices are:
			x       		accept_requested_addresses -
			x       		accept_only_requested_primary_address -
			x       		supply_primary_and_secondary -
			x       		supply_primary_only -
			x       		disable_extension -
			x	-server_wins_primary_address
			x   		The server wins primary address. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-server_wins_secondary_address
			x   		The server wins secondary address. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_domain_groups
			x   		Enable domain groups. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-chap_name
			x   		User name when CHAP Authentication is being used. This parameter is available only for -action create.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-chap_secret
			x   		Secret when CHAP Authentication is being used
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-client_dns_options
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		request_primary_and_secondary -
			x       		request_primary_only -
			x       		accept_addresses_from_server -
			x       		accept_only_primary_address_from_server -
			x       		disable_extension -
			x	-client_ipv4_ncp_configuration
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		learned -
			x       		request -
			x	-client_netmask
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-client_netmask_options
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		request_specific_netmask -
			x       		accept_netmask_from_server -
			x       		disable_extension -
			x	-client_primary_dns_address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-client_secondary_dns_address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-client_ipv6_ncp_configuration
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		learned -
			x       		request -
			x	-client_wins_options
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x       		request_primaryandsecondary_wins -
			x       		request_primaryonly_wins -
			x       		accept_addresses_from_server -
			x       		accept_only_primary_address_from_server -
			x       		disable_extension -
			x	-client_wins_primary_address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-client_wins_secondary_address
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-manual_gateway_mac
			x   		User specified Gateway MAC addresses.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-resolve_gateway
			x   		Enable the gateway MAC address discovery.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_exclude_hdlc
			x   		If checked, HDLC header is not encoded in the L2TP packets.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		A list containing the ethernet protocol stack handles that were added by the command (if any).
			xkey:ethernet_handle               value:A list containing the ethernet protocol stack handles that were added by the command (if any).
		A list containing the ipv4 protocol stack handles that were added by the command (if any).
			xkey:ipv4_handle                   value:A list containing the ipv4 protocol stack handles that were added by the command (if any).
		A list containing the lac protocol stack handles that were added by the command (if any).
			xkey:lac_handle                    value:A list containing the lac protocol stack handles that were added by the command (if any).
		A list containing the lns protocol stack handles that were added by the command (if any).
			xkey:lns_handle                    value:A list containing the lns protocol stack handles that were added by the command (if any).
		A list containing the lns auth credentials protocol stack handles that were added by the command (if any).
			xkey:lns_auth_credentials_handle   value:A list containing the lns auth credentials protocol stack handles that were added by the command (if any).
		A list containing the pppox server sessions protocol stack handles that were added by the command (if any).
			xkey:pppox_server_sessions_handle  value:A list containing the pppox server sessions protocol stack handles that were added by the command (if any).
		A list containing the pppox server protocol stack handles that were added by the command (if any).
			xkey:pppox_server_handle           value:A list containing the pppox server protocol stack handles that were added by the command (if any).
		A list containing the pppox client protocol stack handles that were added by the command (if any).
			xkey:pppox_client_handle           value:A list containing the pppox client protocol stack handles that were added by the command (if any).
		A list containing the dhcpv6 client protocol stack handles that were added by the command (if any).
			xkey:dhcpv6_client_handle          value:A list containing the dhcpv6 client protocol stack handles that were added by the command (if any).
		A list containing the dhcpv6 server protocol stack handles that were added by the command (if any).
			xkey:dhcpv6_server_handle          value:A list containing the dhcpv6 server protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:handle                        value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		$::SUCCESS | $::FAILURE
			 key:status                        value:$::SUCCESS | $::FAILURE
		<l2tp handles>
			 key:handles                       value:<l2tp handles>
		When status is failure, contains more information
			 key:log                           value:When status is failure, contains more information
		
		Examples:
		See files in the Samples/IxNetwork/L2TP subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) Coded versus functional specification.
		2) Sessions might not be distributed as expected over tunnels and the number of
		tunnels might be different from the what was requested when -mode "lac"
		in the following particular case:
		* -tun_distribution domain_group_map
		* -sess_distribution next
		* -l2tp_dst_step 0.0.0.0
		* -num_tunnels  > 1
		* More than 1 domains are configured in -domain_group_map
		To avoid this use -sess_distribution "fill". If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		1) Coded versus functional specification.
		2) Sessions might not be distributed as expected over tunnels and the number of tunnels might be different from the what was requested when -mode "lac" in the following particular case:* -tun_distribution domain_group_map* -sess_distribution next* -l2tp_dst_step 0.0.0.0* -num_tunnels  > 1* More than 1 domains are configured in -domain_group_mapTo avoid this use -sess_distribution "fill".
		
		See Also:
		
		"""
		return self._run_keyword("l2tp_config", kwargs)

	def l2tp_control(self, **kwargs):
		""" Start, stop or restart the l2tpox sessions and tunnels.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: l2tp_control
			 	-action  CHOICES connect
			          CHOICES disconnect
			          CHOICES abort
			          CHOICES abort_async
			          CHOICES retry
			 	[-handle ANY]
		
		Arguments:
			 	-action
			 		Action to be executed.
			 		choices not supported:
			 		reset- Aborts all L2TPoX sessions and resets the L2TP
			 		emulation engine on the specified device. A session is
			 		not notified of termination, and a Terminate Request
			 		packet is not sent to the peers.
			 		clear- Clears the status and statistics.
			 		pause- Pauses all the sessions.
			 		resume- Resumes all the sessions.
			 		Valid choices are:
			    		connect - Brings up configured sessions.
			    		disconnect - Tears down established sessions.
			    		abort - Aborts all L2TPoX sessions. This option is valid only
when using IxTclNetwork. The command returns when the
operation is completed.Parameter -handle
can be a port handle (all l2tpox sessions from that port are aborted), a range
handle (all l2tpox sessions from that range are aborted). If -handle is missing
all l2tpox sessions from all ports are aborted.
			    		abort_async - Aborts all L2TPoX sessions. This option is valid only
when using IxTclNetwork. The command returns immediately.
Rules for parameter -handle are the same as for -action abort.
			    		retry - Attempts to connect sessions that have previously
failed to establish.
			 	-handle
			 		The port where the L2TPoX sessions are to be created.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		See files in the Samples/IxNetwork/L2TP subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		1) Clear action has not been implemented yet.
		Coded versus functional specification.
		1) Clear action has not been implemented yet.
		
		See Also:
		
		"""
		return self._run_keyword("l2tp_control", kwargs)

	def l2tp_stats(self, **kwargs):
		""" Retrieves statistics for the L2TPoX sessions configured on thespecified test port.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: l2tp_stats
			 	-mode               CHOICES aggregate
			                     CHOICES session
			                     CHOICES tunnel
			                     CHOICES session_dhcpv6pd
			                     CHOICES session_dhcp_hosts
			                     CHOICES session_all
			                     DEFAULT aggregate
			 	[-port_handle       ANY]
			 	[-handle            ANY]
			x	[-source            CHOICES client server]
			x	[-execution_timeout NUMERIC
			x                    DEFAULT 1800]
		
		Arguments:
			 	-mode
			 		Specifies statistics retrieval mode as either aggregate for all configured sessions or on a per session basis.Valid choices are:
			    		aggregate - Retrieve statistics for all the sessions. This is the default option.
			    		session - Retrieve per session l2tp statistics.
			    		tunnel - Retrieve per tunnel l2tp statistics.
			    		session_dhcpv6pd - Retrieve dhcp client or dhcp server statistics per session. Not supported in NGPF.
			    		session_dhcp_hosts - Retrieve dhcp hosts statistics per session. Not supported in NGPF.
			    		session_all - Retrieve all the per session statistics.
			 	-port_handle
			 		The port handle for which the L2TPoX sessions statistics needs to be
			 		retrieved. Valid only when using IxNetwork.
			 	-handle
			 		The port for which the L2TPoX sessions statistics needs to be
			 		retrieved. The statistics will be retrieved
			 		for the port where that handle belongs.
			x	-source
			x		Optional parameter when mode is aggregate and port_handle was provided. If specified this
			x		will represent the type of statistics to be returned. If not specified the client statistics
			x		will be tried to be retrieved and if they are empty (ie.: not lac present on the port)
			x		the server ones (LNS) will be retuned insted.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		client -
			x   		server -
			x	-execution_timeout
			x		This is the timeout for the function.
			x		The setting is in seconds.
			x		Setting this setting to 60 it will mean that the command must complete in under 60 seconds.
			x		If the command will last more than 60 seconds the command will be terminated by force.
			x		This flag can be used to prevent dead locks occuring in IxNetwork.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                              value:$::SUCCESS | $::FAILURE 
		When status is failure, contains more information
			 key:log                                                                 value:When status is failure, contains more information
		CDN Rx
			 key:port_handle.aggregate.cdn_rx                                        value:CDN Rx
		CDN Tx
			 key:port_handle.aggregate.cdn_tx                                        value:CDN Tx
		CHAP Challenge Rx .Only for LAC.
			 key:port_handle.aggregate.chap_auth_chal_rx                             value:CHAP Challenge Rx .Only for LAC.
		CHAP Challenge Tx .Only for LNS.
			 key:port_handle.aggregate.chap_auth_chal_tx                             value:CHAP Challenge Tx .Only for LNS.
		CHAP Failure Rx .Only for LAC.
			 key:port_handle.aggregate.chap_auth_fail_rx                             value:CHAP Failure Rx .Only for LAC.
		CHAP Failure Tx .Only for LNS.
			 key:port_handle.aggregate.chap_auth_fail_tx                             value:CHAP Failure Tx .Only for LNS.
		CHAP Response Rx .Only for LNS.
			 key:port_handle.aggregate.chap_auth_rsp_rx                              value:CHAP Response Rx .Only for LNS.
		CHAP Response Tx .Only for LAC.
			 key:port_handle.aggregate.chap_auth_rsp_tx                              value:CHAP Response Tx .Only for LAC.
		CHAP Success Rx .Only for LAC.
			 key:port_handle.aggregate.chap_auth_succ_rx                             value:CHAP Success Rx .Only for LAC.
		CHAP Success Tx .Only for LNS.
			 key:port_handle.aggregate.chap_auth_succ_tx                             value:CHAP Success Tx .Only for LNS.
		Interfaces in PPP Negotiation .Only for LAC.
			 key:port_handle.aggregate.client_interfaces_in_ppp_negotiation          value:Interfaces in PPP Negotiation .Only for LAC.
		Average Establishment Time (usec) .Only for LAC.
			 key:port_handle.aggregate.client_session_avg_latency                    value:Average Establishment Time (usec) .Only for LAC.
		Maximum Establishment Time (usec) .Only for LAC.
			 key:port_handle.aggregate.client_session_max_latency                    value:Maximum Establishment Time (usec) .Only for LAC.
		Minimum Establishment Time (usec) .Only for LAC.
			 key:port_handle.aggregate.client_session_min_latency                    value:Minimum Establishment Time (usec) .Only for LAC.
		L2TP Tunnels Up .Only for LAC.
			 key:port_handle.aggregate.client_tunnels_up                             value:L2TP Tunnels Up .Only for LAC.
		LCP Code Reject Rx
			 key:port_handle.aggregate.code_rej_rx                                   value:LCP Code Reject Rx
		LCP Code Reject Tx
			 key:port_handle.aggregate.code_rej_tx                                   value:LCP Code Reject Tx
		L2TP Window Messages Duplicate Rx
			 key:port_handle.aggregate.duplicate_rx                                  value:L2TP Window Messages Duplicate Rx
		LCP Echo Request Rx
			 key:port_handle.aggregate.echo_req_rx                                   value:LCP Echo Request Rx
		LCP Echo Request Tx
			 key:port_handle.aggregate.echo_req_tx                                   value:LCP Echo Request Tx
		LCP Echo Response Rx
			 key:port_handle.aggregate.echo_rsp_rx                                   value:LCP Echo Response Rx
		LCP Echo Response Tx
			 key:port_handle.aggregate.echo_rsp_tx                                   value:LCP Echo Response Tx
		Hello Rx
			 key:port_handle.aggregate.hello_rx                                      value:Hello Rx
		Hello Tx
			 key:port_handle.aggregate.hello_tx                                      value:Hello Tx
		ICCN Rx
			 key:port_handle.aggregate.iccn_rx                                       value:ICCN Rx
		ICCN Tx
			 key:port_handle.aggregate.iccn_tx                                       value:ICCN Tx
		ICRP Rx
			 key:port_handle.aggregate.icrp_rx                                       value:ICRP Rx
		ICRP Tx
			 key:port_handle.aggregate.icrp_tx                                       value:ICRP Tx
		ICRQ Rx
			 key:port_handle.aggregate.icrq_rx                                       value:ICRQ Rx
		ICRQ Tx
			 key:port_handle.aggregate.icrq_tx                                       value:ICRQ Tx
		L2TP Window Messages Rx in Sequence
			 key:port_handle.aggregate.in_order_rx                                   value:L2TP Window Messages Rx in Sequence
		Interfaces in PPPoE Negotiation
			 key:port_handle.aggregate.interfaces_in_pppoe_l2tp_negotiation          value:Interfaces in PPPoE Negotiation
		IPCP Config ACK Rx
			 key:port_handle.aggregate.ipcp_cfg_ack_rx                               value:IPCP Config ACK Rx
		IPCP Config ACK Tx
			 key:port_handle.aggregate.ipcp_cfg_ack_tx                               value:IPCP Config ACK Tx
		IPCP Config NAK Rx
			 key:port_handle.aggregate.ipcp_cfg_nak_rx                               value:IPCP Config NAK Rx
		IPCP Config NAK Tx
			 key:port_handle.aggregate.ipcp_cfg_nak_tx                               value:IPCP Config NAK Tx
		IPCP Config Reject Rx
			 key:port_handle.aggregate.ipcp_cfg_rej_rx                               value:IPCP Config Reject Rx
		IPCP Config Reject Tx
			 key:port_handle.aggregate.ipcp_cfg_rej_tx                               value:IPCP Config Reject Tx
		IPCP Config Request Rx
			 key:port_handle.aggregate.ipcp_cfg_req_rx                               value:IPCP Config Request Rx
		IPCP Config Request Tx
			 key:port_handle.aggregate.ipcp_cfg_req_tx                               value:IPCP Config Request Tx
		IPv6CP Config ACK Rx
			 key:port_handle.aggregate.ipv6cp_cfg_ack_rx                             value:IPv6CP Config ACK Rx
		IPv6CP Config ACK Tx
			 key:port_handle.aggregate.ipv6cp_cfg_ack_tx                             value:IPv6CP Config ACK Tx
		IPv6CP Config NAK Rx
			 key:port_handle.aggregate.ipv6cp_cfg_nak_rx                             value:IPv6CP Config NAK Rx
		IPv6CP Config NAK Tx
			 key:port_handle.aggregate.ipv6cp_cfg_nak_tx                             value:IPv6CP Config NAK Tx
		IPv6CP Config Reject Rx
			 key:port_handle.aggregate.ipv6cp_cfg_rej_rx                             value:IPv6CP Config Reject Rx
		IPv6CP Config Reject Tx
			 key:port_handle.aggregate.ipv6cp_cfg_rej_tx                             value:IPv6CP Config Reject Tx
		IPv6CP Config Request Rx
			 key:port_handle.aggregate.ipv6cp_cfg_req_rx                             value:IPv6CP Config Request Rx
		IPv6CP Config Request Tx
			 key:port_handle.aggregate.ipv6cp_cfg_req_tx                             value:IPv6CP Config Request Tx
		IPv6CP Router Advertisement Rx .Only for LAC.
			 key:port_handle.aggregate.ipv6cp_router_adv_rx                          value:IPv6CP Router Advertisement Rx .Only for LAC.
		IPv6CP Router Advertisement Tx .Only for LNS.
			 key:port_handle.aggregate.ipv6cp_router_adv_tx                          value:IPv6CP Router Advertisement Tx .Only for LNS.
		IPv6CP Router Solicitation Rx .Only for LNS.
			 key:port_handle.aggregate.ipv6cp_router_solicitation_rx                 value:IPv6CP Router Solicitation Rx .Only for LNS.
		L2TP Calls Up
			 key:port_handle.aggregate.l2tp_calls_up                                 value:L2TP Calls Up
		L2TP Tunnel Total Bytes Rx
			 key:port_handle.aggregate.l2tp_tunnel_total_bytes_rx                    value:L2TP Tunnel Total Bytes Rx
		L2TP Tunnel Total Bytes Tx
			 key:port_handle.aggregate.l2tp_tunnel_total_bytes_tx                    value:L2TP Tunnel Total Bytes Tx
		LCP Average Establishment Time (usec)
			 key:port_handle.aggregate.lcp_avg_latency                               value:LCP Average Establishment Time (usec)
		LCP Configure ACK Rx
			 key:port_handle.aggregate.lcp_cfg_ack_rx                                value:LCP Configure ACK Rx
		LCP Configure ACK Tx
			 key:port_handle.aggregate.lcp_cfg_ack_tx                                value:LCP Configure ACK Tx
		LCP Configure NAK Rx
			 key:port_handle.aggregate.lcp_cfg_nak_rx                                value:LCP Configure NAK Rx
		LCP Configure NAK Tx
			 key:port_handle.aggregate.lcp_cfg_nak_tx                                value:LCP Configure NAK Tx
		LCP Configure Reject Rx
			 key:port_handle.aggregate.lcp_cfg_rej_rx                                value:LCP Configure Reject Rx
		LCP Configure Reject Tx
			 key:port_handle.aggregate.lcp_cfg_rej_tx                                value:LCP Configure Reject Tx
		LCP Configure Request Rx
			 key:port_handle.aggregate.lcp_cfg_req_rx                                value:LCP Configure Request Rx
		LCP Configure Request Tx
			 key:port_handle.aggregate.lcp_cfg_req_tx                                value:LCP Configure Request Tx
		LCP Maximum Establishment Time (usec)
			 key:port_handle.aggregate.lcp_max_latency                               value:LCP Maximum Establishment Time (usec)
		LCP Minimum Establishment Time (usec)
			 key:port_handle.aggregate.lcp_min_latency                               value:LCP Minimum Establishment Time (usec)
		LCP Protocol Reject Rx
			 key:port_handle.aggregate.lcp_protocol_rej_rx                           value:LCP Protocol Reject Rx
		LCP Protocol Reject Tx
			 key:port_handle.aggregate.lcp_protocol_rej_tx                           value:LCP Protocol Reject Tx
		LCP Total Rx
			 key:port_handle.aggregate.lcp_total_msg_rx                              value:LCP Total Rx
		LCP Total Tx
			 key:port_handle.aggregate.lcp_total_msg_tx                              value:LCP Total Tx
		IPCP Average Establishment Time (usec)
			 key:port_handle.aggregate.ncp_avg_latency                               value:IPCP Average Establishment Time (usec)
		IPCP Maximum Establishment Time (usec)
			 key:port_handle.aggregate.ncp_max_latency                               value:IPCP Maximum Establishment Time (usec)
		IPCP Minimum Establishment Time (usec)
			 key:port_handle.aggregate.ncp_min_latency                               value:IPCP Minimum Establishment Time (usec)
		NCP Total Rx
			 key:port_handle.aggregate.ncp_total_msg_rx                              value:NCP Total Rx
		NCP Total Tx
			 key:port_handle.aggregate.ncp_total_msg_tx                              value:NCP Total Tx
		Sessions Total
			 key:port_handle.aggregate.num_sessions                                  value:Sessions Total
		L2TP Window Messages Rx Out of Order
			 key:port_handle.aggregate.out_of_order_rx                               value:L2TP Window Messages Rx Out of Order
		L2TP Window Messages Rx Out of Window
			 key:port_handle.aggregate.out_of_win_rx                                 value:L2TP Window Messages Rx Out of Window
		PADI Rx .Only for LNS.
			 key:port_handle.aggregate.padi_rx                                       value:PADI Rx .Only for LNS.
		PADI Timeouts .Only for LAC.
			 key:port_handle.aggregate.padi_timeouts                                 value:PADI Timeouts .Only for LAC.
		PADI Tx .Only for LAC.
			 key:port_handle.aggregate.padi_tx                                       value:PADI Tx .Only for LAC.
		PADO Rx .Only for LAC.
			 key:port_handle.aggregate.pado_rx                                       value:PADO Rx .Only for LAC.
		PADO Tx .Only for LNS.
			 key:port_handle.aggregate.pado_tx                                       value:PADO Tx .Only for LNS.
		PADR Rx .Only for LNS.
			 key:port_handle.aggregate.padr_rx                                       value:PADR Rx .Only for LNS.
		PADR Timeouts .Only for LAC.
			 key:port_handle.aggregate.padr_timeouts                                 value:PADR Timeouts .Only for LAC.
		PADR Tx .Only for LAC.
			 key:port_handle.aggregate.padr_tx                                       value:PADR Tx .Only for LAC.
		PADS Rx .Only for LAC.
			 key:port_handle.aggregate.pads_rx                                       value:PADS Rx .Only for LAC.
		PADS Tx .Only for LNS.
			 key:port_handle.aggregate.pads_tx                                       value:PADS Tx .Only for LNS.
		PADT Rx
			 key:port_handle.aggregate.padt_rx                                       value:PADT Rx
		PADT Tx
			 key:port_handle.aggregate.padt_tx                                       value:PADT Tx
		PAP Authentication ACK Rx .Only for LAC.
			 key:port_handle.aggregate.pap_auth_ack_rx                               value:PAP Authentication ACK Rx .Only for LAC.
		PAP Authentication ACK Tx .Only for LNS.
			 key:port_handle.aggregate.pap_auth_ack_tx                               value:PAP Authentication ACK Tx .Only for LNS.
		PAP Authentication NAK Rx .Only for LAC.
			 key:port_handle.aggregate.pap_auth_nak_rx                               value:PAP Authentication NAK Rx .Only for LAC.
		PAP Authentication NAK Tx .Only for LNS.
			 key:port_handle.aggregate.pap_auth_nak_tx                               value:PAP Authentication NAK Tx .Only for LNS.
		PAP Authentication Request Rx .Only for LNS.
			 key:port_handle.aggregate.pap_auth_req_rx                               value:PAP Authentication Request Rx .Only for LNS.
		PAP Authentication Request Tx .Only for LAC.
			 key:port_handle.aggregate.pap_auth_req_tx                               value:PAP Authentication Request Tx .Only for LAC.
		PPP Total Bytes Rx
			 key:port_handle.aggregate.ppp_total_bytes_rx                            value:PPP Total Bytes Rx
		PPP Total Bytes Tx
			 key:port_handle.aggregate.ppp_total_bytes_tx                            value:PPP Total Bytes Tx
		L2TP Window Messages Retransmitted
			 key:port_handle.aggregate.retransmits                                   value:L2TP Window Messages Retransmitted
		SCCCN Rx
			 key:port_handle.aggregate.scccn_rx                                      value:SCCCN Rx
		SCCCN Tx
			 key:port_handle.aggregate.scccn_tx                                      value:SCCCN Tx
		SCCRP Rx
			 key:port_handle.aggregate.sccrp_rx                                      value:SCCRP Rx
		SCCRP Tx
			 key:port_handle.aggregate.sccrp_tx                                      value:SCCRP Tx
		SCCRQ Rx
			 key:port_handle.aggregate.sccrq_rx                                      value:SCCRQ Rx
		SCCRQ Tx
			 key:port_handle.aggregate.sccrq_tx                                      value:SCCRQ Tx
		Interfaces in PPP Negotiation .Only for LNS.
			 key:port_handle.aggregate.server_interfaces_in_ppp_negotiation          value:Interfaces in PPP Negotiation .Only for LNS.
		Average Establishment Time (usec) .Only for LNS.
			 key:port_handle.aggregate.server_session_avg_latency                    value:Average Establishment Time (usec) .Only for LNS.
		Maximum Establishment Time (usec) .Only for LNS.
			 key:port_handle.aggregate.server_session_max_latency                    value:Maximum Establishment Time (usec) .Only for LNS.
		Minimum Establishment Time (usec) .Only for LNS.
			 key:port_handle.aggregate.server_session_min_latency                    value:Minimum Establishment Time (usec) .Only for LNS.
		L2TP Tunnels Up .Only for LNS.
			 key:port_handle.aggregate.server_tunnels_up                             value:L2TP Tunnels Up .Only for LNS.
		Sessions Down
			 key:port_handle.aggregate.sessions_failed                               value:Sessions Down
		Sessions Not Started
			 key:port_handle.aggregate.sessions_not_started                          value:Sessions Not Started
		Sessions Up
			 key:port_handle.aggregate.sessions_up                                   value:Sessions Up
		SLI Rx
			 key:port_handle.aggregate.sli_rx                                        value:SLI Rx
		SLI Tx
			 key:port_handle.aggregate.sli_tx                                        value:SLI Tx
		StopCCN Rx
			 key:port_handle.aggregate.stopccn_rx                                    value:StopCCN Rx
		StopCCN Tx
			 key:port_handle.aggregate.stopccn_tx                                    value:StopCCN Tx
		Instantaneous Setup Rate .Only for LAC.
			 key:port_handle.aggregate.success_setup_rate                            value:Instantaneous Setup Rate .Only for LAC.
		Teardown Failed .Only for LAC.
			 key:port_handle.aggregate.teardown_failed                               value:Teardown Failed .Only for LAC.
		Instantaneous Teardown Rate .Only for LAC.
			 key:port_handle.aggregate.teardown_rate                                 value:Instantaneous Teardown Rate .Only for LAC.
		Teardown Succeeded .Only for LAC.
			 key:port_handle.aggregate.teardown_succeeded                            value:Teardown Succeeded .Only for LAC.
		LCP Terminate ACK Rx
			 key:port_handle.aggregate.term_ack_rx                                   value:LCP Terminate ACK Rx
		LCP Terminate ACK Tx
			 key:port_handle.aggregate.term_ack_tx                                   value:LCP Terminate ACK Tx
		LCP Terminate Request Rx
			 key:port_handle.aggregate.term_req_rx                                   value:LCP Terminate Request Rx
		LCP Terminate Request Tx
			 key:port_handle.aggregate.term_req_tx                                   value:LCP Terminate Request Tx
		PPPoE TotalBytes Rx
			 key:port_handle.aggregate.total_bytes_rx                                value:PPPoE TotalBytes Rx
		PPPoE TotalBytes Tx
			 key:port_handle.aggregate.total_bytes_tx                                value:PPPoE TotalBytes Tx
		L2TP Window Messages Tx Attempt While Close
			 key:port_handle.aggregate.tun_tx_win_close                              value:L2TP Window Messages Tx Attempt While Close
		L2TP Window Messages Tx Attempt While Open
			 key:port_handle.aggregate.tun_tx_win_open                               value:L2TP Window Messages Tx Attempt While Open
		L2TP Window Messages ACKed By Peer
			 key:port_handle.aggregate.tx_pkt_acked                                  value:L2TP Window Messages ACKed By Peer
		WEN Rx
			 key:port_handle.aggregate.wen_rx                                        value:WEN Rx
		WEN Tx
			 key:port_handle.aggregate.wen_tx                                        value:WEN Tx
		ZLB Rx
			 key:port_handle.aggregate.zlb_rx                                        value:ZLB Rx
		ZLB Tx
			 key:port_handle.aggregate.zlb_tx                                        value:ZLB Tx
		CDN Rx
			 key:Device Group #.aggregate.cdn_rx                                     value:CDN Rx
		CDN Tx
			 key:Device Group #.aggregate.cdn_tx                                     value:CDN Tx
		CHAP Challenge Tx .Only for LNS.
			 key:Device Group #.aggregate.chap_auth_chal_tx                          value:CHAP Challenge Tx .Only for LNS.
		CHAP Failure Tx .Only for LNS.
			 key:Device Group #.aggregate.chap_auth_fail_tx                          value:CHAP Failure Tx .Only for LNS.
		CHAP Response Rx .Only for LNS.
			 key:Device Group #.aggregate.chap_auth_rsp_rx                           value:CHAP Response Rx .Only for LNS.
		CHAP Success Tx .Only for LNS.
			 key:Device Group #.aggregate.chap_auth_succ_tx                          value:CHAP Success Tx .Only for LNS.
		L2TP Tunnels Up
			 key:Device Group #.aggregate.client_tunnels_up                          value:L2TP Tunnels Up
		LCP Code Reject Rx .Only for LNS.
			 key:Device Group #.aggregate.code_rej_rx                                value:LCP Code Reject Rx .Only for LNS.
		LCP Code Reject Tx .Only for LNS.
			 key:Device Group #.aggregate.code_rej_tx                                value:LCP Code Reject Tx .Only for LNS.
		L2TP Window Messages Duplicate Rx
			 key:Device Group #.aggregate.duplicate_rx                               value:L2TP Window Messages Duplicate Rx
		LCP Echo Request Rx .Only for LNS.
			 key:Device Group #.aggregate.echo_req_rx                                value:LCP Echo Request Rx .Only for LNS.
		LCP Echo Request Tx .Only for LNS.
			 key:Device Group #.aggregate.echo_req_tx                                value:LCP Echo Request Tx .Only for LNS.
		LCP Echo Response Rx .Only for LNS.
			 key:Device Group #.aggregate.echo_rsp_rx                                value:LCP Echo Response Rx .Only for LNS.
		LCP Echo Response Tx .Only for LNS.
			 key:Device Group #.aggregate.echo_rsp_tx                                value:LCP Echo Response Tx .Only for LNS.
		Hello Rx
			 key:Device Group #.aggregate.hello_rx                                   value:Hello Rx
		Hello Tx
			 key:Device Group #.aggregate.hello_tx                                   value:Hello Tx
		ICCN Rx
			 key:Device Group #.aggregate.iccn_rx                                    value:ICCN Rx
		ICCN Tx
			 key:Device Group #.aggregate.iccn_tx                                    value:ICCN Tx
		ICRP Rx
			 key:Device Group #.aggregate.icrp_rx                                    value:ICRP Rx
		ICRP Tx
			 key:Device Group #.aggregate.icrp_tx                                    value:ICRP Tx
		ICRQ Rx
			 key:Device Group #.aggregate.icrq_rx                                    value:ICRQ Rx
		ICRQ Tx
			 key:Device Group #.aggregate.icrq_tx                                    value:ICRQ Tx
		L2TP Window Messages Rx in Sequence
			 key:Device Group #.aggregate.in_order_rx                                value:L2TP Window Messages Rx in Sequence
		Interfaces in PPPoE Negotiation .Only for LNS.
			 key:Device Group #.aggregate.interfaces_in_pppoe_l2tp_negotiation       value:Interfaces in PPPoE Negotiation .Only for LNS.
		IPCP Config ACK Rx .Only for LNS.
			 key:Device Group #.aggregate.ipcp_cfg_ack_rx                            value:IPCP Config ACK Rx .Only for LNS.
		IPCP Config ACK Tx .Only for LNS.
			 key:Device Group #.aggregate.ipcp_cfg_ack_tx                            value:IPCP Config ACK Tx .Only for LNS.
		IPCP Config NAK Rx .Only for LNS.
			 key:Device Group #.aggregate.ipcp_cfg_nak_rx                            value:IPCP Config NAK Rx .Only for LNS.
		IPCP Config NAK Tx .Only for LNS.
			 key:Device Group #.aggregate.ipcp_cfg_nak_tx                            value:IPCP Config NAK Tx .Only for LNS.
		IPCP Config Reject Rx .Only for LNS.
			 key:Device Group #.aggregate.ipcp_cfg_rej_rx                            value:IPCP Config Reject Rx .Only for LNS.
		IPCP Config Reject Tx .Only for LNS.
			 key:Device Group #.aggregate.ipcp_cfg_rej_tx                            value:IPCP Config Reject Tx .Only for LNS.
		IPCP Config Request Rx .Only for LNS.
			 key:Device Group #.aggregate.ipcp_cfg_req_rx                            value:IPCP Config Request Rx .Only for LNS.
		IPCP Config Request Tx .Only for LNS.
			 key:Device Group #.aggregate.ipcp_cfg_req_tx                            value:IPCP Config Request Tx .Only for LNS.
		IPv6CP Config ACK Rx .Only for LNS.
			 key:Device Group #.aggregate.ipv6cp_cfg_ack_rx                          value:IPv6CP Config ACK Rx .Only for LNS.
		IPv6CP Config ACK Tx .Only for LNS.
			 key:Device Group #.aggregate.ipv6cp_cfg_ack_tx                          value:IPv6CP Config ACK Tx .Only for LNS.
		IPv6CP Config NAK Rx .Only for LNS.
			 key:Device Group #.aggregate.ipv6cp_cfg_nak_rx                          value:IPv6CP Config NAK Rx .Only for LNS.
		IPv6CP Config NAK Tx .Only for LNS.
			 key:Device Group #.aggregate.ipv6cp_cfg_nak_tx                          value:IPv6CP Config NAK Tx .Only for LNS.
		IPv6CP Config Reject Rx .Only for LNS.
			 key:Device Group #.aggregate.ipv6cp_cfg_rej_rx                          value:IPv6CP Config Reject Rx .Only for LNS.
		IPv6CP Config Reject Tx .Only for LNS.
			 key:Device Group #.aggregate.ipv6cp_cfg_rej_tx                          value:IPv6CP Config Reject Tx .Only for LNS.
		IPv6CP Config Request Rx .Only for LNS.
			 key:Device Group #.aggregate.ipv6cp_cfg_req_rx                          value:IPv6CP Config Request Rx .Only for LNS.
		IPv6CP Config Request Tx .Only for LNS.
			 key:Device Group #.aggregate.ipv6cp_cfg_req_tx                          value:IPv6CP Config Request Tx .Only for LNS.
		IPv6CP Router Advertisement Tx .Only for LNS.
			 key:Device Group #.aggregate.ipv6cp_router_adv_tx                       value:IPv6CP Router Advertisement Tx .Only for LNS.
		IPv6CP Router Solicitation Rx .Only for LNS.
			 key:Device Group #.aggregate.ipv6cp_router_solicitation_rx              value:IPv6CP Router Solicitation Rx .Only for LNS.
		L2TP Calls Up
			 key:Device Group #.aggregate.l2tp_calls_up                              value:L2TP Calls Up
		L2TP Tunnel Total Bytes Rx
			 key:Device Group #.aggregate.l2tp_tunnel_total_bytes_rx                 value:L2TP Tunnel Total Bytes Rx
		L2TP Tunnel Total Bytes Tx
			 key:Device Group #.aggregate.l2tp_tunnel_total_bytes_tx                 value:L2TP Tunnel Total Bytes Tx
		LCP Average Establishment Time (usec) .Only for LNS.
			 key:Device Group #.aggregate.lcp_avg_latency                            value:LCP Average Establishment Time (usec) .Only for LNS.
		LCP Configure ACK Rx .Only for LNS.
			 key:Device Group #.aggregate.lcp_cfg_ack_rx                             value:LCP Configure ACK Rx .Only for LNS.
		LCP Configure ACK Tx .Only for LNS.
			 key:Device Group #.aggregate.lcp_cfg_ack_tx                             value:LCP Configure ACK Tx .Only for LNS.
		LCP Configure NAK Rx .Only for LNS.
			 key:Device Group #.aggregate.lcp_cfg_nak_rx                             value:LCP Configure NAK Rx .Only for LNS.
		LCP Configure NAK Tx .Only for LNS.
			 key:Device Group #.aggregate.lcp_cfg_nak_tx                             value:LCP Configure NAK Tx .Only for LNS.
		LCP Configure Reject Rx .Only for LNS.
			 key:Device Group #.aggregate.lcp_cfg_rej_rx                             value:LCP Configure Reject Rx .Only for LNS.
		LCP Configure Reject Tx .Only for LNS.
			 key:Device Group #.aggregate.lcp_cfg_rej_tx                             value:LCP Configure Reject Tx .Only for LNS.
		LCP Configure Request Rx .Only for LNS.
			 key:Device Group #.aggregate.lcp_cfg_req_rx                             value:LCP Configure Request Rx .Only for LNS.
		LCP Configure Request Tx .Only for LNS.
			 key:Device Group #.aggregate.lcp_cfg_req_tx                             value:LCP Configure Request Tx .Only for LNS.
		LCP Maximum Establishment Time (usec) .Only for LNS.
			 key:Device Group #.aggregate.lcp_max_latency                            value:LCP Maximum Establishment Time (usec) .Only for LNS.
		LCP Minimum Establishment Time (usec) .Only for LNS.
			 key:Device Group #.aggregate.lcp_min_latency                            value:LCP Minimum Establishment Time (usec) .Only for LNS.
		LCP Protocol Reject Rx .Only for LNS.
			 key:Device Group #.aggregate.lcp_protocol_rej_rx                        value:LCP Protocol Reject Rx .Only for LNS.
		LCP Protocol Reject Tx .Only for LNS.
			 key:Device Group #.aggregate.lcp_protocol_rej_tx                        value:LCP Protocol Reject Tx .Only for LNS.
		LCP Total Rx .Only for LNS.
			 key:Device Group #.aggregate.lcp_total_msg_rx                           value:LCP Total Rx .Only for LNS.
		LCP Total Tx .Only for LNS.
			 key:Device Group #.aggregate.lcp_total_msg_tx                           value:LCP Total Tx .Only for LNS.
		IPCP Average Establishment Time (usec) .Only for LNS.
			 key:Device Group #.aggregate.ncp_avg_latency                            value:IPCP Average Establishment Time (usec) .Only for LNS.
		IPCP Maximum Establishment Time (usec) .Only for LNS.
			 key:Device Group #.aggregate.ncp_max_latency                            value:IPCP Maximum Establishment Time (usec) .Only for LNS.
		IPCP Minimum Establishment Time (usec) .Only for LNS.
			 key:Device Group #.aggregate.ncp_min_latency                            value:IPCP Minimum Establishment Time (usec) .Only for LNS.
		NCP Total Rx .Only for LNS.
			 key:Device Group #.aggregate.ncp_total_msg_rx                           value:NCP Total Rx .Only for LNS.
		NCP Total Tx .Only for LNS.
			 key:Device Group #.aggregate.ncp_total_msg_tx                           value:NCP Total Tx .Only for LNS.
		Sessions Total
			 key:Device Group #.aggregate.num_sessions                               value:Sessions Total
		L2TP Window Messages Rx Out of Order
			 key:Device Group #.aggregate.out_of_order_rx                            value:L2TP Window Messages Rx Out of Order
		L2TP Window Messages Rx Out of Window
			 key:Device Group #.aggregate.out_of_win_rx                              value:L2TP Window Messages Rx Out of Window
		PADI Rx .Only for LNS.
			 key:Device Group #.aggregate.padi_rx                                    value:PADI Rx .Only for LNS.
		PADO Tx .Only for LNS.
			 key:Device Group #.aggregate.pado_tx                                    value:PADO Tx .Only for LNS.
		PADR Rx .Only for LNS.
			 key:Device Group #.aggregate.padr_rx                                    value:PADR Rx .Only for LNS.
		PADS Tx .Only for LNS.
			 key:Device Group #.aggregate.pads_tx                                    value:PADS Tx .Only for LNS.
		PADT Rx .Only for LNS.
			 key:Device Group #.aggregate.padt_rx                                    value:PADT Rx .Only for LNS.
		PADT Tx .Only for LNS.
			 key:Device Group #.aggregate.padt_tx                                    value:PADT Tx .Only for LNS.
		PAP Authentication ACK Tx .Only for LNS.
			 key:Device Group #.aggregate.pap_auth_ack_tx                            value:PAP Authentication ACK Tx .Only for LNS.
		PAP Authentication NAK Tx .Only for LNS.
			 key:Device Group #.aggregate.pap_auth_nak_tx                            value:PAP Authentication NAK Tx .Only for LNS.
		PAP Authentication Request Rx .Only for LNS.
			 key:Device Group #.aggregate.pap_auth_req_rx                            value:PAP Authentication Request Rx .Only for LNS.
		PPP Total Bytes Rx .Only for LNS.
			 key:Device Group #.aggregate.ppp_total_bytes_rx                         value:PPP Total Bytes Rx .Only for LNS.
		PPP Total Bytes Tx .Only for LNS.
			 key:Device Group #.aggregate.ppp_total_bytes_tx                         value:PPP Total Bytes Tx .Only for LNS.
		L2TP Window Messages Retransmitted
			 key:Device Group #.aggregate.retransmits                                value:L2TP Window Messages Retransmitted
		SCCCN Rx
			 key:Device Group #.aggregate.scccn_rx                                   value:SCCCN Rx
		SCCCN Tx
			 key:Device Group #.aggregate.scccn_tx                                   value:SCCCN Tx
		SCCRP Rx
			 key:Device Group #.aggregate.sccrp_rx                                   value:SCCRP Rx
		SCCRP Tx
			 key:Device Group #.aggregate.sccrp_tx                                   value:SCCRP Tx
		SCCRQ Rx
			 key:Device Group #.aggregate.sccrq_rx                                   value:SCCRQ Rx
		SCCRQ Tx
			 key:Device Group #.aggregate.sccrq_tx                                   value:SCCRQ Tx
		Interfaces in PPP Negotiation .Only for LNS.
			 key:Device Group #.aggregate.server_interfaces_in_ppp_negotiation       value:Interfaces in PPP Negotiation .Only for LNS.
		Average Establishment Time (usec) .Only for LNS.
			 key:Device Group #.aggregate.server_session_avg_latency                 value:Average Establishment Time (usec) .Only for LNS.
		Maximum Establishment Time (usec) .Only for LNS.
			 key:Device Group #.aggregate.server_session_max_latency                 value:Maximum Establishment Time (usec) .Only for LNS.
		Minimum Establishment Time (usec) .Only for LNS.
			 key:Device Group #.aggregate.server_session_min_latency                 value:Minimum Establishment Time (usec) .Only for LNS.
		L2TP Tunnels Up
			 key:Device Group #.aggregate.server_tunnels_up                          value:L2TP Tunnels Up
		Sessions Down
			 key:Device Group #.aggregate.sessions_failed                            value:Sessions Down
		Sessions Not Started
			 key:Device Group #.aggregate.sessions_not_started                       value:Sessions Not Started
		Sessions Up
			 key:Device Group #.aggregate.sessions_up                                value:Sessions Up
		SLI Rx
			 key:Device Group #.aggregate.sli_rx                                     value:SLI Rx
		SLI Tx
			 key:Device Group #.aggregate.sli_tx                                     value:SLI Tx
		StopCCN Rx
			 key:Device Group #.aggregate.stopccn_rx                                 value:StopCCN Rx
		StopCCN Tx
			 key:Device Group #.aggregate.stopccn_tx                                 value:StopCCN Tx
		LCP Terminate ACK Rx .Only for LNS.
			 key:Device Group #.aggregate.term_ack_rx                                value:LCP Terminate ACK Rx .Only for LNS.
		LCP Terminate ACK Tx .Only for LNS.
			 key:Device Group #.aggregate.term_ack_tx                                value:LCP Terminate ACK Tx .Only for LNS.
		LCP Terminate Request Rx .Only for LNS.
			 key:Device Group #.aggregate.term_req_rx                                value:LCP Terminate Request Rx .Only for LNS.
		LCP Terminate Request Tx .Only for LNS.
			 key:Device Group #.aggregate.term_req_tx                                value:LCP Terminate Request Tx .Only for LNS.
		PPPoE TotalBytes Rx .Only for LNS.
			 key:Device Group #.aggregate.total_bytes_rx                             value:PPPoE TotalBytes Rx .Only for LNS.
		PPPoE TotalBytes Tx .Only for LNS.
			 key:Device Group #.aggregate.total_bytes_tx                             value:PPPoE TotalBytes Tx .Only for LNS.
		L2TP Window Messages Tx Attempt While Close
			 key:Device Group #.aggregate.tun_tx_win_close                           value:L2TP Window Messages Tx Attempt While Close
		L2TP Window Messages Tx Attempt While Open
			 key:Device Group #.aggregate.tun_tx_win_open                            value:L2TP Window Messages Tx Attempt While Open
		L2TP Window Messages ACKed By Peer
			 key:Device Group #.aggregate.tx_pkt_acked                               value:L2TP Window Messages ACKed By Peer
		WEN Rx
			 key:Device Group #.aggregate.wen_rx                                     value:WEN Rx
		WEN Tx
			 key:Device Group #.aggregate.wen_tx                                     value:WEN Tx
		ZLB Rx
			 key:Device Group #.aggregate.zlb_rx                                     value:ZLB Rx
		ZLB Tx
			 key:Device Group #.aggregate.zlb_tx                                     value:ZLB Tx
		CDN Rx
			 key:l2tp_lac.session.row_id.cdn_rx                                      value:CDN Rx
		CDN Tx
			 key:l2tp_lac.session.row_id.cdn_tx                                      value:CDN Tx
		L2TP Window Messages Duplicate Rx
			 key:l2tp_lac.session.row_id.duplicate_rx                                value:L2TP Window Messages Duplicate Rx
		Hello Rx
			 key:l2tp_lac.session.row_id.hello_rx                                    value:Hello Rx
		Hello Tx
			 key:l2tp_lac.session.row_id.hello_tx                                    value:Hello Tx
		ICCN Rx
			 key:l2tp_lac.session.row_id.iccn_rx                                     value:ICCN Rx
		ICCN Tx
			 key:l2tp_lac.session.row_id.iccn_tx                                     value:ICCN Tx
		ICRP Rx
			 key:l2tp_lac.session.row_id.icrp_rx                                     value:ICRP Rx
		ICRP Tx
			 key:l2tp_lac.session.row_id.icrp_tx                                     value:ICRP Tx
		ICRQ Rx
			 key:l2tp_lac.session.row_id.icrq_rx                                     value:ICRQ Rx
		ICRQ Tx
			 key:l2tp_lac.session.row_id.icrq_tx                                     value:ICRQ Tx
		L2TP Window Messages Rx in Sequence
			 key:l2tp_lac.session.row_id.in_order_rx                                 value:L2TP Window Messages Rx in Sequence
		L2TP Calls Up
			 key:l2tp_lac.session.row_id.l2tp_calls_up                               value:L2TP Calls Up
		L2TP Tunnel Total Bytes Rx
			 key:l2tp_lac.session.row_id.l2tp_tunnel_total_bytes_rx                  value:L2TP Tunnel Total Bytes Rx
		L2TP Tunnel Total Bytes Tx
			 key:l2tp_lac.session.row_id.l2tp_tunnel_total_bytes_tx                  value:L2TP Tunnel Total Bytes Tx
		L2TP Window Messages Rx Out of Order
			 key:l2tp_lac.session.row_id.out_of_order_rx                             value:L2TP Window Messages Rx Out of Order
		L2TP Window Messages Rx Out of Window
			 key:l2tp_lac.session.row_id.out_of_win_rx                               value:L2TP Window Messages Rx Out of Window
		L2TP Window Messages Retransmitted
			 key:l2tp_lac.session.row_id.retransmits                                 value:L2TP Window Messages Retransmitted
		SCCCN Rx
			 key:l2tp_lac.session.row_id.scccn_rx                                    value:SCCCN Rx
		SCCCN Tx
			 key:l2tp_lac.session.row_id.scccn_tx                                    value:SCCCN Tx
		SCCRP Rx
			 key:l2tp_lac.session.row_id.sccrp_rx                                    value:SCCRP Rx
		SCCRP Tx
			 key:l2tp_lac.session.row_id.sccrp_tx                                    value:SCCRP Tx
		SCCRQ Rx
			 key:l2tp_lac.session.row_id.sccrq_rx                                    value:SCCRQ Rx
		SCCRQ Tx
			 key:l2tp_lac.session.row_id.sccrq_tx                                    value:SCCRQ Tx
		SLI Rx
			 key:l2tp_lac.session.row_id.sli_rx                                      value:SLI Rx
		SLI Tx
			 key:l2tp_lac.session.row_id.sli_tx                                      value:SLI Tx
		L2TP LAC Session Status
			 key:l2tp_lac.session.row_id.status                                      value:L2TP LAC Session Status
		StopCCN Rx
			 key:l2tp_lac.session.row_id.stopccn_rx                                  value:StopCCN Rx
		StopCCN Tx
			 key:l2tp_lac.session.row_id.stopccn_tx                                  value:StopCCN Tx
		L2TP Window Messages Tx Attempt While Close
			 key:l2tp_lac.session.row_id.tun_tx_win_close                            value:L2TP Window Messages Tx Attempt While Close
		L2TP Window Messages Tx Attempt While Open
			 key:l2tp_lac.session.row_id.tun_tx_win_open                             value:L2TP Window Messages Tx Attempt While Open
		L2TP Window Messages ACKed By Peer
			 key:l2tp_lac.session.row_id.tx_pkt_acked                                value:L2TP Window Messages ACKed By Peer
		WEN Rx
			 key:l2tp_lac.session.row_id.wen_rx                                      value:WEN Rx
		WEN Tx
			 key:l2tp_lac.session.row_id.wen_tx                                      value:WEN Tx
		ZLB Rx
			 key:l2tp_lac.session.row_id.zlb_rx                                      value:ZLB Rx
		ZLB Tx
			 key:l2tp_lac.session.row_id.zlb_tx                                      value:ZLB Tx
		CDN Rx
			 key:l2tp_lns.session.row_id.cdn_rx                                      value:CDN Rx
		CDN Tx
			 key:l2tp_lns.session.row_id.cdn_tx                                      value:CDN Tx
		L2TP Window Messages Duplicate Rx
			 key:l2tp_lns.session.row_id.duplicate_rx                                value:L2TP Window Messages Duplicate Rx
		Hello Rx
			 key:l2tp_lns.session.row_id.hello_rx                                    value:Hello Rx
		Hello Tx
			 key:l2tp_lns.session.row_id.hello_tx                                    value:Hello Tx
		ICCN Rx
			 key:l2tp_lns.session.row_id.iccn_rx                                     value:ICCN Rx
		ICCN Tx
			 key:l2tp_lns.session.row_id.iccn_tx                                     value:ICCN Tx
		ICRP Rx
			 key:l2tp_lns.session.row_id.icrp_rx                                     value:ICRP Rx
		ICRP Tx
			 key:l2tp_lns.session.row_id.icrp_tx                                     value:ICRP Tx
		ICRQ Rx
			 key:l2tp_lns.session.row_id.icrq_rx                                     value:ICRQ Rx
		ICRQ Tx
			 key:l2tp_lns.session.row_id.icrq_tx                                     value:ICRQ Tx
		L2TP Window Messages Rx in Sequence
			 key:l2tp_lns.session.row_id.in_order_rx                                 value:L2TP Window Messages Rx in Sequence
		L2TP Calls Up
			 key:l2tp_lns.session.row_id.l2tp_calls_up                               value:L2TP Calls Up
		L2TP Tunnel Total Bytes Rx
			 key:l2tp_lns.session.row_id.l2tp_tunnel_total_bytes_rx                  value:L2TP Tunnel Total Bytes Rx
		L2TP Tunnel Total Bytes Tx
			 key:l2tp_lns.session.row_id.l2tp_tunnel_total_bytes_tx                  value:L2TP Tunnel Total Bytes Tx
		L2TP Window Messages Rx Out of Order
			 key:l2tp_lns.session.row_id.out_of_order_rx                             value:L2TP Window Messages Rx Out of Order
		L2TP Window Messages Rx Out of Window
			 key:l2tp_lns.session.row_id.out_of_win_rx                               value:L2TP Window Messages Rx Out of Window
		L2TP Window Messages Retransmitted
			 key:l2tp_lns.session.row_id.retransmits                                 value:L2TP Window Messages Retransmitted
		SCCCN Rx
			 key:l2tp_lns.session.row_id.scccn_rx                                    value:SCCCN Rx
		SCCCN Tx
			 key:l2tp_lns.session.row_id.scccn_tx                                    value:SCCCN Tx
		SCCRP Rx
			 key:l2tp_lns.session.row_id.sccrp_rx                                    value:SCCRP Rx
		SCCRP Tx
			 key:l2tp_lns.session.row_id.sccrp_tx                                    value:SCCRP Tx
		SCCRQ Rx
			 key:l2tp_lns.session.row_id.sccrq_rx                                    value:SCCRQ Rx
		SCCRQ Tx
			 key:l2tp_lns.session.row_id.sccrq_tx                                    value:SCCRQ Tx
		L2TP Tunnels Up
			 key:l2tp_lns.session.row_id.server_tunnels_up                           value:L2TP Tunnels Up
		Status
			 key:l2tp_lns.session.row_id.session_status                              value:Status
		SLI Rx
			 key:l2tp_lns.session.row_id.sli_rx                                      value:SLI Rx
		SLI Tx
			 key:l2tp_lns.session.row_id.sli_tx                                      value:SLI Tx
		L2TP LNS Session Status
			 key:l2tp_lns.session.row_id.status                                      value:L2TP LNS Session Status
		StopCCN Rx
			 key:l2tp_lns.session.row_id.stopccn_rx                                  value:StopCCN Rx
		StopCCN Tx
			 key:l2tp_lns.session.row_id.stopccn_tx                                  value:StopCCN Tx
		L2TP Window Messages Tx Attempt While Close
			 key:l2tp_lns.session.row_id.tun_tx_win_close                            value:L2TP Window Messages Tx Attempt While Close
		L2TP Window Messages Tx Attempt While Open
			 key:l2tp_lns.session.row_id.tun_tx_win_open                             value:L2TP Window Messages Tx Attempt While Open
		L2TP Window Messages ACKed By Peer
			 key:l2tp_lns.session.row_id.tx_pkt_acked                                value:L2TP Window Messages ACKed By Peer
		WEN Rx
			 key:l2tp_lns.session.row_id.wen_rx                                      value:WEN Rx
		WEN Tx
			 key:l2tp_lns.session.row_id.wen_tx                                      value:WEN Tx
		ZLB Rx
			 key:l2tp_lns.session.row_id.zlb_rx                                      value:ZLB Rx
		ZLB Tx
			 key:l2tp_lns.session.row_id.zlb_tx                                      value:ZLB Tx
		AC Cookie
			 key:pppox_client.session.row_id.ac_cookie                               value:AC Cookie
		AC Cookie Tag Rx
			 key:pppox_client.session.row_id.ac_cookie_tag_rx                        value:AC Cookie Tag Rx
		AC Generic Error Occured
			 key:pppox_client.session.row_id.ac_generic_error_occured                value:AC Generic Error Occured
		AC MAC Address
			 key:pppox_client.session.row_id.ac_mac_addr                             value:AC MAC Address
		ACName
			 key:pppox_client.session.row_id.ac_name                                 value:ACName
		AC Offers Rx
			 key:pppox_client.session.row_id.ac_offers_rx                            value:AC Offers Rx
		AC System Error Occured
			 key:pppox_client.session.row_id.ac_system_error_occured                 value:AC System Error Occured
		AC System Error Tag Rx
			 key:pppox_client.session.row_id.ac_system_error_tag_rx                  value:AC System Error Tag Rx
		Authentication ID
			 key:pppox_client.session.row_id.auth_id                                 value:Authentication ID
		Authentication Establishment Time (usec)
			 key:pppox_client.session.row_id.auth_latency                            value:Authentication Establishment Time (usec)
		Authentication Password
			 key:pppox_client.session.row_id.auth_password                           value:Authentication Password
		Authentication Protocol Rx
			 key:pppox_client.session.row_id.auth_protocol_rx                        value:Authentication Protocol Rx
		Authentication Protocol Tx
			 key:pppox_client.session.row_id.auth_protocol_tx                        value:Authentication Protocol Tx
		Authentication Total Rx
			 key:pppox_client.session.row_id.auth_total_rx                           value:Authentication Total Rx
		Authentication Total Tx
			 key:pppox_client.session.row_id.auth_total_tx                           value:Authentication Total Tx
		Establishment Time (usec)
			 key:pppox_client.session.row_id.avg_setup_time                          value:Establishment Time (usec)
		Our Call ID
			 key:pppox_client.session.row_id.call_id                                 value:Our Call ID
		Call State
			 key:pppox_client.session.row_id.call_state                              value:Call State
		CHAP Challenge Rx
			 key:pppox_client.session.row_id.chap_auth_chal_rx                       value:CHAP Challenge Rx
		CHAP Failure Rx
			 key:pppox_client.session.row_id.chap_auth_fail_rx                       value:CHAP Failure Rx
		CHAP Authentication Role
			 key:pppox_client.session.row_id.chap_auth_role                          value:CHAP Authentication Role
		CHAP Response Tx
			 key:pppox_client.session.row_id.chap_auth_rsp_tx                        value:CHAP Response Tx
		CHAP Success Rx
			 key:pppox_client.session.row_id.chap_auth_succ_rx                       value:CHAP Success Rx
		LCP Code Reject Rx
			 key:pppox_client.session.row_id.code_rej_rx                             value:LCP Code Reject Rx
		LCP Code Reject Tx
			 key:pppox_client.session.row_id.code_rej_tx                             value:LCP Code Reject Tx
		Our Cookie
			 key:pppox_client.session.row_id.cookie                                  value:Our Cookie
		Our Cookie Length
			 key:pppox_client.session.row_id.cookie_len                              value:Our Cookie Length
		Data NS
			 key:pppox_client.session.row_id.data_ns                                 value:Data NS
		Destination IP
			 key:pppox_client.session.row_id.destination_ip                          value:Destination IP
		Destination Port
			 key:pppox_client.session.row_id.destination_port                        value:Destination Port
		DNS Server List
			 key:pppox_client.session.row_id.dns_server_list                         value:DNS Server List
		LCP Echo Request Rx
			 key:pppox_client.session.row_id.echo_req_rx                             value:LCP Echo Request Rx
		LCP Echo Request Tx
			 key:pppox_client.session.row_id.echo_req_tx                             value:LCP Echo Request Tx
		LCP Echo Response Rx
			 key:pppox_client.session.row_id.echo_rsp_rx                             value:LCP Echo Response Rx
		LCP Echo Response Tx
			 key:pppox_client.session.row_id.echo_rsp_tx                             value:LCP Echo Response Tx
		Gateway IP
			 key:pppox_client.session.row_id.gateway_ip                              value:Gateway IP
		Generic Error Tag Rx
			 key:pppox_client.session.row_id.generic_error_tag_rx                    value:Generic Error Tag Rx
		Host MAC Address
			 key:pppox_client.session.row_id.host_mac_addr                           value:Host MAC Address
		Host Name
			 key:pppox_client.session.row_id.host_name                               value:Host Name
		IPCP Config ACK Rx
			 key:pppox_client.session.row_id.ipcp_cfg_ack_rx                         value:IPCP Config ACK Rx
		IPCP Config ACK Tx
			 key:pppox_client.session.row_id.ipcp_cfg_ack_tx                         value:IPCP Config ACK Tx
		IPCP Config NAK Rx
			 key:pppox_client.session.row_id.ipcp_cfg_nak_rx                         value:IPCP Config NAK Rx
		IPCP Config NAK Tx
			 key:pppox_client.session.row_id.ipcp_cfg_nak_tx                         value:IPCP Config NAK Tx
		IPCP Config Reject Rx
			 key:pppox_client.session.row_id.ipcp_cfg_rej_rx                         value:IPCP Config Reject Rx
		IPCP Config Reject Tx
			 key:pppox_client.session.row_id.ipcp_cfg_rej_tx                         value:IPCP Config Reject Tx
		IPCP Config Request Rx
			 key:pppox_client.session.row_id.ipcp_cfg_req_rx                         value:IPCP Config Request Rx
		IPCP Config Request Tx
			 key:pppox_client.session.row_id.ipcp_cfg_req_tx                         value:IPCP Config Request Tx
		IPCP Establishment Time (usec)
			 key:pppox_client.session.row_id.ipcp_latency                            value:IPCP Establishment Time (usec)
		IPCP State
			 key:pppox_client.session.row_id.ipcp_state                              value:IPCP State
		IPv6 Address
			 key:pppox_client.session.row_id.ipv6_addr                               value:IPv6 Address
		IPv6 Prefix Length
			 key:pppox_client.session.row_id.ipv6_prefix_len                         value:IPv6 Prefix Length
		IPv6CP Config ACK Rx
			 key:pppox_client.session.row_id.ipv6cp_cfg_ack_rx                       value:IPv6CP Config ACK Rx
		IPv6CP Config ACK Tx
			 key:pppox_client.session.row_id.ipv6cp_cfg_ack_tx                       value:IPv6CP Config ACK Tx
		IPv6CP Config NAK Rx
			 key:pppox_client.session.row_id.ipv6cp_cfg_nak_rx                       value:IPv6CP Config NAK Rx
		IPv6CP Config NAK Tx
			 key:pppox_client.session.row_id.ipv6cp_cfg_nak_tx                       value:IPv6CP Config NAK Tx
		IPv6CP Config Reject Rx
			 key:pppox_client.session.row_id.ipv6cp_cfg_rej_rx                       value:IPv6CP Config Reject Rx
		IPv6CP Config Reject Tx
			 key:pppox_client.session.row_id.ipv6cp_cfg_rej_tx                       value:IPv6CP Config Reject Tx
		IPv6CP Config Request Rx
			 key:pppox_client.session.row_id.ipv6cp_cfg_req_rx                       value:IPv6CP Config Request Rx
		IPv6CP Config Request Tx
			 key:pppox_client.session.row_id.ipv6cp_cfg_req_tx                       value:IPv6CP Config Request Tx
		IPv6CP Establishment Time (usec)
			 key:pppox_client.session.row_id.ipv6cp_latency                          value:IPv6CP Establishment Time (usec)
		IPv6CP Router Advertisement Rx
			 key:pppox_client.session.row_id.ipv6cp_router_adv_rx                    value:IPv6CP Router Advertisement Rx
		IPv6CP State
			 key:pppox_client.session.row_id.ipv6cp_state                            value:IPv6CP State
		LCP Configure ACK Rx
			 key:pppox_client.session.row_id.lcp_cfg_ack_rx                          value:LCP Configure ACK Rx
		LCP Configure ACK Tx
			 key:pppox_client.session.row_id.lcp_cfg_ack_tx                          value:LCP Configure ACK Tx
		LCP Configure NAK Rx
			 key:pppox_client.session.row_id.lcp_cfg_nak_rx                          value:LCP Configure NAK Rx
		LCP Configure NAK Tx
			 key:pppox_client.session.row_id.lcp_cfg_nak_tx                          value:LCP Configure NAK Tx
		LCP Configure Reject Rx
			 key:pppox_client.session.row_id.lcp_cfg_rej_rx                          value:LCP Configure Reject Rx
		LCP Configure Reject Tx
			 key:pppox_client.session.row_id.lcp_cfg_rej_tx                          value:LCP Configure Reject Tx
		LCP Configure Request Rx
			 key:pppox_client.session.row_id.lcp_cfg_req_rx                          value:LCP Configure Request Rx
		LCP Configure Request Tx
			 key:pppox_client.session.row_id.lcp_cfg_req_tx                          value:LCP Configure Request Tx
		LCP Establishment Time (usec)
			 key:pppox_client.session.row_id.lcp_latency                             value:LCP Establishment Time (usec)
		LCP Protocol Reject Rx
			 key:pppox_client.session.row_id.lcp_protocol_rej_rx                     value:LCP Protocol Reject Rx
		LCP Protocol Reject Tx
			 key:pppox_client.session.row_id.lcp_protocol_rej_tx                     value:LCP Protocol Reject Tx
		LCP Total Rx
			 key:pppox_client.session.row_id.lcp_total_msg_rx                        value:LCP Total Rx
		LCP Total Tx
			 key:pppox_client.session.row_id.lcp_total_msg_tx                        value:LCP Total Tx
		Local IP Address
			 key:pppox_client.session.row_id.local_ip_addr                           value:Local IP Address
		Local Ipv6 IID
			 key:pppox_client.session.row_id.local_ipv6_iid                          value:Local Ipv6 IID
		Loopback Detected
			 key:pppox_client.session.row_id.loopback_detected                       value:Loopback Detected
		Magic Number Negotiated
			 key:pppox_client.session.row_id.magic_no_negotiated                     value:Magic Number Negotiated
		Magic Number Rx
			 key:pppox_client.session.row_id.magic_no_rx                             value:Magic Number Rx
		Magic Number Tx
			 key:pppox_client.session.row_id.magic_no_tx                             value:Magic Number Tx
		MRU
			 key:pppox_client.session.row_id.mru                                     value:MRU
		MTU
			 key:pppox_client.session.row_id.mtu                                     value:MTU
		NCP Total Rx
			 key:pppox_client.session.row_id.ncp_total_msg_rx                        value:NCP Total Rx
		NCP Total Tx
			 key:pppox_client.session.row_id.ncp_total_msg_tx                        value:NCP Total Tx
		Negotiation End Time
			 key:pppox_client.session.row_id.negotiation_end_ms                      value:Negotiation End Time
		Negotiation Start Time
			 key:pppox_client.session.row_id.negotiation_start_ms                    value:Negotiation Start Time
		PADI Timeouts
			 key:pppox_client.session.row_id.padi_timeouts                           value:PADI Timeouts
		PADI Tx
			 key:pppox_client.session.row_id.padi_tx                                 value:PADI Tx
		PADO Rx
			 key:pppox_client.session.row_id.pado_rx                                 value:PADO Rx
		PADR Timeouts
			 key:pppox_client.session.row_id.padr_timeouts                           value:PADR Timeouts
		PADR Tx
			 key:pppox_client.session.row_id.padr_tx                                 value:PADR Tx
		PADS Rx
			 key:pppox_client.session.row_id.pads_rx                                 value:PADS Rx
		PADT Rx
			 key:pppox_client.session.row_id.padt_rx                                 value:PADT Rx
		PADT Tx
			 key:pppox_client.session.row_id.padt_tx                                 value:PADT Tx
		PAP Authentication ACK Rx
			 key:pppox_client.session.row_id.pap_auth_ack_rx                         value:PAP Authentication ACK Rx
		PAP Authentication NAK Rx
			 key:pppox_client.session.row_id.pap_auth_nak_rx                         value:PAP Authentication NAK Rx
		PAP Authentication Request Tx
			 key:pppox_client.session.row_id.pap_auth_req_tx                         value:PAP Authentication Request Tx
		Peer Call ID
			 key:pppox_client.session.row_id.peer_call_id                            value:Peer Call ID
		Peer Tunnel ID
			 key:pppox_client.session.row_id.peer_id                                 value:Peer Tunnel ID
		Peer Ipv6 IID
			 key:pppox_client.session.row_id.peer_ipv6_iid                           value:Peer Ipv6 IID
		PPP Close Mode
			 key:pppox_client.session.row_id.ppp_close_mode                          value:PPP Close Mode
		PPP State
			 key:pppox_client.session.row_id.ppp_state                               value:PPP State
		PPPoE Discovery Establishment Time (usec)
			 key:pppox_client.session.row_id.pppoe_discovery_latency                 value:PPPoE Discovery Establishment Time (usec)
		PPPoE Session ID
			 key:pppox_client.session.row_id.pppoe_session_id                        value:PPPoE Session ID
		PPPoE State
			 key:pppox_client.session.row_id.pppox_state                             value:PPPoE State
		Primary WINS Server
			 key:pppox_client.session.row_id.primary_wins_server                     value:Primary WINS Server
		Relay Session ID Tag Rx
			 key:pppox_client.session.row_id.relay_session_id_tag_rx                 value:Relay Session ID Tag Rx
		Remote IP Address
			 key:pppox_client.session.row_id.remote_ip_addr                          value:Remote IP Address
		Secondary WINS Server
			 key:pppox_client.session.row_id.secondary_wins_server                   value:Secondary WINS Server
		Service Name
			 key:pppox_client.session.row_id.service_name                            value:Service Name
		Service Name Error Tag Rx
			 key:pppox_client.session.row_id.service_name_error_tag_rx               value:Service Name Error Tag Rx
		Source IP
			 key:pppox_client.session.row_id.source_ip                               value:Source IP
		Source Port
			 key:pppox_client.session.row_id.source_port                             value:Source Port
		PPPox Client Session Status
			 key:pppox_client.session.row_id.status                                  value:PPPox Client Session Status
		LCP Terminate ACK Rx
			 key:pppox_client.session.row_id.term_ack_rx                             value:LCP Terminate ACK Rx
		LCP Terminate ACK Tx
			 key:pppox_client.session.row_id.term_ack_tx                             value:LCP Terminate ACK Tx
		LCP Terminate Request Rx
			 key:pppox_client.session.row_id.term_req_rx                             value:LCP Terminate Request Rx
		LCP Terminate Request Tx
			 key:pppox_client.session.row_id.term_req_tx                             value:LCP Terminate Request Tx
		PPPoE TotalBytes Rx
			 key:pppox_client.session.row_id.total_bytes_rx                          value:PPPoE TotalBytes Rx
		PPPoE TotalBytes Tx
			 key:pppox_client.session.row_id.total_bytes_tx                          value:PPPoE TotalBytes Tx
		Our Tunnel ID
			 key:pppox_client.session.row_id.tunnel_id                               value:Our Tunnel ID
		Tunnel State
			 key:pppox_client.session.row_id.tunnel_state                            value:Tunnel State
		Vendor Specific Tag Rx
			 key:pppox_client.session.row_id.vendor_specific_tag_rx                  value:Vendor Specific Tag Rx
		AC MAC Address
			 key:pppox_server.session.row_id.ac_mac_addr                             value:AC MAC Address
		ACName
			 key:pppox_server.session.row_id.ac_name                                 value:ACName
		Authentication ID
			 key:pppox_server.session.row_id.auth_id                                 value:Authentication ID
		Authentication Establishment Time (usec)
			 key:pppox_server.session.row_id.auth_latency                            value:Authentication Establishment Time (usec)
		Authentication Password
			 key:pppox_server.session.row_id.auth_password                           value:Authentication Password
		Authentication Protocol Rx
			 key:pppox_server.session.row_id.auth_protocol_rx                        value:Authentication Protocol Rx
		Authentication Protocol Tx
			 key:pppox_server.session.row_id.auth_protocol_tx                        value:Authentication Protocol Tx
		Authentication Total Rx
			 key:pppox_server.session.row_id.auth_total_rx                           value:Authentication Total Rx
		Authentication Total Tx
			 key:pppox_server.session.row_id.auth_total_tx                           value:Authentication Total Tx
		Establishment Time (usec)
			 key:pppox_server.session.row_id.avg_setup_time                          value:Establishment Time (usec)
		Our Call ID
			 key:pppox_server.session.row_id.call_id                                 value:Our Call ID
		Call State
			 key:pppox_server.session.row_id.call_state                              value:Call State
		CHAP Challenge Tx
			 key:pppox_server.session.row_id.chap_auth_chal_tx                       value:CHAP Challenge Tx
		CHAP Failure Tx
			 key:pppox_server.session.row_id.chap_auth_fail_tx                       value:CHAP Failure Tx
		CHAP Authentication Role
			 key:pppox_server.session.row_id.chap_auth_role                          value:CHAP Authentication Role
		CHAP Response Rx
			 key:pppox_server.session.row_id.chap_auth_rsp_rx                        value:CHAP Response Rx
		CHAP Success Tx
			 key:pppox_server.session.row_id.chap_auth_succ_tx                       value:CHAP Success Tx
		LCP Code Reject Rx
			 key:pppox_server.session.row_id.code_rej_rx                             value:LCP Code Reject Rx
		LCP Code Reject Tx
			 key:pppox_server.session.row_id.code_rej_tx                             value:LCP Code Reject Tx
		Our Cookie
			 key:pppox_server.session.row_id.cookie                                  value:Our Cookie
		Our Cookie Length
			 key:pppox_server.session.row_id.cookie_len                              value:Our Cookie Length
		Data NS
			 key:pppox_server.session.row_id.data_ns                                 value:Data NS
		Destination IP
			 key:pppox_server.session.row_id.destination_ip                          value:Destination IP
		Destination Port
			 key:pppox_server.session.row_id.destination_port                        value:Destination Port
		DNS Server List
			 key:pppox_server.session.row_id.dns_server_list                         value:DNS Server List
		LCP Echo Request Rx
			 key:pppox_server.session.row_id.echo_req_rx                             value:LCP Echo Request Rx
		LCP Echo Request Tx
			 key:pppox_server.session.row_id.echo_req_tx                             value:LCP Echo Request Tx
		LCP Echo Response Rx
			 key:pppox_server.session.row_id.echo_rsp_rx                             value:LCP Echo Response Rx
		LCP Echo Response Tx
			 key:pppox_server.session.row_id.echo_rsp_tx                             value:LCP Echo Response Tx
		Gateway IP
			 key:pppox_server.session.row_id.gateway_ip                              value:Gateway IP
		Generic Error Tag Rx
			 key:pppox_server.session.row_id.generic_error_tag_rx                    value:Generic Error Tag Rx
		Host MAC Address
			 key:pppox_server.session.row_id.host_mac_addr                           value:Host MAC Address
		Host Name
			 key:pppox_server.session.row_id.host_name                               value:Host Name
		IPCP Config ACK Rx
			 key:pppox_server.session.row_id.ipcp_cfg_ack_rx                         value:IPCP Config ACK Rx
		IPCP Config ACK Tx
			 key:pppox_server.session.row_id.ipcp_cfg_ack_tx                         value:IPCP Config ACK Tx
		IPCP Config NAK Rx
			 key:pppox_server.session.row_id.ipcp_cfg_nak_rx                         value:IPCP Config NAK Rx
		IPCP Config NAK Tx
			 key:pppox_server.session.row_id.ipcp_cfg_nak_tx                         value:IPCP Config NAK Tx
		IPCP Config Reject Rx
			 key:pppox_server.session.row_id.ipcp_cfg_rej_rx                         value:IPCP Config Reject Rx
		IPCP Config Reject Tx
			 key:pppox_server.session.row_id.ipcp_cfg_rej_tx                         value:IPCP Config Reject Tx
		IPCP Config Request Rx
			 key:pppox_server.session.row_id.ipcp_cfg_req_rx                         value:IPCP Config Request Rx
		IPCP Config Request Tx
			 key:pppox_server.session.row_id.ipcp_cfg_req_tx                         value:IPCP Config Request Tx
		IPCP Establishment Time (usec)
			 key:pppox_server.session.row_id.ipcp_latency                            value:IPCP Establishment Time (usec)
		IPCP State
			 key:pppox_server.session.row_id.ipcp_state                              value:IPCP State
		IPv6 Address
			 key:pppox_server.session.row_id.ipv6_addr                               value:IPv6 Address
		IPv6 Prefix Length
			 key:pppox_server.session.row_id.ipv6_prefix_len                         value:IPv6 Prefix Length
		IPv6CP Config ACK Rx
			 key:pppox_server.session.row_id.ipv6cp_cfg_ack_rx                       value:IPv6CP Config ACK Rx
		IPv6CP Config ACK Tx
			 key:pppox_server.session.row_id.ipv6cp_cfg_ack_tx                       value:IPv6CP Config ACK Tx
		IPv6CP Config NAK Rx
			 key:pppox_server.session.row_id.ipv6cp_cfg_nak_rx                       value:IPv6CP Config NAK Rx
		IPv6CP Config NAK Tx
			 key:pppox_server.session.row_id.ipv6cp_cfg_nak_tx                       value:IPv6CP Config NAK Tx
		IPv6CP Config Reject Rx
			 key:pppox_server.session.row_id.ipv6cp_cfg_rej_rx                       value:IPv6CP Config Reject Rx
		IPv6CP Config Reject Tx
			 key:pppox_server.session.row_id.ipv6cp_cfg_rej_tx                       value:IPv6CP Config Reject Tx
		IPv6CP Config Request Rx
			 key:pppox_server.session.row_id.ipv6cp_cfg_req_rx                       value:IPv6CP Config Request Rx
		IPv6CP Config Request Tx
			 key:pppox_server.session.row_id.ipv6cp_cfg_req_tx                       value:IPv6CP Config Request Tx
		IPv6CP Establishment Time (usec)
			 key:pppox_server.session.row_id.ipv6cp_latency                          value:IPv6CP Establishment Time (usec)
		IPv6CP Router Advertisement Tx
			 key:pppox_server.session.row_id.ipv6cp_router_adv_tx                    value:IPv6CP Router Advertisement Tx
		IPv6CP Router Solicitation Rx
			 key:pppox_server.session.row_id.ipv6cp_router_solicitation_rx           value:IPv6CP Router Solicitation Rx
		IPv6CP State
			 key:pppox_server.session.row_id.ipv6cp_state                            value:IPv6CP State
		LCP Configure ACK Rx
			 key:pppox_server.session.row_id.lcp_cfg_ack_rx                          value:LCP Configure ACK Rx
		LCP Configure ACK Tx
			 key:pppox_server.session.row_id.lcp_cfg_ack_tx                          value:LCP Configure ACK Tx
		LCP Configure NAK Rx
			 key:pppox_server.session.row_id.lcp_cfg_nak_rx                          value:LCP Configure NAK Rx
		LCP Configure NAK Tx
			 key:pppox_server.session.row_id.lcp_cfg_nak_tx                          value:LCP Configure NAK Tx
		LCP Configure Reject Rx
			 key:pppox_server.session.row_id.lcp_cfg_rej_rx                          value:LCP Configure Reject Rx
		LCP Configure Reject Tx
			 key:pppox_server.session.row_id.lcp_cfg_rej_tx                          value:LCP Configure Reject Tx
		LCP Configure Request Rx
			 key:pppox_server.session.row_id.lcp_cfg_req_rx                          value:LCP Configure Request Rx
		LCP Configure Request Tx
			 key:pppox_server.session.row_id.lcp_cfg_req_tx                          value:LCP Configure Request Tx
		LCP Establishment Time (usec)
			 key:pppox_server.session.row_id.lcp_latency                             value:LCP Establishment Time (usec)
		LCP Protocol Reject Rx
			 key:pppox_server.session.row_id.lcp_protocol_rej_rx                     value:LCP Protocol Reject Rx
		LCP Protocol Reject Tx
			 key:pppox_server.session.row_id.lcp_protocol_rej_tx                     value:LCP Protocol Reject Tx
		LCP Total Rx
			 key:pppox_server.session.row_id.lcp_total_msg_rx                        value:LCP Total Rx
		LCP Total Tx
			 key:pppox_server.session.row_id.lcp_total_msg_tx                        value:LCP Total Tx
		Local IP Address
			 key:pppox_server.session.row_id.local_ip_addr                           value:Local IP Address
		Local Ipv6 IID
			 key:pppox_server.session.row_id.local_ipv6_iid                          value:Local Ipv6 IID
		Loopback Detected
			 key:pppox_server.session.row_id.loopback_detected                       value:Loopback Detected
		Magic Number Negotiated
			 key:pppox_server.session.row_id.magic_no_negotiated                     value:Magic Number Negotiated
		Magic Number Rx
			 key:pppox_server.session.row_id.magic_no_rx                             value:Magic Number Rx
		Magic Number Tx
			 key:pppox_server.session.row_id.magic_no_tx                             value:Magic Number Tx
		MRU
			 key:pppox_server.session.row_id.mru                                     value:MRU
		MTU
			 key:pppox_server.session.row_id.mtu                                     value:MTU
		NCP Total Rx
			 key:pppox_server.session.row_id.ncp_total_msg_rx                        value:NCP Total Rx
		NCP Total Tx
			 key:pppox_server.session.row_id.ncp_total_msg_tx                        value:NCP Total Tx
		Negotiation End Time
			 key:pppox_server.session.row_id.negotiation_end_ms                      value:Negotiation End Time
		Negotiation Start Time
			 key:pppox_server.session.row_id.negotiation_start_ms                    value:Negotiation Start Time
		PADI Rx
			 key:pppox_server.session.row_id.padi_rx                                 value:PADI Rx
		PADO Tx
			 key:pppox_server.session.row_id.pado_tx                                 value:PADO Tx
		PADR Rx
			 key:pppox_server.session.row_id.padr_rx                                 value:PADR Rx
		PADS Tx
			 key:pppox_server.session.row_id.pads_tx                                 value:PADS Tx
		PADT Rx
			 key:pppox_server.session.row_id.padt_rx                                 value:PADT Rx
		PADT Tx
			 key:pppox_server.session.row_id.padt_tx                                 value:PADT Tx
		PAP Authentication ACK Tx
			 key:pppox_server.session.row_id.pap_auth_ack_tx                         value:PAP Authentication ACK Tx
		PAP Authentication NAK Tx
			 key:pppox_server.session.row_id.pap_auth_nak_tx                         value:PAP Authentication NAK Tx
		PAP Authentication Request Rx
			 key:pppox_server.session.row_id.pap_auth_req_rx                         value:PAP Authentication Request Rx
		Peer Call ID
			 key:pppox_server.session.row_id.peer_call_id                            value:Peer Call ID
		Peer Tunnel ID
			 key:pppox_server.session.row_id.peer_id                                 value:Peer Tunnel ID
		Peer Ipv6 IID
			 key:pppox_server.session.row_id.peer_ipv6_iid                           value:Peer Ipv6 IID
		PPP Close Mode
			 key:pppox_server.session.row_id.ppp_close_mode                          value:PPP Close Mode
		PPP State
			 key:pppox_server.session.row_id.ppp_state                               value:PPP State
		PPPoE Discovery Establishment Time (usec)
			 key:pppox_server.session.row_id.pppoe_discovery_latency                 value:PPPoE Discovery Establishment Time (usec)
		PPPoE Session ID
			 key:pppox_server.session.row_id.pppoe_session_id                        value:PPPoE Session ID
		PPPoE State
			 key:pppox_server.session.row_id.pppox_state                             value:PPPoE State
		Primary WINS Server
			 key:pppox_server.session.row_id.primary_wins_server                     value:Primary WINS Server
		Relay Session ID Tag Rx
			 key:pppox_server.session.row_id.relay_session_id_tag_rx                 value:Relay Session ID Tag Rx
		Remote IP Address
			 key:pppox_server.session.row_id.remote_ip_addr                          value:Remote IP Address
		Secondary WINS Server
			 key:pppox_server.session.row_id.secondary_wins_server                   value:Secondary WINS Server
		Service Name
			 key:pppox_server.session.row_id.service_name                            value:Service Name
		Source IP
			 key:pppox_server.session.row_id.source_ip                               value:Source IP
		Source Port
			 key:pppox_server.session.row_id.source_port                             value:Source Port
		PPPox Server Session Status
			 key:pppox_server.session.row_id.status                                  value:PPPox Server Session Status
		LCP Terminate ACK Rx
			 key:pppox_server.session.row_id.term_ack_rx                             value:LCP Terminate ACK Rx
		LCP Terminate ACK Tx
			 key:pppox_server.session.row_id.term_ack_tx                             value:LCP Terminate ACK Tx
		LCP Terminate Request Rx
			 key:pppox_server.session.row_id.term_req_rx                             value:LCP Terminate Request Rx
		LCP Terminate Request Tx
			 key:pppox_server.session.row_id.term_req_tx                             value:LCP Terminate Request Tx
		PPPoE TotalBytes Rx
			 key:pppox_server.session.row_id.total_bytes_rx                          value:PPPoE TotalBytes Rx
		PPPoE TotalBytes Tx
			 key:pppox_server.session.row_id.total_bytes_tx                          value:PPPoE TotalBytes Tx
		Our Tunnel ID
			 key:pppox_server.session.row_id.tunnel_id                               value:Our Tunnel ID
		Tunnel State
			 key:pppox_server.session.row_id.tunnel_state                            value:Tunnel State
		Vendor Specific Tag Rx
			 key:pppox_server.session.row_id.vendor_specific_tag_rx                  value:Vendor Specific Tag Rx
		$::SUCCESS | $::FAILURE
			 key:status                                                              value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                                                                 value:If status is failure, detailed information provided.
		Port Name
			 key:session.<session ID>.port_name                                      value:Port Name
		Interface Identifier
			 key:session.<session ID>.interface_id                                   value:Interface Identifier
		Peer Call ID
			 key:session.<session ID>.peer_call_id                                   value:Peer Call ID
		Peer Tunnel ID
			 key:session.<session ID>.tunnel_id                                      value:Peer Tunnel ID
		Data NS
			 key:session.<session ID>.data_ns                                        value:Data NS
		Destination Port
			 key:session.<session ID>.destination_port                               value:Destination Port
		Source Port
			 key:session.<session ID>.source_port                                    value:Source Port
		Destination IP
			 key:session.<session ID>.destination_ip                                 value:Destination IP
		Source IP
			 key:session.<session ID>.source_ip                                      value:Source IP
		Gateway IP
			 key:session.<session ID>.gateway_ip                                     value:Gateway IP
		Our Call ID
			 key:session.<session ID>.call_id                                        value:Our Call ID
		Our Peer ID
			 key:session.<session ID>.peer_id                                        value:Our Peer ID
		Our Cookie Length
			 key:session.<session ID>.cookie_len                                     value:Our Cookie Length
		Our Cookie
			 key:session.<session ID>.cookie                                         value:Our Cookie
		ICRQ Tx
			 key:session.<session ID>.icrq_tx                                        value:ICRQ Tx
		ICRP Tx
			 key:session.<session ID>.icrp_tx                                        value:ICRP Tx
		ICCN Tx
			 key:session.<session ID>.iccn_tx                                        value:ICCN Tx
		CDN Tx
			 key:session.<session ID>.cdn_tx                                         value:CDN Tx
		ICRQ Rx
			 key:session.<session ID>.icrq_rx                                        value:ICRQ Rx
		ICRP Rx
			 key:session.<session ID>.icrp_rx                                        value:ICRP Rx
		ICCN Rx
			 key:session.<session ID>.iccn_rx                                        value:ICCN Rx
		CDN Rx
			 key:session.<session ID>.cdn_rx                                         value:CDN Rx
		PPP State
			 key:session.<session ID>.pppox_state                                    value:PPP State
		Authentication ID
			 key:session.<session ID>.auth_id                                        value:Authentication ID
		Authentication Password
			 key:session.<session ID>.auth_password                                  value:Authentication Password
		Authentication Protocol Rx
			 key:session.<session ID>.auth_protocol_rx                               value:Authentication Protocol Rx
		Authentication Protocol Tx
			 key:session.<session ID>.auth_protocol_tx                               value:Authentication Protocol Tx
		Authentication Total Rx
			 key:session.<session ID>.auth_total_rx                                  value:Authentication Total Rx
		Authentication Total Tx
			 key:session.<session ID>.auth_total_tx                                  value:Authentication Total Tx
		Call State
			 key:session.<session ID>.call_state                                     value:Call State
		CHAP Authentication Role
			 key:session.<session ID>.chap_auth_role                                 value:CHAP Authentication Role
		CHAP Challenge Rx
			 key:session.<session ID>.chap_auth_chal_rx                              value:CHAP Challenge Rx
		CHAP Challenge Tx
			 key:session.<session ID>.chap_auth_chal_tx                              value:CHAP Challenge Tx
		CHAP Failure Rx
			 key:session.<session ID>.chap_auth_fail_rx                              value:CHAP Failure Rx
		CHAP Failure Tx
			 key:session.<session ID>.chap_auth_fail_tx                              value:CHAP Failure Tx
		CHAP Response Rx
			 key:session.<session ID>.chap_auth_rsp_rx                               value:CHAP Response Rx
		CHAP Response Tx
			 key:session.<session ID>.chap_auth_rsp_tx                               value:CHAP Response Tx
		CHAP Success Rx
			 key:session.<session ID>.chap_auth_succ_rx                              value:CHAP Success Rx
		CHAP Success Tx
			 key:session.<session ID>.chap_auth_succ_tx                              value:CHAP Success Tx
		PPP Close Mode
			 key:session.<session ID>.close_mode                                     value:PPP Close Mode
		LCP Code Reject Rx
			 key:session.<session ID>.code_rej_rx                                    value:LCP Code Reject Rx
		LCP Code Reject Tx
			 key:session.<session ID>.code_rej_tx                                    value:LCP Code Reject Tx
		LCP Echo Request Rx
			 key:session.<session ID>.echo_req_rx                                    value:LCP Echo Request Rx
		LCP Echo Request Tx
			 key:session.<session ID>.echo_req_tx                                    value:LCP Echo Request Tx
		LCP Echo Response Rx
			 key:session.<session ID>.echo_rsp_rx                                    value:LCP Echo Response Rx
		LCP Echo Response Tx
			 key:session.<session ID>.echo_rsp_tx                                    value:LCP Echo Response Tx
		DUT Test Mode
			 key:session.<session ID>.dut_test_mode                                  value:DUT Test Mode
		IPCP Config ACK Rx
			 key:session.<session ID>.ipcp_cfg_ack_rx                                value:IPCP Config ACK Rx
		IPCP Config ACK Tx
			 key:session.<session ID>.ipcp_cfg_ack_tx                                value:IPCP Config ACK Tx
		IPCP Config NAK Rx
			 key:session.<session ID>.ipcp_cfg_nak_rx                                value:IPCP Config NAK Rx
		IPCP Config NAK Tx
			 key:session.<session ID>.ipcp_cfg_nak_tx                                value:IPCP Config NAK Tx
		IPCP Config Reject Rx
			 key:session.<session ID>.ipcp_cfg_rej_rx                                value:IPCP Config Reject Rx
		IPCP Config Reject Tx
			 key:session.<session ID>.ipcp_cfg_rej_tx                                value:IPCP Config Reject Tx
		IPCP Config Request Rx
			 key:session.<session ID>.ipcp_cfg_req_rx                                value:IPCP Config Request Rx
		IPCP Config Request Tx
			 key:session.<session ID>.ipcp_cfg_req_tx                                value:IPCP Config Request Tx
		IPCP State
			 key:session.<session ID>.ipcp_state                                     value:IPCP State
		IPv6CP Config ACK Rx
			 key:session.<session ID>.ipv6cp_cfg_ack_rx                              value:IPv6CP Config ACK Rx
		IPv6CP Config ACK Tx
			 key:session.<session ID>.ipv6cp_cfg_ack_tx                              value:IPv6CP Config ACK Tx
		IPv6CP Config NAK Rx
			 key:session.<session ID>.ipv6cp_cfg_nak_rx                              value:IPv6CP Config NAK Rx
		IPv6CP Config NAK Tx
			 key:session.<session ID>.ipv6cp_cfg_nak_tx                              value:IPv6CP Config NAK Tx
		IPv6CP Config Reject Rx
			 key:session.<session ID>.ipv6cp_cfg_rej_rx                              value:IPv6CP Config Reject Rx
		IPv6CP Config Reject Tx
			 key:session.<session ID>.ipv6cp_cfg_rej_tx                              value:IPv6CP Config Reject Tx
		IPv6CP Config Request Rx
			 key:session.<session ID>.ipv6cp_cfg_req_rx                              value:IPv6CP Config Request Rx
		IPv6CP Config Request Tx
			 key:session.<session ID>.ipv6cp_cfg_req_tx                              value:IPv6CP Config Request Tx
		IPv6CP State
			 key:session.<session ID>.ipv6cp_state                                   value:IPv6CP State
		IPv6CP Router Advertisement Rx
			 key:session.<session ID>.ipv6cp_router_adv_rx                           value:IPv6CP Router Advertisement Rx
		IPv6CP Router Advertisement Tx
			 key:session.<session ID>.ipv6cp_router_adv_tx                           value:IPv6CP Router Advertisement Tx
		IPv6 Prefix Length
			 key:session.<session ID>.ipv6_prefix_len                                value:IPv6 Prefix Length
		IPv6 Address
			 key:session.<session ID>.ipv6_addr                                      value:IPv6 Address
		LCP Config ACK Rx
			 key:session.<session ID>.lcp_cfg_ack_rx                                 value:LCP Config ACK Rx
		LCP Config ACK Tx
			 key:session.<session ID>.lcp_cfg_ack_tx                                 value:LCP Config ACK Tx
		LCP Config NAK Rx
			 key:session.<session ID>.lcp_cfg_nak_rx                                 value:LCP Config NAK Rx
		LCP Config NAK Tx
			 key:session.<session ID>.lcp_cfg_nak_tx                                 value:LCP Config NAK Tx
		LCP Config Reject Rx
			 key:session.<session ID>.lcp_cfg_rej_rx                                 value:LCP Config Reject Rx
		LCP Config Reject Tx
			 key:session.<session ID>.lcp_cfg_rej_tx                                 value:LCP Config Reject Tx
		LCP Config Request Rx
			 key:session.<session ID>.lcp_cfg_req_rx                                 value:LCP Config Request Rx
		LCP Config Request Tx
			 key:session.<session ID>.lcp_cfg_req_tx                                 value:LCP Config Request Tx
		LCP Protocol Reject Rx
			 key:session.<session ID>.lcp_protocol_rej_rx                            value:LCP Protocol Reject Rx
		LCP Protocol Reject Tx
			 key:session.<session ID>.lcp_protocol_rej_tx                            value:LCP Protocol Reject Tx
		LCP Total Rx
			 key:session.<session ID>.lcp_total_msg_rx                               value:LCP Total Rx
		LCP Total Tx
			 key:session.<session ID>.lcp_total_msg_tx                               value:LCP Total Tx
		Local IP Address
			 key:session.<session ID>.local_ip_addr                                  value:Local IP Address
		Local IPv6 IID
			 key:session.<session ID>.local_ipv6_iid                                 value:Local IPv6 IID
		Malformed PPP Frames Rejected
			 key:session.<session ID>.malformed_ppp_frames_rejected                  value:Malformed PPP Frames Rejected
		Malformed PPP Frames Used
			 key:session.<session ID>.malformed_ppp_frames_used                      value:Malformed PPP Frames Used
		MRU
			 key:session.<session ID>.mru                                            value:MRU
		MTU
			 key:session.<session ID>.mtu                                            value:MTU
		Magic Number Negotiated
			 key:session.<session ID>.magic_no_negotiated                            value:Magic Number Negotiated
		Magic Number Rx
			 key:session.<session ID>.magic_no_rx                                    value:Magic Number Rx
		Magic Number Tx
			 key:session.<session ID>.magic_no_tx                                    value:Magic Number Tx
		NCP Total Rx
			 key:session.<session ID>.ncp_total_msg_rx                               value:NCP Total Rx
		NCP Total Tx
			 key:session.<session ID>.ncp_total_msg_tx                               value:NCP Total Tx
		Negotiation Start Time [ms]
			 key:session.<session ID>.negotiation_start_ms                           value:Negotiation Start Time [ms]
		Negotiation End Time [ms]
			 key:session.<session ID>.negotiation_end_ms                             value:Negotiation End Time [ms]
		PAP Authentication ACK Rx
			 key:session.<session ID>.pap_auth_ack_rx                                value:PAP Authentication ACK Rx
		PAP Authentication ACK Tx
			 key:session.<session ID>.pap_auth_ack_tx                                value:PAP Authentication ACK Tx
		PAP Authentication NAK Rx
			 key:session.<session ID>.pap_auth_nak_rx                                value:PAP Authentication NAK Rx
		PAP Authentication NAK Tx
			 key:session.<session ID>.pap_auth_nak_tx                                value:PAP Authentication NAK Tx
		PAP Authentication Request Rx
			 key:session.<session ID>.pap_auth_req_rx                                value:PAP Authentication Request Rx
		PAP Authentication Request Tx
			 key:session.<session ID>.pap_auth_req_tx                                value:PAP Authentication Request Tx
		Peer IPv6 IID
			 key:session.<session ID>.peer_ipv6_iid                                  value:Peer IPv6 IID
		PPP Total Bytes Rx
			 key:session.<session ID>.ppp_total_bytes_rx                             value:PPP Total Bytes Rx
		PPP Total Bytes Tx
			 key:session.<session ID>.ppp_total_bytes_tx                             value:PPP Total Bytes Tx
		Remote IP Address
			 key:session.<session ID>.remote_ip_addr                                 value:Remote IP Address
		Loopback Detected
			 key:session.<session ID>.loopback_detected                              value:Loopback Detected
		LCP Terminate ACK Rx
			 key:session.<session ID>.term_ack_rx                                    value:LCP Terminate ACK Rx
		LCP Terminate ACK Tx
			 key:session.<session ID>.term_ack_tx                                    value:LCP Terminate ACK Tx
		LCP Terminate Request Rx
			 key:session.<session ID>.term_req_rx                                    value:LCP Terminate Request Rx
		LCP Terminate Request Tx
			 key:session.<session ID>.term_req_tx                                    value:LCP Terminate Request Tx
		Tunnel State
			 key:session.<session ID>.tunnel_state                                   value:Tunnel State
		Port Name
			 key:session.server.<session ID>.port_name                               value:Port Name
		Lease Name
			 key:session.server.<session ID>.dhcpv6pd_lease_name                     value:Lease Name
		Offer Count
			 key:session.server.<session ID>.dhcpv6pd_offer_count                    value:Offer Count
		Bind Count
			 key:session.server.<session ID>.dhcpv6pd_bind_count                     value:Bind Count
		Bind Rapid Commit Count
			 key:session.server.<session ID>.dhcpv6pd_bind_rapid_commit_count        value:Bind Rapid Commit Count
		Renew Count
			 key:session.server.<session ID>.dhcpv6pd_renew_count                    value:Renew Count
		Release Count
			 key:session.server.<session ID>.dhcpv6pd_release_count                  value:Release Count
		Information-Requests Received
			 key:session.server.<session ID>.dhcpv6pd_information_request_received   value:Information-Requests Received
		Replies Sent
			 key:session.server.<session ID>.dhcpv6pd_replies_sent                   value:Replies Sent
		Lease State
			 key:session.server.<session ID>.dhcpv6pd_lease_state                    value:Lease State
		Lease Address
			 key:session.server.<session ID>.dhcpv6pd_lease_address                  value:Lease Address
		Valid Time
			 key:session.server.<session ID>.dhcpv6pd_valid_time                     value:Valid Time
		Prefered Time
			 key:session.server.<session ID>.dhcpv6pd_prefered_time                  value:Prefered Time
		Renew Time
			 key:session.server.<session ID>.dhcpv6pd_renew_time                     value:Renew Time
		Rebind Time
			 key:session.server.<session ID>.dhcpv6pd_rebind_time                    value:Rebind Time
		Client ID
			 key:session.server.<session ID>.dhcpv6pd_client_id                      value:Client ID
		Remote ID
			 key:session.server.<session ID>.dhcpv6pd_remote_id                      value:Remote ID
		Port Name
			 key:session.client.<session ID>.port_name                               value:Port Name
		Session Name
			 key:session.client.<session ID>.dhcpv6pd_session_name                   value:Session Name
		Solicits Sent
			 key:session.client.<session ID>.dhcpv6pd_solicits_sent                  value:Solicits Sent
		Advertisements Received
			 key:session.client.<session ID>.dhcpv6pd_advertisements_received        value:Advertisements Received
		Advertisements Ignored
			 key:session.client.<session ID>.dhcpv6pd_advertisements_ignored         value:Advertisements Ignored
		Requests Sent
			 key:session.client.<session ID>.dhcpv6pd_requests_sent                  value:Requests Sent
		Replies Received
			 key:session.client.<session ID>.dhcpv6pd_replies_received               value:Replies Received
		Renews Sent
			 key:session.client.<session ID>.dhcpv6pd_renews_sent                    value:Renews Sent
		Rebinds Sent
			 key:session.client.<session ID>.dhcpv6pd_rebinds_sent                   value:Rebinds Sent
		Releases Sent
			 key:session.client.<session ID>.dhcpv6pd_releases_sent                  value:Releases Sent
		IP Prefix
			 key:session.client.<session ID>.dhcpv6pd_ip_prefix                      value:IP Prefix
		Gateway Address
			 key:session.client.<session ID>.dhcpv6pd_gateway_address                value:Gateway Address
		DNS Server List
			 key:session.client.<session ID>.dhcpv6pd_dns_server_list                value:DNS Server List
		Prefix Lease Time
			 key:session.client.<session ID>.dhcpv6pd_prefix_lease_time              value:Prefix Lease Time
		Information Requests Sent
			 key:session.client.<session ID>.dhcpv6pd_onformation_requests_sent      value:Information Requests Sent
		DNS Search List
			 key:session.client.<session ID>.dhcpv6pd_dns_search_list                value:DNS Search List
		Solicits w/ Rapid Commit Sent
			 key:session.client.<session ID>.dhcpv6pd_solicits_rapid_commit_sent     value:Solicits w/ Rapid Commit Sent
		Replies w/ Rapid Commit Received
			 key:session.client.<session ID>.dhcpv6pd_replies_rapid_commit_received  value:Replies w/ Rapid Commit Received
		Lease w/ Rapid Commit
			 key:session.client.<session ID>.dhcpv6pd_lease_rapid_commit             value:Lease w/ Rapid Commit
		Port Name
			 key:session.hosts.<session ID>.port_name                                value:Port Name
		Interface Identifier
			 key:session.hosts.<session ID>.dhcpv6pd_interface_identifier            value:Interface Identifier
		Range Identifier
			 key:session.hosts.<session ID>.dhcpv6pd_range_identifier                value:Range Identifier
		IPv6 Address
			 key:session.hosts.<session ID>.dhcpv6pd_ipv6_address                    value:IPv6 Address
		Prefix Length
			 key:session.hosts.<session ID>.dhcpv6pd_prefix_length                   value:Prefix Length
		Status
			 key:session.hosts.<session ID>.dhcpv6pd_status                          value:Status
		Not supported
			 key:tunnel.<tunnel ID>.cdn_rx                                           value:Not supported                                   
		Not supported
			 key:tunnel.<tunnel ID>.cdn_tx                                           value:Not supported                                   
		Number of duplicate pkt received. Not supported
			 key:tunnel.<tunnel ID>.duplicate_rx                                     value:Number of duplicate pkt received. Not supported 
		Not supported
			 key:tunnel.<tunnel ID>.hello_rx                                         value:Not supported                                   
		Not supported
			 key:tunnel.<tunnel ID>.hello_tx                                         value:Not supported                                   
		Not supported
			 key:tunnel.<tunnel ID>.iccn_rx                                          value:Not supported                                   
		Not supported
			 key:tunnel.<tunnel ID>.iccn_tx                                          value:Not supported                                   
		Not supported
			 key:tunnel.<tunnel ID>.icrp_rx                                          value:Not supported                                   
		Not supported
			 key:tunnel.<tunnel ID>.icrp_tx                                          value:Not supported                                   
		Not supported
			 key:tunnel.<tunnel ID>.icrq_rx                                          value:Not supported                                   
		Not supported
			 key:tunnel.<tunnel ID>.icrq_tx                                          value:Not supported                                   
		Number of in order pkt received. Not supported
			 key:tunnel.<tunnel ID>.in_order_rx                                      value:Number of in order pkt received. Not supported  
		Number of pkt rx out of seq. Not supported
			 key:tunnel.<tunnel ID>.out_of_order_rx                                  value:Number of pkt rx out of seq. Not supported      
		Number of pkt rx outside window. Not supported
			 key:tunnel.<tunnel ID>.out_of_win_rx                                    value:Number of pkt rx outside window. Not supported  
		Number of retransmitted messages. Not supported
			 key:tunnel.<tunnel ID>.retransmits                                      value:Number of retransmitted messages. Not supported 
		Not supported
			 key:tunnel.<tunnel ID>.scccn_rx                                         value:Not supported                                   
		Not supported
			 key:tunnel.<tunnel ID>.scccn_tx                                         value:Not supported                                   
		Not supported
			 key:tunnel.<tunnel ID>.sccrp_rx                                         value:Not supported                                   
		Not supported
			 key:tunnel.<tunnel ID>.sccrp_tx                                         value:Not supported                                   
		Set-Link-Info. Not supported
			 key:tunnel.<tunnel ID>.sli_rx                                           value:Set-Link-Info. Not supported                    
		Set-Link-Info. Not supported
			 key:tunnel.<tunnel ID>.sli_tx                                           value:Set-Link-Info. Not supported                    
		Not supported
			 key:tunnel.<tunnel ID>.stopccn_rx                                       value:Not supported                                   
		Not supported
			 key:tunnel.<tunnel ID>.stopccn_tx                                       value:Not supported                                   
		Number of tx pkt acked by peer. Not supported
			 key:tunnel.<tunnel ID>.tx_pkt_acked                                     value:Number of tx pkt acked by peer. Not supported   
		WAN-Error-Notify. Not supported
			 key:tunnel.<tunnel ID>.wen_rx                                           value:WAN-Error-Notify. Not supported                 
		WAN-Error-Notify. Not supported
			 key:tunnel.<tunnel ID>.wen_tx                                           value:WAN-Error-Notify. Not supported                 
		Not supported
			 key:tunnel.<tunnel ID>.zlb_rx                                           value:Not supported                                   
		Not supported
			 key:tunnel.<tunnel ID>.zlb_tx                                           value:Not supported                                   
		
		Examples:
		See files in the Samples/IxNetwork/L2TP subdirectory.
		
		Sample Input:
		.
		
		Sample Output:
		.
		
		Notes:
		Coded versus functional specification.
		1) Session ID will be local call ID, and tunnel ID will be the local tunnel ID.
		2) Per session and per tunnel stats retrieval can take long time.
		3) Following stats have not been implemented yet:aggregate.disconnectingaggregate.connect_attemptsaggregate.disconnect_successaggregate.sessions_downaggregate.disconnect_failed
		
		See Also:
		
		"""
		return self._run_keyword("l2tp_stats", kwargs)

	def l3vpn_generate_stream(self, **kwargs):
		""" This command configures traffic streams on the specified CE and PE ports  based on L3VPN setups.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: l3vpn_generate_stream
			 	-pe_port_handle                ANY
			 	-ce_port_handle                ANY
			 	-pe_label_protocol             ANY
			 	-ce_routing_protocol           ANY
			 	[-stream_generation            ANY]
			 	[-pe_router_handle             ANY]
			 	[-ce_router_handle             ANY]
			 	[-reset                        ANY]
			 	[-length_mode                  ANY]
			 	[-l3_length                    ANY]
			 	[-l3_length_min                ANY]
			 	[-l3_length_max                ANY]
			 	[-l3_length_step               ANY]
			 	[-l3_imix1_size                ANY]
			 	[-l3_imix1_ratio               ANY]
			 	[-l3_imix2_size                ANY]
			 	[-l3_imix2_ratio               ANY]
			 	[-l3_imix3_size                ANY]
			 	[-l3_imix3_ratio               ANY]
			 	[-l3_imix4_size                ANY]
			 	[-l3_imix4_ratio               ANY]
			 	[-l3_gaus1_avg                 ANY]
			 	[-l3_gaus1_halfbw              ANY]
			 	[-l3_gaus1_weight              ANY]
			 	[-l3_gaus2_avg                 ANY]
			 	[-l3_gaus2_halfbw              ANY]
			 	[-l3_gaus2_weight              ANY]
			 	[-l3_gaus3_avg                 ANY]
			 	[-l3_gaus3_halfbw              ANY]
			 	[-l3_gaus3_weight              ANY]
			 	[-l3_gaus4_avg                 ANY]
			 	[-l3_gaus4_halfbw              ANY]
			 	[-l3_gaus4_weight              ANY]
			 	[-rate_pps                     ANY]
			 	[-rate_bps                     ANY]
			 	[-rate_percent                 ANY]
			 	[-transmit_mode                ANY]
			 	[-pkts_per_burst               ANY]
			 	[-data_pattern                 ANY]
			 	[-data_pattern_mode            ANY]
			 	[-enable_data_integrity        ANY]
			 	[-integrity_signature          ANY]
			 	[-integrity_signature_offset   ANY]
			 	[-frame_sequencing             ANY]
			 	[-frame_sequencing_offset      ANY]
			 	[-frame_size                   ANY]
			 	[-frame_size_max               ANY]
			 	[-frame_size_min               ANY]
			 	[-frame_size_step              ANY]
			 	[-ip_cost                      ANY]
			 	[-ip_delay                     ANY]
			 	[-ip_precedence                ANY]
			 	[-ip_reliability               ANY]
			 	[-ip_reserved                  ANY]
			 	[-ip_throughput                ANY]
			 	[-enable_time_stamp            ANY]
			 	[-number_of_packets_per_stream ANY]
			 	[-enable_pgid                  ANY]
			 	[-pgid_value                   ANY]
			 	[-signature                    ANY]
			 	[-signature_offset             ANY]
			 	[-number_of_packets_tx         ANY]
		
		Arguments:
			 	-pe_port_handle
			 		The PE port for which to configure traffic and to which the traffic on CE port is configured.
			 	-ce_port_handle
			 		The CE port for which to configure traffic and to which the traffic on PE port is configured.
			 	-pe_label_protocol
			 		Specifies which label protocol is used on CE port.Valid options are:ldprsvp
			 	-ce_routing_protocol
			 		Specifies which routing protocol is used on CE port.Valid options are:bgpisisospfrip
			 	-stream_generation
			 		Specifies on which direction traffic is configured: on PE port to CE port, or on CE port to PE port, or in both directions.
			 	-pe_router_handle
			 		List of router handles for which traffic will be configured on CE port. If this option is present traffic will be configured only for route ranges advertised by the specified router handles. Otherwise traffic is configured for route ranges advertised by all routers on the PE port.
			 	-ce_router_handle
			 		List of router handles for which traffic will be configured on PE port. If this option is present traffic will be configured only for route ranges advertised by the specified router handles. Otherwise traffic is configured for route ranges advertised by all routers on the CE port.
			 	-reset
			 		When the option is enabled all streams are deleted on the seding ports(s) before creating new ones.
			 	-length_mode
			 		fixedincrementrandomautoimix - Mix of packet sizes are specified using options l3_imix1_size etcgaussian, quad - Packet sizes are specified as gaussian/quad curves using options l3_gaus1_avg, l3_gaus1_halfbw, l3_gaus1_weight etc.
			 	-l3_length
			 		Packet size in bytes.Use this option in conjunction with option inclusive.
			 	-l3_length_min
			 		Minimum packet size for the specified stream in bytes.Use this option in conjunction with option "length_mode" set to increment.
			 	-l3_length_max
			 		Maximum packet size for the specified stream in bytes.Use this option in conjunction with option "length_mode" set to increment.
			 	-l3_length_step
			 		Step size by which the packet size will be incremented.Use this option in conjunction with option "length_mode" set to increment.
			 	-l3_imix1_size
			 		First Packet size in bytes. Used if length_mode set to imix.
			 	-l3_imix1_ratio
			 		Ratio of first packet size. Used if length_mode set to imix.
			 	-l3_imix2_size
			 		Second Packet size in bytes. Used if length_mode set to imix.
			 	-l3_imix2_ratio
			 		Ratio of second packet size. Used if length_mode set to imix.
			 	-l3_imix3_size
			 		Third Packet size in bytes. Used if length_mode set to imix.
			 	-l3_imix3_ratio
			 		Ratio of third packet size. Used if length_mode set to imix.
			 	-l3_imix4_size
			 		Fourth Packet size in bytes. Used if length_mode set to imix.
			 	-l3_imix4_ratio
			 		Ratio of fourth packet size. Used if length_mode set to imix.
			 	-l3_gaus1_avg
			 		The center of the first curve. Used if length_mode is set to gaussian or quad.
			 	-l3_gaus1_halfbw
			 		The width at half of the first curve. Used if length_mode is set to gaussian or quad.
			 	-l3_gaus1_weight
			 		The weigth of the first curve. Used if length_mode is set to gaussian or quad.
			 	-l3_gaus2_avg
			 		The center of the second curve. Used if length_mode is set to gaussian or quad.
			 	-l3_gaus2_halfbw
			 		The width at half of the second curve. Used if length_mode is set to gaussian or quad.
			 	-l3_gaus2_weight
			 		The weigth of the second curve. Used if length_mode is set to gaussian or quad.
			 	-l3_gaus3_avg
			 		The center of the third curve. Used if length_mode is set to gaussian or quad.
			 	-l3_gaus3_halfbw
			 		The width at half of the third curve. Used if length_mode is set to gaussian or quad.
			 	-l3_gaus3_weight
			 		The weigth of the third curve. Used if length_mode is set to gaussian or quad.
			 	-l3_gaus4_avg
			 		The center of the fourth curve. Used if length_mode is set to gaussian or quad.
			 	-l3_gaus4_halfbw
			 		The width at half of the fourth curve. Used if length_mode is set to gaussian or quad.
			 	-l3_gaus4_weight
			 		The weigth of the fourth curve. Used if length_mode is set to gaussian or quad.
			 	-rate_pps
			 		Traffic rate to send in pps.
			 	-rate_bps
			 		Traffic rate to send in bps.
			 	-rate_percent
			 		Traffic rate in percent of line rate for the specified stream.Valid choices are between 0.00 and 100.00, inclusive.
			 	-transmit_mode
			 		Type of transmit mode to use.Note that all transmit modes need to have one value set in either rate_pps, rate_bps, or rate_percent. Valid options are:continuoussingle_burst
			 	-pkts_per_burst
			 		Number of packets to include in one burst.
			 	-data_pattern
			 		Payload value in bytes. For example, you can specify a custom payload pattern like the following using option "data_pattern":00 44 00 44
			 	-data_pattern_mode
			 		incr_byte - Data patterm increments each byte in the packet payload.decr_byte - Data patterm decrements each byte in the packet payload.fixed- Data patterm is idle for each byte in the packet payload.random- Data patterm is random for the packet payload.repeating - Data patterm repeats for the packet payload.
			 	-enable_data_integrity
			 		0 - Disabled.1 - Enabled.
			 	-integrity_signature
			 		Enables or disables the data integrity signature in the stream
			 	-integrity_signature_offset
			 		The offset value of the data integrity signature
			 	-frame_sequencing
			 		Enables or disables frame sequencing in the stream
			 	-frame_sequencing_offset
			 		The offset value of the frame sequencing value
			 	-frame_size
			 		Actual total frame size coming out of the interface on the wire in
			 	-frame_size_max
			 		Actual maximum total frame size coming out of the interface on the wire in bytes when option "length_mode" is set to random. Valid choices are between 20 and 13312.
			 	-frame_size_min
			 		Actual minimal total frame size coming out of the interface on the wire in bytes when option "length_mode" is set to random. Valid choices are between 20 and 13312.
			 	-frame_size_step
			 		Actual increment by which the actual total frame size in bytes coming out of the interface on the wire will be incremented. Valid choices are between 20 and 13292.
			 	-ip_cost
			 		Part of the Type of Service byte of the IP header datagram (bit 6). 0 - (default) Normal cost.1 - Low cost.
			 	-ip_delay
			 		Part of the Type of Service byte of the IP header datagram (bit 3). 0 - (default) Normal delay.1 - Low delay.
			 	-ip_precedence
			 		Part of the Type of Service byte of the IP header datagram that 7, inclusive.
			 	-ip_reliability
			 		Part of the Type of Service byte of the IP header datagram (bit 5). 0 - (default) Normal reliability.1 - High reliability.
			 	-ip_reserved
			 		Part of the Type of Service byte of the IP header datagram (bit 7). 0 - (default)1
			 	-ip_throughput
			 		Part of the Type of Service byte of the IP header datagram (bit 4). 0 - (default) Normal throughput.1 - High throughput.
			 	-enable_time_stamp
			 		0 - Disabled.1 - Enabled. (default)
			 	-number_of_packets_per_stream
			 		Number of maximum frames in the stream.
			 	-enable_pgid
			 		Tells whether to enable packet group ids in the streams.Valid choices are:
			    		0-- Disabled
			    		1- Enabled
			 	-pgid_value
			 		When packet group ids are enabled, this is the id value to be set.
			 	-signature
			 		Enables or disables the signature in a stream
			 	-signature_offset
			 		The offset value of the signature in a stream
			 	-number_of_packets_tx
			 		The number of frames for the stream to transmit
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log     value:On status of failure, gives detailed information.
		
		Examples:
		See files starting with L3VPN_ in the Samples subdirectory. See the L3VPN example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1. When ISIS is configured on CE port, streams will be generated on PE port only to routes of type stub and external.
		2. When OSPF is configured on CE port, streams will be generated on PE port only to routes of type summary and external.
		
		See Also:
		
		"""
		return self._run_keyword("l3vpn_generate_stream", kwargs)

	def L47_client_mapping(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: L47_client_mapping
			 	[-agent_handle                 ANY]
			 	[-client_network_handle        ANY]
			 	[-client_traffic_handle        ANY]
			 	[-handle                       ANY]
			 	[-iterations                   ANY]
			 	-mode                          ANY
			 	[-objective_type               ANY]
			 	[-objective_type_for_activity  ANY]
			 	[-objective_value              ANY]
			 	[-objective_value_for_activity ANY]
			 	[-offline_time                 ANY]
			 	[-port_map_for_activity        ANY]
			 	[-port_map_policy              ANY]
			 	[-ramp_down_time               ANY]
			 	[-ramp_up_interval             ANY]
			 	[-ramp_up_type                 ANY]
			 	[-ramp_up_value                ANY]
			 	[-standby_time                 ANY]
			 	[-sustain_time                 ANY]
		
		Arguments:
			 	-agent_handle
			 	-client_network_handle
			    	-client_traffic_handle
			        	-handle
			            	-iterations
			                	-mode
			                    	-objective_type
			                        	-objective_type_for_activity
			                            	-objective_value
			                                	-objective_value_for_activity
			                                    	-offline_time
			                                        	-port_map_for_activity
			                                            	-port_map_policy
			                                                	-ramp_down_time
			                                                    	-ramp_up_interval
			                                                        	-ramp_up_type
			                                                            	-ramp_up_value
			                                                                	-standby_time
			                                                                    	-sustain_time
		                                                                   
		                                                                   Return Values:
		                                                                       $::SUCCESS | $::FAILURE
			                                                                        key:status   value:$::SUCCESS | $::FAILURE    
		                                                                       < client traffic mapping configuration handle >
			                                                                        key:handles  value:< client traffic mapping configuration handle >
		                                                                       returned debug info for when status is $::FAILURE
			                                                                        key:log      value:returned debug info for when status is $::FAILURE
		                                                                   
		                                                                   Examples:
		                                                                   
		                                                                   Sample Input:
		                                                                   
		                                                                   Sample Output:
		                                                                   
		                                                                   Notes:
		                                                                   
		                                                                   See Also:
		                                                                   
		"""
		return self._run_keyword("L47_client_mapping", kwargs)

	def L47_dut(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: L47_dut
			 	[-enable_direct_server_return ANY]
			 	[-handle                      ANY]
			 	[-ip_address                  ANY]
			 	-mode                         ANY
			 	[-server_network              ANY]
		
		Arguments:
			 	-enable_direct_server_return
			 	-handle
			    	-ip_address
			        	-mode
			            	-server_network
		           
		           Return Values:
		               $::SUCCESS | $::FAILURE
			                key:status  value:$::SUCCESS | $::FAILURE    
		               < DUT handle >
			                key:handle  value:< DUT handle >
		               returned debug info for when status is $::FAILURE
			                key:log     value:returned debug info for when status is $::FAILURE
		           
		           Examples:
		           
		           Sample Input:
		           
		           Sample Output:
		           
		           Notes:
		           
		           See Also:
		           
		"""
		return self._run_keyword("L47_dut", kwargs)

	def L47_ftp_client(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: L47_ftp_client
			 	[-a_arguments     ANY]
			 	[-a_command       ANY]
			 	[-a_destination   ANY]
			 	[-a_password      ANY]
			 	[-a_user_name     ANY]
			 	[-access_mode     ANY]
			 	[-esm             ANY]
			 	[-esm_enable      ANY]
			 	[-handle          ANY]
			 	[-ip_preference   ANY]
			 	[-loop_enable     ANY]
			 	-mode             ANY
			 	[-password        ANY]
			 	[-property        ANY]
			 	[-tos             ANY]
			 	[-tos_enable      ANY]
			 	[-user_name       ANY]
			 	[-rf_name         ANY]
			 	[-rf_payload_file ANY]
		
		Arguments:
			 	-a_arguments
			 	-a_command
			    	-a_destination
			        	-a_password
			            	-a_user_name
			                	-access_mode
			                    	-esm
			                        	-esm_enable
			                            	-handle
			                                	-ip_preference
			                                    	-loop_enable
			                                        	-mode
			                                            	-password
			                                                	-property
			                                                    	-tos
			                                                        	-tos_enable
			                                                            	-user_name
			                                                                	-rf_name
			                                                                    	-rf_payload_file
		                                                                   
		                                                                   Return Values:
		                                                                   
		                                                                   Examples:
		                                                                   
		                                                                   Sample Input:
		                                                                   
		                                                                   Sample Output:
		                                                                   
		                                                                   Notes:
		                                                                   
		                                                                   See Also:
		                                                                   
		"""
		return self._run_keyword("L47_ftp_client", kwargs)

	def L47_ftp_server(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: L47_ftp_server
			 	[-esm        ANY]
			 	[-esm_enable ANY]
			 	[-ftp_port   ANY]
			 	[-handle     ANY]
			 	-mode        ANY
			 	[-property   ANY]
			 	[-tos        ANY]
			 	[-tos_enable ANY]
			 	[-rf_name    ANY]
		
		Arguments:
			 	-esm
			 	-esm_enable
			    	-ftp_port
			        	-handle
			            	-mode
			                	-property
			                    	-tos
			                        	-tos_enable
			                            	-rf_name
		                           
		                           Return Values:
		                               when -property real_file; -mode add
			                                key:real_file_handle  value:when -property real_file; -mode add
		                           
		                           Examples:
		                           
		                           Sample Input:
		                           
		                           Sample Output:
		                           
		                           Notes:
		                           
		                           See Also:
		                           
		"""
		return self._run_keyword("L47_ftp_server", kwargs)

	def L47_http_client(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: L47_http_client
			 	[-a_abort                   ANY]
			 	[-a_arguments               ANY]
			 	[-a_command                 ANY]
			 	[-a_destination             ANY]
			 	[-a_page_handle             ANY]
			 	[-a_profile_handle          ANY]
			 	[-browser_emulation         ANY]
			 	[-certificate               ANY]
			 	[-certificate_file          ANY]
			 	[-client_ciphers            ANY]
			 	[-cookie_jar_size           ANY]
			 	[-cookie_reject_probability ANY]
			 	[-cookie_support_enable     ANY]
			 	[-esm                       ANY]
			 	[-esm_enable                ANY]
			 	[-follow_http_redirects     ANY]
			 	[-handle                    ANY]
			 	[-http_proxy                ANY]
			 	[-http_proxy_enable         ANY]
			 	[-http_version              ANY]
			 	[-https_proxy               ANY]
			 	[-https_proxy_enable        ANY]
			 	[-ip_preference             ANY]
			 	[-keep_alive                ANY]
			 	[-large_header_enable       ANY]
			 	[-loop_enable               ANY]
			 	[-max_header_len            ANY]
			 	[-max_persistent_requests   ANY]
			 	[-max_pipeline              ANY]
			 	[-max_sessions              ANY]
			 	-mode                       ANY
			 	[-pr_basic_auth             ANY]
			 	[-pr_case_insensitive_match ANY]
			 	[-pr_password               ANY]
			 	[-pr_substring              ANY]
			 	[-pr_substring_match_enable ANY]
			 	[-pr_user_id                ANY]
			 	[-private_key               ANY]
			 	[-private_key_file          ANY]
			 	[-private_key_password      ANY]
			 	[-property                  ANY]
			 	[-request_timeout           ANY]
			 	[-rh_data                   ANY]
			 	[-sequential_session_reuse  ANY]
			 	[-ssl_enable                ANY]
			 	[-ssl_version               ANY]
			 	[-tcp_close_option          ANY]
			 	[-tos                       ANY]
		
		Arguments:
			 	-a_abort
			 	-a_arguments
			    	-a_command
			        	-a_destination
			            	-a_page_handle
			                	-a_profile_handle
			                    	-browser_emulation
			                        	-certificate
			                            	-certificate_file
			                                	-client_ciphers
			                                    	-cookie_jar_size
			                                        	-cookie_reject_probability
			                                            	-cookie_support_enable
			                                                	-esm
			                                                    	-esm_enable
			                                                        	-follow_http_redirects
			                                                            	-handle
			                                                                	-http_proxy
			                                                                    	-http_proxy_enable
			                                                                        	-http_version
			                                                                            	-https_proxy
			                                                                                	-https_proxy_enable
			                                                                                    	-ip_preference
			                                                                                        	-keep_alive
			                                                                                            	-large_header_enable
			                                                                                                	-loop_enable
			                                                                                                    	-max_header_len
			                                                                                                        	-max_persistent_requests
			                                                                                                            	-max_pipeline
			                                                                                                                	-max_sessions
			                                                                                                                    	-mode
			                                                                                                                        	-pr_basic_auth
			                                                                                                                            	-pr_case_insensitive_match
			                                                                                                                                	-pr_password
			                                                                                                                                    	-pr_substring
			                                                                                                                                        	-pr_substring_match_enable
			                                                                                                                                            	-pr_user_id
			                                                                                                                                                	-private_key
			                                                                                                                                                    	-private_key_file
			                                                                                                                                                        	-private_key_password
			                                                                                                                                                            	-property
			                                                                                                                                                                	-request_timeout
			                                                                                                                                                                    	-rh_data
			                                                                                                                                                                        	-sequential_session_reuse
			                                                                                                                                                                            	-ssl_enable
			                                                                                                                                                                                	-ssl_version
			                                                                                                                                                                                    	-tcp_close_option
			                                                                                                                                                                                        	-tos
		                                                                                                                                                                                       
		                                                                                                                                                                                       Return Values:
		                                                                                                                                                                                       
		                                                                                                                                                                                       Examples:
		                                                                                                                                                                                       
		                                                                                                                                                                                       Sample Input:
		                                                                                                                                                                                       
		                                                                                                                                                                                       Sample Output:
		                                                                                                                                                                                       
		                                                                                                                                                                                       Notes:
		                                                                                                                                                                                       
		                                                                                                                                                                                       See Also:
		                                                                                                                                                                                       
		"""
		return self._run_keyword("L47_http_client", kwargs)

	def L47_http_server(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: L47_http_server
			 	[-DH_support_enable                       ANY]
			 	[-accept_ssl_connections                  ANY]
			 	[-server_ciphers                          ANY]
			 	[-c_mode                                  ANY]
			 	[-c_type                                  ANY]
			 	[-cc_domain                               ANY]
			 	[-cc_max_age                              ANY]
			 	[-cc_name                                 ANY]
			 	[-cc_path                                 ANY]
			 	[-cc_value                                ANY]
			 	[-certificate                             ANY]
			 	[-esm                                     ANY]
			 	[-esm_enable                              ANY]
			 	[-handle                                  ANY]
			 	[-http_port                               ANY]
			 	[-https_port                              ANY]
			 	-mode                                     ANY
			 	[-private_key                             ANY]
			 	[-private_key_file                        ANY]
			 	[-private_key_password                    ANY]
			 	[-property                                ANY]
			 	[-request_timeout                         ANY]
			 	[-rh_code                                 ANY]
			 	[-rh_expiration_after_last_modified_value ANY]
			 	[-rh_expiration_after_request_value       ANY]
			 	[-rh_expiration_date_time_value           ANY]
			 	[-rh_expiration_mode                      ANY]
			 	[-rh_key                                  ANY]
			 	[-rh_last_modified_date_time_value        ANY]
			 	[-rh_last_modified_increment_by           ANY]
			 	[-rh_last_modified_increment_enable       ANY]
			 	[-rh_last_modified_increment_for          ANY]
			 	[-rh_last_modified_mode                   ANY]
			 	[-rh_mime_type                            ANY]
			 	[-rh_name                                 ANY]
			 	[-rh_value                                ANY]
			 	[-tcp_close_option                        ANY]
			 	[-tos                                     ANY]
			 	[-tos_enable                              ANY]
			 	[-wp_cookie                               ANY]
			 	[-wp_page                                 ANY]
			 	[-wp_payload_file                         ANY]
			 	[-wp_payload_size                         ANY]
			 	[-wp_payload_type                         ANY]
		
		Arguments:
			 	-DH_support_enable
			 	-accept_ssl_connections
			    	-server_ciphers
			        	-c_mode
			            	-c_type
			                	-cc_domain
			                    	-cc_max_age
			                        	-cc_name
			                            	-cc_path
			                                	-cc_value
			                                    	-certificate
			                                        	-esm
			                                            	-esm_enable
			                                                	-handle
			                                                    	-http_port
			                                                        	-https_port
			                                                            	-mode
			                                                                	-private_key
			                                                                    	-private_key_file
			                                                                        	-private_key_password
			                                                                            	-property
			                                                                                	-request_timeout
			                                                                                    	-rh_code
			                                                                                        	-rh_expiration_after_last_modified_value
			                                                                                            	-rh_expiration_after_request_value
			                                                                                                	-rh_expiration_date_time_value
			                                                                                                    	-rh_expiration_mode
			                                                                                                        	-rh_key
			                                                                                                            	-rh_last_modified_date_time_value
			                                                                                                                	-rh_last_modified_increment_by
			                                                                                                                    	-rh_last_modified_increment_enable
			                                                                                                                        	-rh_last_modified_increment_for
			                                                                                                                            	-rh_last_modified_mode
			                                                                                                                                	-rh_mime_type
			                                                                                                                                    	-rh_name
			                                                                                                                                        	-rh_value
			                                                                                                                                            	-tcp_close_option
			                                                                                                                                                	-tos
			                                                                                                                                                    	-tos_enable
			                                                                                                                                                        	-wp_cookie
			                                                                                                                                                            	-wp_page
			                                                                                                                                                                	-wp_payload_file
			                                                                                                                                                                    	-wp_payload_size
			                                                                                                                                                                        	-wp_payload_type
		                                                                                                                                                                       
		                                                                                                                                                                       Return Values:
		                                                                                                                                                                           -property server | agent. A list of default cookie content handles are returned for each default <cookie_handle> from the key cookie_handle.
			                                                                                                                                                                            key:<cookie_handle>.cookie_content_handle  value:-property server | agent. A list of default cookie content handles are returned for each default <cookie_handle> from the key cookie_handle.
		                                                                                                                                                                       
		                                                                                                                                                                       Examples:
		                                                                                                                                                                       
		                                                                                                                                                                       Sample Input:
		                                                                                                                                                                       
		                                                                                                                                                                       Sample Output:
		                                                                                                                                                                       
		                                                                                                                                                                       Notes:
		                                                                                                                                                                       
		                                                                                                                                                                       See Also:
		                                                                                                                                                                       
		"""
		return self._run_keyword("L47_http_server", kwargs)

	def L47_network(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: L47_network
			 	[-dns_cache_timeout                  ANY]
			 	[-dns_enable                         ANY]
			 	[-dns_server                         ANY]
			 	[-dns_suffix                         ANY]
			 	[-emulated_router_gateway            ANY]
			 	[-emulated_router_subnet             ANY]
			 	[-grat_arp_enable                    ANY]
			 	[-handle                             ANY]
			 	[-mac_mapping_mode                   ANY]
			 	-mode                                ANY
			 	[-ip_type                            ANY]
			 	[-np_ac_name                         ANY]
			 	[-np_ac_selection                    ANY]
			 	[-np_ah_esp_options                  ANY]
			 	[-np_auth_retries                    ANY]
			 	[-np_auth_timeout                    ANY]
			 	[-np_auth_type                       ANY]
			 	[-np_chap_name                       ANY]
			 	[-np_chap_secret                     ANY]
			 	[-np_circuit_id                      ANY]
			 	[-np_circuit_id_enable               ANY]
			 	[-np_circuit_id_group_size           ANY]
			 	[-np_dh_group                        ANY]
			 	[-np_echo_request_interval           ANY]
			 	[-np_emulated_hosts                  ANY]
			 	[-np_emulated_subnet                 ANY]
			 	[-np_emulated_subnet_mask            ANY]
			 	[-np_enable_cid_byte_stream          ANY]
			 	[-np_enable_echo_reply               ANY]
			 	[-np_enable_echo_request             ANY]
			 	[-np_enable_pfs                      ANY]
			 	[-np_enable_redial                   ANY]
			 	[-np_enable_remote_id                ANY]
			 	[-np_enable_rid_byte_stream          ANY]
			 	[-np_enable_stats                    ANY]
			 	[-np_enable_throttling               ANY]
			 	[-np_enable_vendor_class_identifier  ANY]
			 	[-np_first_ip                        ANY]
			 	[-np_first_mac                       ANY]
			 	[-np_first_relay_ip                  ANY]
			 	[-np_first_server_reply              ANY]
			 	[-np_gateway                         ANY]
			 	[-np_gateway_incr_step               ANY]
			 	[-np_ike_mode                        ANY]
			 	[-np_increment_by                    ANY]
			 	[-np_inner_vlan_count                ANY]
			 	[-np_inner_vlan_enable               ANY]
			 	[-np_inner_vlan_id                   ANY]
			 	[-np_inner_vlan_incr_step            ANY]
			 	[-np_inner_vlan_priority             ANY]
			 	[-np_inner_vlan_unique_count         ANY]
			 	[-np_ip_count                        ANY]
			 	[-np_ip_incr_step                    ANY]
			 	[-np_lcp_retries                     ANY]
			 	[-np_lcp_timeout                     ANY]
			 	[-np_mac_incr_step                   ANY]
			 	[-np_max_client_per_second           ANY]
			 	[-np_max_outstanding_requests        ANY]
			 	[-np_max_outstanding_sessions        ANY]
			 	[-np_mss                             ANY]
			 	[-np_mss_enable                      ANY]
			 	[-np_mtu                             ANY]
			 	[-np_ncp_retries                     ANY]
			 	[-np_ncp_timeout                     ANY]
			 	[-np_network_mask                    ANY]
			 	[-np_num_relay_agents                ANY]
			 	[-np_num_retries                     ANY]
			 	[-np_packet_forward_mode             ANY]
			 	[-np_padi_retries                    ANY]
			 	[-np_padi_timeout                    ANY]
			 	[-np_padr_retries                    ANY]
			 	[-np_padr_timeout                    ANY]
			 	[-np_pap_password                    ANY]
			 	[-np_pap_user                        ANY]
			 	[-np_peer_public_ip                  ANY]
			 	[-np_pfs_group                       ANY]
			 	[-np_phase1_encryption_algorithm     ANY]
			 	[-np_phase1_hash_algorithm           ANY]
			 	[-np_phase1_lifetime                 ANY]
			 	[-np_phase2_encryption_algorithm     ANY]
			 	[-np_phase2_hash_algorithm           ANY]
			 	[-np_phase2_lifetime                 ANY]
			 	[-np_pre_shared_key                  ANY]
			 	[-np_protected_subnet                ANY]
			 	[-np_protected_subnet_mask           ANY]
			 	[-np_ra_server_ip                    ANY]
			 	[-np_range_type                      ANY]
			 	[-np_redial_max                      ANY]
			 	[-np_redial_timeout                  ANY]
			 	[-np_relay_vlan_count                ANY]
			 	[-np_relay_vlan_enable               ANY]
			 	[-np_relay_vlan_id                   ANY]
			 	[-np_relay_vlan_incr_step            ANY]
			 	[-np_remote_id                       ANY]
			 	[-np_remote_id_group_size            ANY]
			 	[-np_retry_delay                     ANY]
			 	[-np_retry_interval                  ANY]
			 	[-np_role                            ANY]
			 	[-np_server_ip                       ANY]
			 	[-np_server_response_timeout         ANY]
			 	[-np_service_name                    ANY]
			 	[-np_setup_rate                      ANY]
			 	[-np_timeout                         ANY]
			 	[-np_vendor_class_identifier         ANY]
			 	[-np_vlan_count                      ANY]
			 	[-np_vlan_enable                     ANY]
			 	[-np_vlan_id                         ANY]
			 	[-np_vlan_incr_step                  ANY]
			 	[-np_vlan_increment_mode             ANY]
			 	[-np_vlan_priority                   ANY]
			 	[-np_vlan_unique_count               ANY]
			 	[-port_handle                        ANY]
			 	-property                            ANY
			 	[-rp_first_ip                        ANY]
			 	[-rp_first_mac                       ANY]
			 	[-rp_network_mask                    ANY]
			 	[-rp_ip_count                        ANY]
			 	[-rp_vlan_enable                     ANY]
			 	[-rp_vlan_id                         ANY]
			 	[-source_port_from                   ANY]
			 	[-source_port_to                     ANY]
			 	[-target                             ANY]
			 	[-tcp_enable_congestion_notification ANY]
			 	[-tcp_enable_rx_bw_limit             ANY]
			 	[-tcp_enable_timestamp               ANY]
			 	[-tcp_enable_tx_bw_limit             ANY]
			 	[-tcp_fin_timeout                    ANY]
			 	[-tcp_keep_alive_interval            ANY]
			 	[-tcp_keep_alive_probes              ANY]
			 	[-tcp_keep_alive_time                ANY]
			 	[-tcp_receive_buffer_size            ANY]
			 	[-tcp_retransmit_retries             ANY]
			 	[-tcp_rx_bw_limit                    ANY]
			 	[-tcp_rx_bw_limit_unit               ANY]
			 	[-tcp_syn_ack_retries                ANY]
			 	[-tcp_syn_retries                    ANY]
			 	[-tcp_transmit_buffer_size           ANY]
			 	[-tcp_tx_bw_limit                    ANY]
		
		Arguments:
			 	-dns_cache_timeout
			 	-dns_enable
			    	-dns_server
			        	-dns_suffix
			            	-emulated_router_gateway
			                	-emulated_router_subnet
			                    	-grat_arp_enable
			                        	-handle
			                            	-mac_mapping_mode
			                                	-mode
			                                    	-ip_type
			                                        	-np_ac_name
			                                            	-np_ac_selection
			                                                	-np_ah_esp_options
			                                                    	-np_auth_retries
			                                                        	-np_auth_timeout
			                                                            	-np_auth_type
			                                                                	-np_chap_name
			                                                                    	-np_chap_secret
			                                                                        	-np_circuit_id
			                                                                            	-np_circuit_id_enable
			                                                                                	-np_circuit_id_group_size
			                                                                                    	-np_dh_group
			                                                                                        	-np_echo_request_interval
			                                                                                            	-np_emulated_hosts
			                                                                                                	-np_emulated_subnet
			                                                                                                    	-np_emulated_subnet_mask
			                                                                                                        	-np_enable_cid_byte_stream
			                                                                                                            	-np_enable_echo_reply
			                                                                                                                	-np_enable_echo_request
			                                                                                                                    	-np_enable_pfs
			                                                                                                                        	-np_enable_redial
			                                                                                                                            	-np_enable_remote_id
			                                                                                                                                	-np_enable_rid_byte_stream
			                                                                                                                                    	-np_enable_stats
			                                                                                                                                        	-np_enable_throttling
			                                                                                                                                            	-np_enable_vendor_class_identifier
			                                                                                                                                                	-np_first_ip
			                                                                                                                                                    	-np_first_mac
			                                                                                                                                                        	-np_first_relay_ip
			                                                                                                                                                            	-np_first_server_reply
			                                                                                                                                                                	-np_gateway
			                                                                                                                                                                    	-np_gateway_incr_step
			                                                                                                                                                                        	-np_ike_mode
			                                                                                                                                                                            	-np_increment_by
			                                                                                                                                                                                	-np_inner_vlan_count
			                                                                                                                                                                                    	-np_inner_vlan_enable
			                                                                                                                                                                                        	-np_inner_vlan_id
			                                                                                                                                                                                            	-np_inner_vlan_incr_step
			                                                                                                                                                                                                	-np_inner_vlan_priority
			                                                                                                                                                                                                    	-np_inner_vlan_unique_count
			                                                                                                                                                                                                        	-np_ip_count
			                                                                                                                                                                                                            	-np_ip_incr_step
			                                                                                                                                                                                                                	-np_lcp_retries
			                                                                                                                                                                                                                    	-np_lcp_timeout
			                                                                                                                                                                                                                        	-np_mac_incr_step
			                                                                                                                                                                                                                            	-np_max_client_per_second
			                                                                                                                                                                                                                                	-np_max_outstanding_requests
			                                                                                                                                                                                                                                    	-np_max_outstanding_sessions
			                                                                                                                                                                                                                                        	-np_mss
			                                                                                                                                                                                                                                            	-np_mss_enable
			                                                                                                                                                                                                                                                	-np_mtu
			                                                                                                                                                                                                                                                    	-np_ncp_retries
			                                                                                                                                                                                                                                                        	-np_ncp_timeout
			                                                                                                                                                                                                                                                            	-np_network_mask
			                                                                                                                                                                                                                                                                	-np_num_relay_agents
			                                                                                                                                                                                                                                                                    	-np_num_retries
			                                                                                                                                                                                                                                                                        	-np_packet_forward_mode
			                                                                                                                                                                                                                                                                            	-np_padi_retries
			                                                                                                                                                                                                                                                                                	-np_padi_timeout
			                                                                                                                                                                                                                                                                                    	-np_padr_retries
			                                                                                                                                                                                                                                                                                        	-np_padr_timeout
			                                                                                                                                                                                                                                                                                            	-np_pap_password
			                                                                                                                                                                                                                                                                                                	-np_pap_user
			                                                                                                                                                                                                                                                                                                    	-np_peer_public_ip
			                                                                                                                                                                                                                                                                                                        	-np_pfs_group
			                                                                                                                                                                                                                                                                                                            	-np_phase1_encryption_algorithm
			                                                                                                                                                                                                                                                                                                                	-np_phase1_hash_algorithm
			                                                                                                                                                                                                                                                                                                                    	-np_phase1_lifetime
			                                                                                                                                                                                                                                                                                                                        	-np_phase2_encryption_algorithm
			                                                                                                                                                                                                                                                                                                                            	-np_phase2_hash_algorithm
			                                                                                                                                                                                                                                                                                                                                	-np_phase2_lifetime
			                                                                                                                                                                                                                                                                                                                                    	-np_pre_shared_key
			                                                                                                                                                                                                                                                                                                                                        	-np_protected_subnet
			                                                                                                                                                                                                                                                                                                                                            	-np_protected_subnet_mask
			                                                                                                                                                                                                                                                                                                                                                	-np_ra_server_ip
			                                                                                                                                                                                                                                                                                                                                                    	-np_range_type
			                                                                                                                                                                                                                                                                                                                                                        	-np_redial_max
			                                                                                                                                                                                                                                                                                                                                                            	-np_redial_timeout
			                                                                                                                                                                                                                                                                                                                                                                	-np_relay_vlan_count
			                                                                                                                                                                                                                                                                                                                                                                    	-np_relay_vlan_enable
			                                                                                                                                                                                                                                                                                                                                                                        	-np_relay_vlan_id
			                                                                                                                                                                                                                                                                                                                                                                            	-np_relay_vlan_incr_step
			                                                                                                                                                                                                                                                                                                                                                                                	-np_remote_id
			                                                                                                                                                                                                                                                                                                                                                                                    	-np_remote_id_group_size
			                                                                                                                                                                                                                                                                                                                                                                                        	-np_retry_delay
			                                                                                                                                                                                                                                                                                                                                                                                            	-np_retry_interval
			                                                                                                                                                                                                                                                                                                                                                                                                	-np_role
			                                                                                                                                                                                                                                                                                                                                                                                                    	-np_server_ip
			                                                                                                                                                                                                                                                                                                                                                                                                        	-np_server_response_timeout
			                                                                                                                                                                                                                                                                                                                                                                                                            	-np_service_name
			                                                                                                                                                                                                                                                                                                                                                                                                                	-np_setup_rate
			                                                                                                                                                                                                                                                                                                                                                                                                                    	-np_timeout
			                                                                                                                                                                                                                                                                                                                                                                                                                        	-np_vendor_class_identifier
			                                                                                                                                                                                                                                                                                                                                                                                                                            	-np_vlan_count
			                                                                                                                                                                                                                                                                                                                                                                                                                                	-np_vlan_enable
			                                                                                                                                                                                                                                                                                                                                                                                                                                    	-np_vlan_id
			                                                                                                                                                                                                                                                                                                                                                                                                                                        	-np_vlan_incr_step
			                                                                                                                                                                                                                                                                                                                                                                                                                                            	-np_vlan_increment_mode
			                                                                                                                                                                                                                                                                                                                                                                                                                                                	-np_vlan_priority
			                                                                                                                                                                                                                                                                                                                                                                                                                                                    	-np_vlan_unique_count
			                                                                                                                                                                                                                                                                                                                                                                                                                                                        	-port_handle
			                                                                                                                                                                                                                                                                                                                                                                                                                                                            	-property
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                	-rp_first_ip
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                    	-rp_first_mac
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                        	-rp_network_mask
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                            	-rp_ip_count
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                	-rp_vlan_enable
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    	-rp_vlan_id
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        	-source_port_from
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            	-source_port_to
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                	-target
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    	-tcp_enable_congestion_notification
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        	-tcp_enable_rx_bw_limit
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            	-tcp_enable_timestamp
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                	-tcp_enable_tx_bw_limit
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    	-tcp_fin_timeout
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        	-tcp_keep_alive_interval
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            	-tcp_keep_alive_probes
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                	-tcp_keep_alive_time
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    	-tcp_receive_buffer_size
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        	-tcp_retransmit_retries
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            	-tcp_rx_bw_limit
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                	-tcp_rx_bw_limit_unit
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    	-tcp_syn_ack_retries
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        	-tcp_syn_retries
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            	-tcp_transmit_buffer_size
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                	-tcp_tx_bw_limit
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               Return Values:
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   $::SUCCESS | $::FAILURE
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    key:status               value:$::SUCCESS | $::FAILURE   
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   when -property network; -mode add;
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    key:network_handle       value:when -property network; -mode add;
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   when -property network_pool; -mode add;
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    key:network_pool_handle  value:when -property network_pool; -mode add;
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   when -property router_pool; -mode add;
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    key:router_pool_handle   value:when -property router_pool; -mode add;
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   returned debug info for when status is $::FAILURE
			                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    key:log                  value:returned debug info for when status is $::FAILURE
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               Examples:
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               Sample Input:
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               Sample Output:
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               Notes:
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               See Also:
		                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               
		"""
		return self._run_keyword("L47_network", kwargs)

	def L47_server_mapping(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: L47_server_mapping
			 	[-handle                  ANY]
			 	[-iterations              ANY]
			 	[-match_client_total_time ANY]
			 	-mode                     ANY
			 	[-offline_time            ANY]
			 	[-server_network_handle   ANY]
			 	[-server_traffic_handle   ANY]
			 	[-standby_time            ANY]
			 	[-sustain_time            ANY]
		
		Arguments:
			 	-handle
			 	-iterations
			    	-match_client_total_time
			        	-mode
			            	-offline_time
			                	-server_network_handle
			                    	-server_traffic_handle
			                        	-standby_time
			                            	-sustain_time
		                           
		                           Return Values:
		                               $::SUCCESS | $::FAILURE
			                                key:status   value:$::SUCCESS | $::FAILURE    
		                               < server traffic mapping configuration handle >
			                                key:handles  value:< server traffic mapping configuration handle >
		                               returned debug info for when status is $::FAILURE
			                                key:log      value:returned debug info for when status is $::FAILURE
		                           
		                           Examples:
		                           
		                           Sample Input:
		                           
		                           Sample Output:
		                           
		                           Notes:
		                           
		                           See Also:
		                           
		"""
		return self._run_keyword("L47_server_mapping", kwargs)

	def L47_stats(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: L47_stats
			 	[-aggregation_type ANY]
			 	[-filter_type      ANY]
			 	[-filter_value     ANY]
			 	[-handle           ANY]
			 	[-ip_list          ANY]
			 	-mode              ANY
			 	[-protocol         ANY]
			 	[-stat_name        ANY]
		
		Arguments:
			 	-aggregation_type
			 	-filter_type
			    	-filter_value
			        	-handle
			            	-ip_list
			                	-mode
			                    	-protocol
			                        	-stat_name
		                       
		                       Return Values:
		                           $::SUCCESS | $::FAILURE
			                            key:status   value:$::SUCCESS | $::FAILURE    
		                           < list of stats | filters >
			                            key:handles  value:< list of stats | filters >
		                           returned debug info for when status is $::FAILURE
			                            key:log      value:returned debug info for when status is $::FAILURE
		                       
		                       Examples:
		                       
		                       Sample Input:
		                       
		                       Sample Output:
		                       
		                       Notes:
		                       
		                       See Also:
		                       
		"""
		return self._run_keyword("L47_stats", kwargs)

	def L47_telnet_client(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: L47_telnet_client
			 	[-c_expect       ANY]
			 	[-c_id           ANY]
			 	[-c_max_interval ANY]
			 	[-c_min_interval ANY]
			 	[-c_send         ANY]
			 	[-c_server_ip    ANY]
			 	[-command_prompt ANY]
			 	[-esm            ANY]
			 	[-esm_enable     ANY]
			 	[-expect_timeout ANY]
			 	[-handle         ANY]
			 	[-loop_enable    ANY]
			 	-mode            ANY
			 	[-options_enable ANY]
		
		Arguments:
			 	-c_expect
			 	-c_id
			    	-c_max_interval
			        	-c_min_interval
			            	-c_send
			                	-c_server_ip
			                    	-command_prompt
			                        	-esm
			                            	-esm_enable
			                                	-expect_timeout
			                                    	-handle
			                                        	-loop_enable
			                                            	-mode
			                                                	-options_enable
		                                               
		                                               Return Values:
		                                                   $::SUCCESS | $::FAILURE
			                                                    key:status          value:$::SUCCESS | $::FAILURE
		                                                   when -property client; -mode add
			                                                    key:client_handle   value:when -property client; -mode add
		                                                   when -property client | agent; -mode add
			                                                    key:agent_handles   value:when -property client | agent; -mode add
		                                                   when -property command; -mode add
			                                                    key:command_handle  value:when -property command; -mode add
		                                                   returned debug info for when status is $::FAILURE
			                                                    key:log             value:returned debug info for when status is $::FAILURE
		                                               
		                                               Examples:
		                                               
		                                               Sample Input:
		                                               
		                                               Sample Output:
		                                               
		                                               Notes:
		                                               
		                                               See Also:
		                                               
		"""
		return self._run_keyword("L47_telnet_client", kwargs)

	def L47_telnet_server(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: L47_telnet_server
			 	[-close_command   ANY]
			 	[-command_prompt  ANY]
			 	[-echo_enable     ANY]
			 	[-esm             ANY]
			 	[-esm_enable      ANY]
			 	[-handle          ANY]
			 	[-linemode_enable ANY]
			 	[-listen_port     ANY]
			 	-mode             ANY
			 	[-property        ANY]
		
		Arguments:
			 	-close_command
			 	-command_prompt
			    	-echo_enable
			        	-esm
			            	-esm_enable
			                	-handle
			                    	-linemode_enable
			                        	-listen_port
			                            	-mode
			                                	-property
		                               
		                               Return Values:
		                               
		                               Examples:
		                               
		                               Sample Input:
		                               
		                               Sample Output:
		                               
		                               Notes:
		                               
		                               See Also:
		                               
		"""
		return self._run_keyword("L47_telnet_server", kwargs)

	def L47_test(self, **kwargs):
		""" API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: No
		
		Synopsis: L47_test
			 	[-force_ownership_enable         ANY]
			 	[-handle                         ANY]
			 	[-map_handle                     ANY]
			 	-mode                            ANY
			 	[-release_config_afterrun_enable ANY]
			 	[-reset_ports_enable             ANY]
			 	[-results_dir                    ANY]
			 	[-results_dir_enable             ANY]
		
		Arguments:
			 	-force_ownership_enable
			 	-handle
			    	-map_handle
			        	-mode
			            	-release_config_afterrun_enable
			                	-reset_ports_enable
			                    	-results_dir
			                        	-results_dir_enable
		                       
		                       Return Values:
		                           $::SUCCESS | $::FAILURE
			                            key:status  value:$::SUCCESS | $::FAILURE    
		                           returned debug info for when status is $::FAILURE
			                            key:log     value:returned debug info for when status is $::FAILURE
		                       
		                       Examples:
		                       
		                       Sample Input:
		                       
		                       Sample Output:
		                       
		                       Notes:
		                       
		                       See Also:
		                       
		"""
		return self._run_keyword("L47_test", kwargs)

	def multivalue_config(self, **kwargs):
		""" This procedure is used to create and modify multivalue operations. Multivalue is a very powerful represetation in NGPF. This is useful to generate various patterns like increment, decrement, custom pattern from file, repeatable random, overlay and etc. This command returns a handle for the configured multivalue. This handle can be used in interface and protocol configuration command to set patterns/multivalue against various fields.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: multivalue_config
			x	[-mode                            CHOICES create modify destroy]
			x	[-multivalue_handle               ANY]
			x	[-custom_handle                   ANY]
			x	[-increment_handle                ANY]
			x	[-pattern                         CHOICES none
			x                                  CHOICES single_value
			x                                  CHOICES counter
			x                                  CHOICES custom
			x                                  CHOICES repeatable_random
			x                                  CHOICES random
			x                                  CHOICES repeatable_random_range
			x                                  CHOICES custom_distributed
			x                                  CHOICES distributed
			x                                  CHOICES string
			x                                  CHOICES alternate
			x                                  CHOICES value_list
			x                                  CHOICES subset]
			x	[-single_value                    ALPHA]
			x	[-counter_start                   ANY]
			x	[-counter_step                    ANY]
			x	[-counter_direction               CHOICES increment decrement]
			x	[-nest_step                       ALPHA]
			x	[-nest_owner                      ALPHA]
			x	[-nest_enabled                    CHOICES 0 1]
			x	[-disable_all_nests               CHOICES 0 1
			x                                  DEFAULT 1]
			x	[-overlay_value                   ALPHA]
			x	[-overlay_value_step              ALPHA]
			x	[-overlay_index                   NUMERIC]
			x	[-overlay_index_step              NUMERIC]
			x	[-overlay_count                   NUMERIC]
			x	[-clear_existing_overlays         CHOICES 0 1
			x                                  DEFAULT 1]
			x	[-custom_start                    ANY]
			x	[-custom_step                     ANY]
			x	[-custom_increment_value          ANY]
			x	[-custom_increment_count          NUMERIC]
			x	[-repeatable_random_seed          NUMERIC]
			x	[-repeatable_random_count         NUMERIC]
			x	[-repeatable_random_fixed         ANY]
			x	[-repeatable_random_mask          ANY]
			x	[-repeatable_random_range_min     ANY]
			x	[-repeatable_random_range_max     ANY]
			x	[-repeatable_random_range_step    ANY]
			x	[-repeatable_random_range_seed    NUMERIC]
			x	[-custom_distribution_values      ALPHA]
			x	[-custom_distribution_percentages ALPHA]
			x	[-custom_distribution_weights     ALPHA]
			x	[-custom_distribution_algorithm   CHOICES auto_even
			x                                  CHOICES auto_geometric
			x                                  CHOICES percentage
			x                                  CHOICES weighted
			x                                  DEFAULT percentage]
			x	[-custom_distribution_mode        CHOICES topology device port
			x                                  DEFAULT topology]
			x	[-distributed_value               NUMERIC]
			x	[-string_pattern                  ALPHA]
			x	[-alternate_value                 CHOICES 0 1]
			x	[-values_list                     ALPHA]
			x	[-values_file                     ANY]
			x	[-values_file_type                CHOICES cisco csv juniper unsupported
			x                                  DEFAULT csv]
			x	[-values_file_column_index        NUMERIC
			x                                  DEFAULT 0]
			x	[-subset_source                   ANY]
			x	[-subset_source_attribute         ANY]
			x	[-subset_round_robin_mode         CHOICES none port device manual
			x                                  DEFAULT port]
		
		Arguments:
			x	-mode
			x		The mode parameter is only needed when specifying values for
			x		custom_handle or increment_handle.
			x		When a custom_handle is specified the only valid mode values are
			x		- create
			x		- modify
			x		When a increment_handle is specified all choices are valid.
			x		Valid choices are:
			x   		create - creates a new CustomIncrement with the specified values
			x   		modify - updates the root CustomIncrement with the specified values
			x   		destroy -
			x	-multivalue_handle
			x		The handle of a multivalue that was generated by a previous
			x		multivalue_config command.
			x	-custom_handle
			x		The handle of a custom pattern that was generated by a previous
			x		multivalue_config command.
			x	-increment_handle
			x		The handle of a custom increment that was generated by a previous
			x		multivalue_config command.
			x	-pattern
			x		The pattern that we want the multivalue to have.
			x		Valid choices are:
			x   		none -
			x   		single_value -
			x   		counter -
			x   		custom -
			x   		repeatable_random -
			x   		random -
			x   		repeatable_random_range -
			x   		custom_distributed -
			x   		distributed -
			x   		string -
			x   		alternate -
			x   		valueList -
			x   		subset -
			x	-single_value
			x		The value that will be used when the pattern is single_value.
			x		This argument is valid only if the configured pattern is single_value.
			x	-counter_start
			x		The start value that will be used when the pattern is a counter.
			x		This argument is valid only if the configured pattern is counter.
			x	-counter_step
			x		The step value that will be used when the pattern is a counter.
			x		This argument is valid only if the configured pattern is counter.
			x	-counter_direction
			x		The type of counter pattern that we want to configure.
			x		This argument is valid only if the configured pattern is counter.
			x		Valid choices are:
			x   		increment -
			x   		decrement -
			x	-nest_step
			x		The step of the configured nest(s) for the current multivalue.
			x		If multiple nests are configured the value of this argument must
			x		be a comma separated list of step values which correspond to the
			x		specified nest owners.
			x	-nest_owner
			x		The owner of the configured nest(s) for the current multivalue.
			x		If multiple nests are configured the value of this argument must
			x		be a comma separated list of owner handles.
			x	-nest_enabled
			x		This argument can be used to selectively enable/disable the nests configured
			x		in a multivalue.
			x		If multiple nests are configured the value of this argument must
			x		be a comma separated list of step values which correspond to the
			x		specified nest owners.
			x	-disable_all_nests
			x		This flag can be used to disable all nests in a multivalue.
			x	-overlay_value
			x		The value of an overlay.
			x		This argument can be a comma separated list of values if we want to
			x		configure multiple overlays with a single command.
			x	-overlay_value_step
			x		The step used by an overlay.
			x		This argument should only be used if you want to create overlay patterns.
			x		This argument can be a comma separated list of values if we want to
			x		configure multiple overlays with a single command.
			x	-overlay_index
			x		The index at which the overlay will be created.
			x		This argument can be a comma separated list of values if we want to
			x		configure multiple overlays with a single command.
			x	-overlay_index_step
			x		The index step controls the inteval at which successive overlays will be created.
			x		This argument should only be used if you want to create overlay patterns.
			x		This argument can be a comma separated list of values if we want to
			x		configure multiple overlays with a single command.
			x	-overlay_count
			x		The number of overlays which will be generated by the corresponding overlay pattern.
			x		This argument should only be used if you want to create overlay patterns.
			x		This argument can be a comma separated list of values if we want to
			x		configure multiple overlays with a single command.
			x	-clear_existing_overlays
			x		This flag can be used to remove all overlays from a multivalue.
			x	-custom_start
			x		The start value for the custom pattern.
			x		This argument is valid only if the configured pattern is custom.
			x	-custom_step
			x		The step value for the custom pattern.
			x		This argument is valid only if the configured pattern is custom.
			x	-custom_increment_value
			x		The value of the custom increment being configured by the current command.
			x		This argument is valid only if the configured pattern is custom.
			x	-custom_increment_count
			x		The count of the custom increment being configured by the current command.
			x		This argument is valid only if the configured pattern is custom.
			x	-repeatable_random_seed
			x		The seed that will be used by the repeatable random pattern configured by the current command.
			x		This argument is valid only if the configured pattern is repeatable_random.
			x	-repeatable_random_count
			x		The number of random values that will be generated by the repeatable random
			x		pattern configured by the current command.
			x		This argument is valid only if the configured pattern is repeatable_random.
			x	-repeatable_random_fixed
			x		A template that can be used to configure a static part of the values
			x		that will be generated.
			x		This argument is valid only if the configured pattern is repeatable_random.
			x	-repeatable_random_mask
			x		A mask that can be used to select which parts of the fixed value will
			x		not be changed when a new value is generated.
			x		This argument is valid only if the configured pattern is repeatable_random.
			x	-repeatable_random_range_min
			x		This is the minimum value of the range generated by the repeatable random range
			x		This argument is valid only if the configured pattern is repeatable_random_range.
			x	-repeatable_random_range_max
			x		This is the maximum value of the range generated by the repeatable random range
			x		This argument is valid only if the configured pattern is repeatable_random_range.
			x	-repeatable_random_range_step
			x		This is the minimum difference between generated value by the repeatable random range
			x		This argument is valid only if the configured pattern is repeatable_random_range.
			x	-repeatable_random_range_seed
			x		The seed that will be used by the repeatable random range pattern configured by the current command.
			x		This argument is valid only if the configured pattern is repeatable_random_range.
			x	-custom_distribution_values
			x		The values that will be used by the custom distributed multivalue configured by this command.
			x		This argument is valid only if the configured pattern is custom_distributed.
			x	-custom_distribution_percentages
			x		The distribution percentages that will be used.
			x		This argument is valid only if the configured pattern is custom_distributed.
			x	-custom_distribution_weights
			x		The distribution weights that will be used.
			x		This argument is valid only if the configured pattern is custom_distributed.
			x	-custom_distribution_algorithm
			x		The algorithm that will be used to distribute the values specified in custom_distribution_values.
			x		Valid choices are:
			x   		auto_even - The values specified by custom_distribution_values will be distributed evenly.
			x   		auto_geometric - The values specified by custom_distribution_values will be distributed geometrically.
			x   		percentage - The values specified by custom_distribution_values will be distributed according to the percentages specified in custom_distribution_percentages.
			x   		weighted - The values specified by custom_distribution_values will be distributed accorgind to the weights specified in custom_distribution_percentages.
			x	-custom_distribution_mode
			x		The mode in which the distribution algorithm specified by custom_distribution_algorithm will be applied.
			x		Valid choices are:
			x   		topology - The values specified in custom_distribution_values will be distributed across all the configured devices according to the distribution algorithm specified by custom_distribution_algorithm.
			x   		device - The values specified in custom_distribution_values will be distributed across each set of devices configured for a parent device according to the distribution algorithm specified by custom_distribution_algorithm.
			x   		port - The values specified in custom_distribution_values will be distributed across each set of devices configured on a port according to the distribution algorithm specified by custom_distribution_algorithm.
			x	-distributed_value
			x		The value that will be distributed among the individual items configured with
			x		the current multivalue.
			x		This argument is valid only if the configured pattern is distributed.
			x	-string_pattern
			x		The string pattern that will be used by the multivalue configured by the current command.
			x		This argument is valid only if the configured pattern is string.
			x	-alternate_value
			x		The start value for the alternate pattern.
			x	-values_list
			x		A list of values that will be used to populate the corresponding attribute.
			x		If not enough values are supplied, the existing values will be reused as many times as necessary.
			x	-values_file
			x		The full path of a local file that will be used to import the list of values for the value_list pattern.
			x		The file should be in either CSV, CISCO or Juniper format. This argument's value will be used only if th values_list argument was not manually specified.
			x	-values_file_type
			x		The type of file that will be used to import the list of values for the value_list pattern.
			x		This argument is used only when values_file is specified and used as well and it has a default value of csv.
			x		Valid choices are:
			x   		cisco - Indicates that the file specified by values_file has a CISCO format.
			x   		csv - Indicates that the file specified by values_file has a CSV format.
			x   		juniper - Indicates that the file specified by values_file has a JUNIPER format.
			x   		unsupported - Indicates that the file specified by values_file has an unsupported format.
			x	-values_file_column_index
			x		The0-based index of the column that will be used to import the values.
			x		This argument is used only when values_file is specified and used as well and it has a default value of 0.
			x	-subset_source
			x		The handle of the protocol stack that will be used as a source of values for the corresponding attribute.
			x	-subset_source_attribute
			x		The name of the attribute that will be used as a source of values.
			x		The value of this argument will be ignored if no value was specified for subset_source.
			x		This argument can be omitted if the destination protocol stack is of the same type as the source protocol stack. In this case the name of the destination attribute will be used as the name of the source attribute.
			x	-subset_round_robin_mode
			x		The type of round robin distribution tat will be used to populate the values of the target attribute using the source values.
			x		Valid choices are:
			x   		none -
			x   		port -
			x   		device -
			x   		manual -
		
		Return Values:
		A list containing the multivalue protocol stack handles that were added by the command (if any).
			xkey:multivalue_handle  value:A list containing the multivalue protocol stack handles that were added by the command (if any).
		A list containing the custom protocol stack handles that were added by the command (if any).
			xkey:custom_handle      value:A list containing the custom protocol stack handles that were added by the command (if any).
		A list containing the increment protocol stack handles that were added by the command (if any).
			xkey:increment_handle   value:A list containing the increment protocol stack handles that were added by the command (if any).
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("multivalue_config", kwargs)

	def network_group_config(self, **kwargs):
		""" This procedure creates, modifies and deletes network topologies - IPv4 or Ipv6 Prefix Pools, Simulated routers to design network grid or topologies.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: network_group_config
			x	-protocol_handle                     ANY]
			x	[-protocol_name                      ALPHA]
			x	[-multiplier                         NUMERIC]
			x	[-enable_device                      CHOICES 0 1]
			x	[-connected_to_handle                ANY]
			x	[-connected_to_handle_ipv4           ANY]
			x	[-connected_to_handle_ipv6           ANY]
			x	[-mode                               CHOICES create modify delete
			x                                     DEFAULT create]
			x	[-type                               CHOICES dual-stack-prefix
			x                                     CHOICES ipv4-prefix
			x                                     CHOICES ipv6-prefix
			x                                     CHOICES mac-dual-stack-prefix
			x                                     CHOICES mac-ipv4-prefix
			x                                     CHOICES mac-ipv6-prefix
			x                                     CHOICES mac-pools
			x                                     CHOICES grid
			x                                     CHOICES mesh
			x                                     CHOICES custom
			x                                     CHOICES ring
			x                                     CHOICES hub-and-spoke
			x                                     CHOICES tree
			x                                     CHOICES fat-tree
			x                                     CHOICES linear]
			x	[-mac_pools_multiplier               NUMERIC]
			x	[-mac_pools_number_of_addresses      RANGE 1-100000000]
			x	[-mac_pools_prefix_length            NUMERIC]
			x	[-mac_pools_use_vlans                CHOICES 0 1]
			x	[-mac_pools_mac                      MAC]
			x	[-mac_pools_mac_step                 MAC]
			x	[-mac_pools_vlan_count               RANGE 0-2]
			x	[-mac_pools_vlan_tpid                CHOICES 0x8100
			x                                     CHOICES 0x88a8
			x                                     CHOICES 0x9100
			x                                     CHOICES 0x9200
			x                                     CHOICES 0x9300]
			x	[-mac_pools_vlan_priority            NUMERIC]
			x	[-mac_pools_vlan_priority_step       NUMERIC]
			x	[-mac_pools_vlan_id                  NUMERIC]
			x	[-mac_pools_vlan_id_step             NUMERIC]
			x	[-ipv6_prefix_network_address        IPV6]
			x	[-ipv6_prefix_network_address_step   IPV6]
			x	[-ipv6_prefix_length                 NUMERIC]
			x	[-ipv6_prefix_address_step           NUMERIC]
			x	[-ipv6_prefix_number_of_addresses    RANGE 1-100000000]
			x	[-ipv6_prefix_multiplier             NUMERIC]
			x	[-ipv4_prefix_network_address        IP]
			x	[-ipv4_prefix_network_address_step   IP
			x                                     DEFAULT 0.0.0.1]
			x	[-ipv4_prefix_length                 NUMERIC]
			x	[-ipv4_prefix_address_step           NUMERIC]
			x	[-ipv4_prefix_number_of_addresses    RANGE 1-100000000]
			x	[-ipv4_prefix_multiplier             NUMERIC]
			x	[-external_link_router_source        NUMERIC]
			x	[-external_link_router_destination   NUMERIC]
			x	[-external_link_network_group_handle ANY]
			 	[-grid_col                           RANGE 0-10000
			                                      DEFAULT 1]
			 	[-grid_row                           RANGE 0-10000
			                                      DEFAULT 1]
			x	[-grid_include_emulated_device       CHOICES 0 1]
			x	[-grid_link_multiplier               NUMERIC]
			x	[-mesh_number_of_nodes               NUMERIC]
			x	[-mesh_include_emulated_device       CHOICES 0 1]
			x	[-mesh_link_multiplier               NUMERIC]
			x	[-ring_number_of_nodes               NUMERIC]
			x	[-ring_include_emulated_device       CHOICES 0 1]
			x	[-ring_link_multiplier               NUMERIC]
			x	[-hub_spoke_number_of_first_level    NUMERIC]
			x	[-hub_spoke_number_of_second_level   NUMERIC]
			x	[-hub_spoke_enable_level_2           CHOICES 0 1]
			x	[-hub_spoke_link_multiplier          NUMERIC]
			x	[-tree_number_of_nodes               NUMERIC]
			x	[-tree_include_emulated_device       CHOICES 0 1]
			x	[-tree_use_tree_depth                CHOICES 0 1]
			x	[-tree_depth                         NUMERIC]
			x	[-tree_max_children_per_node         NUMERIC]
			x	[-tree_link_multiplier               NUMERIC]
			x	[-custom_link_multiplier             NUMERIC]
			x	[-custom_from_node_index             NUMERIC]
			x	[-custom_to_node_index               NUMERIC]
			x	[-fat_tree_link_multiplier           NUMERIC]
			x	[-fat_tree_level_count               NUMERIC]
			x	[-fat_tree_node_count                NUMERIC]
			x	[-linear_nodes                       NUMERIC]
			x	[-linear_link_multiplier             NUMERIC]
		
		Arguments:
			x	-protocol_handle
			x	-protocol_name
			x	-multiplier
			x	-enable_device
			x		enables/disables device.
			x	-connected_to_handle
			x		Scenario element this connector is connecting to
			x	-connected_to_handle_ipv4
			x		Scenario element IPV4_prefix connector is connecting to for dual-stack-prefix mode.
			x	-connected_to_handle_ipv6
			x		Scenario element IPV6_prefix connector is connecting to for dual-stack-prefix mode.
			x	-mode
			x		Mode of the procedure call.Valid options are:
			x		create
			x		modify
			x		delete
			x		Valid choices are:
			x   		create -
			x   		modify -
			x   		delete -
			x	-type
			x		The type of topology route to create.
			x		Valid choices are:
			x   		dual-stack-prefix -
			x   		ipv4-prefix -
			x   		ipv6-prefix -
			x   		mac-dual-stack-prefix -
			x   		mac-ipv4-prefix -
			x   		mac-ipv6-prefix -
			x   		mac-pools -
			x   		grid -
			x   		ring -
			x   		mesh -
			x   		custom -
			x   		hub-and-spoke -
			x   		tree -
			x   		fat-tree -
			x   		linear -
			x	-mac_pools_multiplier
			x		Please use mac_pools_number_of_addresses insted of this argument
			x	-mac_pools_number_of_addresses
			x		This argument sets the number of mac addresses
			x	-mac_pools_prefix_length
			x	-mac_pools_use_vlans
			x		Flag to determine whether VLANs are enabled.
			x	-mac_pools_mac
			x		MAC addresses of the plugin
			x	-mac_pools_mac_step
			x		MAC step of the plugin
			x	-mac_pools_vlan_count
			x		Number of active VLANs. The maximum value is 2
			x	-mac_pools_vlan_tpid
			x		16-bit Tag Protocol Identifier (TPID) or EtherType in the VLAN tag.
			x		Valid choices are:
			x   		0x8100 -
			x   		0x88a8 -
			x   		0x9100 -
			x   		0x9200 -
			x   		0x9300 -
			x	-mac_pools_vlan_priority
			x		3-bit user priority field in the VLAN tag.
			x	-mac_pools_vlan_priority_step
			x		3-bit user priority step field in the VLAN tag.
			x	-mac_pools_vlan_id
			x		12-bit VLAN ID in the VLAN tag.
			x	-mac_pools_vlan_id_step
			x		12-bit VLAN ID step in the VLAN tag.
			x	-ipv6_prefix_network_address
			x		Network addresses of the simulated IPv6 network
			x	-ipv6_prefix_network_address_step
			x		Network addresses step of the simulated IPv6 network
			x	-ipv6_prefix_length
			x	-ipv6_prefix_address_step
			x		Prefix Address Step of the simulated IPv6 network
			x	-ipv6_prefix_number_of_addresses
			x		This argument sets the number of ipv6 addresses
			x	-ipv6_prefix_multiplier
			x		Please use ipv6_prefix_network_address insted of this argumen
			x	-ipv4_prefix_network_address
			x		Network addresses of the simulated IPv4 network
			x	-ipv4_prefix_network_address_step
			x		Network addresses of the simulated IPv4 network
			x	-ipv4_prefix_length
			x	-ipv4_prefix_address_step
			x		Prefix Address Step of the simulated IPv4 network
			x	-ipv4_prefix_number_of_addresses
			x		This argument sets the number of ipv4 addresses
			x	-ipv4_prefix_multiplier
			x		Please use ipv4_prefix_number_of_addresses insted of this argumen
			x	-external_link_router_source
			x		Index of the originating node as defined in fromNetworkTopology
			x	-external_link_router_destination
			x		Index of the target node as defined in toNetworkTopology
			x	-external_link_network_group_handle
			x		Network Topology this link is pointing to
			 	-grid_col
			 		Defines number of columns in a grid.
			 		This option is valid only when -type is grid, otherwise it
			 		is ignored. This option is available with IxTclNetwork and IxTclProtocol API.
			 	-grid_row
			 		Defines number of rows in a grid.
			 		This option is valid only when -type is grid, otherwise it
			 		is ignored.
			 		This option is available with IxTclNetwork and IxTclProtocol API.
			x	-grid_include_emulated_device
			x	-grid_link_multiplier
			x	-mesh_number_of_nodes
			x	-mesh_include_emulated_device
			x	-mesh_link_multiplier
			x	-ring_number_of_nodes
			x	-ring_include_emulated_device
			x	-ring_link_multiplier
			x	-hub_spoke_number_of_first_level
			x	-hub_spoke_number_of_second_level
			x	-hub_spoke_enable_level_2
			x	-hub_spoke_link_multiplier
			x	-tree_number_of_nodes
			x	-tree_include_emulated_device
			x	-tree_use_tree_depth
			x	-tree_depth
			x	-tree_max_children_per_node
			x	-tree_link_multiplier
			x	-custom_link_multiplier
			x		number of links between two nodes
			x	-custom_from_node_index
			x	-custom_to_node_index
			x	-fat_tree_link_multiplier
			x		number of links between two nodes
			x	-fat_tree_level_count
			x		Number of Levels
			x	-fat_tree_node_count
			x		Number of Nodes Per Level
			x	-linear_nodes
			x		number of nodes
			x	-linear_link_multiplier
			x		number of links between two nodes
		
		Return Values:
		A list containing the network group protocol stack handles that were added by the command (if any).
			xkey:network_group_handle              value:A list containing the network group protocol stack handles that were added by the command (if any).
		A list containing the mac pools protocol stack handles that were added by the command (if any).
			xkey:mac_pools_handle                  value:A list containing the mac pools protocol stack handles that were added by the command (if any).
		A list containing the ipv4 prefix pools protocol stack handles that were added by the command (if any).
			xkey:ipv4_prefix_pools_handle          value:A list containing the ipv4 prefix pools protocol stack handles that were added by the command (if any).
		A list containing the ipv6 prefix pools protocol stack handles that were added by the command (if any).
			xkey:ipv6_prefix_pools_handle          value:A list containing the ipv6 prefix pools protocol stack handles that were added by the command (if any).
		A list containing the simulated router protocol stack handles that were added by the command (if any).
			xkey:simulated_router_handle           value:A list containing the simulated router protocol stack handles that were added by the command (if any).
		A list containing the external1 protocol stack handles that were added by the command (if any).
			xkey:external1_handle                  value:A list containing the external1 protocol stack handles that were added by the command (if any).
		A list containing the external2 protocol stack handles that were added by the command (if any).
			xkey:external2_handle                  value:A list containing the external2 protocol stack handles that were added by the command (if any).
		A list containing the nssa protocol stack handles that were added by the command (if any).
			xkey:nssa_handle                       value:A list containing the nssa protocol stack handles that were added by the command (if any).
		A list containing the stub protocol stack handles that were added by the command (if any).
			xkey:stub_handle                       value:A list containing the stub protocol stack handles that were added by the command (if any).
		A list containing the summary protocol stack handles that were added by the command (if any).
			xkey:summary_handle                    value:A list containing the summary protocol stack handles that were added by the command (if any).
		A list containing the sim interface ipv4 config protocol stack handles that were added by the command (if any).
			xkey:sim_interface_ipv4_config_handle  value:A list containing the sim interface ipv4 config protocol stack handles that were added by the command (if any).
		A list containing the v3 inter area protocol stack handles that were added by the command (if any).
			xkey:v3_inter_area_handle              value:A list containing the v3 inter area protocol stack handles that were added by the command (if any).
		A list containing the v3 external protocol stack handles that were added by the command (if any).
			xkey:v3_external_handle                value:A list containing the v3 external protocol stack handles that were added by the command (if any).
		A list containing the v3 intra area prefix protocol stack handles that were added by the command (if any).
			xkey:v3_intra_area_prefix_handle       value:A list containing the v3 intra area prefix protocol stack handles that were added by the command (if any).
		A list containing the v3 nssa protocol stack handles that were added by the command (if any).
			xkey:v3_nssa_handle                    value:A list containing the v3 nssa protocol stack handles that were added by the command (if any).
		A list containing the v3 inter area prefix protocol stack handles that were added by the command (if any).
			xkey:v3_inter_area_prefix_handle       value:A list containing the v3 inter area prefix protocol stack handles that were added by the command (if any).
		A list containing the v3 linklsa protocol stack handles that were added by the command (if any).
			xkey:v3_linklsa_handle                 value:A list containing the v3 linklsa protocol stack handles that were added by the command (if any).
		A list containing the ipv6 prefix interface protocol stack handles that were added by the command (if any).
			xkey:ipv6_prefix_interface_handle      value:A list containing the ipv6 prefix interface protocol stack handles that were added by the command (if any).
		A list containing the simulated rbridge protocol stack handles that were added by the command (if any).
			xkey:simulated_rbridge_handle          value:A list containing the simulated rbridge protocol stack handles that were added by the command (if any).
		A list containing the simulated interface ipv6 protocol stack handles that were added by the command (if any).
			xkey:simulated_interface_ipv6_handle   value:A list containing the simulated interface ipv6 protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:v3_inter_area_handles             value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:v3_external_handles               value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:v3_intra_area_prefix_handles      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:v3_nssa_handles                   value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:v3_inter_area_prefix_handles      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:v3_linklsa_handles                value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  v3_inter_area_handles, v3_external_handles, v3_intra_area_prefix_handles, v3_nssa_handles, v3_inter_area_prefix_handles, v3_linklsa_handles
		
		See Also:
		
		"""
		return self._run_keyword("network_group_config", kwargs)

	def packet_config_buffers(self, **kwargs):
		""" Defines how the buffers will be managed for packet capturing
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: packet_config_buffers
			 	-port_handle                   ANY
			 	[-action                       ANY]
			x	[-after_trigger_filter         ANY]
			x	[-before_trigger_filter        ANY]
			x	[-capture_mode                 ANY]
			x	[-continuous_filter            ANY]
			x	[-data_plane_capture_enable    ANY]
			x	[-control_plane_capture_enable ANY]
			x	[-control_plane_filter_pcap    ANY]
			x	[-control_plane_trigger_pcap   ANY]
			x	[-small_packet_capture         ANY]
			x	[-slice_size                   ANY]
			x	[-trigger_position             ANY]
			x	[-no_write                     ANY]
		
		Arguments:
			 	-port_handle
			 		Supported with IxTclHal and IxTclNetwork. Associates the command performed by action to the port handle listed.
			 	-action
			 		Supported with IxTclHal. Controls the action of the buffer when it reaches the full status. Not supported with IxTclNetwork and warning will be printed on stdout if this parameter is used.DEFAULT: wrap
			x	-after_trigger_filter
			x		Supported with IxTclHal and IxTclNetwork. Controls the capture of data after triggering when operating.
			x		Valid choices are:
			x   		all - Captures all data after trigger.
			x   		filter - (default)Captures filtered data after trigger using filter settings.
			x   		condition_filter - Captures filtered data after trigger as per the filter settings.
			x	-before_trigger_filter
			x		Supported with IxTclHal and IxTclNetwork. Controls the capture of data prior to triggering when operating in triggered mode (capture_mode = trigger).
			x		Valid choices are:
			x   		all - Captures all data before trigger.
			x   		none - (default) Captures none of the data before trigger.
			x   		filter - Captures filtered data before trigger as per the filter settings.
			x	-capture_mode
			x		Supported with IxTclHal and IxTclNetwork. Controls whether data capture is performed in a continuous or triggered mode.
			x		Valid choices are:
			x   		continuous - Captures data in the buffer continuously, regardless of trigger settings. Data may be filtered; see continuous_filter.
			x   		trigger - (default) Captures data only after triggered.
			x	-continuous_filter
			x		Supported with IxTclHal and IxTclNetwork. Controls whether data captured in continous mode (capture_mode = continuous) is filtered or not.
			x		Valid choices are:
			x   		all - (default) Captures all data, regardless of filter settings.
			x   		filter - Captures only filtered data, as per filter settings.
			x	-data_plane_capture_enable
			x		Supported with IxTclNetwork. If 1, enables the capture of data plane traffic.
			x	-control_plane_capture_enable
			x		Supported with IxTclNetwork. If 1, enables the capture of control plane traffic.
			x	-control_plane_filter_pcap
			x		Supported with IxTclHal and IxTclNetwork. This is the filter string for control plane traffic capture (a valid pcap filter syntax). Valid only when control_plane_capture_enable is 1.
			x	-control_plane_trigger_pcap
			x		Supported with IxTclNetwork. This is the trigger string for control plane traffic capture (a valid pcap filter syntax). Valid only when control_plane_capture_enable is 1.
			x	-small_packet_capture
			x		Supported with IxTclHal. Applies to OC12 cards only. Capture of packets of 48 bytes or less at full wire rates can be erroneous and is usually treated as an error. This setting allows packets of 48 bytes or less in length to be captured. The data captured, can also be corrupted. Not supported with IxTclNetwork and warning will be printed on "stdout" if this parameter is used.
			x	-slice_size
			x		Supported with IxTclHal and IxTclNetwork. The maximum number of octets of each frame that will be saved in this capture buffer. For example, if a 1500 octet frame is received by the probe and this option is set to 500, then only 500 octets of the frame will be stored in the associated capture buffer. If this option is set to 0, the capture buffer will save as many octets as is possible. If the slice_size is set larger than the maximim hardware supported slice size, the maximum will be used.
			x	-trigger_position
			x		Supported with IxTclHal and IxTclNetwork. Controls the dividing line within the capture buffer between before trigger data and post trigger data. This control is only useful in triggered mode (capture_mode = trigger) and before trigger capture enabled (before_trigger_filter= all or filter). Trigger_position is expressed as a percentage of the total buffer size. The beginning of the buffer with this percentage is used in a wrap-around mode for before trigger data and the remainder is filled up with triggered data.
			x	-no_write
			x		Supported with IxTclHal and IxTclNetwork. Determines whether to enable the procedure to commit change to the hardware.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status       value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log          value:If status is failure, detailed information provided.
		The port_handle received as a paramater
			 key:port_handle  value:The port_handle received as a paramater
		
		Examples:
		See files starting with Capture_ in the Samples subdirectory. See the Capture example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		When calling ::<namespace>::packet_config_buffers a L1 reset will be triggered which will cause any protocol/traffic on that port to stop.
		
		See Also:
		
		"""
		return self._run_keyword("packet_config_buffers", kwargs)

	def packet_config_filter(self, **kwargs):
		""" Values for filters and/or triggers are set with the ::<namespace>::packet_config_filter. The usage of these values (as filters and/or triggers) will be set with the ::<namespace>::packet_config_triggers.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: packet_config_filter
			 	-port_handle           ANY
			x	[-mode                 ANY]
			x	[-gfp_bad_fcs_error    ANY]
			x	[-gfp_eHec_error       ANY]
			x	[-gfp_payload_crc      ANY]
			x	[-gfp_tHec_error       ANY]
			x	[-DA1                  ANY]
			x	[-DA2                  ANY]
			x	[-DA_mask1             ANY]
			x	[-DA_mask2             ANY]
			x	[-gfp_error_condition  ANY]
			x	[-match_type1          ANY]
			x	[-match_type2          ANY]
			x	[-pattern1             ANY]
			x	[-pattern2             ANY]
			x	[-pattern_atm          ANY]
			x	[-pattern_mask1        ANY]
			x	[-pattern_mask2        ANY]
			x	[-pattern_mask_atm     ANY]
			x	[-pattern_offset1      ANY]
			x	[-pattern_offset2      ANY]
			x	[-pattern_offset_type1 ANY]
			x	[-pattern_offset_type2 ANY]
			x	[-pattern_offset_atm   ANY]
			x	[-SA1                  ANY]
			x	[-SA2                  ANY]
			x	[-SA_mask1             ANY]
			x	[-SA_mask2             ANY]
			x	[-vpi                  ANY]
			x	[-vpi_count            ANY]
			x	[-vpi_step             ANY]
			x	[-vci                  ANY]
			x	[-vci_count            ANY]
			x	[-vci_step             ANY]
			x	[-no_write             ANY]
		
		Arguments:
			 	-port_handle
			 		Supported with IxTclHal and IxTclNetwork. Associates the command performed by action to the port handle listed.
			x	-mode
			x		Supported with IxTclHal and IxTclNetwork (addAtmFilter choice is not valid with IxTclNetwork). When mode is create ATM specific configurations and general configurations will be set.The user can set the same pattern_atm for more pairs vpi/vci pairs (see parameters -vpi and -vci).If the user wants to set different pattern_atm for some pairs, he has to call this procedure using -mode addAtmFilter.When using -mode addAtmFilter, only ATM specific configurations will be set and all the other configurations will be ignored. These ATM specific configurations will be appended to the previous ones.This procedure must be called only once with -mode create, otherwise it will overwrite the previous configurations.
			x	-gfp_bad_fcs_error
			x	-gfp_eHec_error
			x   	-gfp_payload_crc
			x       	-gfp_tHec_error
			x           	-DA1
			x               		Supported with IxTclHal and IxTclNetwork. Only frames that contain this destination MAC address are filtered, captured or counted.
			x           	-DA2
			x               		Supported with IxTclHal and IxTclNetwork. Only frames that contain this destination MAC address are filtered, captured or counted.
			x           	-DA_mask1
			x               		Supported with IxTclHal and IxTclNetwork. A bit mask that allows the user to specify which bits of the DA1 should be used when filtering. If the mask bit is set high, the pattern bit will be used in the filter.
			x           	-DA_mask2
			x               		Supported with IxTclHal and IxTclNetwork. A bit mask that allows the user to specify which bits of the DA2 should be used when filtering. If the mask bit is set high, the pattern bit will be used in the filter.
			x           	-gfp_error_condition
			x               	-match_type1
			x                   		Supported with IxTclHal and IxTclNetwork. Match type for pattern1 set in class member pattern1.
			x                   		Valid choices are:
			x                       		IpEthernetII - An Ethernet II packet.
			x                       		Ip8023Snap - An 802.3 SNAP packet.
			x                       		Vlan - A VLAN tagged packet.
			x                       		User - (default) A value as specified by pattern1, pattern Mask1 and patternOffset1.
			x                       		IpPpp - A PPP format packet.
			x                       		IpCiscoHdlc - A Cisco HDLC format packet.
			x                       		IpSAEthernetII - Match the IP Source Address for an Ethernet II packet located at offset 26. Pattern will become the source IP address and pattern_mask will become the netmask for the IP address.
			x                       		IpDAEthernetII - Match the IP Destination Address for an Ethernet II packet located at offset 30. Pattern will become the destination IP address and pattern_mask will become the netmask for the IP address.
			x                       		IpSADAEthernetII - Match the IP Source and Destination Address for an Ethernet II packet located at offset 26. Pattern represents the IP addresses of the source and destination (in this order) and pattern_mask represents the masks of the source and destination IP addresses.
			x                       		IpSA8023Snap - Match the IP Source Address for an 802.3 Snap packet located at offset 34.(same as IpSAEthernetII)
			x                       		IpDA8023Snap - Match the IP Destination Address for an 802.3 Snap packet located at offset 38. (same as IpDAEthernetII)
			x                       		IpSADA8023Snap - Match the IP Source and Destination Address for an 802.3 Snap packet located at offset 34. (same as IpSADAEthernetII)
			x                       		IpSAPos - Match the IP Source Address for an POS packet located at offset 16.(same as IpSAEthernetII)
			x                       		IpDAPos - match the IP Destination Address for an POS packet located at offset 20. (same as IpDAEthernetII)
			x                       		IpSADAPos - Match the IP Source and Destination Addresses for an POS packet located at offset 16. (same as IpSADAEthernetII)
			x                       		TcpSourcePortIPEthernetII - Match the TCP Source Port for an Ethernet II packet located at offset 34. (pattern represents the source port and the default mask value 00 will always overrides pattern_mask).
			x                       		TcpDestPortIPEthernetII - Match the TCP Destination Port for an Ethernet II packet located at offset 36. (pattern represents the dest port and the default mask value 00 will always overrides pattern_mask).
			x                       		UdpSourcePortIPEthernetII - Match the UDP Source Port for an Ethernet II packet located at offset 34.(pattern represents the source port)
			x                       		UdpDestPortIPEthernetII - Match the UDP Destination Port for an Ethernet II packet located at offset 36. (pattern represents the dest port)
			x                       		TcpSourcePortIP8023Snap - Match the TCP Source Port for an 802.3 Snap packet located at offset 42. (pattern represents the source port)
			x                       		TcpDestPortIP8023Snap - Match the TCP Destination Port for an 802.3 Snap packet located at offset 44. (pattern represents the dest port)
			x                       		UdpSourcePortIP8023Snap - Match the UDP Source Port for an 802.3 Snap packet located at offset 42. (pattern represents the source port)
			x                       		UdpDestPortIP8023Snap - Match the UDP Destination Port for an 802.3 Snap packet located at offset 44. (pattern represents the dest port)
			x                       		TcpSourcePortIPPos - Match the TCP Source Port for a POS.
			x                       		TcpDestPortIPPos - Match the TCP Destination Port for a POS packet located at offset 26. (pattern represents the dest port)
			x                       		UdpSourcePortIPPos - Match the UDP Source Port for a POS packet located at offset 24. (pattern represents the source port)
			x                       		UdpDestPortIPPos - Match the UDP Source Port for a POS packet located at offset 26. (pattern represents the dest port)
			x                       		SrpModeReserved000 - Match an SRP packet whose mode is reserved 000.
			x                       		SrpModeReserved001 - Match an SRP packet whose mode is reserved 001.
			x                       		SrpModeReserved010 - Match an SRP packet whose mode is reserved 010.
			x                       		SrpModeAtmCell011 - Match an SRP packet whose mode is ATM cell.
			x                       		SrpControlMessagePassToHost100 - Match an SRP packet whose mode is control message 1.
			x                       		SrpControlMessageBufferForHost101 - Match an SRP packet whose mode is control message 2.
			x                       		SrpUsageMessage110 - Match an SRP packet which is an SRP usage message.
			x                       		SrpPacketData111 - Match an SRP packet which is a data packet.
			x                       		SrpAllControlMessages10x - Match SRP control messages 1 and 2.
			x                       		SrpUsageMessageOrPacketData11x - Match SRP usage message or data packet.
			x                       		SrpControlUsageOrPacketData1xx - Match SRP usage message, control message 1 or 2, or data packet.
			x                       		SrpInnerRing - Match an SRP packet whose ringIdentifier is set to inner.
			x                       		SrpOuterRing - Match an SRP packet whose ringIdentifier is set to outer.
			x                       		SrpPriority0-7 - Match an SRP packet whose priority is set to 0-7.
			x                       		SrpParityOdd - Match an SRP packet with odd parity.
			x                       		SrpParityEven - Match an SRP packet with even parity.
			x                       		SrpDiscoveryFrame - Match an SRP discovery packet.
			x                       		SrpIpsFrame - Match an SRP IPS packet.
			x                       		RprRingId0 - Match any RPR packet which specifies Ringlet 0. (Originally transmitted on Ringlet 0 by the Source)
			x                       		RprRingId1 - Match any RPR packet which specifies Ringlet 1. (Originally transmitted on Ringlet 1 by the Source)
			x                       		RprFairnessEligibility0 - Match any RPR packet which specifies Fairness Eligibility 0. (0 = Not eligible for Fairness algorithm)
			x                       		RprFairnessEligibility1 - Match any RPR packet which specifies Fairness Eligibility 1. (0 = Not eligible for Fairness algorithm)
			x                       		RprIdlePacket - Match any RPR Idle packet. (Type = 00)
			x                       		RprControlPacket - Match any RPR Control packet. (Type = 01)
			x                       		RprFairnessPacket - Match any RPR Fairness packet. (Type = 10)
			x                       		RprDataPacket - Match any RPR Data packet. (Type = 11)
			x                       		RprServiceClassC - Match any RPR packet which specifies service Class C.
			x                       		RprServiceClassB - Match any RPR packet which specifies service Class B.
			x                       		RprServiceClassA1 - Match any RPR packet which specifies service Class A1.
			x                       		RprServiceClassA0 - Match any RPR packet which specifies service Class A0.
			x                       		RprWrapEligibility0 - Match any RPR packet which specifies Wrap Eligibility 0. (0 = Steerable only)
			x                       		RprWrapEligibility1 - Match any RPR packet which specifies Wrap Eligibility 1. (1 = Wrap Eligible)
			x                       		RprParityBit0 - Match any RPR packet which specifies Parity Bit 0.
			x                       		RprParityBit1 - Match any RPR packet which specifies Parity Bit 1.
			x                       		IpV6SAEthernetII - Match the IPv6 Source Address for an Ethernet II packet. (pattern represents the IPv6 source address)
			x                       		IpV6DAEthernetII - Match the IPv6 Destination Address for an Ethernet II packet. (pattern represents the IPv6 destination address)
			x                       		IpV6SA8023Snap - Match the IPv6 Source Address for an 802.3 packet. (pattern represents the IPv6 source address)
			x                       		IpV6DA8023Snap - Match the IPv6 Destination Address for an 802.3 packet. (pattern represents the IPv6 destination address)
			x                       		IpV6SAPos - Match the IPv6 Source Address for a POS packet. (pattern represents the IPv6 source address)
			x                       		IpV6DAPos - Match the IPv6 Destination Address for a POS packet. (pattern represents the IPv6 destination address)
			x                       		Ipv6TcpSourcePortEthernetII - Match the IPv6 TCP source port number for an Ethernet II 	packet. (pattern represents the source port)
			x                       		Ipv6TcpDestPortEthernetII - Match the IPv6 TCP destination port number for an Ethernet II packet. (pattern represents the destination port)
			x                       		Ipv6UdpSourcePortEthernetII - Match the IPv6 UDP source port number for an Ethernet II packet. (pattern represents the source port)
			x                       		Ipv6UdpDestPortEthernetII - Match the IPv6 UDP destination port number for an Ethernet II packet. (pattern represents the destination port)
			x                       		Ipv6TcpSourcePort8023Snap - Match the IPv6 TCP source port number for an 802.3 SNAP packet. (pattern represents the source port)
			x                       		Ipv6TcpDestPort8023Snap - Match the IPv6 TCP destination port number for an 802.3 Snap packet. (pattern represents the destination port)
			x                       		Ipv6UdpSourcePort8023Snap - Match the IPv6 UDP source port number for an 802.3 Snap packet. (pattern represents the source port)
			x                       		Ipv6UdpDestPort8023Snap - Match the IPv6 UDP destination port number for an 802.3 Snap packet. (pattern represents the destination port)
			x                       		Ipv6TcpSourcePortPos - Match the IPv6 TCP source port number for an pos packet. (pattern represents the source port)
			x                       		Ipv6TcpDestPortPos - Match the IPv6 TCP destination port number for an pos packet. (pattern represents the destination port)
			x                       		Ipv6UdpSourcePortPos - Match the IPv6 UDP source port number for an pos packet. (pattern represents the source port)
			x                       		Ipv6UdpDestPortPos - Match the IPv6 UDP destination port number for an pos packet. (pattern represents the destination port)
			x                       		Ipv6IpTcpSourcePortEthernetII - Match the TCP source port number for an IPv4 over IPv6 or IPv6 over IPv4 frame in an Ethernet II packet. (pattern represents the source port)
			x                       		Ipv6IpTcpDestPortEthernetII - Match the TCP destination port number for an IPv4 over IPv6 or IPv6 over IPv4 frame in an Ethernet II packet. (pattern represents the destination port)
			x                       		Ipv6IpUdpSourcePortEthernetII - Match the UDP source port number for an IPv4 over IPv6 or IPv6 over IPv4 frame in an Ethernet II packet. (pattern represents the source port)
			x                       		Ipv6IpUdpDestPortEthernetII - Match the UPD destination port number for an IPv4 over IPv6 or IPv6 over IPv4 frame in an Ethernet II packet. (pattern represents the destination port)
			x                       		Ipv6IpTcpSourcePort8023Snap - Match the TCP source port number for an IPv4 over IPv6 or IPv6 over IPv4 frame in an 802.3 Snap packet. (pattern represents the source port)
			x                       		Ipv6IpTcpDestPort8023Snap - Match the TCP destination port number for an IPv4 over IPv6 or IPv6 over IPv4 frame in an 802.3 Snap packet. (pattern represents the destination port)
			x                       		Ipv6IpUdpSourcePort8023Snap - Match the UDP source port number for an IPv4 over IPv6 or IPv6 over IPv4 frame in an 802.3 Snap packet. (pattern represents the source port)
			x                       		Ipv6IpUdpDestPort8023Snap - Match the UPD destination port number for an IPv4 over IPv6 or IPv6 over IPv4 frame in an 802.3 Snap packet. (pattern represents the destination port)
			x                       		Ipv6IpTcpSourcePortPos - Match the TCP source port number for an IPv4 over IPv6 or IPv6 over IPv4 frame in a POS packet. (pattern represents the source port)
			x                       		Ipv6IpTcpDestPortPos - Match the TCP destination port number for an IPv4 over IPv6 or IPv6 over IPv4 frame in a POS packet. (pattern represents the destination port)
			x                       		Ipv6IpUdpSourcePortPos - Match the UDP source port number for an IPv4 over IPv6 or IPv6 over IPv4 frame in a POS packet. (pattern represents the source port)
			x                       		Ipv6IpUdpDestPortPos - Match the UPD destination port number for an IPv4 over IPv6 or IPv6 over IPv4 frame in a POS packet. (pattern represents the destination port)
			x                       		IpOverIpv6IpSAEthernetII - Match the IPv4 source address in an IPv4 frame encapsulated in an IPv6 frame in an Ethernet II packet. (pattern represents the source IP address and pattern_mask will become the netmask for the IP address)
			x                       		IpOverIpv6IpDAEthernetII - Match the IPv4 destination address in an IPv4 frame encapsulated in an IPv6 frame in an Ethernet II packet. (pattern represents the destination IP address and pattern_mask will become the netmask for the IP address)
			x                       		IpOverIpv6IpSA8023Snap - Match the IPv4 source address in an IPv4 frame encapsulated in an IPv6 frame in an 802.3 Snap packet. (pattern represents the source IP address and pattern_mask will become the netmask for the IP address)
			x                       		IpOverIpv6IpDA8023Snap - Match the IPv4 destination address in an IPv4 frame encapsulated in an IPv6 frame in an 802.3 Snap packet. (pattern represents the destination IP address and pattern_mask will become the netmask for the IP address)
			x                       		IpOverIpv6IpSAPos - Match the IPv4 source address in an IPv4 frame encapsulated in an IPv6 frame in POS packet. (pattern represents the source IP address and pattern_mask will become the netmask for the IP address)
			x                       		IpOverIpv6IpDAPos - Match the IPv4 destination address in an IPv4 frame encapsulated in an IPv6 frame in POS packet. (pattern represents the destination IP address and pattern_mask will become the netmask for the IP address)
			x                       		Ipv6OverIpIpv6SAEthernetII - Match the IPv6 source address in an IPv6 frame encapsulated in an IPv4 frame in an Ethernet II packet. (pattern represents the IPv6 source address)
			x                       		Ipv6OverIpIpv6DAEthernetII - Match the IPv6 destination address in an IPv6 frame encapsulated in anIPv4 frame in an Ethernet II packet. (pattern represents the IPv6 destination address)
			x                       		Ipv6OverIpIpv6SA8023Snap - Match the IPv6 source address in an IPv6 frame encapsulated in an IPv4 frame in an 802.3 Snap packet. (pattern represents the IPv6 source address)
			x                       		Ipv6OverIpIpv6DA8023Snap - Match the IPv6 destination address in an IPv6 frame encapsulated in an IPv4 frame in an 802.3 Snap packet. (pattern represents the IPv6 destination address)
			x                       		Ipv6OverIpIpv6SAPos - Match the IPv6 source address in an IPv6 frame encapsulated in an IPv4 frame in POS packet. (pattern represents the IPv6 source address)
			x                       		Ipv6OverIpIpv6DAPos - Match the IPv6 destination address in an IPv6 frame encapsulated in an IPv4 frame in POS packet. (pattern represents the IPv6 destination address)
			x                       		Ipv6Ppp - Match an IPv6 PPP packet.
			x                       		Ipv6CiscoHdlc - Match an IPv6 packet encapsulated with Cisco HDLC.
			x                       		GfpDataFcsNullExtEthernet - Match a user data GFP frame which includes an FCS and whose payload uses a null extension and indicates frame-mapped ethernet data.
			x                       		GfpDataNoFcsNullExtEthernet - Match a user data GFP frame which does not includes an FCS and whose payload uses a null extension and indicates frame-mapped Ethernet data.
			x                       		GfpDataFcsLinearExtEthernet - Match a user data GFP frame which includes an FCS and whose payload uses a linear frame extension and indicates frame-mapped Ethernet data.
			x                       		GfpDataNoFcsLinearExtEthernet - Match a user data GFP frame which does not includes an FCS and whose payload uses a linear frame extension and indicates frame-mapped Ethernet data.
			x                       		GfpMgmtFcsNullExtEthernet - Match a management GFP frame which includes an FCS and whose payload uses a null extension and indicates frame-mapped Ethernet data.
			x                       		GfpMgmtNoFcsNullExtEthernet - Match a management GFP frame which does not includes an FCS and whose payload uses a null extension and indicates frame-mapped Ethernet data.
			x                       		GfpMgmtFcsLinearExtEthernet - Match a management GFP frame which includes an FCS and whose payload uses a linear frame extension and indicates frame-mapped Ethernet data.
			x                       		GfpMgmtNoFcsLinearExtEthernet - Match a management GFP frame which does not includes 	an FCS and whose payload uses a linear frame extension and indicates framemapped ethernet data.
			x                       		GfpDataFcsNullExtPpp - Match a user data GFP frame which includes an FCS and whose payload uses a null extension and indicates frame-mapped PPP data.
			x                       		GfpDataNoFcsNullExtPpp - Match a user data GFP frame which does not includes an FCS and whose payload uses a null extension and indicates frame-mapped PPP data.
			x                       		GfpDataFcsLinearExtPpp - Match a user data GFP frame which includes an FCS and whose payload uses a linear frame extension and indicates frame-mapped PPP data.
			x                       		GfpDataNoFcsLinearExtPpp - Match a user data GFP frame which does not includes an FCS and whose payload uses a linear frame extension and indicates frame-mapped PPP data.
			x                       		GfpMgmtFcsNullExtPpp - Match a management GFP frame which includes an FCS and whose payload uses a null extension and indicates frame-mapped PPP data.
			x                       		GfpMgmtNoFcsNullExtPpp - Match a management GFP frame which does not includes 	an FCS and whose payload uses a null extension and indicates frame-mapped PPP data.
			x                       		GfpMgmtFcsLinearExtPpp - Match a management GFP frame which includes an FCS and whose payload uses a linear frame extension and 	indicates frame-mapped PPP data.
			x                       		GfpMgmtNoFcsLinearExtPpp - Match a management GFP frame which does not includes an FCS and whose payload uses a linear frame extension and indicates framemapped PPP data.
			x               	-match_type2
			x                   		Supported with IxTclHal and IxTclNetwork. Match type for pattern2. The available match types are as in match_type1.
			x               	-pattern1
			x                   		Supported with IxTclHal and IxTclNetwork. Only frames that contain this pattern at offset pattern_offset1 are filtered, captured or counted. Must be provided as a HEX list less then 16 bytes (Example: {00 11 ff}).
			x               	-pattern2
			x                   		Supported with IxTclHal and IxTclNetwork. Only frames that contain this pattern at offset pattern_offset2 are filtered, captured or counted. Must be provided as a HEX list less then 16 bytes (Example: {00 22 ff aa dd ee aa dd aa dd ee ff ee 33 55 66}).
			x               	-pattern_atm
			x                   	-pattern_mask1
			x                       		Supported with IxTclHal and IxTclNetwork. A bit mask that allows the user to specify which bits of pattern1 should be used when filtering. If the mask bit is set low, the pattern bit will be used in the filter. Must be provided as a HEX list less then 16 bytes (Example: {00 00 ff}).
			x                   	-pattern_mask2
			x                       		Supported with IxTclHal and IxTclNetwork. A bit mask that allows the user to specify which bits of pattern2 should be used when filtering. If the mask bit is set high, the pattern bit will be used in the filter. Must be provided as a HEX list less then 16 bytes (Example: {00 ff ff}).
			x                   	-pattern_mask_atm
			x                       	-pattern_offset1
			x                           		Supported with IxTclHal and IxTclNetwork. Offset of pattern1 in the frame to be filtered, captured or counted.
			x                       	-pattern_offset2
			x                           		Supported with IxTclHal and IxTclNetwork. Offset of pattern2 in the frame to be filtered, captured or counted.
			x                       	-pattern_offset_type1
			x                           		Supported with IxTclHal and IxTclNetwork. For ports that support the portFeaturePatternOffsetFlexible feature, this option specifies the place where pattern_offset1 is relative.
			x                           		Valid choices are:
			x                               		startOfFrame - (default) Offset from the start of the frame.
			x                               		startOfIp - Offset from the start of the IP header.
			x                               		startOfProtocol - Offset from the start of the protocol within the IP header.
			x                               		startOfSonet - Offset from the start of the SONET frame. This choice is not supported with IxTclNetwork.
			x                       	-pattern_offset_type2
			x                           		Supported with IxTclHal and IxTclNetwork. For ports that support the portFeaturePatternOffsetFlexible feature, this option specifies the place where pattern_offset2 is relative. See pattern_offset
			x                       	-pattern_offset_atm
			x                           	-SA1
			x                               		Supported with IxTclHal and IxTclNetwork. Only frames that contain this source MAC address are filtered, captured or counted.
			x                           	-SA2
			x                               		Supported with IxTclHal and IxTclNetwork. Only frames that contain this source MAC address are filtered, captured or counted.
			x                           	-SA_mask1
			x                               		Supported with IxTclHal and IxTclNetwork. A bit mask that allows the user to specify which bits of the SA1 should be used when filtering. If the mask bit is set high, the pattern bit will be used in the filter.
			x                           	-SA_mask2
			x                               		Supported with IxTclHal and IxTclNetwork. A bit mask that allows the user to specify which bits of the SA2 should be used when filtering. If the mask bit is set high, the pattern bit will be used in the filter.
			x                           	-vpi
			x                               	-vpi_count
			x                                   	-vpi_step
			x                                       	-vci
			x                                           	-vci_count
			x                                               	-vci_step
			x                                                   	-no_write
		                                                   
		                                                   Return Values:
		                                                       $::SUCCESS | $::FAILURE
			                                                        key:status  value:$::SUCCESS | $::FAILURE
		                                                       If status is failure, detailed information provided.
			                                                        key:log     value:If status is failure, detailed information provided.
		                                                       List of handles with ATM patterns. These handles will be used in the ::<namespace>::packet_config_triggers
			                                                        key:handle  value:List of handles with ATM patterns. These handles will be used in the ::<namespace>::packet_config_triggers
		                                                   
		                                                   Examples:
		                                                       See files starting with Capture_ in the Samples subdirectory. See the Capture example in Appendix A, "Example APIs," for one specific example usage.
		                                                   
		                                                   Sample Input:
		                                                   
		                                                   Sample Output:
		                                                   
		                                                   Notes:
		                                                       When using ATM specific filters calling ::<namespace>::traffic_stats -mode add_atm_stats is mandatory
		                                                       When calling ::<namespace>::packet_config_filter a L1 reset will be triggered which will cause any protocol/traffic on that port to stop.
		                                                   
		                                                   See Also:
		                                                   
		"""
		return self._run_keyword("packet_config_filter", kwargs)

	def packet_config_triggers(self, **kwargs):
		""" Defines the triggers and filters for packet capturing. The values for the triggers and filters must be set with
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: packet_config_triggers
			 	-port_handle                        ANY
			x	[-handle                            ANY]
			x	[-mode                              ANY]
			x	[-async_trigger1                    ANY]
			x	[-async_trigger1_DA                 ANY]
			x	[-async_trigger1_error              ANY]
			x	[-async_trigger1_framesize          ANY]
			x	[-async_trigger1_framesize_from     ANY]
			x	[-async_trigger1_framesize_to       ANY]
			x	[-async_trigger1_pattern            ANY]
			x	[-async_trigger1_SA                 ANY]
			x	[-async_trigger2                    ANY]
			x	[-async_trigger2_DA                 ANY]
			x	[-async_trigger2_error              ANY]
			x	[-async_trigger2_framesize          ANY]
			x	[-async_trigger2_framesize_from     ANY]
			x	[-async_trigger2_framesize_to       ANY]
			x	[-async_trigger2_pattern            ANY]
			x	[-async_trigger2_SA                 ANY]
			x	[-capture_filter                    ANY]
			x	[-capture_filter_DA                 ANY]
			x	[-capture_filter_error              ANY]
			x	[-capture_filter_expression_string  ANY]
			x	[-capture_filter_framesize          ANY]
			x	[-capture_filter_framesize_from     ANY]
			x	[-capture_filter_framesize_to       ANY]
			x	[-capture_filter_pattern            ANY]
			x	[-capture_filter_SA                 ANY]
			x	[-capture_trigger                   ANY]
			x	[-capture_trigger_DA                ANY]
			x	[-capture_trigger_error             ANY]
			x	[-capture_trigger_expression_string ANY]
			x	[-capture_trigger_framesize         ANY]
			x	[-capture_trigger_framesize_from    ANY]
			x	[-capture_trigger_framesize_to      ANY]
			x	[-capture_trigger_pattern           ANY]
			x	[-capture_trigger_SA                ANY]
			x	[-uds1                              ANY]
			x	[-uds1_DA                           ANY]
			x	[-uds1_error                        ANY]
			x	[-uds1_framesize                    ANY]
			x	[-uds1_framesize_from               ANY]
			x	[-uds1_framesize_to                 ANY]
			x	[-uds1_pattern                      ANY]
			x	[-uds1_SA                           ANY]
			x	[-uds2                              ANY]
			x	[-uds2_DA                           ANY]
			x	[-uds2_error                        ANY]
			x	[-uds2_framesize                    ANY]
			x	[-uds2_framesize_from               ANY]
			x	[-uds2_framesize_to                 ANY]
			x	[-uds2_pattern                      ANY]
			x	[-uds2_SA                           ANY]
		
		Arguments:
			 	-port_handle
			 		Supported with IxTclHal and IxTclNetwork. Associates the command performed by action to the port handle listed. This parameter will be ignored when -mode is addAtmTrigger.
			x	-handle
			x	-mode
			x   		Supported with IxTclHal and IxTclNetwork (addAtmFilter choice is not valid with IxTclNetwork). When -mode is create, all the filters, triggers and counters (general and ATM specific) will be configured.When -mode is addAtmTrigger, only the ATM specific configurations will be taken into consideration. This is useful when different configurations are needed for some handles.
			x	-async_trigger1
			x   		Supported with IxTclHal and IxTclNetwork. Enables or disables User Defined Statistics counter 5 that counts the number of frames filtered. Async triggers can not be set when error type is other thanerrAnyFrame, errGoodFrame, errBadCRC, errBadFrame.
			x	-async_trigger1_DA
			x   		Supported with IxTclHal and IxTclNetwork. Enables or disables User Defined Statistics counter 5 to filter on the destination MAC addresses. The possible values are as in capture_filter_DA. When configuring UDS(1-6), only one of the six UDS slots can be configured for DA1, and DA2.
			x	-async_trigger1_error
			x   		Supported with IxTclHal and IxTclNetwork (not all choices supported for IxTclNetwork). Enables or disables the frame size constraint which specifies a range of frame sizes to filter for User Defined Statistics counter 5.
			x	-async_trigger1_framesize
			x   		Supported with IxTclHal and IxTclNetwork (not all choices supported for IxTclHal). Enables or disables the frame size constraint which specifies a
			x   		Valid choices are:
			x       		0 - Any framesize
			x       		1 - Custom framesize
			x       		jumbo - Valid only for IxTclNetwork
			x       		oversized - Valid only for IxTclNetwork
			x       		undersized - Valid only for IxTclNetwork
			x	-async_trigger1_framesize_from
			x   		Supported with IxTclHal and IxTclNetwork. The minimum range of the size of frame to be filtered for User Defined Statistics counter 5. Applicable only when async_trigger1_framesize is set to 1.
			x	-async_trigger1_framesize_to
			x   		Supported with IxTclHal and IxTclNetwork. The maximum range of the size of frame to be filtered for User Defined Statistics counter 5. Applicable only when async_trigger1_framesize is set to 1.
			x	-async_trigger1_pattern
			x   		Supported with IxTclHal and IxTclNetwork (not all choices supported for IxTclNetwork). Enables or disables User Defined Statistics counter 5 to filter on the pattern.
			x   		Valid choices are:
			x       		any - (default) disables the pattern filter constraint
			x       		pattern1 - sets the pattern filter constraint to trigger on frames with a pattern that matches pattern1 and patternMask1 at offset patternOffset1 as specified with ::<namespace>::packet_config_filter
			x       		notPattern1 - sets the pattern filter constraint to trigger on frames except those with a pattern that matches pattern1and patternMask1 at offset patternOffset1 as specified with ::<namespace>::packet_config_filter
			x       		pattern2 - sets the pattern filter constraint to trigger on frames with a pattern that matches pattern2 and patternMask2 at offset patternOffset2 as specified with ::<namespace>::packet_config_filter
			x       		notPattern2 - sets the pattern filter constraint to trigger on frames except those with a pattern that matches pattern2and patternMask2 at offset patternOffset2 as specified with ::<namespace>::packet_config_filter
			x       		pattern1and2 - not supported for IxTclNetwork. Sets the pattern filter constraint to trigger on frames with a pattern that matches pattern1, pattern2 and patternMask1, patternMask2 at offset patternOffset1 and patternOffset2 as specified with ::<namespace>::packet_config_filter
			x       		patternAtm - not supported for IxTclNetwork. -handle parameter is mandatory. The atm patterns in conjunctions with their vpi/vci pair will be extracted from the handle and set as filter criteria.
			x	-async_trigger1_SA
			x   		Supported with IxTclHal and IxTclNetwork. Enables or disables User Defined Statistics counter 5 to filter on the source MAC addresses.
			x	-async_trigger2
			x   		Supported with IxTclHal and IxTclNetwork. Enables or disables User Defined Statistics counter 6 that counts the number of frames filtered. Asynctriggers can not be set when error type is other thanerrAnyFrame, errGoodFrame,errBadCRC, errBadFrame.
			x	-async_trigger2_DA
			x   		Supported with IxTclHal and IxTclNetwork. Enables or disables User Defined Statistics counter 6 to filter on the destination MAC addresses. When configuring UDS(1-6), only one of the six UDS slots can be configured for DA1, and DA2.
			x	-async_trigger2_error
			x   		Supported with IxTclHal and IxTclNetwork (not all choices supported for IxTclNetwork). Enables or disables User Defined Statistics counter 6 filter on the errored frames.
			x	-async_trigger2_framesize
			x   		Supported with IxTclHal and IxTclNetwork (not all choices supported for IxTclHal). Enables or disables the frame size constraint which specifies a range of frame sizes to filter for User Defined Statistics counter 6.
			x	-async_trigger2_framesize_from
			x   		Supported with IxTclHal and IxTclNetwork. The minimum range of the size of frame to be filtered for User Defined Statistics counter 6. Applicable only when async_trigger2_framesize is set to 1.
			x	-async_trigger2_framesize_to
			x   		Supported with IxTclHal and IxTclNetwork. The maximum range of the size of frame to be filtered for User Defined Statistics counter 6. Applicable only when async_trigger2_framesize_enable is set to 1.
			x	-async_trigger2_pattern
			x   		Supported with IxTclHal and IxTclNetwork (not all choices supported for IxTclNetwork). Enables or disables User Defined Statistics counter 6 to filter on the pattern. Same choices as for async_trigger1_pattern.
			x	-async_trigger2_SA
			x   		Supported with IxTclHal and IxTclNetwork. Enables or disables User Defined Statistics counter 6 to filter on the source MAC addresses.
			x	-capture_filter
			x   		Supported with IxTclHal and IxTclNetwork. Enables or disables the capture filter.
			x	-capture_filter_DA
			x   		Supported with IxTclHal and IxTclNetwork. One of two available destination MAC addresses to filter on. Applicable only when capture_filter is set to 1.
			x   		Valid choices are:
			x       		any - (default) Disables the destination address filter constraint.
			x       		DA1 - Sets the destination address filter constraint to trigger on frames with a destination MAC 
address that matches DA1and DA1mask as specified with ::<namespace>::packet_config_filter.
			x       		notDA1 - Sets the destination address filter constraint to trigger on all frames except those with a destination MAC address that matches DA1 and DA1 mask as specified in the filter palette.
			x       		DA2 - Sets the destination address filter constraint to trigger on frames with a destination MAC address that matches DA2 and DA2 mask.
			x       		notDA2 - Sets the destination address filter constraint to trigger on all frames except those with a destination MAC address that matches DA2 and DA2 mask.
			x	-capture_filter_error
			x   		Supported with IxTclHal and IxTclNetwork (not all choices supported for IxTclNetwork). Applicable only when capture_filter is set to 1. Asynctriggers and uds1/uds2 can not be set when error type is other than errAnyFrame, errGoodFrame,errBadCRC, errBadFrame.
			x   		Valid choices are:
			x       		errAnyFrame-(default) Disables the error filter constraint.
			x       		errGoodFrame-Sets the error filter constraint to trigger when frames with no errors are received.
			x       		errBadCRC-Sets the error filter constraint to trigger when frames with bad CRC errors are received.
			x       		errBadFrame-Sets the error filter constraint to trigger when corrupted frames are received.
			x       		errAlign-Not supported with IxTclNetwork. Sets the error filter constraint to trigger when frames with alignment errors are received (10/100 only).
			x       		errDribble-Not supported with IxTclNetwork. Sets the error filter constraint to trigger when frames with dribble errors are received (10/100 only).
			x       		errBadCRCAlignDribble-Not supported with IxTclNetwork. Sets the error filter constraint to trigger when frames with bad CRC, alignment error or dribble errors are received (10/100 only).
			x       		errLineError-Not supported with IxTclNetwork. Sets the error filter constraint to trigger when frames with line errors are received (gigabit only).
			x       		errLineAndBadCRC-Not supported with IxTclNetwork. Sets the error filter constraint to trigger line errors and bad CRC are received (gigabit only).
			x       		errLineAndGoodCRC-Not supported with IxTclNetwork. Sets the error filter constraint to trigger when frames with line errors and bad CRC are received (gigabit only).
			x       		errUndersize-Not supported with IxTclNetwork. Sets the error filter constraint to trigger when undersized frames (less than 64 bytes) are received.
			x       		errOversize-Not supported with IxTclNetwork. Sets the error filter constraint to trigger when oversized frames (greater than 1518 bytes) are received.
			x       		errFragment-Not supported with IxTclNetwork. Sets the error filter constraint to trigger when fragmented frames are received.
			x       		errAnySequenceError-Sets the error filter constraint to trigger when any of the next three conditions are true.
			x       		errSmallSequenceError-Sets the error filter constraint to trigger when the current sequence number minus the previous sequence number is less than or equal to the error threshold and not negative, or when the current sequence number is equal to the previous sequence number.
			x       		errBigSequenceError-Sets the error filter constraint to trigger when the current sequence number minus the previous sequence number is greater than the error threshold.
			x       		errReverseSequenceError-Sets the error filter constraint to trigger when the current sequence number is less than the previous sequence number.
			x       		errDataIntegrityError-Sets the error filter constraint to trigger when any data integrity error is detected.
			x       		errGfpErrors-Not supported with IxTclNetwork. Sets the error filter constraint to trigger when any GFP error is detected. The particular errors that are used are controlled by options of the ::<namespace>::packet_config_filter.
			x       		errCdlErrors-Not supported with IxTclNetwork. Sets the error filter constraint to trigger when any CDL preamble error is detected.
			x       		errAnyIpTcpUdpChecksumError-Not supported with IxTclHal.
			x       		errInvalidFcoeFrame-Not supported with IxTclHal.
			x	-capture_filter_expression_string
			x   		Supported only with IxTclNetwork. String that is composed of SA1,DA1,P1,P2, optionally negated with ! and connected with operators 'and','or','xor','nand' or 'nor'.Eg: {DA1 and SA1 or !P1 and P2}.
			x	-capture_filter_framesize
			x   		Supported with IxTclHal and IxTclNetwork. Enables or disables the frame size constraint which specifies a range of frame sizes to filter.
			x	-capture_filter_framesize_from
			x   		Supported with IxTclHal and IxTclNetwork. Applicable only when capture_filter_framesize is 1. The minimum range of the size of frame to be filtered.
			x	-capture_filter_framesize_to
			x   		Supported with IxTclHal and IxTclNetwork. Applicable only when capture_filter_framesize is 1. The maximum range of the size of frame to be filtered.
			x	-capture_filter_pattern
			x   		Supported with IxTclHal and IxTclNetwork (not all choices supported for IxTclNetwork). Applicable only when capture_filter is set to 1.
			x   		Valid choices are:
			x       		any - (default) Disables the pattern filter constraint.
			x       		pattern1 - Sets the pattern filter constraint to trigger on frames with a pattern that matches pattern1 and patternMask1 at offset patternOffset1 as specified with ::<namespace>::packet_config_filter.
			x       		notPattern1 - Sets the pattern filter constraint to trigger on frames except those with a pattern that matches pattern1and patternMask1 at offset patternOffset1 as specified with ::<namespace>::packet_config_filter.
			x       		pattern2 - Sets the pattern filter constraint to trigger on frames with a pattern that matches pattern2 and patternMask2 at offset patternOffset2 as specified with ::<namespace>::packet_config_filter.
			x       		notPattern2 - Sets the pattern filter constraint to trigger on frames except those with a pattern that matches pattern2and patternMask2 at offset patternOffset2 as specified with ::<namespace>::packet_config_filter.
			x       		pattern1and2 - Sets the pattern filter constraint to trigger on frames with a pattern that matches pattern1, pattern2 and patternMask1, patternMask2 at offset patternOffset1 and patternOffset2 as specified with ::<namespace>::packet_config_filter.
			x       		patternAtm - Not supported with IxTclNetwork. -handle parameter is mandatory. The atm patterns in conjunctions with their vpi/vci pair will be extracted from the handle and set as filter criteria.
			x	-capture_filter_SA
			x   		Supported with IxTclHal and IxTclNetwork. One of two available source MAC addresses to filter on. Applicable only when capture_filter is set to 1.
			x   		Valid choices are:
			x       		any - (default) disables the source address filter constraint
			x       		SA1 - sets the source address filter constraint to trigger on frames with a source MAC address that matches SA1and SA1mask as specified specified with ::<namespace>::packet_config_filter
			x       		notSA1 - sets the source address filter constraint to trigger on all frames except those with a source MAC address that matches SA1 and SA1 mask
			x       		SA2 - sets the source address filter constraint to trigger on frames with a source MAC address that matches SA2 and SA2mask
			x       		notSA2 - sets the source address filter constraint to trigger on all frames except those with a source MAC address that matches SA2 and SA2 mask
			x	-capture_trigger
			x   		Supported with IxTclHal and IxTclNetwork. Enables or disables the capture trigger.
			x	-capture_trigger_DA
			x   		Supported with IxTclHal and IxTclNetwork. One of two available destination MAC addresses to filter on. Applicable only when capture_trigger is set to 1. The possible values are as in capture_filter_DA.
			x	-capture_trigger_error
			x   		Supported with IxTclHal and IxTclNetwork (not all choices supported for IxTclNetwork). Applicable only when capture_trigger is set to 1. The possible values are as in capture_filter_error.
			x	-capture_trigger_expression_string
			x   		Supported only with IxTclNetwork. String that is composed of SA1,DA1,P1,P2, optionally negated with ! and connected with operators 'and','or','xor','nand' or 'nor'.Eg: {DA1 and SA1 or !P1 and P2}.
			x	-capture_trigger_framesize
			x   		Supported with IxTclHal and IxTclNetwork. Enables or disables the frame size constraint which specifies a range of frame sizes to trigger.
			x	-capture_trigger_framesize_from
			x   		Supported with IxTclHal and IxTclNetwork. Applicable only when capture_trigger_framesize is enabled. The minimum range of the size of frame to be triggered.
			x	-capture_trigger_framesize_to
			x   		Supported with IxTclHal and IxTclNetwork. Applicable only when capture_trigger_framesize is enabled. The maximum range of the size of frame to be triggered.
			x	-capture_trigger_pattern
			x   		Supported with IxTclHal and IxTclNetwork (not all choices supported for IxTclNetwork). Applicable only when capture_trigger is set to 1. The possible values are as in capture_filter_pattern.
			x	-capture_trigger_SA
			x   		Supported with IxTclHal and IxTclNetwork. One of two available source MAC addresses to filter on. Applicable only when capture_trigger is set to 1. The possible values are as in capture_filter_SA.
			x	-uds1
			x   		Supported with IxTclHal and IxTclNetwork. Enables or disables the User Defined Statistics counter 1 that counts the number of frames filtered.
			x	-uds1_DA
			x   		Supported with IxTclHal and IxTclNetwork. One of two available destination MAC addresses to filter on. Applicable only when useDefinedStat1 is set to 1. The possible values are as in capture_filter_DA.
			x	-uds1_error
			x   		Supported with IxTclHal and IxTclNetwork (not all choices supported for IxTclNetwork). Applicable only when uds1 is set to 1. The possible values are as in capture_filter_error.
			x	-uds1_framesize
			x   		Supported with IxTclHal and IxTclNetwork. Enables or disables the frame size constraint which specifies a range of frame sizes to count.
			x	-uds1_framesize_from
			x   		Supported with IxTclHal and IxTclNetwork. Applicable only when uds1_framesize is set to 1. The minimum range of the size of frame to be counted.
			x	-uds1_framesize_to
			x   		Supported with IxTclHal and IxTclNetwork. Applicable only when uds1_framesize is set to 1. The maximum range of the size of frame to be counted.
			x	-uds1_pattern
			x   		Supported with IxTclHal and IxTclNetwork (not all choices supported for IxTclNetwork). Applicable only when uds1 is set to 1. The possible values are as in capture_filter_pattern. Same choices as for async_trigger1_pattern.
			x	-uds1_SA
			x   		Supported with IxTclHal and IxTclNetwork. One of two available source MAC addresses to filter on. Applicable only when uds1 is set to 1. The possible values are as in capture_filter_SA.
			x	-uds2
			x   		Supported with IxTclHal and IxTclNetwork. Enables or disables User Defined Statistics counter 2 that counts the number of frames filtered.
			x	-uds2_DA
			x   		Supported with IxTclHal and IxTclNetwork. One of two available destination MAC addresses to filter on. Applicable only when uds2 is set to 1. The possible values are as in capture_filter_DA.
			x	-uds2_error
			x   		Supported with IxTclHal and IxTclNetwork (not all choices supported for IxTclNetwork). Applicable only when uds2 is set to 1. The possible values are as in capture_filter_error.
			x	-uds2_framesize
			x   		Supported with IxTclHal and IxTclNetwork. Enables or disables the frame size constraint which specifies a range of frame sizes to count.
			x	-uds2_framesize_from
			x   		Supported with IxTclHal and IxTclNetwork. Applicable only when uds2_framesize is enabled. The minimum range of the size of frame to be counted.
			x	-uds2_framesize_to
			x   		Supported with IxTclHal and IxTclNetwork. Applicable only when uds2_framesize is enabled. The maximum range of the size of frame to be counted.
			x	-uds2_pattern
			x   		Supported with IxTclHal and IxTclNetwork (not all choices supported for IxTclNetwork). Applicable only when uds2 is set to 1. The possible values are as in capture_filter_pattern. Same choices as for async_trigger1_pattern.
			x	-uds2_SA
			x   		Supported with IxTclHal and IxTclNetwork. One of two available source MAC addresses to filter on. Applicable only when uds2 is set to 1. The possible values are as in capture_filter_SA.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		See files starting with Capture_ in the Samples subdirectory. See the Capture example in Appendix A, "Example APIs," for one specific example usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		When calling ::<namespace>::packet_config_triggers a L1 reset will be triggered which will cause any protocol/traffic on that port to stop.
		
		See Also:
		
		"""
		return self._run_keyword("packet_config_triggers", kwargs)

	def packet_control(self, **kwargs):
		""" Defines the beginning and end of packet capturing. The type of capturing performed is provided by the packet_config commands. If these commands have not be defined correctly, the capturing will not start and an error message will be returned. Fully supported with IxTclHal and IxTclNetwork.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: packet_control
			 	-port_handle  ANY
			x	-action       ANY
			x	-packet_type  ANY
		
		Arguments:
			 	-port_handle
			 		Associates the command performed by action to the port handle listed.
			x	-action
			x   		start - Closes in progres captures and starts packet capturing on the specified port_handle.
			x   		cumulative_start - Starts packet capturing on the specified port_handle. In progress captures remain started.
			x   		stop - Stops packet capturing.
			x   		reset - Resets the filters and triggers to the default values.
			x   		get_capture_buffer_state - Checks status of the capture buffer.
			x	-packet_type
			x   		both - (DEFAULT) Both control and data frames will be captured.
			x   		control - Only control frames will be captured.
			x   		data - Only data frames will be captured.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		0 | 1
			 key:stopped  value: 0 | 1
		If status is failure, detailed information provided.
			 key:log      value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("packet_control", kwargs)

	def packet_stats(self, **kwargs):
		""" Returns the information related to the packet capture. It is also required that each captured packet is returned with a timestamp per packet.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: packet_stats
			x	[-chunk_size           ANY]
			x	[-dirname              ANY]
			x	[-enable_ethernet_type ANY]
			x	[-enable_framesize     ANY]
			x	[-enable_pattern       ANY]
			x	[-ethernet_type        ANY]
			 	[-filename             ANY]
			 	[-format               CHOICES var cap enc txt none
			                        DEFAULT cap]
			x	[-frame_id_end         NUMERIC
			x                       DEFAULT 20]
			x	[-frame_id_start       NUMERIC
			x                       DEFAULT 1]
			x	[-framesize            ANY]
			x	[-packet_type          CHOICES data control both
			x                       DEFAULT both]
			x	[-pattern              ANY]
			x	[-pattern_offset       ANY]
			 	-port_handle           REGEXP ^[0-9]+/[0-9]+/[0-9]+$
			 	-stop                  CHOICES 0 1
		
		Arguments:
			x	-chunk_size
			x	-dirname
			x   		This parameter is used in conjunction with the -format parameter. When -format is cap it represents the directory in which the cap files will be saved.When -format is csv it represents the directory in which the csv files will be saved.Valid only for IxTclNetwork.
			x	-enable_ethernet_type
			x   	-enable_framesize
			x       	-enable_pattern
			x           	-ethernet_type
			                	-filename
			                    	-format
			                        		Specifies how the data is returned.
			                        		Valid choices are:
			                            		txt - IxTclHal: Returns the data in a text (.txt) file specified by parameter -filename. Aggregate stats keys are also returned.
Example: 
Frames 1 to 2 of 2
Frame,Time Stamp,DA,SA,Type/Length,Data,Frame Length,Status
1 00:00:24.47426236000 00 DE BB 00 0200 DE 01 07 03 0008 0045 00 00 2C 00 00 00 00 40 FF 5E D0 0C 01 01 01 0D 01 01 01 00 01 02 03 04 05 06 07 08 09 0A 0B 0C 0D DE AD BE EF 00 00 48 F0 61 42 5B 3D FF EA 62Bad Packet 0x0002
2 00:00:24.47430564000 00 DE BB 00 0200 DE 01 07 03 0008 0045 00 00 2D 00 00 00 00 40 FF 5E CF 0C 01 01 01 0D 01 01 01 00 01 02 03 04 05 06 07 08 09 0A 0B 0C 0D DE AD BE EF 00 00 00 48 F0 69 B6 18 71 D4 B263Bad Packet 0x0002
IxTclNetwork: The text file format is not supported. Aggregate stats keys are returned.
			                            		cap - IxTclHal (default): Returns the data in a .cap file specified by parameter -filename. Aggregate stats keys are also returned.
IxTclNetwork (default): Returns the data in .cap files (for both data and control captured packets) 
in the folder specified by the -dirname parameter. Aggregate stats keys are also returned.
			                            		enc - IxTclHal: Returns the data in binary format for use with NAI's Sniffer program. The file is specified by parameter -filename. Aggregate stats keys are also returned.
IxTclNetwork: The enc format is not supported. Aggregate stats keys are returned.
			                            		none - IxTclHal: Do not export capture buffer. Aggregate stats keys are returned.
IxTclNetwork: Do not export capture buffer. Aggregate stats keys are returned.
			                            		var - IxTclHal: Returns a keyed list (aggregate and frame stats). Can be used only if the capture buffer contains a number of frames less or equal than 20 frames. If thecapture buffer contains more than 20 frames, the first 20 frames from the capture are returned and a warning willbe displayed.IxTclNetwork: Returns a keyed list (aggregate and frame stats). Returns the frames that are between frame_id_start and frame_id_end. If the frame_id_start and frame_id_end are not given only the first 20 frames will be returned.
			                            		csv - IxTclHal: Not supported, an error will be returned.
IxTclNetwork: A csv file will be returned with the captured frames in the folder specified by the -dirname parameter. The keys data_file and control_file will be returned. These keys contain the names of the files csv files created.
Output example:
Field Id,Field Display Name,Field Value
Packet 0
Display Stack Name: Frame::ixNet::OBJ-/vport:2/capture/currentPacket/stack:"Frame$0"/field:"root$0/Frame$0/Frame is marked$0",Frame is marked,False
::ixNet::OBJ-/vport:2/capture/currentPacket/stack:"Frame$0"/field:"root$0/Frame$0/Arrival Time$1",Arrival Time,"Feb 28, 2013 14:41:10.817357000"
::ixNet::OBJ-/vport:2/capture/currentPacket/stack:"Frame$0"/field:"root$0/Frame$0/Time delta from previous packet$2",Time delta from previous packet,0.000000000
::ixNet::OBJ-/vport:2/capture/currentPacket/stack:"Frame$0"/field:"root$0/Frame$0/Time since reference or first frame$3",Time since reference or first frame,0.000000000
::ixNet::OBJ-/vport:2/capture/currentPacket/stack:"Frame$0"/field:"root$0/Frame$0/Frame Number$4",Frame Number,1
::ixNet::OBJ-/vport:2/capture/currentPacket/stack:"Frame$0"/field:"root$0/Frame$0/Frame length on the wire$5",Frame length on the wire,38
::ixNet::OBJ-/vport:2/capture/currentPacket/stack:"Frame$0"/field:"root$0/Frame$0/Frame length stored into the capture file$6",Frame length stored into the capture file,38
::ixNet::OBJ-/vport:2/capture/currentPacket/stack:"Frame$0"/field:"root$0/Frame$0/Protocols in frame$7",Protocols in frame,eth:ip:data
Display Stack Name: Ethernet
::ixNet::OBJ-/vport:2/capture/currentPacket/stack:"Ethernet$1"/field:"root$0/Ethernet$1/Destination$0",Destination,00:00:00:00:00:00
::ixNet::OBJ-/vport:2/capture/currentPacket/stack:"Ethernet$1"/field:"root$0/Ethernet$1/Source$1",Source,00:00:00:00:00:00
::ixNet::OBJ-/vport:2/capture/currentPacket/stack:"Ethernet$1"/field:"root$0/Ethernet$1/Source or Destination Address$2",Source or Destination Address,00:00:00:00:00:00
::ixNet::OBJ-/vport:2/capture/currentPacket/stack:"Ethernet$1"/field:"root$0/Ethernet$1/Source or Destination Address$3",Source or Destination Address,00:00:00:00:00:00
::ixNet::OBJ-/vport:2/capture/currentPacket/stack:"Ethernet$1"/field:"root$0/Ethernet$1/Type$4",Type,2048
::ixNet::OBJ-/vport:2/capture/currentPacket/stack:"Ethernet$1"/field:"root$0/Ethernet$1/Trailer$5",Trailer,1EB741F2
			x                   	-frame_id_end
			x                       		The number of the last frame that needs to be retrieved. The default value is 20. The value of this parameter must be greater than frame_id_start. This parameter is needed for -format 'var' and 'csv'. Valid only for IxTclNetwork.
			x                   	-frame_id_start
			x                       		The number of the first frame that needs to be retrieved. The default value is 1. The value of this parameter must be less than frame_id_end. This parameter is needed for -format 'var' and 'csv'. Valid only for IxTclNetwork.
			x                   	-framesize
			x                       	-packet_type
			x                           		Supported with IxTclNetwork. It is used to specify the types of frames that will be returned by the packet_stats procedure. Valid values are: data, control or both. The default value is both.
			x                       	-pattern
			x                           	-pattern_offset
			                                	-port_handle
			                                    		Supported with IxTclHal and IxTclNetwork. Associate the command performed by action to the port handle listed
			                                	-stop
			                                    		Supported with IxTclHal and IxTclNetwork. Stops capture when collecting statistics and downloading capture buffer.
		                           
		                           Return Values:
		                               $::SUCCESS | $::FAILURE
			                                key:status                                                        value:$::SUCCESS | $::FAILURE
		                               If status is failure, detailed information provided.
			                                key:log                                                           value:If status is failure, detailed information provided.
		                               Supported with IxTclHal and IxTclNetwork
			                                key:Aggregated Stats                                              value:Supported with IxTclHal and IxTclNetwork
		                               Number of frames counted by User Defined Statistics Counter 1 that meet the criteria set.
			                                key:<port_handle>.aggregate.uds1_frame_count                      value:Number of frames counted by User Defined Statistics Counter 1 that meet the criteria set.
		                               Number of frames counted by User Defined Statistics Counter 2 that meet the criteria set.
			                                key:<port_handle>.aggregate.uds2_frame_count                      value:Number of frames counted by User Defined Statistics Counter 2 that meet the criteria set.
		                               User-Defined Statistic counter 5 indicating number of frames received that meet the filtering criteria set.
			                                key:<port_handle>.aggregate.uds5_frame_count                      value:User-Defined Statistic counter 5 indicating number of frames received that meet the filtering criteria set.
		                               User-Defined Statistic counter 6 indicating number of frames received that meet the filtering criteria set.
			                                key:<port_handle>.aggregate.uds6_frame_count                      value:User-Defined Statistic counter 6 indicating number of frames received that meet the filtering criteria set.
		                               Supported with IxTclNetwork only
			                                key:Aggregated Stats                                              value:Supported with IxTclNetwork only
		                               The number of frames (or slices, a slice could contain a whole frame or a part of a frame) in the capture buffer.
			                                key:<port_handle>.aggregate.num_frames                            value:The number of frames (or slices, a slice could contain a whole frame or a part of a frame) in the capture buffer.
		                               The number of frames (or slices, a slice could contain a whole frame or a part of a frame) in the capture buffer.
			                                key:<port_handle>.aggregate.num_frames_data                       value:The number of frames (or slices, a slice could contain a whole frame or a part of a frame) in the capture buffer.
		                               The number of frames (or slices, a slice could contain a whole frame or a part of a frame) in the capture buffer.
			                                key:<port_handle>.aggregate.num_frames_control                    value:The number of frames (or slices, a slice could contain a whole frame or a part of a frame) in the capture buffer.
		                               Supported with IxTclHal only
			                                key:Aggregated Stats                                              value:Supported with IxTclHal only
		                               The average deviation of the average latencies.
			                                key:<port_handle>.aggregate.average_deviation                     value:The average deviation of the average latencies.
		                               The list of average deviation of the average latencies per chunk.
			                                key:<port_handle>.aggregate.average_deviation_per_chunk           value:The list of average deviation of the average latencies per chunk.
		                               The average latency.
			                                key:<port_handle>.aggregate.average_latency                       value:The average latency.
		                               The maximum frame latency.
			                                key:<port_handle>.aggregate.max_latency                           value:The maximum frame latency.
		                               The minimum frame latency.
			                                key:<port_handle>.aggregate.min_latency                           value:The minimum frame latency.
		                               The standard deviation of the average latencies.
			                                key:<port_handle>.aggregate.standard_deviation                    value:The standard deviation of the average latencies.
		                               The list of standard deviation of the average latencies per chunk.
			                                key:<port_handle>.aggregate.standard_deviation_per_chunk          value:The list of standard deviation of the average latencies per chunk.
		                               Supported with IxTclHal only
			                                key:Frame Stats                                                   value:Supported with IxTclHal only
		                               The frame identity record.
			                                key:<port_handle>.frame.<id>.fir                                  value:The frame identity record.
		                               The contents of the selected frame based on the sliceSize parameter.
			                                key:<port_handle>.frame.<id>.frame                                value:The contents of the selected frame based on the sliceSize parameter.
		                               The frame latency, calculated as the difference between the transmit time and receive time of the frame, in nanoseconds.
			                                key:<port_handle>.frame.<id>.latency                              value:The frame latency, calculated as the difference between the transmit time and receive time of the frame, in nanoseconds.
		                               The total length of the frame, regardless of the actual number of bytes in the capture buffer.
			                                key:<port_handle>.frame.<id>.length                               value:The total length of the frame, regardless of the actual number of bytes in the capture buffer.
		                               The status of the frame.
			                                key:<port_handle>.frame.<id>.status                               value:The status of the frame.
		                               capNoErrors 0x00 captured frame has no error
		                               capBadCrcGig 0x01 captured frame has a bad or missing CRC (gigabit only)
		                               capSymbolErrorsGig 0x02 captured frame has symbol error (gigabit only)
		                               capBadCrcAndSymbolGig	0x03 captured frame has a bad or missing CRC and symbol error (gigabit only)
		                               capUndersizeGig 0x04 captured frame is undersize (gigabit only)
		                               capBadCrcAndUndersizeGig 0x05 captured frame has a bad or missing CRC and is undersize (gigabit only)
		                               capBadCrcAndSymbolAndUndersizeGig 0x07 captured frame has a bad or missing CRC and is undersize (gigabit only)
		                               capOversizeGig 0x08 captured frame is oversize with a valid CRC (gigabit only)
		                               capBadCrc 0x41 captured frame has a bad or missing CRC
		                               capBadCrcAndSymbolError 0x43 captured frame has a bad or missing CRC and symbol error
		                               capUndersize 0x44 captured frame is undersize
		                               capFragment 0x45 captured frame is a fragment
		                               capOversize 0x48 captured frame is oversize with a valid CRC
		                               capOversizeAndBadCrc 0x49 captured frame is oversize with a bad or missing CRC
		                               capDribble 0x50 captured frame has a dribble error
		                               capAlignmentError 0x51 captured frame has alignment error (10/100 only)
		                               capAlignAndSymbolError 0x53 captured frame has alignment and symbol error
		                               capGoodFrame 0xC0 captured frame is a valid frame with no errors (default)
		                               capBadCrcAndGoodFrame 0xC1 captured frame has a bad or missing CRC but otherwise valid frame
		                               capErrorFrame 0xFF captured frame has a general error other than one of the specified errors in this list
		                               capOc48Trigger 0x40000000 A status bit that indicates that the captured packet includes the bit that caused the trigger. (OC48 cards only)
		                               capOc48GoodPacket 0x80000000 captured frame is valid with no errors (OC48 cards only)
		                               capOc48TruncatedPacket 0x80000001 captured frame is a truncated packet (OC48 cards only)
		                               capOc48IntegritySignatureMatch 0x80000008 captured frame's integrity signature matched (OC48 cards only)
		                               capOc48BadIntegrityCheck 0x80000010 captured frame failed data integrity validation (OC48 cards only)
		                               capOc48BadTCPUDPChecksum 0x80000020 captured frame has a bad TCP or UDP checksum (OC48 cards only)
		                               capOc48BadIPChecksum 0x80000040 captured frame is valid with no errors (OC48 cards only)
		                               capOc48BadCrc 0x80000080 captured frame is valid with no errors (OC48 cards only)
		                               cap10100DpmTrigger 0x40000000 A status bit that indicates that the captured packet includes the bit that caused the trigger. (10/100 TX and 10/100/1000 TXS cards only)
		                               cap10100DpmGoodPacket 0x80000000 captured frame is valid with no errors (10/100 TX and 10/100/1000 TXS cards only)
		                               cap10100DpmOversize 0x80000001 capture frame is oversized. (10/100 TX and 10/100/1000 TXS cards only)
		                               cap10100DpmUndersize 0x80000002 capture frame is undersized. (10/100 TX and 10/100/1000 TXS cards only)
		                               cap10100DpmIntegritySignatureMatch 0x80000008 captured frame's integrity signature matched (10/100 TX and 10/100/1000 TXS cards only)
		                               cap10100DpmBadIntegrityCheck 0x80000010 captured frame failed data integrity validation (10/100 TX and 10/100/1000 TXS cards only)
		                               cap10100DpmBadTCPUDPChecksum 0x80000020 captured frame has a bad TCP or UDP checksum (10/100 TX and 10/100/1000 TXS cards only)
		                               cap10100DpmBadIPChecksum 0x80000040 captured frame is valid with no errors (10/100 TX and 10/100/1000 TXS cards only)
		                               cap10100DpmBadCrc 0x80000080 captured frame is valid with no errors (10/100 TX and 10/100/1000 TXS cards only)
		                               capAtmEthernetBadCrc 0x80000080 Bad Ethernet CRC. (ATM and ATM/POS cards only)
		                               capAtmBadIPChecksum 0x80000040 Bad IP checksum. (ATM and ATM/POS cards only)
		                               capAtmBadTCPUDPChecksum 0x80000020 Bad TCP or UDP checksum. (ATM and ATM/POS cards only)
		                               capAtmBadIntegrityCheck 0x80000010 Bad Data Integrity. (ATM and ATM/POS cards only)
		                               capAtmIntegritySignatureMatch 0x80000008 Data integrity signature matched. (ATM and ATM/POS cards only)
		                               capAtmAal5BadCrc 0x80000004 Bad AAL5 CRC. (ATM and ATM/POS cards only)
		                               capAtmTimeout 0x80000002 ATM timeout. (ATM and ATM/POS cards only)
		                               capAtmOversize 0x80000001 ATM oversize packet. (ATM and ATM/POS cards only)
		                               capAtmGoodPacket 0x80000000 Good packet received. (ATM and ATM/POS cards only)
		                               capAtmTrigger 0x40000000 Data capture was triggered. (ATM and ATM/POS cards only)
		                               64-bit value. The arrival time of the captured frame in nanoseconds.
			                                key:<port_handle>.frame.<id>.time_stamp                           value:64-bit value. The arrival time of the captured frame in nanoseconds.
		                               Supported with IxTclNetwork only
			                                key:Frame Stats                                                   value:Supported with IxTclNetwork only
		                               The display_name of the field.
			                                key:<port_handle>.frame.<control|data>.<id>.<field>.display_name  value:The display_name of the field.
		                               The value for the field.
			                                key:<port_handle>.frame.<control|data>.<id>.<field>               value:The value for the field.
		                               The id for the first frame currently returned.
			                                key:<port_handle>.frame.<control|data>.frame_id_start             value:The id for the first frame currently returned.
		                               The id for the last frame currently returned.
			                                key:<port_handle>.frame.<control|data>.frame_id_end               value:The id for the last frame currently returned.
		                               Supported with IxTclNetwork only.
			                                key:Name of returned csv files                                    value:Supported with IxTclNetwork only.
		                               The name of the data file saved in the dirname directory.
			                                key:<port_handle>.data_file                                       value:The name of the data file saved in the dirname directory.
		                               The name of the control file saved in the dirname directory.
			                                key:<port_handle>.control_file                                    value:The name of the control file saved in the dirname directory.
		                           
		                           Examples:
		                           
		                           Sample Input:
		                           
		                           Sample Output:
		                           
		                           Notes:
		                           
		                           See Also:
		                           
		"""
		return self._run_keyword("packet_stats", kwargs)

	def pppox_config(self, **kwargs):
		""" This procedure configures PPPoA, PPPoEoA, PPPoE sessions for the specified test port. This command allows the user to configure a specified number of PPPoX sessions on the test port. Each port can have upto 32000 sessions.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: pppox_config
			x	[-port_role                                      CHOICES access network]
			 	[-handle                                         ANY]
			x	[-protocol_name                                  ALPHA]
			x	[-unlimited_redial_attempts                      CHOICES 0 1]
			x	[-enable_mru_negotiation                         CHOICES 0 1]
			x	[-desired_mru_rate                               NUMERIC]
			x	[-max_payload                                    NUMERIC]
			x	[-enable_max_payload                             CHOICES 0 1]
			x	[-client_ipv6_ncp_configuration                  CHOICES learned request
			x                                                 DEFAULT learned]
			x	[-client_ipv4_ncp_configuration                  CHOICES learned request
			x                                                 DEFAULT learned]
			x	[-server_ipv6_ncp_configuration                  CHOICES clientmay serveronly
			x                                                 DEFAULT clientmay]
			x	[-server_ipv4_ncp_configuration                  CHOICES clientmay serveronly
			x                                                 DEFAULT clientmay]
			x	[-lcp_enable_accm                                CHOICES 0 1]
			x	[-lcp_accm                                       ANY]
			 	[-num_sessions                                   RANGE 1-32000]
			 	[-ac_select_mode                                 CHOICES first_responding
			                                                  CHOICES ac_mac
			                                                  CHOICES ac_name
			                                                  DEFAULT first_responding]
			 	[-ac_match_name                                  ALPHA]
			 	[-ac_match_mac                                   ALPHA]
			 	[-auth_req_timeout                               RANGE 1-65535
			                                                  DEFAULT 5]
			 	[-config_req_timeout                             RANGE 1-120
			                                                  DEFAULT 5]
			 	[-echo_req                                       CHOICES 0 1
			                                                  DEFAULT 0]
			 	[-echo_rsp                                       CHOICES 0 1
			                                                  DEFAULT 1]
			 	[-ip_cp                                          CHOICES ipv4_cp ipv6_cp dual_stack
			                                                  DEFAULT ipv4_cp]
			 	[-ipcp_req_timeout                               RANGE 1-120
			                                                  DEFAULT 5]
			 	[-max_auth_req                                   RANGE 1-65535
			                                                  DEFAULT 10]
			 	[-max_padi_req                                   RANGE 1-65535
			                                                  DEFAULT 10]
			 	[-max_padr_req                                   RANGE 1-65535
			                                                  DEFAULT 10]
			 	[-max_terminate_req                              RANGE 0-65535
			                                                  DEFAULT 10]
			 	[-padi_req_timeout                               RANGE 1-65535
			                                                  DEFAULT 5]
			 	[-padr_req_timeout                               RANGE 1-65535
			                                                  DEFAULT 5]
			 	[-password                                       ALPHA]
			 	[-chap_secret                                    ALPHA]
			 	[-username                                       ALPHA]
			 	[-chap_name                                      ALPHA]
			 	[-vlan_id                                        RANGE 0-4095
			                                                  DEFAULT 1]
			 	[-vlan_id_count                                  RANGE 1-4094
			                                                  DEFAULT 4094]
			 	[-vlan_id_step                                   RANGE 0-4094
			                                                  DEFAULT 1]
			 	[-vlan_user_priority                             RANGE 0-7
			                                                  DEFAULT 0]
			x	[-vlan_user_priority_step                        RANGE 1-7
			x                                                 DEFAULT 1]
			 	[-vlan_user_priority_outer                       RANGE 0-7
			                                                  DEFAULT 0]
			 	-mode                                            CHOICES add remove modify
			 	[-auth_mode                                      CHOICES none pap chap pap_or_chap]
			 	[-echo_req_interval                              RANGE 1-3600]
			 	[-mac_addr                                       MAC]
			 	[-mac_addr_step                                  MAC
			                                                  DEFAULT 0000.0000.0001]
			 	[-max_configure_req                              RANGE 1-255]
			 	[-max_ipcp_req                                   RANGE 1-255]
			x	[-ac_name                                        ALPHA]
			x	[-actual_rate_downstream                         RANGE 1-65535]
			x	[-actual_rate_upstream                           RANGE 1-65535]
			x	[-agent_circuit_id                               ALPHA]
			x	[-agent_remote_id                                ALPHA]
			x	[-agent_access_aggregation_circuit_id            ALPHA]
			x	[-data_link                                      CHOICES atm_aal5 ethernet]
			x	[-enable_domain_group_map                        CHOICES 0 1]
			x	[-domain_group_map                               ALPHA]
			x	[-enable_client_signal_iwf                       CHOICES 0 1]
			x	[-enable_client_signal_loop_char                 CHOICES 0 1]
			x	[-enable_client_signal_loop_encap                CHOICES 0 1]
			x	[-enable_client_signal_loop_id                   CHOICES 0 1]
			x	[-enable_server_signal_iwf                       CHOICES 0 1]
			x	[-enable_server_signal_loop_char                 CHOICES 0 1]
			x	[-enable_server_signal_loop_encap                CHOICES 0 1]
			x	[-enable_server_signal_loop_id                   CHOICES 0 1]
			x	[-intermediate_agent                             CHOICES 0 1]
			x	[-intermediate_agent_encap1                      CHOICES na
			x                                                 CHOICES untagged_eth
			x                                                 CHOICES single_tagged_eth]
			x	[-intermediate_agent_encap2                      CHOICES na
			x                                                 CHOICES pppoa_llc
			x                                                 CHOICES pppoa_null
			x                                                 CHOICES ipoa_llc
			x                                                 CHOICES ipoa_null
			x                                                 CHOICES eth_aal5_llc_fcs
			x                                                 CHOICES eth_aal5_llc_no_fcs
			x                                                 CHOICES eth_aal5_null_fcs
			x                                                 CHOICES eth_aal5_null_no_fcs]
			x	[-ipv6_global_address_mode                       CHOICES icmpv6 dhcpv6_pd
			x                                                 DEFAULT icmpv6]
			x	[-ipv6_pool_prefix_len                           NUMERIC]
			x	[-ipv6_pool_prefix                               IPV6
			x                                                 DEFAULT 00 00 00 00 00 00 00 00]
			x	[-ipv6_pool_addr_prefix_len                      NUMERIC]
			x	[-ppp_local_iid                                  IPV6
			x                                                 DEFAULT 00 00 00 00 00 00 00 00]
			x	[-ppp_local_ip                                   IPV4
			x                                                 DEFAULT 2.2.2.2]
			x	[-ppp_local_ip_step                              IPV4
			x                                                 DEFAULT 0.0.0.1]
			x	[-ppp_local_iid_step                             NUMERIC]
			x	[-ppp_peer_iid                                   IPV6
			x                                                 DEFAULT 00 00 00 00 00 00 00 00]
			x	[-ppp_peer_iid_step                              NUMERIC]
			x	[-ppp_peer_ip                                    IPV4
			x                                                 DEFAULT 1.1.1.1]
			x	[-ppp_peer_ip_step                               IPV4]
			x	[-redial                                         CHOICES 0 1
			x                                                 DEFAULT 1]
			x	[-redial_max                                     RANGE 1-255
			x                                                 DEFAULT 20]
			x	[-redial_timeout                                 RANGE 1-65535
			x                                                 DEFAULT 10]
			x	[-service_name                                   ALPHA]
			x	[-service_type                                   CHOICES any name]
			x	[-send_dns_options                               CHOICES 0 1]
			x	[-dns_server_list                                ANY]
			x	[-client_dns_options                             CHOICES request_primary_and_secondary
			x                                                 CHOICES request_primary_only
			x                                                 CHOICES accept_addresses_from_server
			x                                                 CHOICES accept_only_primary_address_from_server
			x                                                 CHOICES disable_extension
			x                                                 DEFAULT disable_extension]
			x	[-client_dns_primary_address                     IPV4]
			x	[-client_dns_secondary_address                   IPV4]
			x	[-client_netmask_options                         CHOICES disable_extension
			x                                                 CHOICES request
			x                                                 CHOICES request_specific_netmask
			x                                                 CHOICES accept_netmask_from_server
			x                                                 DEFAULT disable_extension]
			x	[-client_netmask                                 IPV4]
			x	[-client_wins_options                            CHOICES disable_extension
			x                                                 CHOICES request_primaryonly_wins
			x                                                 CHOICES request_primaryandsecondary_wins
			x                                                 CHOICES accept_addresses_from_server
			x                                                 CHOICES accept_only_primary_address_from_server
			x                                                 DEFAULT disable_extension]
			x	[-client_wins_primary_address                    IPV4]
			x	[-client_wins_secondary_address                  IPV4]
			x	[-server_dns_options                             CHOICES accept_requested_addresses
			x                                                 CHOICES accept_only_requested_primary_address
			x                                                 CHOICES supply_primary_and_secondary
			x                                                 CHOICES supply_primary_only
			x                                                 CHOICES disable_extension
			x                                                 DEFAULT disable_extension]
			x	[-server_dns_primary_address                     IPV4]
			x	[-server_dns_secondary_address                   IPV4]
			x	[-server_netmask_options                         CHOICES disable_extension
			x                                                 CHOICES request
			x                                                 CHOICES accept_requested_netmask
			x                                                 CHOICES supply_netmask
			x                                                 DEFAULT disable_extension]
			x	[-server_netmask                                 IPV4]
			x	[-server_wins_options                            CHOICES disable_extension
			x                                                 CHOICES accept_requested_addresses
			x                                                 CHOICES accept_only_requested_primary_address
			x                                                 CHOICES supply_primary_and_secondary
			x                                                 CHOICES supply_primary_only
			x                                                 DEFAULT disable_extension]
			x	[-server_wins_primary_address                    IPV4]
			x	[-server_wins_secondary_address                  IPV4]
			x	[-ra_timeout                                     NUMERIC]
			x	[-create_interfaces                              CHOICES 0 1]
			 	[-attempt_rate                                   RANGE 1-1000
			                                                  DEFAULT 100]
			x	[-attempt_max_outstanding                        RANGE 1-1000]
			x	[-attempt_interval                               NUMERIC]
			x	[-attempt_enabled                                CHOICES 0 1]
			x	[-attempt_scale_mode                             CHOICES port device_group
			x                                                 DEFAULT port]
			 	[-disconnect_rate                                RANGE 1-1000
			                                                  DEFAULT 100]
			x	[-disconnect_max_outstanding                     RANGE 1-1000]
			x	[-disconnect_interval                            NUMERIC]
			x	[-disconnect_enabled                             CHOICES 0 1]
			x	[-disconnect_scale_mode                          CHOICES port device_group
			x                                                 DEFAULT port]
			x	[-enable_session_lifetime                        CHOICES 0 1]
			x	[-min_lifetime                                   NUMERIC]
			x	[-max_lifetime                                   NUMERIC]
			x	[-enable_session_lifetime_restart                CHOICES 0 1]
			x	[-max_session_lifetime_restarts                  NUMERIC]
			x	[-unlimited_session_lifetime_restarts            CHOICES 0 1]
			x	[-accept_any_auth_value                          CHOICES 0 1]
			 	[-port_handle                                    REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-protocol                                       CHOICES pppoe pppoeoa pppoa
			                                                  DEFAULT pppoe]
			 	[-vci                                            ANY]
			 	[-vci_step                                       ANY]
			 	[-vci_count                                      ANY]
			x	[-addr_count_per_vci                             ANY]
			 	[-vpi                                            ANY]
			 	[-vpi_step                                       ANY]
			 	[-vpi_count                                      ANY]
			x	[-addr_count_per_vpi                             ANY]
			 	[-pvc_incr_mode                                  ANY]
			 	[-encap                                          CHOICES ethernet_ii
			                                                  CHOICES ethernet_ii_vlan
			                                                  CHOICES ethernet_ii_qinq
			                                                  CHOICES vc_mux
			                                                  CHOICES vc_mux_routed
			                                                  CHOICES vc_mux_nofcs
			                                                  CHOICES llcsnap
			                                                  CHOICES llcsnap_routed
			                                                  CHOICES llcsnap_nofcs]
			x	[-address_per_vlan                               RANGE 1-1000000000
			x                                                 DEFAULT 1]
			x	[-address_per_svlan                              RANGE 1-1000000000
			x                                                 DEFAULT 1]
			 	[-qinq_incr_mode                                 CHOICES inner outer both
			                                                  DEFAULT both]
			 	[-vlan_id_outer                                  RANGE 0-4095
			                                                  DEFAULT 1]
			 	[-vlan_id_outer_count                            RANGE 1-4094
			                                                  DEFAULT 4094]
			 	[-vlan_id_outer_step                             RANGE 0-4094
			                                                  DEFAULT 1]
			n	[-vlan_user_priority_count                       ANY]
			 	[-password_wildcard                              CHOICES 0 1
			                                                  DEFAULT 0]
			 	[-username_wildcard                              CHOICES 0 1
			                                                  DEFAULT 0]
			 	[-wildcard_pound_start                           NUMERIC
			                                                  DEFAULT 0]
			 	[-wildcard_pound_end                             NUMERIC
			                                                  DEFAULT 0]
			 	[-wildcard_question_start                        NUMERIC
			                                                  DEFAULT 0]
			 	[-wildcard_question_end                          NUMERIC
			                                                  DEFAULT 0]
			 	[-ac_select_list                                 ANY]
			n	[-enable_throttling                              ANY]
			n	[-enable_setup_throttling                        ANY]
			n	[-enable_multicast                               ANY]
			 	[-local_magic                                    ANY]
			 	[-term_req_timeout                               ANY]
			x	[-lcp_max_failure                                NUMERIC]
			x	[-lcp_start_delay                                NUMERIC]
			 	[-max_outstanding                                RANGE 1-1000
			                                                  DEFAULT 1000]
			x	[-dhcpv6_hosts_enable                            CHOICES 0 1
			x                                                 DEFAULT 0]
			x	[-dhcp6_global_echo_ia_info                      CHOICES 0 1
			x                                                 DEFAULT 0]
			x	[-dhcp6_global_max_outstanding_releases          RANGE 1-100000
			x                                                 DEFAULT 500]
			x	[-dhcp6_global_max_outstanding_requests          RANGE 1-100000
			x                                                 DEFAULT 20]
			x	[-dhcp6_global_reb_max_rt                        RANGE 1-10000
			x                                                 DEFAULT 500]
			x	[-dhcp6_global_reb_timeout                       RANGE 1-100
			x                                                 DEFAULT 10]
			x	[-dhcp6_global_rel_max_rc                        RANGE 1-100
			x                                                 DEFAULT 5]
			x	[-dhcp6_global_rel_timeout                       RANGE 1-100
			x                                                 DEFAULT 1]
			x	[-dhcp6_global_ren_max_rt                        RANGE 1-10000
			x                                                 DEFAULT 600]
			x	[-dhcp6_global_ren_timeout                       RANGE 1-100
			x                                                 DEFAULT 10]
			x	[-dhcp6_global_req_max_rc                        RANGE 1-100
			x                                                 DEFAULT 10]
			x	[-dhcp6_global_req_max_rt                        RANGE 1-10000
			x                                                 DEFAULT 30]
			x	[-dhcp6_global_req_timeout                       RANGE 1-100
			x                                                 DEFAULT 1]
			x	[-dhcp6_global_setup_rate_initial                RANGE 1-10000
			x                                                 DEFAULT 10]
			x	[-dhcp6_global_setup_rate_increment              ANY]
			x	[-dhcp6_global_setup_rate_max                    ANY]
			x	[-dhcp6_global_sol_max_rc                        RANGE 1-100
			x                                                 DEFAULT 3]
			x	[-dhcp6_global_sol_max_rt                        RANGE 1-10000
			x                                                 DEFAULT 120]
			x	[-dhcp6_global_sol_timeout                       RANGE 1-100
			x                                                 DEFAULT 4]
			x	[-dhcp6_global_teardown_rate_initial             RANGE 1-10000
			x                                                 DEFAULT 50]
			x	[-dhcp6_global_teardown_rate_increment           ANY]
			x	[-dhcp6_global_teardown_rate_max                 ANY]
			x	[-dhcp6_global_wait_for_completion               ANY]
			x	[-dhcpv6pd_type                                  CHOICES client server
			x                                                 DEFAULT client]
			x	[-dhcp6_pd_client_range_duid_enterprise_id       RANGE 1-2147483647
			x                                                 DEFAULT 10]
			x	[-dhcp6_pd_client_range_duid_type                CHOICES duid_en duid_llt duid_ll
			x                                                 DEFAULT duid_llt]
			x	[-dhcp6_pd_client_range_duid_vendor_id           RANGE 1-2147483647
			x                                                 DEFAULT 10]
			x	[-dhcp6_pd_client_range_duid_vendor_id_increment RANGE 1-2147483647
			x                                                 DEFAULT 1]
			x	[-dhcp6_pd_client_range_ia_id                    RANGE 1-2147483647
			x                                                 DEFAULT 10]
			x	[-dhcp6_pd_client_range_ia_id_increment          RANGE 1-2147483647
			x                                                 DEFAULT 1]
			x	[-dhcp6_pd_client_range_ia_t1                    RANGE 0-2147483647
			x                                                 DEFAULT 302400]
			x	[-dhcp6_pd_client_range_ia_t2                    RANGE 0-2147483647
			x                                                 DEFAULT 483840]
			x	[-dhcp6_pd_client_range_ia_type                  CHOICES iapd iana iata iana_iapd
			x                                                 DEFAULT iapd]
			x	[-dhcp6_pd_client_range_param_request_list       ANY]
			x	[-dhcp6_pd_client_range_renew_timer              RANGE 0-1000000000
			x                                                 DEFAULT 0]
			x	[-dhcp6_pd_client_range_use_vendor_class_id      ANY]
			x	[-dhcp6_pd_client_range_vendor_class_id          ANY]
			x	[-dhcp6_pd_server_range_dns_domain_search_list   ANY]
			x	[-dhcp6_pd_server_range_first_dns_server         IP]
			x	[-dhcp6_pd_server_range_second_dns_server        IP]
			x	[-dhcp6_pd_server_range_subnet_prefix            NUMERIC]
			x	[-dhcp6_pd_server_range_start_pool_address       IP]
			x	[-dhcp6_pgdata_max_outstanding_requests          RANGE 1-100000
			x                                                 DEFAULT 20]
			x	[-dhcp6_pgdata_override_global_setup_rate        CHOICES 0 1
			x                                                 DEFAULT 0]
			x	[-dhcp6_pgdata_setup_rate_initial                RANGE 1-10000
			x                                                 DEFAULT 10]
			x	[-dhcp6_pgdata_setup_rate_increment              ANY]
			x	[-dhcp6_pgdata_setup_rate_max                    ANY]
			x	[-dhcp6_pgdata_max_outstanding_releases          RANGE 1-100000
			x                                                 DEFAULT 500]
			x	[-dhcp6_pgdata_override_global_teardown_rate     CHOICES 0 1
			x                                                 DEFAULT 0]
			x	[-dhcp6_pgdata_teardown_rate_initial             RANGE 1-10000
			x                                                 DEFAULT 50]
			x	[-dhcp6_pgdata_teardown_rate_increment           ANY]
			x	[-dhcp6_pgdata_teardown_rate_max                 ANY]
			x	[-hosts_range_ip_outer_prefix                    ANY]
			x	[-hosts_range_ip_prefix_addr                     ANY]
			x	[-hosts_range_count                              ANY]
			x	[-hosts_range_eui_increment                      ANY]
			x	[-hosts_range_first_eui                          ANY]
			x	[-hosts_range_ip_prefix                          ANY]
			x	[-hosts_range_subnet_count                       ANY]
			x	[-lease_time_max                                 ANY]
			x	[-lease_time                                     RANGE 300-30000000
			x                                                 DEFAULT 3600]
			x	[-padi_include_tag                               ANY]
			x	[-pado_include_tag                               ANY]
			x	[-padr_include_tag                               ANY]
			x	[-pads_include_tag                               ANY]
			n	[-re_connect_on_link_up                          ANY]
			n	[-group_ip_count                                 ANY]
			n	[-group_ip_step                                  ANY]
			n	[-start_group_ip                                 ANY]
			n	[-igmp_version                                   ANY]
			n	[-is_last_subport                                ANY]
			n	[-join_leaves_per_second                         ANY]
			n	[-l4_src_port                                    ANY]
			n	[-l4_dst_port                                    ANY]
			n	[-l4_flow_number                                 ANY]
			n	[-l4_flow_type                                   ANY]
			n	[-l4_flow_variant                                ANY]
			n	[-mc_enable_general_query                        ANY]
			n	[-mc_enable_group_specific_query                 ANY]
			n	[-mc_enable_immediate_response                   ANY]
			n	[-mc_enable_packing                              ANY]
			n	[-mc_enable_router_alert                         ANY]
			n	[-mc_enable_suppress_reports                     ANY]
			n	[-mc_enable_unsolicited                          ANY]
			n	[-mc_group_id                                    ANY]
			n	[-mc_report_frequency                            ANY]
			n	[-ppp_local_mode                                 ANY]
			n	[-ppp_peer_mode                                  ANY]
			n	[-enable_delete_config                           ANY]
			n	[-flap_repeat_count                              ANY]
			n	[-flap_rate                                      ANY]
			n	[-switch_duration                                ANY]
			n	[-watch_duration                                 ANY]
			n	[-hold_time                                      ANY]
			n	[-cool_off_time                                  ANY]
			n	[-dut_assigned_src_addr                          ANY]
			n	[-include_id                                     ANY]
			n	[-sessions_per_vc                                ANY]
			x	[-enable_host_uniq                               ANY]
			x	[-host_uniq_length                               ANY]
			x	[-host_uniq                                      ANY]
			x	[-multiplier                                     NUMERIC]
			x	[-dsl_type_tlv                                   CHOICES none
			x                                                 CHOICES adsl_1
			x                                                 CHOICES adsl_2
			x                                                 CHOICES adsl_2_p
			x                                                 CHOICES vdsl_1
			x                                                 CHOICES vdsl_2
			x                                                 CHOICES sdsl
			x                                                 CHOICES g_fast
			x                                                 CHOICES svvdsl
			x                                                 CHOICES sdsl_bonded
			x                                                 CHOICES vdsl_bonded
			x                                                 CHOICES g_fast_bonded
			x                                                 CHOICES svvdsl_bonded
			x                                                 CHOICES other
			x                                                 CHOICES userdefined]
			x	[-user_defined_dsl_type_tlv                      RANGE 0-4294967295
			x                                                 DEFAULT 50]
			x	[-enable_server_signal_dsl_type_tlv              CHOICES 0 1]
			x	[-pon_type_tlv                                   CHOICES none
			x                                                 CHOICES gpon
			x                                                 CHOICES xg_pon_1
			x                                                 CHOICES twdm_pon
			x                                                 CHOICES xgs_pon
			x                                                 CHOICES wdm_pon
			x                                                 CHOICES other
			x                                                 CHOICES userdefined]
			x	[-user_defined_pon_type_tlv                      RANGE 0-4294967295
			x                                                 DEFAULT 50]
			x	[-enable_server_signal_pon_type_tlv              CHOICES 0 1]
			x	[-enable_mrru_negotiation                        CHOICES 0 1]
			x	[-multilink_mrru_size                            RANGE 576-9000
			x                                                 DEFAULT 1492]
			x	[-mlppp_endpointdiscriminator_option             CHOICES 0 1]
			x	[-endpoint_discriminator_class                   CHOICES class_null
			x                                                 CHOICES class_ip_address
			x                                                 CHOICES class_mac_address]
			x	[-internet_protocol_address                      IPV4]
			x	[-mac_address                                    MAC]
		
		Arguments:
			x	-port_role
			x		The role of the port in the test: access or network.
			x		Valid choices are:
			x   		access - is PPPoX client
			x   		network - is PPPoX server
			 	-handle
			 		PPPoX handle of a configuration to be modified or removed.
			 		Dependencies: only available when IxNetwork is used for the PPPoX configuration.
			 		When -handle is provided with the /globals value the arguments that configure global protocol
			 		setting accept both multivalue handles and simple values.
			 		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
			 		that configure global settings will only accept simple values. In this situation, these arguments will
			 		configure only the settings of the parent device group or the ports associated with the parent topology.
			x	-protocol_name
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-unlimited_redial_attempts
			x		If checked, PPPoE unlimited redial attempts is enabled
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_mru_negotiation
			x		Enable MRU Negotiation
			x	-desired_mru_rate
			x		Max Transmit Unit for PPP
			x	-max_payload
			x		Max Payload. Valid only when enable_max_payload is enabled.
			x	-enable_max_payload
			x		Enables PPP Max Payload tag
			x	-client_ipv6_ncp_configuration
			x		Valid only when ip_cp is ipv6_cp or dual_stack
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		learned -
			x   		request -
			x	-client_ipv4_ncp_configuration
			x		Valid only when ip_cp is ipv4_cp or dual_stack
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		learned -
			x   		request -
			x	-server_ipv6_ncp_configuration
			x		Valid only when ip_cp is ipv6_cp or dual_stack
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		clientmay -
			x   		serveronly -
			x	-server_ipv4_ncp_configuration
			x		Valid only when ip_cp is ipv4_cp or dual_stack
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		clientmay -
			x   		serveronly -
			x	-lcp_enable_accm
			x		Enable Async-Control-Character-Map
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-lcp_accm
			x		Async-Control-Character-Map. Valid only when lcp_enable_accm is enabled.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-num_sessions
			 		The number of PPP sessions to configure.
			 		For PPP servers this will configure the number of sessions supprted by each server.
			 		For PPP clients this will configure the number of client sessions that are available.
			 	-ac_select_mode
			 		There are various ways AC can be selected based on the PADO
			 		received from AC.
			 		Valid choices are:
			    		first_responding - (DEFAULT)
			    		ac_mac - Specify the AC MAC Address and percentage pair using -ac_select_list.
			    		ac_name - Specify the AC Name and percentage pair using -ac_select_list option.
			 	-ac_match_name
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ac_match_mac
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-auth_req_timeout
			 		Specifies the timeout value in seconds for acknowledgement of an
			 		authentication Request.
			 	-config_req_timeout
			 		Specifies the timeout value in seconds for acknowledgement of a
			 		Configure Request or Terminate Request.
			 	-echo_req
			 		When set to 1, enables Echo Requests, when set to 0, disables Echo
			 		Requests.
			 	-echo_rsp
			 		This can be used to do negative testing. Dependencies: -mode add (when IxNetwork is used for the PPPoX configuration). Valid choices are:
			 		0 - Disable sending of the echo Responses.
			 		1 - (DEFAULT) Enable Echo Replies.
			 	-ip_cp
			    		ipv4_cp - IPv4 Control Protocol. When dhcpv6_hosts_enable is 1 a PPPoX IPv4
range will be created that can coexist with other ranges from the same
port created with dhcpv6_hosts_enable 1. An error will be issued if
dhcpv6_hosts_enable is 0 and other ranges created with dhcpv6_hosts_enable
1 exist on the same port.
			    		ipv6_cp - IPv6 Control Protocol. When dhcpv6_hosts_enable is 1 a DHCPv6 behind
PPP CPE range will be created. An error will be issued if
dhcpv6_hosts_enable is 0 and other ranges created with dhcpv6_hosts_enable
1 exist on the same port.
			    		dual_stack - Valid only when dhcpv6_hosts_enable is 1. A dual stack DHCPv6 behind
PPP CPE range will be created. An error will be issued if
other ranges created with dhcpv6_hosts_enable 0 exist on the same port.
			 	-ipcp_req_timeout
			 		Specifies the timeout value in seconds for acknowledgement of an
			 		IPCP configure request.
			 	-max_auth_req
			 		Specifies the maximum number of Authentication Requests that can be
			 		sent without getting an authentication response from the DUT.
			 	-max_padi_req
			 		Specifies the maximum number of PADI Requests that can be sent
			 		without getting a PADO from the DUT.
			 	-max_padr_req
			 		Specifies the maximum number of PADR Requests that can be sent
			 		without getting a PADS from the DUT.
			 	-max_terminate_req
			 		Specifies the maximum number of Terminate Requests that can be sent
			 		without acknowledgement.
			 	-padi_req_timeout
			 		Specifies the timeout value in seconds for acknowledgement of a
			 		PADI Request.
			 	-padr_req_timeout
			 		Specifies the timeout value in seconds for acknowledgement of a
			 		PADR Request.
			 	-password
			 		Password, PAP and CHAP only.
			 	-chap_secret
			 		Secret when CHAP Authentication is being used
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-username
			 		Username, PAP and CHAP only.
			 	-chap_name
			 		User name when CHAP Authentication is being used
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_id
			 		Starting VLAN ID, applies to PPPoE w/VLAN only.
			 	-vlan_id_count
			 		Number of VLAN IDs, applies to PPPoE w/VLAN only.
			 	-vlan_id_step
			 		Step value applied to VLAN ID, PPPoEoE w/VLAN only.
			 	-vlan_user_priority
			 		VLAN user priority, PPPoEoE w/VLAN only.
			x	-vlan_user_priority_step
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-vlan_user_priority_outer
			 		Outer VLAN user priority, PPPoEoE w/VLAN only.
			 	-mode
			 		Dependencies: only available when IxNetwork is used for the PPPoX configuration.
			 		Valid choices are:
			    		add - add a new PPPoX configuration
			    		remove - Remove an existing PPPoX configuration (specified by -handle)
			    		modify - modify an existing PPPoX configuration (specified by -handle)
			 	-auth_mode
			 		Authentication mode.
			 		Valid choices are:
			    		none - (DEFAULT)
			    		pap -
			    		chap -
			    		pap_or_chap - Accept both PAP and CHAP offered by DUT.
			 	-echo_req_interval
			 		Specifies the time interval in seconds for sending LCP echo
			 		requests. Valid only if -echo_req is set to 1.
			 		When using IxNetwork this parameter can take values from the 1-3600
			 		range.
			 	-mac_addr
			 		<aa.bb.cc.dd.ee.ff>
			 	-mac_addr_step
			 		<aa.bb.cc.dd.ee.ff>
			 		Dependencies: -mode add or modify (when IxNetwork is used for the PPPoX configuration).
			 	-max_configure_req
			 		Specifies the maximum number of LCP Configure Requests that can be sent
			 		without acknowledgement.
			 		When using IxNetwork this parameter can take values from the 1-255
			 		range.
			 	-max_ipcp_req
			 		Specifies the maximum number of IPCP configure requests that can be
			 		sent without getting an ack from the DUT.
			 		When using IxNetwork this parameter can take values from the 1-255
			 		range.
			x	-ac_name
			x		When the port is used as a server, this is the name sent in the
			x		PADO message.
			x	-actual_rate_downstream
			x		This parameter configures Access Loop Characteristics. For details
			x		refer to -enable_server_signal_loop_char.
			x		The actual downstream data rate (sub-option 0x81), in kbps.
			x		Available only when IxNetwork is used for PPPoX configurations.
			x		Dependencies: -intermediate_agent 1
			x	-actual_rate_upstream
			x		This parameter configures Access Loop Characteristics. For details
			x		refer to -enable_server_signal_loop_char.
			x		The actual upstream data rate (sub-option 0x82), in kbps
			x		Available only when IxNetwork is used for PPPoX configurations.
			x		Dependencies: -intermediate_agent 1
			x	-agent_circuit_id
			x		When intermediate_agent is true, the program inserts an Agent
			x		Circuit ID and an Agent Remote ID into PPPoE tags for each PPPoE
			x		session. These IDs serve to distinguish the CPE premises from
			x		each other. This field has a maximum length of 32 characters.The
			x		agent_circuit_id field is defined in strings of the form:
			x		%<start-width>:<count>:<repeat count>i.
			x	-agent_remote_id
			x		When intermediate_agent is true, the program inserts an Agent
			x		Circuit ID and an Agent Remote ID into PPPoE tags for each PPPoE
			x		session. These IDs serve to distinguish the CPE premises from
			x		each other. This field has a maximum length of 32 characters. The
			x		agentRemoteId field is defined in strings of the form:
			x		%<start-width>:<count>:<repeat count>i.
			x	-agent_access_aggregation_circuit_id
			x		When intermediate_agent is true, the program inserts an Agent
			x		Circuit ID and an Agent Remote ID and an Agent Access Aggregation Circuit ID into PPPoE tags for each PPPoE
			x		session. These IDs serve to distinguish the CPE premises from
			x		each other. This field has a maximum length of 32 characters.The
			x		agent_circuit_id field is defined in strings of the form:
			x		%<start-width>:<count>:<repeat count>i.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-data_link
			x		This parameter configures Signaling the Access Loop Encapsulation
			x		(sub-option 0x90), for details refer to -enable_server_signal_loop_encap.
			x		The PPPoE intermediate agent on the Access Node inserts the 0x90
			x		sub-option to signal to the BNG the data-link protocol on the Access Loop.
			x		Available only when IxNetwork is used for PPPoX configurations.
			x		Dependencies: -intermediate_agent 1
			x		Valid choices are:
			x   		atm_aal5 -
			x   		ethernet -
			x	-enable_domain_group_map
			x		This parameter configures the Interworking function (IWF). For details
			x		refer to -enable_server_signal_iwf.
			x		When enabled, the Access Node provides protocol translation between the
			x		ATM layer on the user side and the Ethernet layer on the network side.
			x		Available only when IxNetwork is used for PPPoX configurations.
			x		Dependencies: -intermediate_agent 1; -port_role access
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-domain_group_map
			x		List of domain group to LNS IP mapping.
			x		Each domain group can have thousands of domains.
			x		With the help of domain group it is very easy to map thousands of
			x		domains to one or more LNS IP addresses. Each domain group is defined
			x		as: { { domain_name } {lnsIP1 lnsIP2} }.
			x		Where domain_name is defined as:
			x		{name wc wc_start wc_end <wc_repeat >}
			x		name <string> : name to be used for the domain(s).
			x		wc {1|0} : enables wildcard substitution in the name field.
			x		wc_start <0-65535> : starting value for wildcard symbol for the name
			x		(%) substitution
			x		wc_end <0-65535> : ending value for wildcard symbol for the name
			x		(%) substitution
			x		lnsIP <a.b.c.d> : LNS IP address list to be used for this domain.
			x		Example: You want to set up 20 domains,
			x		out of which cisco1.com to cisco10.com going to 192.1.1.1 &amp;amp; 192.1.1.2
			x		and cisco11.com to cisco20.com going to 192.1.2.1. Also assume number
			x		of sessions per tunnel is 5. Your domain group list will look like:
			x		{ { {cisco%.com 1 1 10} {192.1.1.1 192.1.1.2} }
			x		{ {cisco%.com 1 11 20} {192.1.2.1} } }
			x		Tunnel Allocation will look like this:
			x		Sessions 1-5, tunnel1 dst 192.1.1.1;
			x		Sessions 5-10, tunnel2 dst 192.1.1.2;
			x		Sessions 11-15, tunnel3 dst 192.1.2.1;
			x		Sessions 16-20, tunnel4 dst 192.1.2.1.
			x	-enable_client_signal_iwf
			x		This parameter configures the Interworking function (IWF). For details
			x		refer to -enable_server_signal_iwf.
			x		When enabled, the Access Node provides protocol translation between the
			x		ATM layer on the user side and the Ethernet layer on the network side.
			x		Available only when IxNetwork is used for PPPoX configurations.
			x		Dependencies: -intermediate_agent 1; -port_role access
			x	-enable_client_signal_loop_char
			x		This parameter configures Access Loop Characteristics. For details
			x		refer to -enable_server_signal_loop_char.
			x		When this parameter is enabled, the discovery packets will include
			x		the 0x81 and 0x82 sub-options.
			x		Available only when IxNetwork is used for PPPoX configurations.
			x		Dependencies: -intermediate_agent 1; -port_role access
			x	-enable_client_signal_loop_encap
			x		This parameter configures Signaling the Access Loop Encapsulation
			x		(sub-option 0x90), for details refer to -enable_server_signal_loop_encap
			x		When this parameter is enabled, the discovery packets will include the
			x		0x90 sub-option.
			x		Available only when IxNetwork is used for PPPoX configurations.
			x		Dependencies: -intermediate_agent 1; -port_role access
			x	-enable_client_signal_loop_id
			x		When this parameter is 1, the discovery packets will include
			x		the -agent_circuit_id and -agent_remote_id options.
			x		Available only when IxNetwork is used for PPPoX configurations.
			x		Dependencies: -intermediate_agent 1; -port_role access
			x	-enable_server_signal_iwf
			x		This parameter configures the Interworking function (IWF) - When ATM
			x		is supported on the DSL line (the U interface), the Access Node must
			x		provide protocol translation between the ATM layer on the user side and
			x		the Ethernet layer on the network side.
			x		When enabled, the Access Node provides protocol translation between
			x		the ATM layer on the user side and the Ethernet layer on the network side.
			x		Available only when IxNetwork is used for PPPoX configurations.
			x		Dependencies: -intermediate_agent 1; -port_role network
			x	-enable_server_signal_loop_char
			x		This parameter configures Access Loop Characteristics - the Access Node
			x		reports the access loop sync rate and interleave delay to the
			x		Broadband Network Gateway (BNG). This allows the BNG to enable
			x		policy decisions and advanced QoS enforcement, while potentially
			x		taking full advantage of the data rate of a given access loop.
			x		When this parameter is enabled, the discovery packets will include
			x		the 0x81 and 0x82 sub-options.
			x		Available only when IxNetwork is used for PPPoX configurations.
			x		Dependencies: -intermediate_agent 1; -port_role network
			x	-enable_server_signal_loop_encap
			x		This parameter configures Signaling the Access Loop Encapsulation
			x		(sub-option 0x90): for access loop encapsulation the PPPoE intermediate
			x		agent inserts information in the PPPoE packets to signal to the BNG the
			x		data-link protocol and the encapsulation overhead on the Access Loop.
			x		For signaling of interworked sessions the Access Node must signal the
			x		BNG that a given PPPoE session is going to carry interworked PPPoA traffic.
			x		When this parameter is enabled, the discovery packets will include the
			x		0x90 sub-option.
			x		Available only when IxNetwork is used for PPPoX configurations.
			x		Dependencies: -intermediate_agent 1; -port_role network
			x	-enable_server_signal_loop_id
			x		When this parameter is 1, the discovery packets will include
			x		the -agent_circuit_id and -agent_remote_id options.
			x		Available only when IxNetwork is used for PPPoX configurations.
			x		Dependencies: -intermediate_agent 1; -port_role network
			x	-intermediate_agent
			x		Enables the Intermediate Agent feature. This feature allows for
			x		the testing of DSLAM/BRAS devices that translate from PPPoA
			x		traffic to PPPoE traffic. When this option is true, the program
			x		inserts agent_circuit_id and agent_remote_id values into PPPoE
			x		tags for each PPPoE session.
			x	-intermediate_agent_encap1
			x		This parameter configures Signaling the Access Loop Encapsulation
			x		(sub-option 0x90), for details refer to -enable_server_signal_loop_encap.
			x		The PPPoE intermediate agent on the Access Node inserts the 0x90
			x		sub-option to signal to the BNG the encapsulation overhead on the
			x		Access Loop.
			x		Available only when IxNetwork is used for PPPoX configurations.
			x		Dependencies: -intermediate_agent 1
			x		Valid choices are:
			x   		na -
			x   		untagged_eth -
			x   		single_tagged_eth -
			x	-intermediate_agent_encap2
			x		This parameter configures Signaling the Access Loop Encapsulation
			x		(sub-option 0x90), for details refer to -enable_server_signal_loop_encap.
			x		The PPPoE intermediate agent on the Access Node inserts the 0x90
			x		sub-option to signal to the BNG the encapsulation overhead on the
			x		Access Loop.
			x		Available only when IxNetwork is used for PPPoX configurations.
			x		Dependencies: -intermediate_agent 1
			x		Valid choices are:
			x   		na -
			x   		pppoa_llc -
			x   		pppoa_null -
			x   		ipoa_llc -
			x   		ipoa_null -
			x   		eth_aal5_llc_fcs -
			x   		eth_aal5_llc_no_fcs -
			x   		eth_aal5_null_fcs -
			x   		eth_aal5_null_no_fcs -
			x	-ipv6_global_address_mode
			x		Select the protocol used to set IPv6 global interfaces on PPP interfaces.
			x		This configuration applies at port level.
			x		Dependencies: Available starting with HLT API 3.90. Valid when port_role is
			x		'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x		Valid choices are:
			x   		icmpv6 - (DEFAULT) IPv6 global address is fetched like before ' using ICMPV4 RA/RS messages.
			x   		dhcpv6_pd - PPP plugin will trigger - for each session, after completing
the IPCPv6 phase ' the DHCPv6-PD port plugin to request a pool prefix
and DNS server list. the IPv6 pool prefix will be used for both PPP-IPv6
interface global address and the DHCPv6 hosts behind the CPE.
			x	-ipv6_pool_prefix_len
			x		Pool prefix length. The difference between the address and pool prefix
			x		lengths determine the size of the IPv6 IP pool
			x	-ipv6_pool_prefix
			x		Pool prefix length. The difference between the address and pool prefix
			x		lengths determine the size of the IPv6 IP pool
			x	-ipv6_pool_addr_prefix_len
			x		The IPv6 address prefix length.
			x	-ppp_local_iid
			x		The local base IPv6 interface ID.
			x	-ppp_local_ip
			x		The first address assigned on the local PPP node.
			x	-ppp_local_ip_step
			x		The value by which ppp_local_ip is incremented for each session.
			x	-ppp_local_iid_step
			x		Server IPv6CP interface identifier increment, used in conjuction with the base identifier
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ppp_peer_iid
			x		The peer base IPv6 interface ID.
			x	-ppp_peer_iid_step
			x		Client IPv6CP interface identifier increment, used in conjuction with the base identifier
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ppp_peer_ip
			x		The first address assigned on the peer PPP node.
			x	-ppp_peer_ip_step
			x		The value by which ppp_peer_ip is incremented for each session.
			x	-redial
			x		If true, enables access ports to redial at the PPPoE level.
			x	-redial_max
			x		The maximum number of redial attempts.
			x		When using IxNetwork this parameter can take values from the 1-255
			x		range.
			x	-redial_timeout
			x		The time to wait before restarting a session if the call was
			x		dropped, expressed in seconds.
			x		When using IxNetwork this parameter can take values from the 1-65535
			x		range.
			x	-service_name
			x		This string is used for matching of the PADO messages for the
			x		client. For server ports, this string is also sent by the server
			x		as the server name in the PADO message. Any string up to 32
			x		characters in length may be used.The string may contain text
			x		characters, plus a specification of the form:
			x		%[<start-width>:<modulo>:<repeat>]i
			x	-service_type
			x		The type of Access Concentrator matching that is desired.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		any - (DEFAULT) A service name is not required; a null service is sent
during Discovery indicating to the access concentrator that the service is not specified.
			x   		name - Allows a matching service name to be configured in the service_name option.
			x	-send_dns_options
			x		Enable RDNSS routing advertisments
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-dns_server_list
			x		DNS server list separacted by semicolon. Enabled just for IPv6 and send_dns_options.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-client_dns_options
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		request_primary_and_secondary -
			x   		request_primary_only -
			x   		accept_addresses_from_server -
			x   		accept_only_primary_address_from_server -
			x   		disable_extension -
			x	-client_dns_primary_address
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-client_dns_secondary_address
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-client_netmask_options
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		disable_extension -
			x   		request -
			x   		request_specific_netmask -
			x   		accept_netmask_from_server -
			x	-client_netmask
			x		Valid only when client_netmask_options is request_specific_netmask
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-client_wins_options
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		disable_extension -
			x   		request_primaryonly_wins -
			x   		request_primaryandsecondary_wins -
			x   		accept_addresses_from_server -
			x   		accept_only_primary_address_from_server -
			x	-client_wins_primary_address
			x		Valid only when client_wins_options is request_primaryonly_wins or accept_only_primary_address_from_server
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-client_wins_secondary_address
			x		Valid only when client_wins_options is request_primaryonly_wins
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-server_dns_options
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		accept_requested_addresses -
			x   		accept_only_requested_primary_address -
			x   		supply_primary_and_secondary -
			x   		supply_primary_only -
			x   		disable_extension -
			x	-server_dns_primary_address
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-server_dns_secondary_address
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-server_netmask_options
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		disable_extension -
			x   		request -
			x   		accept_requested_netmask -
			x   		supply_netmask -
			x	-server_netmask
			x		Valid only when server_netmask_options is supply_netmask
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-server_wins_options
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x   		disable_extension -
			x   		accept_requested_addresses -
			x   		accept_only_requested_primary_address -
			x   		supply_primary_and_secondary -
			x   		supply_primary_only -
			x	-server_wins_primary_address
			x		Valid when server_wins_options is supply_primary_and_secondary or supply_primary_only.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-server_wins_secondary_address
			x		Valid when server_wins_options is supply_primary_and_secondary.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ra_timeout
			x		Time to wait (in seconds) for Router Advertisment before NCP up. Valid only for port_role access.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-create_interfaces
			x		Enable echo request/reply. This command applies only for PPPv4 clients. Valid only for port_role access.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-attempt_rate
			 		Specifies the rate in attempts/second at which attempts are made to
			 		bring up sessions.
			 		When using IxNetwork this parameter can take values from the 1-1000 range.
			x	-attempt_max_outstanding
			x		The number of triggered instances of an action that is still awaiting a response or completion
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-attempt_interval
			x		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-attempt_enabled
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-attempt_scale_mode
			x		Indicates whether the control is specified per port or per device group.
			x		This setting is global for all the pppoxclient protocols configured in the ixncfg
			x		and can be configured just when handle is /globals (when the user wants to configure just the global settings)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		port -
			x   		device_group -
			 	-disconnect_rate
			 		Specifies the rate in disconnects/s at which sessions are
			 		disconnected. This parameter can take values from the 1-1000 range.
			x	-disconnect_max_outstanding
			x		The number of triggered instances of an action that is still awaiting a response or completion
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-disconnect_interval
			x		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-disconnect_enabled
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-disconnect_scale_mode
			x		Indicates whether the control is specified per port or per device group.
			x		This setting is global for all the pppoxclient protocols configured in the ixncfg
			x		and can be configured just when handle is /globals (when the user wants to configure just the global settings)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		port -
			x   		device_group -
			x	-enable_session_lifetime
			x		Enable session lifetime
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-min_lifetime
			x		Minimum session lifetime (in seconds)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-max_lifetime
			x		Maximum session lifetime (in seconds)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-enable_session_lifetime_restart
			x		Enable automatic session restart after stop at lifetime expiry
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-max_session_lifetime_restarts
			x		Maximum number of times each session is automatically restarted
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-unlimited_session_lifetime_restarts
			x		Allow each session to always be automatically restarted
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-accept_any_auth_value
			x		Configures a PAP/CHAP authenticator to accept all offered usernames, passwords, and base domain names
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-port_handle
			 		The port on which the PPPoX sessions is to be created.
			 		Dependencies: -mode add (when IxNetwork is used for the
			 		PPPoX configuration).
			 	-protocol
			 		Type of sessions to be configured.Valid options are:
			 		pppoa
			 		pppoeoa
			 		pppoe
			 		Only the pppoe options is supported.
			 		Valid choices are:
			    		pppoe -
			    		pppoeoa -
			    		pppoa -
			 	-vci
			 		Starting VCI for PPPoA and PPPoEoA.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vci_step
			 		Step value applied to VCI, PPPoA, and PPPoEoA only.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vci_count
			 		Number of VCIs.When using IxNetwork this parameter can take values from the 1-65504 range.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-addr_count_per_vci
			x		VCI value. When this number is reached, an increment operation is initiated.This parameter is valid only when using IxTclNetwork API.Valid values: 1 - 65535.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-vpi
			 		Starting VPI for PPPoA and PPPoEoA.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vpi_step
			 		Step value applied to VPI, PPPoA and PPPoEoA only.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-vpi_count
			 		Number of VPIs.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-addr_count_per_vpi
			x		VPI value. 	When this number is reached, an increment operation is initiated. This parameter is valid only when using IxTclNetwork API.Valid values: 1- 65535.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			 	-pvc_incr_mode
			 		vpi - increment VPI first then VCI (all based on the info configured)vci - (DEFAULT) increment first VCI then VPIboth - increment both VPI and VCI at the same time
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-encap
			 		Encapsulation type for session.
			 		Dependencies: -mode add (when IxNetwork is used for the
			 		PPPoX configuration) and -protocol.
			 		Valid choices are:
			    		ethernet_ii - Ethernet (valid for -protocol pppoe)
			    		ethernet_ii_vlan - Ethernet with VLAN (valid for -protocol pppoe)
			    		ethernet_ii_qinq - Ethernet with stacked VLAN (valid for -protocol pppoe)
			    		vc_mux - VC Mux Bridged Ethernet (FCS) (valid for -protocol pppoeoa)
			    		vc_mux_routed - VC Mux IPv4/IPv6 Routed (valid for -protocol pppoa)
			    		vc_mux_nofcs - VC Mux Bridged Ethernet (no FCS) (valid for -protocol pppoeoa)
			    		llcsnap - LLC Bridged Ethernet (FCS) (valid for -protocol pppoeoa)
			    		llcsnap_routed - LLC Routed AAL5 Snap (valid for -protocol pppoa)
			    		llcsnap_nofcs - LLC Bridged Ethernet (no FCS) (valid for -protocol pppoeoa)
			x	-address_per_vlan
			x		How often a new outer VLAN ID is generated. For example, a value of 10
			x		will cause a new VLAN ID to be used in blocks of 10 IP addresses.
			x	-address_per_svlan
			x		How often a new inner VLAN ID is generated. For example, a value of 10
			x		will cause a new VLAN ID to be used in blocks of 10 IP addresses.
			 	-qinq_incr_mode
			    		inner - Increment the inner VLAN ID. Based on the
vlan_id parameter first then increment the outer vlan_id_outer parameters next.
			    		outer - Increment the outer first then inner.
			    		both - (DEFAULT) Increment both inner and outer at the same time.
			 	-vlan_id_outer
			 		Starting outer VLAN ID, applies to PPPoE w/Stacked VLAN only.
			 	-vlan_id_outer_count
			 		Number of outer VLAN IDs, applies to PPPoE w/Stacked VLAN only.
			 	-vlan_id_outer_step
			 		Step value applied to outer VLAN ID, PPPoEoE w/Stacked VLAN only.
			n	-vlan_user_priority_count
			 	-password_wildcard
			    		Enables wildcard substituation in the password field.
			    		Notes: If mode is modify, all the wildcard parameters (password
			    		username_wildcard password_wildcard wildcard_pound_start
			    		wildcard_pound_end wildcard_question_start wildcard_question_end)
			    		must be reconfigured. Otherwise invalid configurations may result.
			 	-username_wildcard
			    		Enables wildcard substitution in the username field.
			    		Notes: If mode is modify, all the wildcard parameters (username
			    		username_wildcard password_wildcard wildcard_pound_start
			    		wildcard_pound_end wildcard_question_start wildcard_question_end)
			    		must be reconfigured. Otherwise invalid configurations may result.
			 	-wildcard_pound_start
			    		Starting value for wildcard symbol 1 (\) substitution. It is also
			    		valid to useas the substitution symbol.
			    		Enables wildcard substitution in the username field.
			    		Notes: If mode is modify, all the wildcard parameters (username
			    		username_wildcard password_wildcard wildcard_pound_start
			    		wildcard_pound_end wildcard_question_start wildcard_question_end)
			    		must be reconfigured. Otherwise invalid configurations may result.
			    		This parameter can be provided in various formats. For example, the
			    		number 2 can be provided as follows: 2, 02, 002, 0002, 00002.
			 	-wildcard_pound_end
			    		Ending value for wildcard symbol 1 (\) substitution. It is also valid
			    		to useas the substitution symbol.
			    		Enables wildcard substitution in the username field.
			    		Notes: If mode is modify, all the wildcard parameters (username
			    		username_wildcard password_wildcard wildcard_pound_start
			    		wildcard_pound_end wildcard_question_start wildcard_question_end)
			    		must be reconfigured. Otherwise invalid configurations may result.
			    		This parameter can be provided in various formats. For example, the
			    		number 2 can be provided as follows: 2, 02, 002, 0002, 00002.
			    		It must be the same format as for wildcard_pound_start.
			 	-wildcard_question_start
			    		Starting value for wildcard symbol 2 (?) substitution.
			    		Enables wildcard substitution in the username field.
			    		Notes: If mode is modify, all the wildcard parameters (username
			    		username_wildcard password_wildcard wildcard_pound_start
			    		wildcard_pound_end wildcard_question_start wildcard_question_end)
			    		must be reconfigured. Otherwise invalid configurations may result.
			    		This parameter can be provided in various formats. For example, the
			    		number 2 can be provided as follows: 2, 02, 002, 0002, 00002.
			 	-wildcard_question_end
			    		Ending value for wildcard symbol 2 (?) substitution.
			    		Enables wildcard substitution in the username field.
			    		Notes: If mode is modify, all the wildcard parameters (username
			    		username_wildcard password_wildcard wildcard_pound_start
			    		wildcard_pound_end wildcard_question_start wildcard_question_end)
			    		must be reconfigured. Otherwise invalid configurations may result.
			    		This parameter can be provided in various formats. For example, the
			    		number 2 can be provided as follows: 2, 02, 002, 0002, 00002.
			    		It must be the same format as for wildcard_question_start.
			 	-ac_select_list
			    		This option is used in case ac_select_mode is chosen as ac_mac or.
			    		ac_name. It specifies the AC MAC address and percentage pair as list:
			    		{00:11:00:00:00:11|50 00:11:00:00:00:12|50} or
			    		[list 00:11:00:00:00:11|50 00:11:00:00:00:12|50]
			    		or it specifies the ac name and percentage pair as list:
			    		{ciscoAC1|60 ciscoAC2|40} or [list ciscoAC1|60 ciscoAC2|40]
			n	-enable_throttling
			n   	-enable_setup_throttling
			n       	-enable_multicast
			            	-local_magic
			                		0 - Enable negotiaton of magic numbers.1 - (DEFAULT) Disable negotiation of magic numbers.
			                		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			            	-term_req_timeout
			                		Specifies the timeout value in seconds for acknowledgement of a Terminate Request.
			                		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x           	-lcp_max_failure
			x               		Number of Configure-Nak packets received before abandon link setup
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x           	-lcp_start_delay
			x               		Delay time in milliseconds to wait before sending LCP Config packet
			x               		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			            	-max_outstanding
			                		Specifies the maximum number of sessions in progress, which
			                		includes the sessions in the process of either coming up or
			                		disconnecting, at one time.
			                		When using IxNetwork this parameter can take values from the 1-1000
			                		range.
			x           	-dhcpv6_hosts_enable
			x               		Valid choices are:
			x               		0 ' Configure standard PPPoE
			x               		1 ' Enable using DHCPv6 hosts behind PPP CPE feature.
			x               		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x               		is 'access' and 'mode is 'create'. Configurations created with 'dhcpv6_hosts_enable '0'
			x               		cannot coexist on the same port with ranges created with 'dhcpv6_hosts_enable 1.
			x           	-dhcp6_global_echo_ia_info
			x               		If 1 the DHCPv6 client will request the exact address as advertised by the server.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x               		Valid choices are:
			x               		0 - (DEFAULT) Disabled
			x               		1 - Enabled
			x           	-dhcp6_global_max_outstanding_releases
			x               		The maximum number of requests to be sent by all DHCP clients during session
			x               		teardown.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_max_outstanding_requests
			x               		The maximum number of requests to be sent by all DHCP clients during session
			x               		startup.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_reb_max_rt
			x               		RFC 3315 max rebind timeout value in seconds.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_reb_timeout
			x               		RFC 3315 initial rebind timeout value in seconds.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_rel_max_rc
			x               		RFC 3315 release attempts.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_rel_timeout
			x               		RFC 3315 initial release timeout in seconds.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_ren_max_rt
			x               		RFC 3315 max renew timeout in secons.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_ren_timeout
			x               		RFC 3315 initial renew timeout in secons.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_req_max_rc
			x               		RFC 3315 max request retry attempts.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_req_max_rt
			x               		RFC 3315 max request timeout value in secons.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_req_timeout
			x               		RFC 3315 initial request timeout value in secons.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_setup_rate_initial
			x               		Setup rate is the number of clients to start in each second. This value
			x               		represents the initial value for setup rate.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_setup_rate_increment
			x               		This value represents the increment value for setup rate. This value is applied every second and can be negative. This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-dhcp6_global_setup_rate_max
			x               		This value represents the final value for setup rate. The setup rate will not change after this value is reached. This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-dhcp6_global_sol_max_rc
			x               		RFC 3315 max solicit retry attempts.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_sol_max_rt
			x               		RFC 3315 max solicit timeout value in seconds.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_sol_timeout
			x               		RFC 3315 initial solicit timeout value in seconds.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_teardown_rate_initial
			x               		Setup rate is the number of clients to stop in each second. This value
			x               		represents the initial value for teardown rate.
			x               		This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_global_teardown_rate_increment
			x               		This value represents the increment value for teardown rate. This value is applied every second and can be negative. This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-dhcp6_global_teardown_rate_max
			x               		This value represents the final value for teardown rate. The teardown rate will not change after this value is reached. This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-dhcp6_global_wait_for_completion
			x               		This parameter applies globally for all the ports in the configuration. Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x               		Valid choices are:
			x                   		0 - (DEFAULT) Disabled
			x                   		1 - Enabled
			x           	-dhcpv6pd_type
			x                   		client - DHCPv6PDoPPPServer
			x                   		server - DHCPv6PDoPPPClient
			x           	-dhcp6_pd_client_range_duid_enterprise_id
			x               		Define the vendor's registered Private Enterprise Number as maintained by IANA.
			x               		Available starting with HLT API 3.90. Valid when port_role is 'access';
			x               		dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack';
			x               		dhcp6_pd_client_range_duid_type is 'duid_en'.
			x           	-dhcp6_pd_client_range_duid_type
			x               		Define the DHCP unique identifier type.
			x               		Available starting with HLT API 3.90. Valid when port_role is 'access';
			x               		dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x               		Valid choices are:
			x                   		duid_en - duid_en
			x                   		duid_llt - (DEFAULT) duid_llt
			x                   		duid_ll - duid_ll
			x           	-dhcp6_pd_client_range_duid_vendor_id
			x               		Define the vendor-assigned unique ID for this range. This ID is incremented
			x               		automatically for each DHCP client.
			x               		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x               		is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or
			x               		'dual_stack'; dhcp6_pd_client_range_duid_type is 'duid_en'.
			x           	-dhcp6_pd_client_range_duid_vendor_id_increment
			x               		Define the step to increment the vendor ID for each DHCP client.
			x               		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x               		is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack';
			x               		dhcp6_pd_client_range_duid_type is 'duid_en'.
			x           	-dhcp6_pd_client_range_ia_id
			x               		Define the identity association unique ID for this range. This ID is incremented
			x               		automatically for each DHCP client.
			x               		Dependencies: Available starting with HLT API 3.90. Valid when port_role is '
			x               		access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_pd_client_range_ia_id_increment
			x               		Define the step used to increment dhcp6_pd_client_range_ia_id for each
			x               		DHCP client.
			x               		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x               		is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_pd_client_range_ia_t1
			x               		Define the suggested time at which the client contacts the server from which
			x               		the addresses were obtained to extend the lifetimes of the addresses assigned.
			x               		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x               		is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_pd_client_range_ia_t2
			x               		Define the suggested time at which the client contacts any available
			x               		server to extend the lifetimes of the addresses assigned.
			x               		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x               		is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_pd_client_range_ia_type
			x               		Define Identity Association Type.
			x               		Valid choices are:IAPD, IANA, IATA, IANA_IAPD
			x               		Dependencies: Available starting with HLT API 3.90. Valid when port_role is
			x               		'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x               		Valid choices are:
			x                   		iapd -
			x                   		iana -
			x                   		iata -
			x                   		iana_iapd -
			x           	-dhcp6_pd_client_range_param_request_list
			x               		Accepts list of values. Define the list of options in a message between a client and a server. (DEFAULT = {2 7 23 24})Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-dhcp6_pd_client_range_renew_timer
			x               		Define the user-defined lease renewal timer. The value is estimated in seconds
			x               		and will override the lease renewal timer if it is not zero and is smaller than the server-defined value.
			x               		Dependencies: Available starting with HLT API 3.90. Valid when port_role is
			x               		'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_pd_client_range_use_vendor_class_id
			x               		Enable using vendor class id.Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x               		Valid choices are:
			x                   		0 - disable
			x                   		1 - enable
			x           	-dhcp6_pd_client_range_vendor_class_id
			x               		This option is used by a client to identify the vendor that manufactured the hardware on which the client is running. (DEFAULT = 'Ixia DHCP Client')Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'; dhcp6_pd_client_range_use_vendor_class_id is 1
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-dhcp6_pd_server_range_dns_domain_search_list
			x               		Specifies the domain that the client will use when resolving host names with DNS.
			x           	-dhcp6_pd_server_range_first_dns_server
			x               		The first DNS server associated with this address pool. This is the first DNS
			x               		address that will be assigned to any client that is allocated an IP address from this
			x               		pool.
			x           	-dhcp6_pd_server_range_second_dns_server
			x               		The second DNS server associated with this address pool. This is the second (of
			x               		two) DNS addresses that will be assigned to any client that is allocated an IP
			x               		address from this pool.
			x           	-dhcp6_pd_server_range_subnet_prefix
			x               		The prefix value used to subnet the addresses specified in the address pool. This
			x               		is the subnet prefix length advertised in DHCPv6PD Offer and Reply messages.
			x           	-dhcp6_pd_server_range_start_pool_address
			x               		The starting IPv6 address for this DHCPv6 address pool.
			x           	-dhcp6_pgdata_max_outstanding_requests
			x               		The maximum number of requests to be sent by all DHCP clients during session
			x               		startup. This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or
			x               		'dual_stack'.
			x               		Parameter dhcp6_pgdata_override_global_setup_rate is '1'
			x           	-dhcp6_pgdata_override_global_setup_rate
			x               		This parameter refers to the DHCPv6 Client Port Group Data. This parameter
			x               		applies at the port level.
			x               		Dependencies: Available starting with HLT API 3.90. Valid when port_role is
			x               		'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x           	-dhcp6_pgdata_setup_rate_initial
			x               		This parameter refers to the DHCPv6 Client Port Group Data. This parameter
			x               		applies at the port level.
			x               		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x               		is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x               		Parameter dhcp6_pgdata_override_global_setup_rate is '1'
			x           	-dhcp6_pgdata_setup_rate_increment
			x               		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'. Parameter dhcp6_pgdata_override_global_setup_rate is '1'.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-dhcp6_pgdata_setup_rate_max
			x               		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'. Parameter dhcp6_pgdata_override_global_setup_rate is '1'
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-dhcp6_pgdata_max_outstanding_releases
			x               		The maximum number of requests to be sent by all DHCP clients during session
			x               		teardown. This parameter applies globally for all the ports in the configuration.
			x               		Available starting with HLT API 3.90 IxNetwork is used for PPPoX configurations.
			x               		Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or
			x               		'dual_stack'.
			x               		Parameter dhcp6_pgdata_override_global_teardown_rate is '1'
			x           	-dhcp6_pgdata_override_global_teardown_rate
			x               		This parameter refers to the DHCPv6 Client Port Group Data. This parameter
			x               		applies at the port level.
			x               		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x               		is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'
			x           	-dhcp6_pgdata_teardown_rate_initial
			x               		Description This parameter refers to the DHCPv6 Client Port Group Data.
			x               		This parameter applies at the port level.
			x               		Dependencies: Available starting with HLT API 3.90. Valid when port_role
			x               		is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x               		Parameter dhcp6_pgdata_override_global_teardown_rate is '1'
			x           	-dhcp6_pgdata_teardown_rate_increment
			x               		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'. Parameter dhcp6_pgdata_override_global_teardown_rate is '1'
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-dhcp6_pgdata_teardown_rate_max
			x               		This parameter refers to the DHCPv6 Client Port Group Data. This parameter applies at the port level. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'. Parameter dhcp6_pgdata_override_global_teardown_rate is '1'
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-hosts_range_ip_outer_prefix
			x               		This parameter represents the address prefix allocated to the hosts in all of the subnets behind the CPE interface. The default prefix is 64, the minimum is 0, and the maximum is 128.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-hosts_range_ip_prefix_addr
			x               		The IPv6 prefix to be used for the static host addresses. The default prefix is 3001.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-hosts_range_count
			x               		Configures the DHCP Hosts Range count property. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-hosts_range_eui_increment
			x               		This parameter configures the EUI step to increment 'hosts_range_first_eui ' from the DHCP Hosts Range. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'. Parameter hosts_range_count greater than 1
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-hosts_range_first_eui
			x               		Configures the first EUI value of the DHCP Hosts Range. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-hosts_range_ip_prefix
			x               		Defines the network prefix length associated with the address pool for the DHCP Hosts Range. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-hosts_range_subnet_count
			x               		It defines the number of subnets for the DHCP Hosts Range. Dependencies: Available starting with HLT API 3.90. Valid when port_role is 'access'; dhcpv6_hosts_enable is 1; ip_cp is 'ipv6_cp' or 'dual_stack'.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-lease_time_max
			x               		The maximum lease duration, in seconds. The default value is 86,400; the minimum is 300; and the maximum is 30,000,000.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-lease_time
			x               		The duration of an address lease, in seconds, if the client requesting the lease
			x               		does not ask for a specific expiration time. The default value is 3600; the
			x               		minimum is 300; and the maximum is 30,000,000.
			x           	-padi_include_tag
			x               		Enables sending the Access Loop Tag in the PADI message.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-pado_include_tag
			x               		Enables sending the Access Loop Tag in the PADO message.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-padr_include_tag
			x               		Enables sending the Access Loop Tag in the PADR message.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x           	-pads_include_tag
			x               		Enables sending the Access Loop Tag in the PADS message.
			x               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			n           	-re_connect_on_link_up
			n               	-group_ip_count
			n                   	-group_ip_step
			n                       	-start_group_ip
			n                           	-igmp_version
			n                               	-is_last_subport
			n                                   	-join_leaves_per_second
			n                                       	-l4_src_port
			n                                           	-l4_dst_port
			n                                               	-l4_flow_number
			n                                                   	-l4_flow_type
			n                                                       	-l4_flow_variant
			n                                                           	-mc_enable_general_query
			n                                                               	-mc_enable_group_specific_query
			n                                                                   	-mc_enable_immediate_response
			n                                                                       	-mc_enable_packing
			n                                                                           	-mc_enable_router_alert
			n                                                                               	-mc_enable_suppress_reports
			n                                                                                   	-mc_enable_unsolicited
			n                                                                                       	-mc_group_id
			n                                                                                           	-mc_report_frequency
			n                                                                                               	-ppp_local_mode
			n                                                                                                   	-ppp_peer_mode
			n                                                                                                       	-enable_delete_config
			n                                                                                                           	-flap_repeat_count
			n                                                                                                               	-flap_rate
			n                                                                                                                   	-switch_duration
			n                                                                                                                       	-watch_duration
			n                                                                                                                           	-hold_time
			n                                                                                                                               	-cool_off_time
			n                                                                                                                                   	-dut_assigned_src_addr
			n                                                                                                                                       	-include_id
			n                                                                                                                                           	-sessions_per_vc
			x                                                                                                                                               	-enable_host_uniq
			x                                                                                                                                                   		Enables PPPoE Host-Uniq tag
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                               	-host_uniq_length
			x                                                                                                                                                   		Host-Uniq
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                               	-host_uniq
			x                                                                                                                                                   		Host-Uniq
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                               	-multiplier
			x                                                                                                                                                   		number of layer instances per parent instance (multiplier)
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                               	-dsl_type_tlv
			x                                                                                                                                                   		DSL Type to be advertised in PPPoE VSA Tag. For undefined DSL type user has to select "User-defined DSL Type".
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		none - (DEFAULT)
			x                                                                                                                                                       		adsl_1 -
			x                                                                                                                                                       		adsl_2 -
			x                                                                                                                                                       		adsl_2_p -
			x                                                                                                                                                       		vdsl_1 -
			x                                                                                                                                                       		vdsl_2 -
			x                                                                                                                                                       		sdsl -
			x                                                                                                                                                       		g_fast -
			x                                                                                                                                                       		svvdsl -
			x                                                                                                                                                       		sdsl_bonded -
			x                                                                                                                                                       		vdsl_bonded -
			x                                                                                                                                                       		g_fast_bonded -
			x                                                                                                                                                       		svvdsl_bonded -
			x                                                                                                                                                       		other -
			x                                                                                                                                                       		user_defined - User defined value for DSL type TLV.
			x                                                                                                                                               	-user_defined_dsl_type_tlv
			x                                                                                                                                                   		User Defined DSL-Type Value.
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                               	-enable_server_signal_dsl_type_tlv
			x                                                                                                                                                   		DSL-Type TLV to be inserted in PPPoE VSA Tag.
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                               	-pon_type_tlv
			x                                                                                                                                                   		PON Type to be advertised in PPPoE VSA Tag. For undefined PON type user has to select "User-defined PON Type".
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		none - (DEFAULT)
			x                                                                                                                                                       		gpon -
			x                                                                                                                                                       		xg_pon_1 -
			x                                                                                                                                                       		twdm_pon -
			x                                                                                                                                                       		xgs_pon -
			x                                                                                                                                                       		wdm_pon -
			x                                                                                                                                                       		other -
			x                                                                                                                                                       		user_defined - User defined value for DSL type TLV.
			x                                                                                                                                               	-user_defined_pon_type_tlv
			x                                                                                                                                                   		User Defined PON-Type Value.
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                               	-enable_server_signal_pon_type_tlv
			x                                                                                                                                                   		PON-Type TLV to be inserted in PPPoE VSA Tag.
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                               	-enable_mrru_negotiation
			x                                                                                                                                                   		The presence of the LCP MRRU option indicates that the PPP multilink protocol is implemented by the system sending it.
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                               	-multilink_mrru_size
			x                                                                                                                                                   		The maximum number of octets in the information fields of reassembled packets of the MRRU.
			x                                                                                                                                                   		Select to configure the MRRU size used in negotiation of the multilink protocol MRRU option in the LCP stage. Valid values are: 576 to 9000.
			x                                                                                                                                                   		Default value is 1492.
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                               	-mlppp_endpointdiscriminator_option
			x                                                                                                                                                   		Select to define the ML-PPP endpoint discriminator options in the LCP-Configure request.
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                               	-endpoint_discriminator_class
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                                       		class_null - It has a Null value. Null Class (Default).
			x                                                                                                                                                       		class_ip_address - The IP address used in the ML-PPP endpoint discriminator option of the LCP configure request sent by PPP clients.
			x                                                                                                                                                       		class_mac_address - The MAC addresses are automatically derived from the local MAC address. An address in this class contains an IEEE 802.1 MAC address is canonical (802.3) format.
			x                                                                                                                                               	-internet_protocol_address
			x                                                                                                                                                   		The IP address used in the ML-PPP endpoint discriminator option of the LCP configure request sent by PPP clients.
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x                                                                                                                                               	-mac_address
			x                                                                                                                                                   		The MAC addresses are automatically derived from the local MAC address. An address in this class contains an IEEE 802.1 MAC address is canonical (802.3) format.
			x                                                                                                                                                   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		                                                                                                                                           
		                                                                                                                                           Return Values:
		                                                                                                                                               A list containing the pppox client protocol stack handles that were added by the command (if any).
			x                                                                                                                                               key:pppox_client_handle           value:A list containing the pppox client protocol stack handles that were added by the command (if any).
		                                                                                                                                               A list containing the pppox server protocol stack handles that were added by the command (if any).
			x                                                                                                                                               key:pppox_server_handle           value:A list containing the pppox server protocol stack handles that were added by the command (if any).
		                                                                                                                                               A list containing the pppox server sessions protocol stack handles that were added by the command (if any).
			x                                                                                                                                               key:pppox_server_sessions_handle  value:A list containing the pppox server sessions protocol stack handles that were added by the command (if any).
		                                                                                                                                               A list containing the dhcpv6 client protocol stack handles that were added by the command (if any).
			x                                                                                                                                               key:dhcpv6_client_handle          value:A list containing the dhcpv6 client protocol stack handles that were added by the command (if any).
		                                                                                                                                               A list containing the dhcpv6 server protocol stack handles that were added by the command (if any).
			x                                                                                                                                               key:dhcpv6_server_handle          value:A list containing the dhcpv6 server protocol stack handles that were added by the command (if any).
		                                                                                                                                               A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			x                                                                                                                                               key:handle                        value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		                                                                                                                                               $::SUCCESS | $::FAILURE
			                                                                                                                                                key:status                        value:$::SUCCESS | $::FAILURE
		                                                                                                                                               ppp handles
			                                                                                                                                                key:handles                       value:ppp handles
		                                                                                                                                               When status is failure, contains more information
			                                                                                                                                                key:log                           value:When status is failure, contains more information
		                                                                                                                                           
		                                                                                                                                           Examples:
		                                                                                                                                               See the PPPoE examples in Appendix A, "Example APIs," for specific examples of usage.
		                                                                                                                                           
		                                                                                                                                           Sample Input:
		                                                                                                                                           
		                                                                                                                                           Sample Output:
		                                                                                                                                           
		                                                                                                                                           Notes:
		                                                                                                                                               1) Coded versus functional specification.
		                                                                                                                                               2) When -handle is provided with the /globals value the arguments that configure global protocol
		                                                                                                                                               setting accept both multivalue handles and simple values.
		                                                                                                                                               When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
		                                                                                                                                               that configure global settings will only accept simple values. In this situation, these arguments will
		                                                                                                                                               configure only the settings of the parent device group or the ports associated with the parent topology.
		                                                                                                                                               If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		                                                                                                                                               1) Coded versus functional specification.
		                                                                                                                                           
		                                                                                                                                           See Also:
		                                                                                                                                           
		"""
		return self._run_keyword("pppox_config", kwargs)

	def pppox_control(self, **kwargs):
		""" Start, stop, or restart the PPPoX sessions.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: pppox_control
			 	[-handle        ANY]
			x	-action         CHOICES abort
			x                CHOICES abort_async
			x                CHOICES connect
			x                CHOICES disconnect
			x                CHOICES reset
			x                CHOICES reset_async
			x                CHOICES restart_down
			x                CHOICES send_ping
			x                CHOICES open_ipcp
			x                CHOICES close_ipcp
			x                CHOICES open_ipv6cp
			x                CHOICES close_ipv6cp
			x	[-ipv4_ping_dst ANY]
			x	[-ipv6_ping_dst ANY]
		
		Arguments:
			 	-handle
			 		For ixiangpf implementation, -handle argument can be a protocol or interface handle returned by pppox_config.
			 		For legacy implementation, -handle argument can be a port_handle or a range handle, returned by legacy pppox_config.
			x	-action
			x		Action to be executed.
			x		Choices not supported:
			x		clear- Clears the status and statistics of the PPP sessions.
			x		Not available when IxNetwork is used for PPPoX configurations.
			x		pause- Pauses all the PPP sessions.
			x		Not available when IxNetwork is used for PPPoX configurations.
			x		resume- Resumes all the PPP sessions.
			x		Not available when IxNetwork is used for PPPoX configurations.
			x		retry- Attempts to connect PPP sessions that have previously failed to establish.
			x		Not available when IxNetwork is used for PPPoX configurations.
			x		Valid choices are:
			x   		abort - Aborts all PPPoX sessions on the specified device. A session is not
notified of termination, and a Terminate Request
packet is not sent to the peers. The call will block until
all sessions are aborted. The configuration remains intact. Parameter -handle
can be a port handle (all pppox sessions from that port are aborted), a range
handle (all pppox sessions from that range are aborted). If -handle is missing
all pppox sessions from all ports are aborted.
			x   		abort_async - Aborts all PPPoX sessions on the specified device. A session is not
notified of termination, and a Terminate Request
packet is not sent to the peers. The call will not block. The configuration remains intact.
Rules for parameter -handle are the same as for -action abort.
			x   		connect - Brings up configured sessions.
			x   		disconnect - Tears down established sessions.
			x   		reset - Aborts all PPPoX sessions and resets the PPP emulation
engine on the specified device. A session is not
notified of termination, and a Terminate Request
packet is not sent to the peers. The call will block until
all sessions are aborted.
			x   		reset_async - Aborts all PPPoX sessions and resets the PPP emulation
engine on the specified device. A session is not
notified of termination, and a Terminate Request
packet is not sent to the peers. The call will not block.
			x   		restart_down -
			x   		send_ping - Sends a ping to the specified address.
			x   		open_ipcp - Sends a configure-request to establish IPCP sessions.
			x   		close_ipcp - Sends a terminate-request to close IPCP sessions.
			x   		open_ipv6cp - Sends a configure-request to establish IPv6CP sessions.
			x   		close_ipv6cp - Sends a terminate-request to close IPv6CP sessions.
			x	-ipv4_ping_dst
			x		The IPv4 destination to which you want to send ping.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-ipv6_ping_dst
			x		The IPv6 destination to which you want to send ping.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		See the PPPoE examples in Appendix A, "Example APIs," for specific examples of usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		1) clear action has not been implemented yet
		Coded versus functional specification.
		1) clear action has not been implemented yet
		
		See Also:
		
		"""
		return self._run_keyword("pppox_control", kwargs)

	def pppox_stats(self, **kwargs):
		""" Retrieves statistics for the PPPoX sessions configured on the specified test port or for the PPPoX handle passed in -handle argument.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: pppox_stats
			 	[-handle            ANY]
			 	[-port_handle       ANY]
			 	-mode               CHOICES aggregate
			                     CHOICES session
			                     CHOICES session_dhcpv6pd
			                     CHOICES session_dhcp_hosts
			                     CHOICES session_all
			x	[-source            CHOICES client server]
			n	[-csv_filename      ANY]
			n	[-retry             ANY]
			x	[-execution_timeout NUMERIC
			x                    DEFAULT 1800]
		
		Arguments:
			 	-handle
			 		The PPPoX handle for which the PPPoX sessions statistics needs to be retrieved.
			 		When using IxNetwork the statistics will be retrieved
			 		for the port where that handle belongs.
			 	-port_handle
			 		The port for which the PPPoX sessions statistics needs to be retrieved.
			 		Only available when using IxNetwork to retrieve statistics.
			 	-mode
			 		Specifies statistics retrieval mode as either aggregate for all
			 		configured sessions or on a per session basis.
			 		Valid choices are:
			    		aggregate - Retrieve statistics for all the sessions.
			    		session - Retrieve statistics for each individual session.
			    		session_dhcpv6pd - Retrieve dhcp client or dhcp server statistics per session. Available only for IxTclNetwork.
			    		session_dhcp_hosts - Retrieve dhcp hosts statistics per session.Available only for IxTclNetwork.
			    		session_all - Retrieve all the per session statistics. Available only fot IxTclNetwork
			x	-source
			x		Valid only when a port handle is available
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		client - indicates to retrieve client specific statistics
			x   		server - indicates to retrieve server specific statistics
			n	-csv_filename
			n		The .csv filename that can be created under HLT library install folder and where per session stats can be found.Only available when using IxAccess to retrieve statistics. Not available when using IxNetwork.
			n		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			n	-retry
			x	-execution_timeout
			x   		This is the timeout for the function.
			x   		The setting is in seconds.
			x   		Setting this setting to 60 it will mean that the command must complete in under 60 seconds.
			x   		If the command will last more than 60 seconds the command will be terminated by force.
			x   		This flag can be used to prevent dead locks occuring in IxNetwork.
			x   		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                              value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log                                                                 value:If status is failure, detailed information provided.
		The stats can be used with or without <port_handle>
			 key:AGGREGATE STATS                                                     value:The stats can be used with or without <port_handle>
		If -handle is specified, the aggregate.* keys that are not prefixed are the pppox per range statistics. If more than one handle is specified, the per range statistics will be prefixed with the handle value. If -handle is not provided, the perRange statistics are not returned.
			 key:PER RANGE STATS                                                     value:If -handle is specified, the aggregate.* keys that are not prefixed are the pppox per range statistics. If more than one handle is specified, the per range statistics will be prefixed with the handle value. If -handle is not provided, the perRange statistics are not returned.
		The aggregate statistic keys that are not documented as having a 'pppox_handle' prefix will always have the 'N/A' value.
			 key:PER RANGE STATS                                                     value:The aggregate statistic keys that are not documented as having a 'pppox_handle' prefix will always have the 'N/A' value.
		Aggregate per port statistics will also be returned for the ports on which the pppox handles reside
			 key:PER RANGE STATS                                                     value:Aggregate per port statistics will also be returned for the ports on which the pppox handles reside
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.auth_total_rx                            value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.auth_total_tx                            value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.avg_setup_time                           value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.chap_auth_chal_rx                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.chap_auth_chal_tx                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.chap_auth_fail_rx                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.chap_auth_fail_tx                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.chap_auth_rsp_rx                         value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.chap_auth_rsp_tx                         value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.chap_auth_succ_rx                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.chap_auth_succ_tx                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.client_max_setup_rate                    value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.code_rej_rx                              value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.code_rej_tx                              value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.connect_success                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.connected                                value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.connecting                               value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.echo_req_rx                              value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.echo_req_tx                              value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.echo_rsp_rx                              value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.echo_rsp_tx                              value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.idle                                     value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.interfaces_in_ppp_negotiation            value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.interfaces_in_pppoe_l2tp_negotiation     value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.interfaces_teardown_rate                 value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipcp_cfg_ack_rx                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipcp_cfg_ack_tx                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipcp_cfg_nak_rx                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipcp_cfg_nak_tx                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipcp_cfg_rej_rx                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipcp_cfg_rej_tx                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipcp_cfg_req_rx                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipcp_cfg_req_tx                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipv6cp_cfg_ack_rx                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipv6cp_cfg_ack_tx                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipv6cp_cfg_nak_rx                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipv6cp_cfg_nak_tx                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipv6cp_cfg_rej_rx                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipv6cp_cfg_rej_tx                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipv6cp_cfg_req_rx                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ipv6cp_cfg_req_tx                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.lcp_avg_latency                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.lcp_cfg_ack_rx                           value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.lcp_cfg_ack_tx                           value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.lcp_cfg_nak_rx                           value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.lcp_cfg_nak_tx                           value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.lcp_cfg_rej_rx                           value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.lcp_cfg_rej_tx                           value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.lcp_cfg_req_rx                           value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.lcp_cfg_req_tx                           value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.lcp_max_latency                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.lcp_min_latency                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.lcp_total_msg_rx                         value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.lcp_total_msg_tx                         value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.malformed_ppp_frames_rejected            value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.malformed_ppp_frames_used                value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.max_setup_time                           value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.min_setup_time                           value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ncp_avg_latency                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ncp_max_latency                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ncp_min_latency                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ncp_total_msg_rx                         value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ncp_total_msg_tx                         value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.num_sessions                             value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.padi_rx                                  value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.padi_timeout                             value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.padi_tx                                  value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pado_rx                                  value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pado_tx                                  value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.padr_rx                                  value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.padr_timeout                             value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.padr_tx                                  value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pads_rx                                  value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pads_tx                                  value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.padt_rx                                  value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.padt_tx                                  value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pap_auth_ack_rx                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pap_auth_ack_tx                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pap_auth_nak_rx                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pap_auth_nak_tx                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pap_auth_req_rx                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pap_auth_req_tx                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.port_name                                value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ppp_total_bytes_rx                       value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.ppp_total_bytes_tx                       value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pppoe_avg_latency                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pppoe_max_latency                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pppoe_min_latency                        value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pppoe_total_bytes_rx                     value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.pppoe_total_bytes_tx                     value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.sessions_failed                          value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.sessions_up                              value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.sessions_initiated                       value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.success_setup_rate                       value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.teardown_rate                            value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.term_ack_rx                              value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.term_ack_tx                              value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.term_req_rx                              value:Available with IxNetwork
		Available with IxNetwork
			 key:[<port_handle.>].aggregate.term_req_tx                              value:Available with IxNetwork
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].port_name                                          value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_addresses_discovered                      value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_advertisements_ignored                    value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_advertisements_received                   value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_enabled_interfaces                        value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_rebinds_sent                              value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_releases_sent                             value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_renews_sent                               value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_replies_received                          value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_requests_sent                             value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_sessions_failed                           value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_sessions_initiated                        value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_sessions_succeeded                        value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_setup_success_rate                        value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_solicits_sent                             value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_teardown_fail                             value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_teardown_initiated                        value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcpv6pd_teardown_success                          value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcp_hosts_sessions_failed                         value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcp_hosts_sessions_initiated                      value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
			 key:[<port_handle.>].dhcp_hosts_sessions_succeeded                      value:Available with IxNetwork when pppox was configured with dhcpv6_hosts_enable 1
		Available with IxNetwork. Only for per range statistics
			 key:[<pppox_handle>].aggregate.connect_success                          value:Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:[<pppox_handle>].aggregate.connected                                value:Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:[<pppox_handle>].aggregate.interfaces_in_chap_negotiation           value:Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:[<pppox_handle>].aggregate.interfaces_in_discovery                  value:Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:[<pppox_handle>].aggregate.interfaces_in_ipcp_negotiation           value:Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:[<pppox_handle>].aggregate.interfaces_in_ipv6cp_negotiation         value:Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:[<pppox_handle>].aggregate.interfaces_in_lcp_negotiation            value:Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:[<pppox_handle>].aggregate.interfaces_in_pap_negotiation            value:Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:[<pppox_handle>].aggregate.interfaces_in_ppp_negotiation            value:Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:[<pppox_handle>].aggregate.sessions_failed                          value:Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:[<pppox_handle>].aggregate.sessions_up                              value:Available with IxNetwork. Only for per range statistics
		Available with IxNetwork. Only for per range statistics
			 key:[<pppox_handle>].aggregate.sessions_initiated                       value:Available with IxNetwork. Only for per range statistics
		(Available with IxNetwork only)
			xkey:SESSION STATS                                                       value:(Available with IxNetwork only)
		"Port Name"
			xkey:session.<session ID>.port_name                                      value:"Port Name"
		"AC Cookie"
			xkey:session.<session ID>.ac_cookie                                      value:"AC Cookie"
		"AC System Error Occured"
			xkey:session.<session ID>.ac_system_error                                value:"AC System Error Occured"
		"AC Generic Error Occured"
			xkey:session.<session ID>.ac_generic_error                               value:"AC Generic Error Occured"
		"AC Cookie Tag Rx"
			xkey:session.<session ID>.ac_cookie_tag_rx                               value:"AC Cookie Tag Rx"
		"AC MAC Address"
			xkey:session.<session ID>.ac_mac_addr                                    value:"AC MAC Address"
		"AC System Error Tag Rx"
			xkey:session.<session ID>.ac_system_error_tag_rx                         value:"AC System Error Tag Rx"
		"CHAP Authentication Role"
			xkey:session.<session ID>.chap_auth_role                                 value:"CHAP Authentication Role"
		"DNS Server List"
			xkey:session.<session ID>.dns_server_list                                value:"DNS Server List"
		"Discovery Start Time"
			xkey:session.<session ID>.discovery_start                                value:"Discovery Start Time"
		"Discovery End Time"
			xkey:session.<session ID>.discovery_end                                  value:"Discovery End Time"
		"Generic Error Tag Tx"
			xkey:session.<session ID>.generic_error_tag_tx                           value:"Generic Error Tag Tx"
		"Host MAC Address"
			xkey:session.<session ID>.host_mac_addr                                  value:"Host MAC Address"
		"IPv6 Prefix Length"
			xkey:session.<session ID>.ipv6_prefix_len                                value:"IPv6 Prefix Length"
		"IPv6 Address"
			xkey:session.<session ID>.ipv6_addr                                      value:"IPv6 Address"
		"IPv6CP Router Advertisement Rx"
			xkey:session.<session ID>.ipv6cp_router_adv_rx                           value:"IPv6CP Router Advertisement Rx"
		"IPv6CP Router Advertisement Tx"
			xkey:session.<session ID>.ipv6cp_router_adv_tx                           value:"IPv6CP Router Advertisement Tx"
		"Interface Identifier"
			xkey:session.<session ID>.interface_id                                   value:"Interface Identifier"
		"Local IP Address"
			xkey:session.<session ID>.local_ip_addr                                  value:"Local IP Address"
		"Local IPv6 IID"
			xkey:session.<session ID>.local_ipv6_iid                                 value:"Local IPv6 IID"
		"LCP Protocol Reject Rx"
			xkey:session.<session ID>.lcp_protocol_rej_rx                            value:"LCP Protocol Reject Rx"
		"LCP Protocol Reject Tx"
			xkey:session.<session ID>.lcp_protocol_rej_tx                            value:"LCP Protocol Reject Tx"
		"Loopback Detected"
			xkey:session.<session ID>.loopback_detected                              value:"Loopback Detected"
		"MRU"
			xkey:session.<session ID>.mru                                            value:"MRU"
		"MTU"
			xkey:session.<session ID>.mtu                                            value:"MTU"
		"Magic Number Negotiated"
			xkey:session.<session ID>.magic_no_negotiated                            value:"Magic Number Negotiated"
		"Magic Number Rx"
			xkey:session.<session ID>.magic_no_rx                                    value:"Magic Number Rx"
		"Magic Number Tx"
			xkey:session.<session ID>.magic_no_tx                                    value:"Magic Number Tx"
		"Malformed PPPoE Frames Used"
			xkey:session.<session ID>.malformed_pppoe_frames_used                    value:"Malformed PPPoE Frames Used"
		"Malformed PPPoE Frames Rejected"
			xkey:session.<session ID>.malformed_pppoe_frames_rejected                value:"Malformed PPPoE Frames Rejected"
		"Negotiation Start Time \[ms\]"
			xkey:session.<session ID>.negotiation_start_ms                           value:"Negotiation Start Time \[ms\]"
		"Negotiation End Time \[ms\]"
			xkey:session.<session ID>.negotiation_end_ms                             value:"Negotiation End Time \[ms\]"
		"Peer IPv6 IID"
			xkey:session.<session ID>.peer_ipv6_iid                                  value:"Peer IPv6 IID"
		"PPPoE Total Bytes Rx"
			xkey:session.<session ID>.pppoe_total_bytes_rx                           value:"PPPoE Total Bytes Rx"
		"PPPoE Total Bytes Tx"
			xkey:session.<session ID>.pppoe_total_bytes_tx                           value:"PPPoE Total Bytes Tx"
		"PPP state"
			xkey:session.<session ID>.pppoe_state                                    value:"PPP state"
		"Range Identifier"
			xkey:session.<session ID>.range_id                                       value:"Range Identifier"
		"Remote IP Address"
			xkey:session.<session ID>.remote_ip_addr                                 value:"Remote IP Address"
		"Relay Session ID Tag Rx"
			xkey:session.<session ID>.relay_session_id_tag_rx                        value:"Relay Session ID Tag Rx"
		"Service Name Error Tag Rx"
			xkey:session.<session ID>.service_name_error_tag_rx                      value:"Service Name Error Tag Rx"
		"Session ID"
			xkey:session.<session ID>.session_id                                     value:"Session ID"
		"Vendor Specific Tag Rx"
			xkey:session.<session ID>.vendor_specific_tag_rx                         value:"Vendor Specific Tag Rx"
		Port Name
			xkey:session.server.<session ID>.port_name                               value:Port Name
		Lease Name
			 key:session.server.<session ID>.dhcpv6pd_lease_name                     value:Lease Name
		Offer Count
			xkey:session.server.<session ID>.dhcpv6pd_offer_count                    value:Offer Count
		Bind Count
			xkey:session.server.<session ID>.dhcpv6pd_bind_count                     value:Bind Count
		Bind Rapid Commit Count
			xkey:session.server.<session ID>.dhcpv6pd_bind_rapid_commit_count        value:Bind Rapid Commit Count
		Renew Count
			xkey:session.server.<session ID>.dhcpv6pd_renew_count                    value:Renew Count
		Release Count
			xkey:session.server.<session ID>.dhcpv6pd_release_count                  value:Release Count
		Information-Requests Received
			xkey:session.server.<session ID>.dhcpv6pd_information_request_received   value:Information-Requests Received
		Replies Sent
			xkey:session.server.<session ID>.dhcpv6pd_replies_sent                   value:Replies Sent
		Lease State
			xkey:session.server.<session ID>.dhcpv6pd_lease_state                    value:Lease State
		Lease Address
			xkey:session.server.<session ID>.dhcpv6pd_lease_address                  value:Lease Address
		Valid Time
			xkey:session.server.<session ID>.dhcpv6pd_valid_time                     value:Valid Time
		Prefered Time
			xkey:session.server.<session ID>.dhcpv6pd_prefered_time                  value:Prefered Time
		Renew Time
			xkey:session.server.<session ID>.dhcpv6pd_renew_time                     value:Renew Time
		Rebind Time
			xkey:session.server.<session ID>.dhcpv6pd_rebind_time                    value:Rebind Time
		Client ID
			xkey:session.server.<session ID>.dhcpv6pd_client_id                      value:Client ID
		Remote ID
			xkey:session.server.<session ID>.dhcpv6pd_remote_id                      value:Remote ID
		Port Name
			xkey:session.client.<session ID>.port_name                               value:Port Name
		Session Name
			xkey:session.client.<session ID>.dhcpv6pd_session_name                   value:Session Name
		Solicits Sent
			xkey:session.client.<session ID>.dhcpv6pd_solicits_sent                  value:Solicits Sent
		Advertisements Received
			xkey:session.client.<session ID>.dhcpv6pd_advertisements_received        value:Advertisements Received
		Advertisements Ignored
			xkey:session.client.<session ID>.dhcpv6pd_advertisements_ignored         value:Advertisements Ignored
		Requests Sent
			xkey:session.client.<session ID>.dhcpv6pd_requests_sent                  value:Requests Sent
		Replies Received
			xkey:session.client.<session ID>.dhcpv6pd_replies_received               value:Replies Received
		Renews Sent
			xkey:session.client.<session ID>.dhcpv6pd_renews_sent                    value:Renews Sent
		Rebinds Sent
			xkey:session.client.<session ID>.dhcpv6pd_rebinds_sent                   value:Rebinds Sent
		Releases Sent
			xkey:session.client.<session ID>.dhcpv6pd_releases_sent                  value:Releases Sent
		IP Prefix
			xkey:session.client.<session ID>.dhcpv6pd_ip_prefix                      value:IP Prefix
		Gateway Address
			xkey:session.client.<session ID>.dhcpv6pd_gateway_address                value:Gateway Address
		DNS Server List
			xkey:session.client.<session ID>.dhcpv6pd_dns_server_list                value:DNS Server List
		Prefix Lease Time
			xkey:session.client.<session ID>.dhcpv6pd_prefix_lease_time              value:Prefix Lease Time
		Information Requests Sent
			xkey:session.client.<session ID>.dhcpv6pd_onformation_requests_sent      value:Information Requests Sent
		DNS Search List
			xkey:session.client.<session ID>.dhcpv6pd_dns_search_list                value:DNS Search List
		Solicits w/ Rapid Commit Sent
			xkey:session.client.<session ID>.dhcpv6pd_solicits_rapid_commit_sent     value:Solicits w/ Rapid Commit Sent
		Replies w/ Rapid Commit Received
			xkey:session.client.<session ID>.dhcpv6pd_replies_rapid_commit_received  value:Replies w/ Rapid Commit Received
		Lease w/ Rapid Commit
			xkey:session.client.<session ID>.dhcpv6pd_lease_rapid_commit             value:Lease w/ Rapid Commit
		Port Name
			xkey:session.hosts.<session ID>.port_name                                value:Port Name
		Interface Identifier
			xkey:session.hosts.<session ID>.dhcpv6pd_interface_identifier            value:Interface Identifier
		Range Identifier
			xkey:session.hosts.<session ID>.dhcpv6pd_range_identifier                value:Range Identifier
		IPv6 Address
			xkey:session.hosts.<session ID>.dhcpv6pd_ipv6_address                    value:IPv6 Address
		Prefix Length
			xkey:session.hosts.<session ID>.dhcpv6pd_prefix_length                   value:Prefix Length
		Status
			xkey:session.hosts.<session ID>.dhcpv6pd_status                          value:Status
		Not supported
			nkey:AGGREGATE STATS                                                     value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.cdn_rx                                   value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.cdn_tx                                   value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.cookie_size_mismatch                     value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.data_seq_mismatch                        value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.duplicate_rx                             value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.ex_ack_rx                                value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.ex_ack_tx                                value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.hello_rx                                 value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.hello_tx                                 value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.hostname_mismatch                        value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.iccn_rx                                  value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.iccn_tx                                  value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.icrp_rx                                  value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.icrp_tx                                  value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.icrq_rx                                  value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.icrq_tx                                  value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.in_order_rx                              value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.l2_sub_layer_mismatch                    value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.l2tp_avg_setup_time                      value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.l2tp_last_avg_latency                    value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.l2tp_last_max_latency                    value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.l2tp_last_min_latency                    value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.l2tp_max_setup_time                      value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.l2tp_min_setup_time                      value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.last_avg_latency                         value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.last_max_latency                         value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.last_min_latency                         value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.lcp_last_avg_latency                     value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.lcp_last_max_latency                     value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.lcp_last_min_latency                     value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.msg_digest_algo_mismatch                 value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.msg_digest_val_mismatch                  value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.ncp_last_avg_latency                     value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.ncp_last_max_latency                     value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.ncp_last_min_latency                     value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.out_of_order_rx                          value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.out_of_win_rx                            value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.relay_session_id_tag_rx                  value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.remote_end_id_mismatch                   value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.report_count                             value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.retransmits                              value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.router_id_mismatch                       value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.scccn_rx                                 value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.scccn_tx                                 value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.sccrp_rx                                 value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.sccrp_tx                                 value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.sccrq_rx                                 value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.sccrq_tx                                 value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.service_name_error_tag_rx                value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.sess_avg_latency                         value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.sess_last_avg_latency                    value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.sess_last_max_latency                    value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.sess_last_min_latency                    value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.sess_max_latency                         value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.sess_min_latency                         value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.setup_rate                               value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.sli_rx                                   value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.sli_tx                                   value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.stopccn_rx                               value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.stopccn_tx                               value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.test_duration                            value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.total_bytes_rx                           value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.total_bytes_tx                           value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.tun_tx_win_close                         value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.tun_tx_win_open                          value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.tunnels_neg                              value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.tunnels_up                               value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.tx_pkt_acked                             value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.vendor_specific_tag_rx                   value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.wen_rx                                   value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.wen_tx                                   value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.zlb_rx                                   value:Not supported
		Not supported
			nkey:[<port_handle.>].aggregate.zlb_tx                                   value:Not supported
		Not available
			nkey:SESSION STATS                                                       value:Not available
			nkey:session.<session ID>.ac_name                                        value:
			nkey:session.<session ID>.ac_offer_rx                                    value:
			nkey:session.<session ID>.auth_id                                        value:
			nkey:session.<session ID>.auth_password                                  value:
			nkey:session.<session ID>.auth_protocol_rx                               value:
			nkey:session.<session ID>.auth_protocol_tx                               value:
			nkey:session.<session ID>.auth_total_rx                                  value:
			nkey:session.<session ID>.auth_total_tx                                  value:
			nkey:session.<session ID>.chap_auth_chal_rx                              value:
			nkey:session.<session ID>.chap_auth_chal_tx                              value:
			nkey:session.<session ID>.chap_auth_fail_rx                              value:
			nkey:session.<session ID>.chap_auth_fail_tx                              value:
			nkey:session.<session ID>.chap_auth_rsp_rx                               value:
			nkey:session.<session ID>.chap_auth_rsp_tx                               value:
			nkey:session.<session ID>.chap_auth_succ_rx                              value:
			nkey:session.<session ID>.chap_auth_succ_tx                              value:
			nkey:session.<session ID>.close_mode                                     value:
			nkey:session.<session ID>.code_rej_rx                                    value:
			nkey:session.<session ID>.code_rej_tx                                    value:
			nkey:session.<session ID>.echo_req_rx                                    value:
			nkey:session.<session ID>.echo_req_tx                                    value:
			nkey:session.<session ID>.echo_rsp_rx                                    value:
			nkey:session.<session ID>.echo_rsp_tx                                    value:
			nkey:session.<session ID>.ipcp_cfg_ack_rx                                value:
			nkey:session.<session ID>.ipcp_cfg_ack_tx                                value:
			nkey:session.<session ID>.ipcp_cfg_nak_rx                                value:
			nkey:session.<session ID>.ipcp_cfg_nak_tx                                value:
			nkey:session.<session ID>.ipcp_cfg_rej_rx                                value:
			nkey:session.<session ID>.ipcp_cfg_rej_tx                                value:
			nkey:session.<session ID>.ipcp_cfg_req_rx                                value:
			nkey:session.<session ID>.ipcp_cfg_req_tx                                value:
			nkey:session.<session ID>.ipcp_state                                     value:
			nkey:session.<session ID>.ipv6cp_cfg_ack_rx                              value:
			nkey:session.<session ID>.ipv6cp_cfg_ack_tx                              value:
			nkey:session.<session ID>.ipv6cp_cfg_nak_rx                              value:
			nkey:session.<session ID>.ipv6cp_cfg_nak_tx                              value:
			nkey:session.<session ID>.ipv6cp_cfg_rej_rx                              value:
			nkey:session.<session ID>.ipv6cp_cfg_rej_tx                              value:
			nkey:session.<session ID>.ipv6cp_cfg_req_rx                              value:
			nkey:session.<session ID>.ipv6cp_cfg_req_tx                              value:
			nkey:session.<session ID>.ipv6cp_state                                   value:
			nkey:session.<session ID>.lcp_cfg_ack_rx                                 value:
			nkey:session.<session ID>.lcp_cfg_ack_tx                                 value:
			nkey:session.<session ID>.lcp_cfg_nak_rx                                 value:
			nkey:session.<session ID>.lcp_cfg_nak_tx                                 value:
			nkey:session.<session ID>.lcp_cfg_rej_rx                                 value:
			nkey:session.<session ID>.lcp_cfg_rej_tx                                 value:
			nkey:session.<session ID>.lcp_cfg_req_rx                                 value:
			nkey:session.<session ID>.lcp_cfg_req_tx                                 value:
			nkey:session.<session ID>.term_ack_rx                                    value:
			nkey:session.<session ID>.term_ack_tx                                    value:
			nkey:session.<session ID>.term_req_rx                                    value:
			nkey:session.<session ID>.term_req_tx                                    value:
			nkey:session.<session ID>.lcp_total_msg_rx                               value:
			nkey:session.<session ID>.lcp_total_msg_tx                               value:
			nkey:session.<session ID>.malformed_ppp_frames_rejected                  value:
			nkey:session.<session ID>.malformed_ppp_frames_used                      value:
			nkey:session.<session ID>.ncp_total_msg_rx                               value:
			nkey:session.<session ID>.ncp_total_msg_tx                               value:
			nkey:session.<session ID>.padi_rx                                        value:
			nkey:session.<session ID>.padi_tx                                        value:
			nkey:session.<session ID>.padi_timeout                                   value:
			nkey:session.<session ID>.pado_rx                                        value:
			nkey:session.<session ID>.pado_tx                                        value:
			nkey:session.<session ID>.padr_rx                                        value:
			nkey:session.<session ID>.padr_tx                                        value:
			nkey:session.<session ID>.padr_timeout                                   value:
			nkey:session.<session ID>.pads_rx                                        value:
			nkey:session.<session ID>.pads_tx                                        value:
			nkey:session.<session ID>.padt_rx                                        value:
			nkey:session.<session ID>.padt_tx                                        value:
			nkey:session.<session ID>.pap_auth_ack_rx                                value:
			nkey:session.<session ID>.pap_auth_ack_tx                                value:
			nkey:session.<session ID>.pap_auth_nak_rx                                value:
			nkey:session.<session ID>.pap_auth_nak_tx                                value:
			nkey:session.<session ID>.pap_auth_req_rx                                value:
			nkey:session.<session ID>.pap_auth_req_tx                                value:
			nkey:session.<session ID>.pppoe_state                                    value:
			nkey:session.<session ID>.ppp_total_bytes_rx                             value:
			nkey:session.<session ID>.ppp_total_bytes_tx                             value:
			nkey:session.<session ID>.service_name                                   value:
		The total number of sessions initiated. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is re-established
			xkey:session.<session handle>.cumulative_setup_initiated                 value:The total number of sessions initiated. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is re-established
		The total number of sessions negotiated successfully. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is re-established successfully
			xkey:session.<session handle>.cumulative_setup_succeeded                 value:The total number of sessions negotiated successfully. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is re-established successfully
		The total number of sessions whose negotiation failed. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is not re-established successfully
			xkey:session.<session handle>.cumulative_setup_failed                    value:The total number of sessions whose negotiation failed. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is not re-established successfully
		The total number of sessions whose tear down failed. This value is preserved between subsequent session connects and disconnects, and is incremented whenever when a session is not torn down successfully
			xkey:session.<session handle>.cumulative_teardown_failed                 value:The total number of sessions whose tear down failed. This value is preserved between subsequent session connects and disconnects, and is incremented whenever when a session is not torn down successfully
		The total number of sessions torn down successfully. This value is preserved between subsequent session connects and disconnects, and is incremented whenever when a session is torn down successfully
			xkey:session.<session handle>.cumulative_teardown_succeeded              value:The total number of sessions torn down successfully. This value is preserved between subsequent session connects and disconnects, and is incremented whenever when a session is torn down successfully
		The total number of sessions initiated. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is re-established
			xkey:<port handle>.aggregate.cumulative_setup_initiated                  value:The total number of sessions initiated. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is re-established
		The total number of sessions negotiated successfully. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is re-established successfully
			xkey:<port handle>.aggregate.cumulative_setup_succeeded                  value:The total number of sessions negotiated successfully. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is re-established successfully
		The total number of sessions whose negotiation failed. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is not re-established successfully
			xkey:<port handle>.aggregate.cumulative_setup_failed                     value:The total number of sessions whose negotiation failed. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is not re-established successfully
		The total number of sessions whose tear down failed. This value is preserved between subsequent session connects and disconnects, and is incremented whenever when a session is not torn down successfully
			xkey:<port handle>.aggregate.cumulative_teardown_failed                  value:The total number of sessions whose tear down failed. This value is preserved between subsequent session connects and disconnects, and is incremented whenever when a session is not torn down successfully
		The total number of sessions torn down successfully. This value is preserved between subsequent session connects and disconnects, and is incremented whenever when a session is torn down successfully
			xkey:<port handle>.aggregate.cumulative_teardown_succeeded               value:The total number of sessions torn down successfully. This value is preserved between subsequent session connects and disconnects, and is incremented whenever when a session is torn down successfully
		The total number of sessions initiated. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is re-established
			xkey:<DG handle>.aggregate.cumulative_setup_initiated                    value:The total number of sessions initiated. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is re-established
		The total number of sessions negotiated successfully. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is re-established successfully
			xkey:<DG handle>.aggregate.cumulative_setup_succeeded                    value:The total number of sessions negotiated successfully. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is re-established successfully
		The total number of sessions whose negotiation failed. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is not re-established successfully
			xkey:<DG handle>.aggregate.cumulative_setup_failed                       value:The total number of sessions whose negotiation failed. This value is preserved between subsequent session connects and disconnects, and is incremented whenever a session is not re-established successfully
		The total number of sessions whose tear down failed. This value is preserved between subsequent session connects and disconnects, and is incremented whenever when a session is not torn down successfully
			xkey:<DG handle>.aggregate.cumulative_teardown_failed                    value:The total number of sessions whose tear down failed. This value is preserved between subsequent session connects and disconnects, and is incremented whenever when a session is not torn down successfully
		The total number of sessions torn down successfully. This value is preserved between subsequent session connects and disconnects, and is incremented whenever when a session is torn down successfully
			xkey:<DG handle>.aggregate.cumulative_teardown_succeeded                 value:The total number of sessions torn down successfully. This value is preserved between subsequent session connects and disconnects, and is incremented whenever when a session is torn down successfully
		The stats can be used with or without <port_handle>
			 key:AGGREGATE STATS                                                     value: The stats can be used with or without <port_handle>
		If -handle is specified, the aggregate.* keys that are not prefixed are the pppox per range statistics. If more than one handle is specified, the per range statistics will be prefixed with the handle value. If -handle is not provided, the perRange statistics are not returned.
			 key:PER RANGE STATS                                                     value: If -handle is specified, the aggregate.* keys that are not prefixed are the pppox per range statistics. If more than one handle is specified, the per range statistics will be prefixed with the handle value. If -handle is not provided, the perRange statistics are not returned.
		The aggregate statistic keys that are not documented as having a 'pppox_handle' prefix will always have the 'N/A' value.
			 key:PER RANGE STATS                                                     value: The aggregate statistic keys that are not documented as having a 'pppox_handle' prefix will always have the 'N/A' value.
		Aggregate per port statistics will also be returned for the ports on which the pppox handles reside
			 key:PER RANGE STATS                                                     value: Aggregate per port statistics will also be returned for the ports on which the pppox handles reside
		"Port Name"
			 key:session.<session ID>.port_name                                      value: "Port Name"
		"AC Cookie"
			 key:session.<session ID>.ac_cookie                                      value: "AC Cookie"
		"AC System Error Occured"
			 key:session.<session ID>.ac_system_error                                value: "AC System Error Occured"
		"AC Generic Error Occured"
			 key:session.<session ID>.ac_generic_error                               value: "AC Generic Error Occured"
		"AC Cookie Tag Rx"
			 key:session.<session ID>.ac_cookie_tag_rx                               value: "AC Cookie Tag Rx"
		"AC MAC Address"
			 key:session.<session ID>.ac_mac_addr                                    value: "AC MAC Address"
		"AC System Error Tag Rx"
			 key:session.<session ID>.ac_system_error_tag_rx                         value: "AC System Error Tag Rx"
		"CHAP Authentication Role"
			 key:session.<session ID>.chap_auth_role                                 value: "CHAP Authentication Role"
		"DNS Server List"
			 key:session.<session ID>.dns_server_list                                value: "DNS Server List"
		"Discovery Start Time"
			 key:session.<session ID>.discovery_start                                value: "Discovery Start Time"
		"Discovery End Time"
			 key:session.<session ID>.discovery_end                                  value: "Discovery End Time"
		"Generic Error Tag Tx"
			 key:session.<session ID>.generic_error_tag_tx                           value: "Generic Error Tag Tx"
		"Host MAC Address"
			 key:session.<session ID>.host_mac_addr                                  value: "Host MAC Address"
		"IPv6 Prefix Length"
			 key:session.<session ID>.ipv6_prefix_len                                value: "IPv6 Prefix Length"
		"IPv6 Address"
			 key:session.<session ID>.ipv6_addr                                      value: "IPv6 Address"
		"IPv6CP Router Advertisement Rx"
			 key:session.<session ID>.ipv6cp_router_adv_rx                           value: "IPv6CP Router Advertisement Rx"
		"IPv6CP Router Advertisement Tx"
			 key:session.<session ID>.ipv6cp_router_adv_tx                           value: "IPv6CP Router Advertisement Tx"
		"Interface Identifier"
			 key:session.<session ID>.interface_id                                   value: "Interface Identifier"
		"Local IP Address"
			 key:session.<session ID>.local_ip_addr                                  value: "Local IP Address"
		"Local IPv6 IID"
			 key:session.<session ID>.local_ipv6_iid                                 value: "Local IPv6 IID"
		"LCP Protocol Reject Rx"
			 key:session.<session ID>.lcp_protocol_rej_rx                            value: "LCP Protocol Reject Rx"
		"LCP Protocol Reject Tx"
			 key:session.<session ID>.lcp_protocol_rej_tx                            value: "LCP Protocol Reject Tx"
		"Loopback Detected"
			 key:session.<session ID>.loopback_detected                              value: "Loopback Detected"
		"MRU"
			 key:session.<session ID>.mru                                            value: "MRU"
		"MTU"
			 key:session.<session ID>.mtu                                            value: "MTU"
		"Magic Number Negotiated"
			 key:session.<session ID>.magic_no_negotiated                            value: "Magic Number Negotiated"
		"Magic Number Rx"
			 key:session.<session ID>.magic_no_rx                                    value: "Magic Number Rx"
		"Magic Number Tx"
			 key:session.<session ID>.magic_no_tx                                    value: "Magic Number Tx"
		"Malformed PPPoE Frames Used"
			 key:session.<session ID>.malformed_pppoe_frames_used                    value: "Malformed PPPoE Frames Used"
		"Malformed PPPoE Frames Rejected"
			 key:session.<session ID>.malformed_pppoe_frames_rejected                value: "Malformed PPPoE Frames Rejected"
		"Negotiation Start Time \[ms\]"
			 key:session.<session ID>.negotiation_start_ms                           value: "Negotiation Start Time \[ms\]"
		"Negotiation End Time \[ms\]"
			 key:session.<session ID>.negotiation_end_ms                             value: "Negotiation End Time \[ms\]"
		"Peer IPv6 IID"
			 key:session.<session ID>.peer_ipv6_iid                                  value: "Peer IPv6 IID"
		"PPPoE Total Bytes Rx"
			 key:session.<session ID>.pppoe_total_bytes_rx                           value: "PPPoE Total Bytes Rx"
		"PPPoE Total Bytes Tx"
			 key:session.<session ID>.pppoe_total_bytes_tx                           value: "PPPoE Total Bytes Tx"
		"PPP state"
			 key:session.<session ID>.pppoe_state                                    value: "PPP state"
		"Range Identifier"
			 key:session.<session ID>.range_id                                       value: "Range Identifier"
		"Remote IP Address"
			 key:session.<session ID>.remote_ip_addr                                 value: "Remote IP Address"
		"Relay Session ID Tag Rx"
			 key:session.<session ID>.relay_session_id_tag_rx                        value: "Relay Session ID Tag Rx"
		"Service Name Error Tag Rx"
			 key:session.<session ID>.service_name_error_tag_rx                      value: "Service Name Error Tag Rx"
		"Session ID"
			 key:session.<session ID>.session_id                                     value: "Session ID"
		"Vendor Specific Tag Rx"
			 key:session.<session ID>.vendor_specific_tag_rx                         value: "Vendor Specific Tag Rx"
		Not supported
			 key:AGGREGATE STATS                                                     value: Not supported
		
		Examples:
		See the PPPoE examples in Appendix A, "Example APIs," for specific examples of usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		Coded versus functional specification.
		1) Session ID will be PPPoE session ID for the case of PPPoE and PPPoEoA.
		For the case of PPPoA, session ID will be VPI/VCI.
		2) Per session stats retrieval can take long time.
		3) Following stats have not been implemented yet:
		aggregate.disconnecting
		aggregate.atm_mode
		aggregate.connect_attempts
		aggregate.disconnect_success
		aggregate.sessions_down
		aggregate.disconnect_failed
		4) PPPoX implementation using IxTclAccess is NOT SUPPORTED starting from HLTAPI 3.30.
		Coded versus functional specification.
		1) Session ID will be PPPoE session ID for the case of PPPoE and PPPoEoA. For the case of PPPoA, session ID will be VPI/VCI.
		2) Per session stats retrieval can take long time.
		3) Following stats have not been implemented yet:aggregate.disconnectingaggregate.atm_modeaggregate.connect_attemptsaggregate.disconnect_successaggregate.sessions_downaggregate.disconnect_failed4) PPPoX implementation using IxTclAccess is NOT SUPPORTED starting from HLTAPI 3.30.
		
		See Also:
		
		"""
		return self._run_keyword("pppox_stats", kwargs)

	def protocol_info(self, **kwargs):
		""" This procedure is used to get session status statistics for NGPF protocols that support start and stop operations.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: protocol_info
			x	[-handle            ANY]
			x	[-port_filter       ANY]
			x	[-mode              CHOICES aggregate
			x                    CHOICES handles
			x                    CHOICES global_per_protocol
			x                    CHOICES global_per_port
			x                    DEFAULT global_per_protocol]
			x	[-execution_timeout NUMERIC
			x                    DEFAULT 1800]
		
		Arguments:
			x	-handle
			x		A handle or list of handles that correspond to NGPF protocols.
			x		If an invalid handle is given, a warning will be printed to the console and the corresponding handle will be ignored.
			x		If the argument is omitted, the command will return the status of all NGPF protocols that are found.
			x	-port_filter
			x		A port handle, virtual port handle or a list containing any combination of port handles and virtual ports.
			x		The ports that correspond to the specified handles will be used to filter the results of the command. If any of the specified handles does not match any of the port filters, no information about the sessions configured on that handle will be returned.
			x		If an invalid port is specified, the command will return an error.
			x	-mode
			x		Specifies the retrieval mode as either aggregate for all configured sessions or on a per session basis.
			x		Valid choices are:
			x   		aggregate - Retrieve statistics for all the sessions and return the number of sessions that are in each state.
			x   		handles - Retrieve statistics for all the sessions and return the handles of sessions that are in each state.
			x   		global_per_protocol - Retrieves statistics of the complete configuration aggregated per protocol. This is the equivalent of Protocol Summary Statistics View and does not accept any handle or port_filter arguments.
			x   		global_per_port - Retrieves statistics of the complete configuration aggregated per port. This is the equivalent of Port Summary Statistics View and does not accept any handle or port_filter arguments.
			x	-execution_timeout
			x		This is the time-out for the function.
			x		The setting is in seconds.
			x		Setting this to 60 means that the command must complete in under 60 seconds.
			x		If the command lasts more than 60 seconds the command is terminated by force.
			x		This flag can be used to prevent dead locks occurring in IxNetwork.
		
		Return Values:
		The number of sessions belonging to the specified handle that are not joined. This key is returned only if the mode is set to aggregate and the port_filter argument is omitted. If the protocol that corresponds to handle does not support the notion of join/leave for its sessions, this key will not be returned.
			 key:[<handle>].aggregate.sessions_not_joined                   value:The number of sessions belonging to the specified handle that are not joined. This key is returned only if the mode is set to aggregate and the port_filter argument is omitted. If the protocol that corresponds to handle does not support the notion of join/leave for its sessions, this key will not be returned.
		The number of sessions belonging to the specified handle that are joined. This key is returned only if the mode is set to aggregate and the port_filter argument is omitted. If the protocol that corresponds to handle does not support the notion of join/leave for its sessions, this key will not be returned.
			 key:[<handle>].aggregate.sessions_joined                       value:The number of sessions belonging to the specified handle that are joined. This key is returned only if the mode is set to aggregate and the port_filter argument is omitted. If the protocol that corresponds to handle does not support the notion of join/leave for its sessions, this key will not be returned.
		The number of sessions belonging to the specified handle that are down. This key is returned only if the mode is set to aggregate and the port_filter argument is omitted. If the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
			 key:[<handle>].aggregate.sessions_down                         value:The number of sessions belonging to the specified handle that are down. This key is returned only if the mode is set to aggregate and the port_filter argument is omitted. If the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
		The number of sessions belonging to the specified handle that are up. This key is returned only if the mode is set to aggregate and the port_filter argument is omitted. If the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
			 key:[<handle>].aggregate.sessions_up                           value:The number of sessions belonging to the specified handle that are up. This key is returned only if the mode is set to aggregate and the port_filter argument is omitted. If the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
		The number of sessions belonging to the specified handle that are not started. This key is returned only if the mode is set to aggregate and the port_filter argument is omitted.
			 key:[<handle>].aggregate.sessions_not_started                  value:The number of sessions belonging to the specified handle that are not started. This key is returned only if the mode is set to aggregate and the port_filter argument is omitted.
		The number of sessions belonging to the specified handle that are configured. This key is returned only if the mode is set to aggregate and the port_filter argument is omitted.
			 key:[<handle>].aggregate.sessions_total                        value:The number of sessions belonging to the specified handle that are configured. This key is returned only if the mode is set to aggregate and the port_filter argument is omitted.
		The number sessions belonging to the specified handle that are not joined on the specified port. This key is returned only if the mode is set to aggregate and the port_filter argument is given. If the protocol that corresponds to handle does not support the notion of join/leave for its sessions, this key will not be returned.
			 key:[<handle>].aggregate.[<port_filter>].sessions_not_joined   value:The number sessions belonging to the specified handle that are not joined on the specified port. This key is returned only if the mode is set to aggregate and the port_filter argument is given. If the protocol that corresponds to handle does not support the notion of join/leave for its sessions, this key will not be returned.
		The number of sessions belonging to the specified handle that are joined on the specified port. This key is returned only if the mode is set to aggregate and the port_filter argument is given. If the protocol that corresponds to handle does not support the notion of join/leave for its sessions, this key will not be returned.
			 key:[<handle>].aggregate.[<port_filter>].sessions_joined       value:The number of sessions belonging to the specified handle that are joined on the specified port. This key is returned only if the mode is set to aggregate and the port_filter argument is given. If the protocol that corresponds to handle does not support the notion of join/leave for its sessions, this key will not be returned.
		The number sessions belonging to the specified handle that are down on the specified port. This key is returned only if the mode is set to aggregate and the port_filter argument is given. If the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
			 key:[<handle>].aggregate.[<port_filter>].sessions_down         value:The number sessions belonging to the specified handle that are down on the specified port. This key is returned only if the mode is set to aggregate and the port_filter argument is given. If the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
		The number of sessions belonging to the specified handle that are up on the specified port. This key is returned only if the mode is set to aggregate and the port_filter argument is given. If the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
			 key:[<handle>].aggregate.[<port_filter>].sessions_up           value:The number of sessions belonging to the specified handle that are up on the specified port. This key is returned only if the mode is set to aggregate and the port_filter argument is given. If the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
		The number of sessions belonging to the specified handle that are not started on the specified port. This key is returned only if the mode is set to aggregate and the port_filter argument is given.
			 key:[<handle>].aggregate.[<port_filter>].sessions_not_started  value:The number of sessions belonging to the specified handle that are not started on the specified port. This key is returned only if the mode is set to aggregate and the port_filter argument is given.
		The number of sessions belonging to the specified handle that are configured on the specified port. This key is returned only if the mode is set to aggregate and the port_filter argument is given.
			 key:[<handle>].aggregate.[<port_filter>].sessions_total        value:The number of sessions belonging to the specified handle that are configured on the specified port. This key is returned only if the mode is set to aggregate and the port_filter argument is given.
		The handles of all sessions belonging to the specified handle that are not joined. This key is returned only if the mode is set to handles and the port_filter argument is omitted. If no sessions are in the not joined state or the protocol that corresponds to handle does not support the notion of join/leave for its sessions, this key will not be returned.
			 key:[<handle>].handles.sessions_not_joined                     value:The handles of all sessions belonging to the specified handle that are not joined. This key is returned only if the mode is set to handles and the port_filter argument is omitted. If no sessions are in the not joined state or the protocol that corresponds to handle does not support the notion of join/leave for its sessions, this key will not be returned.
		The handles of all sessions belonging to the specified handle that are joined. This key is returned only if the mode is set to handles and the port_filter argument is omitted. If no sessions are joined or the protocol that corresponds to handle does not support the notion of leave/join for its sessions, this key will not be returned.
			 key:[<handle>].handles.sessions_joined                         value:The handles of all sessions belonging to the specified handle that are joined. This key is returned only if the mode is set to handles and the port_filter argument is omitted. If no sessions are joined or the protocol that corresponds to handle does not support the notion of leave/join for its sessions, this key will not be returned.
		The handles of all sessions belonging to the specified handle that are down. This key is returned only if the mode is set to handles and the port_filter argument is omitted. If no sessions are down or the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
			 key:[<handle>].handles.sessions_down                           value:The handles of all sessions belonging to the specified handle that are down. This key is returned only if the mode is set to handles and the port_filter argument is omitted. If no sessions are down or the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned. 
		The handles of all sessions belonging to the specified handle that are up. This key is returned only if the mode is set to handles and the port_filter argument is omitted. If no sessions are up or the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
			 key:[<handle>].handles.sessions_up                             value:The handles of all sessions belonging to the specified handle that are up. This key is returned only if the mode is set to handles and the port_filter argument is omitted. If no sessions are up or the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
		The handles of all sessions belonging to the specified handle that are not started. This key is returned only if the mode is set to handles and the port_filter argument is omitted. If all sessions are started, this key will not be returned.
			 key:[<handle>].handles.sessions_not_started                    value:The handles of all sessions belonging to the specified handle that are not started. This key is returned only if the mode is set to handles and the port_filter argument is omitted. If all sessions are started, this key will not be returned.
		The handles of all sessions belonging to the specified handle that are configured. This key is returned only if the mode is set to handles and the port_filter argument is omitted. If no sessions are configured, this key will not be returned.
			 key:[<handle>].handles.sessions_total                          value:The handles of all sessions belonging to the specified handle that are configured. This key is returned only if the mode is set to handles and the port_filter argument is omitted. If no sessions are configured, this key will not be returned.
		The handles of all sessions belonging to the specified handle that are not joined on the specified port. This key is returned only if the mode is set to handles and the port_filter argument is given. If no sessions are in the not joined state or the protocol that corresponds to handle does not support the notion of leave/join for its sessions, this key will not be returned.
			 key:[<handle>].handles.[<port_filter>].sessions_not_joined     value:The handles of all sessions belonging to the specified handle that are not joined on the specified port. This key is returned only if the mode is set to handles and the port_filter argument is given. If no sessions are in the not joined state or the protocol that corresponds to handle does not support the notion of leave/join for its sessions, this key will not be returned.
		The handles of all sessions belonging to the specified handle that are joined on the specified port. This key is returned only if the mode is set to handles and the port_filter argument is given. If no sessions are joined or the protocol that corresponds to handle does not support the notion of leave/join for its sessions, this key will not be returned.
			 key:[<handle>].handles.[<port_filter>].sessions_joined         value:The handles of all sessions belonging to the specified handle that are joined on the specified port. This key is returned only if the mode is set to handles and the port_filter argument is given. If no sessions are joined or the protocol that corresponds to handle does not support the notion of leave/join for its sessions, this key will not be returned.
		The handles of all sessions belonging to the specified handle that are down on the specified port. This key is returned only if the mode is set to handles and the port_filter argument is given. If no sessions are down or the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
			 key:[<handle>].handles.[<port_filter>].sessions_down           value:The handles of all sessions belonging to the specified handle that are down on the specified port. This key is returned only if the mode is set to handles and the port_filter argument is given. If no sessions are down or the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
		The handles of all sessions belonging to the specified handle that are up on the specified port. This key is returned only if the mode is set to handles and the port_filter argument is given. If no sessions are up or the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
			 key:[<handle>].handles.[<port_filter>].sessions_up             value:The handles of all sessions belonging to the specified handle that are up on the specified port. This key is returned only if the mode is set to handles and the port_filter argument is given. If no sessions are up or the protocol that corresponds to handle does not support the notion of start/stop for its sessions, this key will not be returned.
		The handles of all sessions belonging to the specified handle that are not started on the specified port. This key is returned only if the mode is set to handles and the port_filter argument is given. If all sessions are started, this key will not be returned.
			 key:[<handle>].handles.[<port_filter>].sessions_not_started    value:The handles of all sessions belonging to the specified handle that are not started on the specified port. This key is returned only if the mode is set to handles and the port_filter argument is given. If all sessions are started, this key will not be returned.
		The handles of all sessions belonging to the specified handle that are configured on the specified port. This key is returned only if the mode is set to handles and the port_filter argument is given. If no sessions are configured, this key will not be returned.
			 key:[<handle>].handles.[<port_filter>].sessions_total          value:The handles of all sessions belonging to the specified handle that are configured on the specified port. This key is returned only if the mode is set to handles and the port_filter argument is given. If no sessions are configured, this key will not be returned.
		Name of the protocol. This is used as a grouping key when mode is global_per_protocol (default). This is returned for global_per_protocol mode.
			 key:[<grouping_key>].protocol                                  value:Name of the protocol. This is used as a grouping key when mode is global_per_protocol (default). This is returned for global_per_protocol mode.
		Name of the port. This is used as grouping key when mode is global_per_port. This is returned for global_per_port mode.
			 key:[<grouping_key>].port_name                                 value:Name of the port. This is used as grouping key when mode is global_per_port. This is returned for global_per_port mode.
		The number of sessions which are up. This is returned for global_per_protocol or global_per_port modes.
			 key:[<grouping_key>].sessions_up                               value:The number of sessions which are up. This is returned for global_per_protocol or global_per_port modes.
		The number of sessions which are down. This is returned for global_per_protocol or global_per_port modes.
			 key:[<grouping_key>].sessions_down                             value:The number of sessions which are down. This is returned for global_per_protocol or global_per_port modes.
		The number of sessions which are not started. This is returned for global_per_protocol or global_per_port modes.
			 key:[<grouping_key>].sessions_not_started                      value:The number of sessions which are not started. This is returned for global_per_protocol or global_per_port modes.
		Total number of sessions. This is returned for global_per_protocol or global_per_port modes.
			 key:[<grouping_key>].sessions_total                            value:Total number of sessions. This is returned for global_per_protocol or global_per_port modes.
		This value represents the Average Setup Rate. This is returned for global_per_protocol mode.
			 key:[<grouping_key>].setup_avg_rate                            value:This value represents the Average Setup Rate. This is returned for global_per_protocol mode.
		This value represents the Average Teardown Rate. This is returned for global_per_protocol mode.
			 key:[<grouping_key>].teardown_avg_rate                         value:This value represents the Average Teardown Rate. This is returned for global_per_protocol mode.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("protocol_info", kwargs)

	def ptp_globals_config(self, **kwargs):
		""" Not supported in ixiangpf namespace.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: ptp_globals_config
			x	-mode             CHOICES create add modify delete
			x	-parent_handle    ANY
			x	[-handle          ANY]
			x	[-style           ANY]
			x	[-max_outstanding RANGE 1-10000
			x                  DEFAULT 20]
			x	[-setup_rate      RANGE 1-20000
			x                  DEFAULT 5]
			x	[-teardown_rate   RANGE 1-20000
			x                  DEFAULT 5]
		
		Arguments:
			x	-mode
			x		Not supported in ixiangpf namespace.
			x		Valid choices are:
			x   		create -
			x   		add -
			x   		modify -
			x   		delete -
			x	-parent_handle
			x		Not supported in ixiangpf namespace.
			x	-handle
			x		Not supported in ixiangpf namespace.
			x	-style
			x		Not supported in ixiangpf namespace.
			x	-max_outstanding
			x		Not supported in ixiangpf namespace.
			x	-setup_rate
			x		Not supported in ixiangpf namespace.
			x	-teardown_rate
			x		Not supported in ixiangpf namespace.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log      value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles  value:The returned handle(s) of the  config command.
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("ptp_globals_config", kwargs)

	def ptp_options_config(self, **kwargs):
		""" Performs ptp_options configuration.      PortGroup settings placeholder for PtpPlugin.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: ptp_options_config
			x	-mode                                CHOICES create add modify delete
			x	-parent_handle                       ANY
			x	[-handle                             ANY]
			x	[-style                              ANY]
			x	[-max_outstanding                    ANY]
			x	[-override_global_rate_options       CHOICES 0 1]
			x	[-role                               CHOICES master
			x                                     CHOICES slave
			x                                     CHOICES transparentMaster
			x                                     DEFAULT master]
			x	[-setup_rate                         RANGE 1-1000
			x                                     DEFAULT 5]
			x	[-teardown_rate                      RANGE 1-1000
			x                                     DEFAULT 5]
			x	[-tos                                ANY]
			x	[-traffic_class                      ANY]
			 	[-override_global_start_rate_options CHOICES 0 1]
			 	[-override_global_stop_rate_options  CHOICES 0 1]
			x	[-start_rate_interval                ANY]
			x	[-stop_rate_interval                 ANY]
			x	[-start_scale_mode                   CHOICES deviceGroup port
			x                                     DEFAULT port]
			x	[-stop_scale_mode                    CHOICES deviceGroup port
			x                                     DEFAULT port]
		
		Arguments:
			x	-mode
			x		create - not supported in case of ::ixiangpf::ptp_options_config.
			x		add - not supported in case of ::ixiangpf::ptp_options_config.
			x		modify - modified attributes on the given object by the -handle param
			x		delete - not supported in case of ::ixiangpf::ptp_options_config.
			x		Valid choices are:
			x   		create - Not supported in case of ::ixiangpf::ptp_options_config.
			x   		add - Not supported in case of ::ixiangpf::ptp_options_config.
			x   		modify - Modified attributes on the given object by the -handle param.
			x   		delete - Not supported in case of ::ixiangpf::ptp_options_config.
			x	-parent_handle
			x		The parent handle used for creating this object.
			x	-handle
			x		A handle returned via a ::ixiangpf::ptp_over_mac_config/ptp_over_ip_config command or the /globals handle. Valid for mode create.
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-max_outstanding
			x		The number of PTP connections to be in initiation or terminating state at any time.
			x		The number of PTP connections to be in initiation or terminating state at any time.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-override_global_rate_options
			x		If true then all the rate settings defined at Session level will be overriden by
			x		rate settings defined on this PortGroup.
			x	-role
			x		Clock type.
			x		Valid choices are:
			x		master - Master
			x		slave - Slave
			x		Valid choices are:
			x   		master - Master
			x   		slave - Slave
			x   		transparentMaster - Not supported in ixiangpf namespace.
			x	-setup_rate
			x		Initiation rate for the PTP connection establishement.
			x		The number of PTP connections initiated in a second.
			x	-teardown_rate
			x		Teardown rate for the PTP connection establishement.
			x		The number of PTP connections torn down in a second.
			x	-tos
			x		TOS/DSCP set for PTP packets over IPv4
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-traffic_class
			x		Traffic Class set for PTP packets over IPv6
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-override_global_start_rate_options
			 		If true then all the rate settings defined at Session level will be overriden by
			 		rate settings defined on this PortGroup.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-override_global_stop_rate_options
			 		If true then all the rate settings defined at Session level will be overriden by
			 		rate settings defined on this PortGroup.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-start_rate_interval
			x		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-stop_rate_interval
			x		Time interval used to calculate the rate for triggering an action(rate = count/interval)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-start_scale_mode
			x		Indicates whether the control is specified per port or per device group
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		deviceGroup -
			x   		port -
			x	-stop_scale_mode
			x		Indicates whether the control is specified per port or per device group
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		deviceGroup -
			x   		port -
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status   value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log      value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles  value:The returned handle(s) of the  config command.
		When status is failure, contains more information
			 key:log      value:When status is failure, contains more information
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("ptp_options_config", kwargs)

	def ptp_over_ip_config(self, **kwargs):
		""" Performs ptp_over_ip configuration. Manages a device group of PTP clocks.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: ptp_over_ip_config
			x	-mode                                 CHOICES create add modify delete
			x	-parent_handle                        ANY
			x	[-handle                              ANY]
			x	[-style                               ANY]
			x	[-announce_current_utc_offset_valid   CHOICES 0 1]
			x	[-announce_drop_rate                  RANGE 0-100
			x                                      DEFAULT 0]
			x	[-announce_frequency_traceable        CHOICES 0 1
			x                                      DEFAULT 0]
			x	[-announce_leap59                     CHOICES 0 1
			x                                      DEFAULT 0]
			x	[-announce_leap61                     CHOICES 0 1
			x                                      DEFAULT 0]
			x	[-announce_ptp_timescale              CHOICES 0 1
			x                                      DEFAULT 0]
			x	[-announce_receipt_timeout            RANGE 0-128
			x                                      DEFAULT 3]
			x	[-announce_time_traceable             CHOICES 0 1
			x                                      DEFAULT 0]
			x	[-client_count                        ANY]
			x	[-client_ip_address                   ANY]
			x	[-client_ip_increment_by              ANY]
			x	[-client_mac_address                  ANY]
			x	[-client_mac_increment_by             ANY]
			x	[-clock_accuracy                      CHOICES 32
			x                                      CHOICES 33
			x                                      CHOICES 34
			x                                      CHOICES 35
			x                                      CHOICES 36
			x                                      CHOICES 37
			x                                      CHOICES 38
			x                                      CHOICES 39
			x                                      CHOICES 40
			x                                      CHOICES 41
			x                                      CHOICES 42
			x                                      CHOICES 43
			x                                      CHOICES 44
			x                                      CHOICES 45
			x                                      CHOICES 46
			x                                      CHOICES 47
			x                                      CHOICES 48
			x                                      CHOICES 49
			x                                      DEFAULT 47]
			x	[-clock_class                         RANGE 0-255
			x                                      DEFAULT 6]
			x	[-clock_increment                     ANY]
			x	[-communication_mode                  CHOICES multicast
			x                                      CHOICES unicast
			x                                      CHOICES mixedmode
			x                                      CHOICES g8265
			x                                      DEFAULT multicast]
			x	[-delay_mechanism                     CHOICES E2E P2P 1WAY
			x                                      DEFAULT E2E]
			x	[-delay_resp_drop_rate                RANGE 0-100
			x                                      DEFAULT 0]
			x	[-delay_resp_receipt_timeout          RANGE 1-1000
			x                                      DEFAULT 100]
			x	[-delay_response_delay                RANGE 0-1000000000
			x                                      DEFAULT 0]
			x	[-delay_response_delay_insertion_rate RANGE 0-100
			x                                      DEFAULT 0]
			x	[-domain                              RANGE 0-255
			x                                      DEFAULT 0]
			x	[-drop_signal_req_announce            CHOICES 0 1]
			x	[-drop_signal_req_delay_resp          CHOICES 0 1]
			x	[-drop_signal_req_sync                CHOICES 0 1]
			x	[-enabled                             ANY]
			x	[-first_clock                         ANY
			x                                      DEFAULT 00:00:00:00:00:00:11:11]
			x	[-follow_up_bad_crc_rate              RANGE 0-100
			x                                      DEFAULT 0]
			x	[-follow_up_delay                     RANGE 0-1000000000
			x                                      DEFAULT 0]
			x	[-follow_up_delay_insertion_rate      RANGE 0-100
			x                                      DEFAULT 0]
			x	[-follow_up_drop_rate                 RANGE 0-100
			x                                      DEFAULT 0]
			x	[-grant_delay_resp_duration_interval  RANGE 5-1200
			x                                      DEFAULT 300]
			x	[-grant_sync_duration_interval        RANGE 5-1200
			x                                      DEFAULT 300]
			x	[-grant_unicast_duration_interval     RANGE 5-1200
			x                                      DEFAULT 300]
			x	[-ip_tos                              RANGE 0-255
			x                                      DEFAULT 0]
			x	[-learn_port_id                       CHOICES 0 1]
			x	[-log_announce_interval               CHOICES 247
			x                                      CHOICES 248
			x                                      CHOICES 249
			x                                      CHOICES 250
			x                                      CHOICES 251
			x                                      CHOICES 252
			x                                      CHOICES 253
			x                                      CHOICES 254
			x                                      CHOICES 255
			x                                      CHOICES 0
			x                                      CHOICES 1
			x                                      CHOICES 2
			x                                      CHOICES 3
			x                                      CHOICES 4
			x                                      CHOICES 5
			x                                      CHOICES 6
			x                                      CHOICES 7
			x                                      CHOICES 8
			x                                      CHOICES 9
			x                                      DEFAULT 0]
			x	[-log_delay_req_interval              CHOICES 247
			x                                      CHOICES 248
			x                                      CHOICES 249
			x                                      CHOICES 250
			x                                      CHOICES 251
			x                                      CHOICES 252
			x                                      CHOICES 253
			x                                      CHOICES 254
			x                                      CHOICES 255
			x                                      CHOICES 0
			x                                      CHOICES 1
			x                                      CHOICES 2
			x                                      CHOICES 3
			x                                      CHOICES 4
			x                                      CHOICES 5
			x                                      CHOICES 6
			x                                      CHOICES 7
			x                                      CHOICES 8
			x                                      CHOICES 9
			x                                      DEFAULT 0]
			x	[-log_sync_interval                   CHOICES 247
			x                                      CHOICES 248
			x                                      CHOICES 249
			x                                      CHOICES 250
			x                                      CHOICES 251
			x                                      CHOICES 252
			x                                      CHOICES 253
			x                                      CHOICES 254
			x                                      CHOICES 255
			x                                      CHOICES 0
			x                                      CHOICES 1
			x                                      CHOICES 2
			x                                      CHOICES 3
			x                                      CHOICES 4
			x                                      CHOICES 5
			x                                      CHOICES 6
			x                                      CHOICES 7
			x                                      CHOICES 8
			x                                      CHOICES 9
			x                                      DEFAULT 0]
			x	[-master_count                        RANGE 1-500
			x                                      DEFAULT 1]
			x	[-master_ip_address                   ANY
			x                                      DEFAULT 10.10.0.1]
			x	[-master_ip_increment_by              ANY
			x                                      DEFAULT 0.0.0.1]
			x	[-master_ip_increment_inter_entity    ANY]
			x	[-master_mac_address                  ANY
			x                                      DEFAULT aa:bb:cd:00:00:00]
			x	[-master_mac_increment_by             ANY
			x                                      DEFAULT 00:00:00:00:00:01]
			x	[-master_mac_increment_inter_entity   ANY]
			x	[-name                                ALPHA]
			x	[-port_number                         RANGE 1-65535
			x                                      DEFAULT 1]
			x	[-port_number_increment               ANY]
			x	[-priority1                           RANGE 0-255
			x                                      DEFAULT 128]
			x	[-priority2                           RANGE 0-255
			x                                      DEFAULT 128]
			x	[-renewal_invited                     CHOICES 0 1]
			x	[-request_attempts                    RANGE 1-100
			x                                      DEFAULT 3]
			x	[-request_holddown                    RANGE 10-1000
			x                                      DEFAULT 60]
			x	[-request_interval                    RANGE 1-100
			x                                      DEFAULT 1]
			x	[-residence_time                      RANGE 0-1000000000
			x                                      DEFAULT 0]
			x	[-rx_calibration                      RANGE 0-10000
			x                                      DEFAULT 0]
			x	[-send_announce_multicast             CHOICES 0 1]
			x	[-send_announce_tlv                   CHOICES 0 1]
			x	[-send_cancel_tlv                     CHOICES 0 1]
			x	[-signal_interval                     RANGE 3-1200
			x                                      DEFAULT 64]
			x	[-signal_unicast_handling             CHOICES individually
			x                                      CHOICES allInOne
			x                                      CHOICES doNotSend
			x                                      DEFAULT individually]
			x	[-step_mode                           CHOICES two-step single-step
			x                                      DEFAULT two-step]
			x	[-steps_removed                       RANGE 0-655535
			x                                      DEFAULT 0]
			x	[-strict_grant                        CHOICES 0 1]
			x	[-sync_drop_rate                      RANGE 0-100
			x                                      DEFAULT 0]
			x	[-sync_receipt_timeout                RANGE 1-1000
			x                                      DEFAULT 100]
			x	[-time_source                         CHOICES 0X10
			x                                      CHOICES 0X20
			x                                      CHOICES 0X30
			x                                      CHOICES 0X40
			x                                      CHOICES 0X50
			x                                      CHOICES 0X60
			x                                      CHOICES 0X90
			x                                      CHOICES 0XA0
			x                                      DEFAULT 0X20]
			x	[-timestamp_offset                    RANGE 0-9223372036854775807
			x                                      DEFAULT 0]
			x	[-timestamp_offset_variation          ANY]
			x	[-tx_calibration                      RANGE 0-1000000
			x                                      DEFAULT 0]
			x	[-use_alternate_master_flag           CHOICES 0 1]
			x	[-use_clock_identity                  CHOICES 0 1]
			x	[-profile                             CHOICES ieee1588
			x                                      CHOICES g82651
			x                                      CHOICES g82751
			x                                      CHOICES ieee8021as]
			 	[-current_utc_offset                  RANGE 0-32767
			                                       DEFAULT 0]
			x	[-sync_receipt_timeout_gptp           RANGE 1-128
			x                                      DEFAULT 3]
			x	[-bmca                                CHOICES 0 1
			x                                      DEFAULT 1]
			x	[-reverse_sync                        CHOICES 0 1
			x                                      DEFAULT 0]
			x	[-reverse_sync_interval_percent       RANGE 0-4294967295
			x                                      DEFAULT 96]
			x	[-cumulative_scaled_rate_offset       ANY
			x                                      DEFAULT 0x0]
			x	[-gm_time_base_indicator              RANGE 0-65535
			x                                      DEFAULT 0]
			x	[-last_gm_phase_change                RANGE 0-9223372036854775807
			x                                      DEFAULT 0]
			x	[-scaled_last_gm_freq_change          RANGE 0-4294967295
			x                                      DEFAULT 0]
			x	[-update_time                         CHOICES 0 1
			x                                      DEFAULT 1]
			x	[-nanoseconds_per_second              RANGE 999023438-1000976562
			x                                      DEFAULT 1000000000]
			 	[-slave_count                         RANGE 1-500
			                                       DEFAULT 1]
			 	[-slave_ip_address                    ANY
			                                       DEFAULT 10.10.0.1]
			 	[-slave_ip_increment_by               ANY
			                                       DEFAULT 0.0.0.1]
			 	[-slave_mac_address                   ANY
			                                       DEFAULT aa:bb:cd:00:00:00]
			 	[-slave_mac_increment_by              ANY
			                                       DEFAULT 00:00:00:00:00:01]
			x	[-drop_malformed                      CHOICES 0 1]
			x	[-delay_req_drop_rate                 RANGE 0-100
			x                                      DEFAULT 0]
			x	[-delay_req_offset                    RANGE 50-200
			x                                      DEFAULT 100]
			x	[-delay_req_spread                    RANGE 0-50
			x                                      DEFAULT 0]
			x	[-multicastAddress                    CHOICES nonforwardable forwardable
			x                                      DEFAULT nonforwardable]
			x	[-not_slave                           CHOICES 0 1]
			x	[-path_trace_tlv                      CHOICES 0 1]
			x	[-tx_two_step_calibration             RANGE 0-1000000
			x                                      DEFAULT 0]
			x	[-one_way                             CHOICES 0 1]
			x	[-simulate_boundary                   CHOICES 0 1
			x                                      DEFAULT 0]
			x	[-grandmaster_identity                ANY
			x                                      DEFAULT 00:00:00:00:00:00:00:01]
			x	[-simulate_transparent                CHOICES 0 1]
			x	[-sync_residence_time                 ANY]
			x	[-follow_up_residence_time            ANY]
			x	[-delay_req_residence_time            ANY]
			x	[-delay_resp_residence_time           ANY]
			x	[-p_delay_follow_up_residence_time    ANY]
			x	[-offset_scaled_log_variance          ANY]
			x	[-role                                CHOICES slave master]
			x	[-master_ipv6_address                 ANY]
			x	[-master_ipv6_increment_by            ANY]
			x	[-slave_ipv6_address                  ANY]
			x	[-slave_ipv6_increment_by             ANY]
			 	[-mtu                                 RANGE 68-9216]
			x	[-mac_address_init                    MAC]
			x	[-mac_address_step                    MAC
			x                                      DEFAULT 0000.0000.0001]
			x	[-vlan                                CHOICES 0 1]
			 	[-vlan_id_mode                        CHOICES fixed increment
			                                       DEFAULT increment]
			 	[-vlan_id                             RANGE 0-4096]
			 	[-vlan_id_step                        RANGE 0-4096
			                                       DEFAULT 1]
			 	[-vlan_user_priority                  RANGE 0-7
			                                       DEFAULT 0]
			 	[-ip_type                             CHOICES ipv4 ipv6
			                                       DEFAULT ipv4]
			 	[-intf_ip_addr                        IP]
			 	[-intf_ip_addr_step                   IP
			                                       DEFAULT 0.0.1.0]
			 	[-intf_prefix_length                  RANGE 1-128
			                                       DEFAULT 24]
			 	[-neighbor_intf_ip_addr               IP
			                                       DEFAULT 0.0.0.0]
			 	[-neighbor_intf_ip_addr_step          IP
			                                       DEFAULT 0.0.0.0]
			 	[-intf_ipv6_addr                      IP]
			 	[-intf_ipv6_addr_step                 IP
			                                       DEFAULT 0000:0000:0000:0000:0000:0000:0000:0001]
			 	[-intf_prefixv6_length                RANGE 1-128
			                                       DEFAULT 64]
			 	[-neighbor_intf_ipv6_addr             IP]
			 	[-neighbor_intf_ipv6_addr_step        IP
			                                       DEFAULT 0000:0000:0000:0000:0000:0000:0000:0001]
			x	[-num_sessions                        RANGE 1-100000000
			x                                      DEFAULT 10]
		
		Arguments:
			x	-mode
			x		create - creates and configures a new object
			x		add - not supported in case of ::ixiangpf::ptp_over_ip_config.
			x		modify - modified attributes on the given object by the -handle param
			x		delete - deletes the object given by the -handle param
			x		Valid choices are:
			x   		create - Creates and configures a new object.
			x   		add - Not supported in case of ::ixiangpf::ptp_over_ip_config.
			x   		modify - Modified attributes on the given object by the -handle param.
			x   		delete - Deletes the object given by the -handle param.
			x	-parent_handle
			x		The parent handle used for creating this object. It can be a topology, or a device group, or an ethernet or an ipv4/v6.
			x	-handle
			x		A handle returned via a ::ixiangpf::ptp_over_ip_config command. This is used for mode modify.
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-announce_current_utc_offset_valid
			x		Set Announce currentUtcOffsetValid bit.
			x	-announce_drop_rate
			x		Percentage rate of the dropped Announce messages.
			x	-announce_frequency_traceable
			x		Set Announce frequency traceable bit.
			x	-announce_leap59
			x		Set Announce leap59 bit.
			x	-announce_leap61
			x		Set Announce leap61 bit.
			x	-announce_ptp_timescale
			x		Set Announce ptpTimescale bit.
			x	-announce_receipt_timeout
			x		The number of announceInterval that has to pass without receipt of an Announce message.
			x	-announce_time_traceable
			x		Set Announce time traceable bit.
			x	-client_count
			x		The total number of Unicast clients to be used for the range.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-client_ip_address
			x		Defines the base address to be used for enumerating all the addresses
			x		in the range.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-client_ip_increment_by
			x		Defines the increment to be used for enumerating all the addresses
			x		in the range.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-client_mac_address
			x		Defines the base address to be used for enumerating all the addresses
			x		in the range.
			x		This property is used in conjunction with 'clientMacIncrementBy' as an incrementor.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-client_mac_increment_by
			x		Defines the increment to be used for enumerating all the addresses
			x		in the range.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-clock_accuracy
			x		Clock accuracy.
			x		Valid choices are:
			x		32 - {The time is accurate to within 25 ns}
			x		33 - {The time is accurate to within 100 ns}
			x		34 - {The time is accurate to within 250 ns}
			x		35 - {The time is accurate to within 1 us}
			x		36 - {The time is accurate to within 2.5 us}
			x		37 - {The time is accurate to within 10 us}
			x		38 - {The time is accurate to within 25 us}
			x		39 - {The time is accurate to within 100 us}
			x		40 - {The time is accurate to within 250 us}
			x		41 - {The time is accurate to within 1 ms}
			x		42 - {The time is accurate to within 2.5 ms}
			x		43 - {The time is accurate to within 10 ms}
			x		44 - {The time is accurate to within 25 ms}
			x		45 - {The time is accurate to within 100 ms}
			x		46 - {The time is accurate to within 250 ms}
			x		47 - {The time is accurate to within 1 s}
			x		48 - {The time is accurate to within 10 s}
			x		49 - {The time is accurate to greater than 10 s}
			x		Valid choices are:
			x   		32 - The time is accurate to within 25 ns.
			x   		33 - The time is accurate to within 100 ns.
			x   		34 - The time is accurate to within 250 ns.
			x   		35 - The time is accurate to within 1 us.
			x   		36 - The time is accurate to within 2.5 us.
			x   		37 - The time is accurate to within 10 us.
			x   		38 - The time is accurate to within 25 us.
			x   		39 - The time is accurate to within 100 us.
			x   		40 - The time is accurate to within 250 us.
			x   		41 - The time is accurate to within 1 ms.
			x   		42 - The time is accurate to within 2.5 ms.
			x   		43 - The time is accurate to within 10 ms.
			x   		44 - The time is accurate to within 25 ms.
			x   		45 - The time is accurate to within 100 ms.
			x   		46 - The time is accurate to within 250 ms.
			x   		47 - The time is accurate to within 1 s.
			x   		48 - The time is accurate to within 10 s.
			x   		49 - The time is accurate to greater than 10 s.
			x	-clock_class
			x		Traceability of the time or frequency distributed by the grandmaster clock.
			x	-clock_increment
			x		Defines the ClockIdentity increment to be used in this range.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-communication_mode
			x		Communication mode (unicast/multicast/mixedmode).
			x		Valid choices are:
			x		multicast - Multicast
			x		unicast - Unicast
			x		mixedmode - MixedMode
			x		g8265 - deprecated for ixngpf command
			x		Valid choices are:
			x   		multicast - Multicast
			x   		unicast - Unicast
			x   		mixedmode - MixedMode
			x   		g8265 - DEPRECATED for ixngpf command.
			x	-delay_mechanism
			x		Clock delay mechanism.
			x		Valid choices are:
			x		E2E - RequestResponse
			x		P2P - PeerDelay
			x		1WAY - deprecated for ixngpf command
			x		Valid choices are:
			x   		E2E - RequestResponse
			x   		P2P - PeerDelay
			x   		1WAY - DEPRECATED for ixngpf command.
			x	-delay_resp_drop_rate
			x		Percentage rate of the dropped Delay_Resp messages.
			x	-delay_resp_receipt_timeout
			x		DelayResponse Receipt Timeout in seconds.
			x	-delay_response_delay
			x		Additional delay introduced in the Delay_Resp message timestamp (nanoseconds).
			x	-delay_response_delay_insertion_rate
			x		Percentage rate of the Delay_Resp messages in which the delay is introduced.
			x	-domain
			x		PTP Domain.
			x	-drop_signal_req_announce
			x		Select this check box to drop any Signal Request that contains Announce TLV.
			x	-drop_signal_req_delay_resp
			x		Select this check box to drop any Signal Request that contains DelayResp TLV.
			x	-drop_signal_req_sync
			x		Select this check box to drop any Signal Request that contains Sync TLV.
			x	-enabled
			x		Disabled ranges won't be configured nor validated.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-first_clock
			x		Defines the ClockIdentity to be used by this device.
			x	-follow_up_bad_crc_rate
			x		Percentage rate of the bad crc Follow_Up messages.
			x	-follow_up_delay
			x		Additional delay introduced in the Follow_Up message timestamp (nanoseconds).
			x	-follow_up_delay_insertion_rate
			x		Percentage rate of the Follow_Up messages in which the delay is introduced.
			x	-follow_up_drop_rate
			x		Percentage rate of the dropped Follow_Up messages.
			x	-grant_delay_resp_duration_interval
			x		Value of DurationField in REQUEST_UNICAST_TRANSMISSION_TLV for DelayResp messages.
			x	-grant_sync_duration_interval
			x		Value of DurationField in REQUEST_UNICAST_TRANSMISSION_TLV for Sync messages.
			x	-grant_unicast_duration_interval
			x		Value of DurationField in REQUEST_UNICAST_TRANSMISSION_TLV.
			x	-ip_tos
			x		DEPRECATED - Use per port option for setting IP TOS or DS.
			x	-learn_port_id
			x		Slave learns Master Port ID.
			x	-log_announce_interval
			x		The log mean time interval between successive Announce messages.
			x		Valid choices are:
			x		minus 9 - {-9 (512 per second)}
			x		minus 8 - {-8 (256 per second)}
			x		minus 7 - {-7 (128 per second)}
			x		minus 6 - {-6 (64 per second)}
			x		minus 5 - {-5 (32 per second)}
			x		minus 4 - {-4 (16 per second)}
			x		minus 3 - {-3 (8 per second)}
			x		minus 2 - {-2 (4 per second)}
			x		minus 1 - {-1 (2 per second)}
			x		0 - {0 (1 per second)}
			x		1 - {1 (1 per 2 seconds)}
			x		2 - {2 (1 per 4 seconds)}
			x		3 - {3 (1 per 8 seconds)}
			x		4 - {4 (1 per 16 seconds)}
			x		5 - {5 (1 per 32 seconds)}
			x		6 - {6 (1 per 64 seconds)}
			x		7 - {7 (1 per 128 seconds)}
			x		8 - {8 (1 per 256 seconds)}
			x		9 - {9 (1 per 512 seconds)}
			x		Valid choices are:
			x   		247 - -9 (512 per second)
			x   		248 - -8 (256 per second)
			x   		249 - -7 (128 per second)
			x   		250 - -6 (64 per second)
			x   		251 - -5 (32 per second)
			x   		252 - -4 (16 per second)
			x   		253 - -3 (8 per second)
			x   		254 - -2 (4 per second)
			x   		255 - -1 (2 per second)
			x   		0 - 0 (1 per second)
			x   		1 - 1 (1 per 2 seconds)
			x   		2 - 2 (1 per 4 seconds)
			x   		3 - 3 (1 per 8 seconds)
			x   		4 - 4 (1 per 16 seconds)
			x   		5 - 5 (1 per 32 seconds)
			x   		6 - 6 (1 per 64 seconds)
			x   		7 - 7 (1 per 128 seconds)
			x   		8 - 8 (1 per 256 seconds)
			x   		9 - 9 (1 per 512 seconds)
			x	-log_delay_req_interval
			x		The log mean time interval between successive (P)Delay_Req messages.
			x		Valid choices are:
			x		minus 9 - {-9 (512 per second)}
			x		minus 8 - {-8 (256 per second)}
			x		minus 7 - {-7 (128 per second)}
			x		minus 6 - {-6 (64 per second)}
			x		minus 5 - {-5 (32 per second)}
			x		minus 4 - {-4 (16 per second)}
			x		minus 3 - {-3 (8 per second)}
			x		minus 2 - {-2 (4 per second)}
			x		minus 1 - {-1 (2 per second)}
			x		0 - {0 (1 per second)}
			x		1 - {1 (1 per 2 seconds)}
			x		2 - {2 (1 per 4 seconds)}
			x		3 - {3 (1 per 8 seconds)}
			x		4 - {4 (1 per 16 seconds)}
			x		5 - {5 (1 per 32 seconds)}
			x		6 - {6 (1 per 64 seconds)}
			x		7 - {7 (1 per 128 seconds)}
			x		8 - {8 (1 per 256 seconds)}
			x		9 - {9 (1 per 512 seconds)}
			x		Valid choices are:
			x   		247 - -9 (512 per second)
			x   		248 - -8 (256 per second)
			x   		249 - -7 (128 per second)
			x   		250 - -6 (64 per second)
			x   		251 - -5 (32 per second)
			x   		252 - -4 (16 per second)
			x   		253 - -3 (8 per second)
			x   		254 - -2 (4 per second)
			x   		255 - -1 (2 per second)
			x   		0 - 0 (1 per second)
			x   		1 - 1 (1 per 2 seconds)
			x   		2 - 2 (1 per 4 seconds)
			x   		3 - 3 (1 per 8 seconds)
			x   		4 - 4 (1 per 16 seconds)
			x   		5 - 5 (1 per 32 seconds)
			x   		6 - 6 (1 per 64 seconds)
			x   		7 - 7 (1 per 128 seconds)
			x   		8 - 8 (1 per 256 seconds)
			x   		9 - 9 (1 per 512 seconds)
			x	-log_sync_interval
			x		The log mean time interval between successive Sync messages.
			x		Valid choices are:
			x		minus 9 - {-9 (512 per second)}
			x		minus 8 - {-8 (256 per second)}
			x		minus 7 - {-7 (128 per second)}
			x		minus 6 - {-6 (64 per second)}
			x		minus 5 - {-5 (32 per second)}
			x		minus 4 - {-4 (16 per second)}
			x		minus 3 - {-3 (8 per second)}
			x		minus 2 - {-2 (4 per second)}
			x		minus 1 - {-1 (2 per second)}
			x		0 - {0 (1 per second)}
			x		1 - {1 (1 per 2 seconds)}
			x		2 - {2 (1 per 4 seconds)}
			x		3 - {3 (1 per 8 seconds)}
			x		4 - {4 (1 per 16 seconds)}
			x		5 - {5 (1 per 32 seconds)}
			x		6 - {6 (1 per 64 seconds)}
			x		7 - {7 (1 per 128 seconds)}
			x		8 - {8 (1 per 256 seconds)}
			x		9 - {9 (1 per 512 seconds)}
			x		Valid choices are:
			x   		247 - -9 (512 per second)
			x   		248 - -8 (256 per second)
			x   		249 - -7 (128 per second)
			x   		250 - -6 (64 per second)
			x   		251 - -5 (32 per second)
			x   		252 - -4 (16 per second)
			x   		253 - -3 (8 per second)
			x   		254 - -2 (4 per second)
			x   		255 - -1 (2 per second)
			x   		0 - 0 (1 per second)
			x   		1 - 1 (1 per 2 seconds)
			x   		2 - 2 (1 per 4 seconds)
			x   		3 - 3 (1 per 8 seconds)
			x   		4 - 4 (1 per 16 seconds)
			x   		5 - 5 (1 per 32 seconds)
			x   		6 - 6 (1 per 64 seconds)
			x   		7 - 7 (1 per 128 seconds)
			x   		8 - 8 (1 per 256 seconds)
			x   		9 - 9 (1 per 512 seconds)
			x	-master_count
			x		The total number of Unicast masters to be used.
			x	-master_ip_address
			x		Defines the base address to be used for enumerating all the addresses.
			x	-master_ip_increment_by
			x		Defines the increment to be used for enumerating all the addresses.
			x	-master_ip_increment_inter_entity
			x		Defines the increment to be used for the start address of Master
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-master_mac_address
			x		Defines the base address to be used for enumerating all the addresses.
			x	-master_mac_increment_by
			x		Defines the increment to be used for enumerating all the addresses.
			x	-master_mac_increment_inter_entity
			x		Defines the increment to be used for the start address of Master
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-name
			x		Name of protocol.
			x	-port_number
			x		Port number.
			x	-port_number_increment
			x		Port number increment
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-priority1
			x		PTP priority1.
			x	-priority2
			x		PTP priority2.
			x	-renewal_invited
			x		Set the Renewal Invited flag in Grant Unicast Transmission TLV.
			x	-request_attempts
			x		How many succesive requests a slave can request before entering into holddown.
			x	-request_holddown
			x		Time between succesive requests if denied/timeout for Signal Request.
			x	-request_interval
			x		Time between succesive requests if denied/timeout for Signal Request.
			x	-residence_time
			x		DEPRECATED - use per message setting of Residence Time.
			x	-rx_calibration
			x		The amount of time (in ns) that the Receive side timestamp needs to be offset to allow for error.
			x	-send_announce_multicast
			x		Send multicast Announce messages.
			x	-send_announce_tlv
			x		Send and respond to Announce TLV unicast requests in signal messages.
			x	-send_cancel_tlv
			x		Send and respond to Cancel TLV unicast requests in signal messages.
			x	-signal_interval
			x		Time between Signal Request messages, in seconds.
			x	-signal_unicast_handling
			x		Valid choices are:
			x		individually - {Send Individually}
			x		allInOne - {Send In One Message}
			x		doNotSend - {Do Not Send}
			x		Valid choices are:
			x   		individually - Send Individually
			x   		allInOne - Send In One Message
			x   		doNotSend - Do Not Send
			x	-step_mode
			x		Clock step mode.
			x		Valid choices are:
			x		two-step - TwoStep
			x		single-step - SingleStep
			x		Valid choices are:
			x   		two-step - TwoStep
			x   		single-step - SingleStep
			x	-steps_removed
			x		The number of hops between the Grandmaster Clock and the emulated clock. Valid values: 0 to 65,535.
			x	-strict_grant
			x		If selected, server will not grant values that are above maximum offered values.
			x	-sync_drop_rate
			x		Percentage rate of the dropped Sync messages.
			x	-sync_receipt_timeout
			x		Sync Receipt Timeout in seconds.
			x	-time_source
			x		Time source for the PTP device.
			x		Valid choices are:
			x		0X10 - AtomicClock
			x		0X20 - GPS
			x		0X30 - TerrestrialRadio
			x		0X40 - PTP
			x		0X50 - NTP
			x		0X60 - HandSet
			x		0X90 - Other
			x		0XA0 - InternalOscilator
			x		Valid choices are:
			x   		0X10 - AtomicClock
			x   		0X20 - GPS
			x   		0X30 - TerrestrialRadio
			x   		0X40 - PTP
			x   		0X50 - NTP
			x   		0X60 - HandSet
			x   		0X90 - Other
			x   		0XA0 - InternalOscilator
			x	-timestamp_offset
			x		Timestamp offset.
			x	-timestamp_offset_variation
			x		Timestamp offset variation.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-tx_calibration
			x		The amount of time (in ns) that the transmit timestamp of one step messages (Sync, PDelayResp) needs to be adjusted for error.
			x	-use_alternate_master_flag
			x		Select this check box to set the Alternate Master flag in all Announce and Sync messages.
			x	-use_clock_identity
			x		Use the ClockIdentity configured in the next column instead of MAC based generated one.
			x	-profile
			x		The profile used by this clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		ieee1588 -
			x   		g82651 -
			x   		g82751 -
			x   		ieee8021as -
			 	-current_utc_offset
			 		Set announced Current UTC Offset (seconds)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-sync_receipt_timeout_gptp
			x		The number of Sync Intervals that have to pass without receipt of an Sync message to trigger timeout.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-bmca
			x		Run the Best Master Clock Algorithm for gPTP (if disabled can use a pre-defined Master or accept messages from any source)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-reverse_sync
			x		As a slave, periodically send Reverse Sync messages with recovered clock.
			x		As a master, calculate the Offset of the Slave reported time to master time.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-reverse_sync_interval_percent
			x		The percentage of incoming Sync interval to use for Reverse Sync interval.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-cumulative_scaled_rate_offset
			x		Cumulative Scaled Rate Offset field set in the gPTP FollowUp TLV.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-gm_time_base_indicator
			x		GM Time Base Indicator field set in the gPTP FollowUp TLV.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-last_gm_phase_change
			x		Last GM Phase Change nanoseconds set in the gPTP FollowUp TLV.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-scaled_last_gm_freq_change
			x		Scaled Last GM Freq Change field set in the gPTP FollowUp TLV.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-update_time
			x		Clocks in Slave role will correct their time based on received Sync messages.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-nanoseconds_per_second
			x		The number of nanoseconds the emulated clock should effectively count for one second of hardware ticks.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-slave_count
			 		The total number of Unicast slaves to be used.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-slave_ip_address
			 		Defines the base address to be used for enumerating all the addresses.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-slave_ip_increment_by
			 		Defines the increment to be used for enumerating all the addresses.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-slave_mac_address
			 		Defines the base address to be used for enumerating all the addresses.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-slave_mac_increment_by
			 		Defines the increment to be used for enumerating all the addresses.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-drop_malformed
			x		Drop packets that for which fields like Domain, message rates, Clock Class, Clock Accuracy
			x		and Offset Scaled Log Variance are not respecting strict G8275.1 imposed intervals.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-delay_req_drop_rate
			x		Percentage rate of the dropped (P)DelayReq messages.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-delay_req_offset
			x		Percentage of the agreed (P)DelayReq Inter-arrival time to schedule between two subsequent DelayReq messages.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-delay_req_spread
			x		Distribute (P)DelayReq messages in an interval around the targeted Inter-arrival mean time (expressed as a % of targeted mean).
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-multicastAddress
			x		The destination multicast address for G8275.1:
			x		non-forwardable - 01:80:C2:00:00:0E (recommended)
			x		forwardable - 01:1B:19:00:00:00
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		nonforwardable - Non-forwardable
			x   		forwardable - Forwardable
			x	-not_slave
			x		When enabled for Master clocks it prevents a G8275.1 port from going into Slave state, by ignoring Announce messages.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-path_trace_tlv
			x		If selected, the master will append a Path Trace TLV to Announce messages.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-tx_two_step_calibration
			x		The amount of time (in ns) that the read transmit timestamp of sent messages (two-step Sync, DelayReq, PDelayReq, two-step PDelayResp) needs to be adjusted for error.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-one_way
			x		Do not send Delay Requests.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-simulate_boundary
			x		Simulate a transparent clock in front of this master clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-grandmaster_identity
			x		Defines the ClockIdentity of the Grandmaster behind this device.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-simulate_transparent
			x		Simulate a transparent clock in front of this master clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-sync_residence_time
			x		Master to slave residence time of Sync messages through an associated one-step
			x		transparent clock inserted in the correction field of Sync messages sent by this clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-follow_up_residence_time
			x		Master to slave residence of Sync messages through an associated two-step transparent clock
			x		inserted in the correction field of FollowUp messages sent by this clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-delay_req_residence_time
			x		Residence time of (P)DelayReq messages through an associated one-step end-to-end
			x		transparent clock inserted in the correction field of (P)DelayReq messages sent by this clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-delay_resp_residence_time
			x		Residence time of DelayReq messages through an associated two-step end-to-end transparent clock inserted
			x		in the correction field of DelayResp messages sent by this clock, or the residence time of PdelayResp messages
			x		through an associated one-step end-to-end transparent clock inserted in the correction field
			x		of PdelayResp messages sent by this clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p_delay_follow_up_residence_time
			x		Total residence time of PdelayReq and PdelayResp messagews through an associated two-step end-to-end
			x		transparent clock inserted in the correction field of PdelayRespFollowUp messages sent by this clock
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-offset_scaled_log_variance
			x		Static Offset Scaled Log Variance of this clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-role
			x		The desired role of this clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		slave -
			x   		master -
			x	-master_ipv6_address
			x		Defines the base address to be used for enumerating all the addresses.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-master_ipv6_increment_by
			x		Defines the increment to be used for enumerating all the addresses.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-slave_ipv6_address
			x		Defines the base address to be used for enumerating all the addresses.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-slave_ipv6_increment_by
			x		Defines the increment to be used for enumerating all the addresses.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-mtu
			 		The advertised MTU value in database entries sent to other routers create on the Ixia interface. RANGE 68-9216.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-mac_address_init
			x		This option defines the MAC address that will be configured on
			x		the Ixia interface. This parameter is not valid on mode modify when
			x		IxTclProtocol is used.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-mac_address_step
			x		This option defines the incrementing step for the MAC address that
			x		will be configured on the Ixia interface.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-vlan
			x		Enables vlan.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-vlan_id_mode
			 		If the user configures more than one interface on the Ixia with
			 		VLAN, he can choose to automatically increment the VLAN tag or
			 		leave it idle for each interface. CHOICES fixed increment.
			 		This parameter is not valid on mode modify when IxTclProtocol is used.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		fixed -
			    		increment -
			 	-vlan_id
			 		If VLAN is enable on the Ixia interface, this option will configure the VLAN number.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_id_step
			 		If the -vlan_id_mode is increment, this will be the step value by
			 		which the VLAN tags are incremented. RANGE 0-4095
			 		When vlan_id_step causes the vlan_id value to exceed it's maximum value the
			 		increment will be done modulo <number of possible vlan ids>.
			 		Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0
			 		vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_user_priority
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-ip_type
			 		ipv4
			 		ipv6
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		ipv4 -
			    		ipv6 -
			 	-intf_ip_addr
			 		The IP address of the IP Protocol from underneath PTP Protocol
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-intf_ip_addr_step
			 		What step will be use for incrementing the -intf_ip_addr option.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-intf_prefix_length
			 		Defines the mask of the IP address used for the Ixia (-intf_ip_addr) and the DUT interface.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-neighbor_intf_ip_addr
			 		The IPv4 address of the gateway.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-neighbor_intf_ip_addr_step
			 		What step will be use for incrementing the -neighbor_intf_ip_addr option.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-intf_ipv6_addr
			 		The IPv6 address of the IP Protocol from underneath the PTP Protocol.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-intf_ipv6_addr_step
			 		What step will be use for incrementing the -intf_ipv6_addr option.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-intf_prefixv6_length
			 		Defines the mask of the IPv6 address used for the Ixia (-intf_ipv6_addr) and the DUT interface.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-neighbor_intf_ipv6_addr
			 		The IPv6 address of the gateway.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-neighbor_intf_ipv6_addr_step
			 		What step will be use for incrementing the -neighbor_intf_ipv6_addr option.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-num_sessions
			x		The number of PTP sessions to configure.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status      value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log         value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles     value:The returned handle(s) of the  config command.
		A list containing the ptp protocol stack handles that were added by the command (if any).
			xkey:ptp_handle  value:A list containing the ptp protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:handle      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		ptp_over_ip handles
			 key:handles     value:ptp_over_ip handles
		When status is failure, contains more information
			 key:log         value:When status is failure, contains more information
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("ptp_over_ip_config", kwargs)

	def ptp_over_ip_control(self, **kwargs):
		""" Perform control plane operations on an endpoint created     by a ::ixiangpf::ptp_over_ip_config command
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: ptp_over_ip_control
			x	-handle  ANY
			x	-action  CHOICES abort
			x         CHOICES abort_async
			x         CHOICES start
			x         CHOICES connect
			x         CHOICES stop
			x         CHOICES disconnect
			x         CHOICES sendgPtpSignaling
		
		Arguments:
			x	-handle
			x		A handle returned via a ::<namespace>::ptp_over_ip_config
			x		command. This is the object on which the action will take place.
			x	-action
			x		Action to be executed. Valid choices are:
			x		abort- abort all sessions on the same port with the target
			x		endpoint designated by -handle. The control is
			x		returned when the operation is completed.
			x		abort_async- abort all sessions on the same port with the target
			x		endpoint designated by -handle. The control is
			x		returned immediately. The operation is executed in the background.
			x		start/connect - start and/or negotiate session for the target endpoint
			x		designated by -handle. Start and connect offer the same functionality.
			x		stop/disconnect - stop and/or release session for the target endpoint
			x		designated by -handle. Stop and disconnect offer the same functionality.
			x		Valid choices are:
			x   		abort - Aborts the PTP. The command returns when the operation is completed.
			x   		abort_async - Aborts the PTP. The command returns immediately and the operation is executed in the backgronud.
			x   		start - Start and connect offer the same functionality.
			x   		connect - Start and connect offer the same functionality.
			x   		stop - Stop and disconnect offer the same functionality.
			x   		disconnect - Stop and disconnect offer the same functionality.
			x   		sendgPtpSignaling - Send Signaling messages for the selected PTP IEEE 802.1AS sessions.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status         value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log            value:Error message if command returns {status 0}
		The result(s) of the  control action.
			 key:inner_results  value:The result(s) of the  control action.
		When status is failure, contains more information
			 key:log            value:When status is failure, contains more information
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		This command applies only to IxNetwork.
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("ptp_over_ip_control", kwargs)

	def ptp_over_ip_stats(self, **kwargs):
		""" Retrieve statistics plane on an endpoint created     by a ::ixiangpf::ptp_over_ip_config command
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: ptp_over_ip_stats
			x	[-port_handle ANY]
			 	[-handle      ANY]
			x	-mode         CHOICES aggregate session]
		
		Arguments:
			x	-port_handle
			x		The port handle for which the ptp_over_ip stats need to
			x		be retrieved
			 	-handle
			 		The PTP handle for which the PTP statistics are to be retrieved. Valid for -mode session.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-mode
			x		Specifies statistics retrieval mode as either aggregate for all
			x		configured sessions or on a per session basis.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		aggregate - Retrieve statistics for all the sessions.
			x   		session - Retrieve statistics for each individual session.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                          value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log                                                             value:Error message if command returns {status 0}
		Port Name
			 key:<port_handle>.gen.port_name                                     value:Port Name
		Sessions Initiated
			 key:<port_handle>.gen.sessions_initiated                            value:Sessions Initiated
		Sessions Succeeded
			 key:<port_handle>.gen.sessions_succeeded                            value:Sessions Succeeded
		Sessions Failed
			 key:<port_handle>.gen.sessions_failed                               value:Sessions Failed
		Sessions Active
			 key:<port_handle>.gen.sessions_active                               value:Sessions Active
		Initiated Sessions Rate
			 key:<port_handle>.gen.initiated_sessions_rate                       value:Initiated Sessions Rate
		Successful Sessions Rate
			 key:<port_handle>.gen.successful_sessions_rate                      value:Successful Sessions Rate
		Failed Sessions Rate
			 key:<port_handle>.gen.failed_sessions_rate                          value:Failed Sessions Rate
		Announce Messages Sent
			 key:<port_handle>.gen.announce_messages_sent                        value:Announce Messages Sent
		Announce Messages Received
			 key:<port_handle>.gen.announce_messages_received                    value:Announce Messages Received
		Sync Messages Sent
			 key:<port_handle>.gen.sync_messages_sent                            value:Sync Messages Sent
		Sync Messages Received
			 key:<port_handle>.gen.sync_messages_received                        value:Sync Messages Received
		FollowUp Messages Sent
			 key:<port_handle>.gen.followup_messages_sent                        value:FollowUp Messages Sent
		FollowUp Messages Received
			 key:<port_handle>.gen.followup_messages_received                    value:FollowUp Messages Received
		DelayReq Messages Sent
			 key:<port_handle>.gen.delayreq_messages_sent                        value:DelayReq Messages Sent
		DelayReq Messages Received
			 key:<port_handle>.gen.delayreq_messages_received                    value:DelayReq Messages Received
		DelayResp Messages Sent
			 key:<port_handle>.gen.delayresp_messages_sent                       value:DelayResp Messages Sent
		DelayResp Messages Received
			 key:<port_handle>.gen.delayresp_messages_received                   value:DelayResp Messages Received
		PdelayReq Messages Sent
			 key:<port_handle>.gen.pdelayreq_messages_sent                       value:PdelayReq Messages Sent
		PdelayReq Messages Received
			 key:<port_handle>.gen.pdelayreq_messages_received                   value:PdelayReq Messages Received
		PdelayResp Messages Sent
			 key:<port_handle>.gen.pdelayresp_messages_sent                      value:PdelayResp Messages Sent
		PdelayResp Messages Received
			 key:<port_handle>.gen.pdelayrest_messages_received                  value:PdelayResp Messages Received
		PdelayRespFollowUp Messages Sent
			 key:<port_handle>.gen.pdelayrespfollowup_messages_sent              value:PdelayRespFollowUp Messages Sent
		PdelayRespFollowUp Messages Received
			 key:<port_handle>.gen.pdelayrespfollowup_messages_received          value:PdelayRespFollowUp Messages Received
		When status is failure, contains more information
			 key:log                                                             value:When status is failure, contains more information
		Port Name
			 key:[<port_handle.>].gen.port_name                                  value:Port Name
		Sessions Up
			 key:[<port_handle.>].gen.sessions_up                                value:Sessions Up
		Sessions Down
			 key:[<port_handle.>].gen.sessions_down                              value:Sessions Down
		Sessions Not Started
			 key:[<port_handle.>].gen.sessions_not_started                       value:Sessions Not Started
		Sessions Total
			 key:[<port_handle.>].gen.sessions_total                             value:Sessions Total
		Sessions Active
			 key:[<port_handle.>].gen.sessions_active                            value:Sessions Active
		Announce Messages Sent
			 key:[<port_handle.>].gen.announce_messages_sent                     value:Announce Messages Sent
		Announce Messages Received
			 key:[<port_handle.>].gen.announce_messages_received                 value:Announce Messages Received
		Sync Messages Sent
			 key:[<port_handle.>].gen.sync_messages_sent                         value:Sync Messages Sent
		Sync Messages Received
			 key:[<port_handle.>].gen.sync_messages_received                     value:Sync Messages Received
		FollowUp Messages Sent
			 key:[<port_handle.>].gen.followup_messages_sent                     value:FollowUp Messages Sent
		FollowUp Messages Received
			 key:[<port_handle.>].gen.followup_messages_received                 value:FollowUp Messages Received
		DelayReq Messages Sent
			 key:[<port_handle.>].gen.delayreq_messages_sent                     value:DelayReq Messages Sent
		DelayReq Messages Received
			 key:[<port_handle.>].gen.delayreq_messages_received                 value:DelayReq Messages Received
		DelayResp Messages Sent
			 key:[<port_handle.>].gen.delayresp_messages_sent                    value:DelayResp Messages Sent
		DelayResp Messages Received
			 key:[<port_handle.>].gen.delayresp_messages_received                value:DelayResp Messages Received
		PdelayReq Messages Sent
			 key:[<port_handle.>].gen.pdelayreq_messages_sent                    value:PdelayReq Messages Sent
		PdelayReq Messages Received
			 key:[<port_handle.>].gen.pdelayreq_messages_received                value:PdelayReq Messages Received
		PdelayResp Messages Sent
			 key:[<port_handle.>].gen.pdelayresp_messages_sent                   value:PdelayResp Messages Sent
		PdelayResp Messages Received
			 key:[<port_handle.>].gen.pdelayrest_messages_received               value:PdelayResp Messages Received
		PdelayRespFollowUp Messages Sent
			 key:[<port_handle.>].gen.pdelayrespfollowup_messages_sent           value:PdelayRespFollowUp Messages Sent
		PdelayRespFollowUp Messages Received
			 key:[<port_handle.>].gen.pdelayrespfollowup_messages_received       value:PdelayRespFollowUp Messages Received
		Signaling Messages Sent
			 key:[<port_handle.>].gen.signaling_messages_sent                    value:Signaling Messages Sent
		Signaling Messages Received
			 key:[<port_handle.>].gen.signaling_messages_received                value:Signaling Messages Received
		Sync Messages Received Rate
			 key:[<port_handle.>].gen.sync_messages_received_rate                value:Sync Messages Received Rate
		FollowUp Messages Received Rate
			 key:[<port_handle.>].gen.followup_messages_received_rate            value:FollowUp Messages Received Rate
		DelayReq Messages Received Rate
			 key:[<port_handle.>].gen.delayreq_messages_received_rate            value:DelayReq Messages Received Rate
		DelayResp Messages Received Rate
			 key:[<port_handle.>].gen.delayresp_messages_received_rate           value:DelayResp Messages Received Rate
		PdelayReq Messages Received Rate
			 key:[<port_handle.>].gen.pdelayreq_messages_received_rate           value:PdelayReq Messages Received Rate
		PdelayResp Messages Received Rate
			 key:[<port_handle.>].gen.pdelayresp_messages_received_rate          value:PdelayResp Messages Received Rate
		PdelayRespFollowUp Messages Received Rate
			 key:[<port_handle.>].gen.pdelayrespfollowup_messages_received_rate  value:PdelayRespFollowUp Messages Received Rate
		GPS Unit Present
			 key:[<port_handle.>].gen.gps_unit_present                           value:GPS Unit Present
		GPS Synchronized
			 key:[<port_handle.>].gen.gps_synchronized                           value:GPS Synchronized
		Sessions Up
			 key:[<handle.>].gen.sessions_up                                     value:Sessions Up
		Sessions Down
			 key:[<handle.>].gen.sessions_down                                   value:Sessions Down
		Sessions Not Started
			 key:[<handle.>].gen.sessions_not_started                            value:Sessions Not Started
		Sessions Total
			 key:[<handle.>].gen.sessions_total                                  value:Sessions Total
		Sessions Active
			 key:[<handle.>].gen.sessions_active                                 value:Sessions Active
		Announce Messages Sent
			 key:[<handle.>].gen.announce_messages_sent                          value:Announce Messages Sent
		Announce Messages Received
			 key:[<handle.>].gen.announce_messages_received                      value:Announce Messages Received
		Sync Messages Sent
			 key:[<handle.>].gen.sync_messages_sent                              value:Sync Messages Sent
		Sync Messages Received
			 key:[<handle.>].gen.sync_messages_received                          value:Sync Messages Received
		FollowUp Messages Sent
			 key:[<handle.>].gen.followup_messages_sent                          value:FollowUp Messages Sent
		FollowUp Messages Received
			 key:[<handle.>].gen.followup_messages_received                      value:FollowUp Messages Received
		DelayReq Messages Sent
			 key:[<handle.>].gen.delayreq_messages_sent                          value:DelayReq Messages Sent
		DelayReq Messages Received
			 key:[<handle.>].gen.delayreq_messages_received                      value:DelayReq Messages Received
		DelayResp Messages Sent
			 key:[<handle.>].gen.delayresp_messages_sent                         value:DelayResp Messages Sent
		DelayResp Messages Received
			 key:[<handle.>].gen.delayresp_messages_received                     value:DelayResp Messages Received
		PdelayReq Messages Sent
			 key:[<handle.>].gen.pdelayreq_messages_sent                         value:PdelayReq Messages Sent
		PdelayReq Messages Received
			 key:[<handle.>].gen.pdelayreq_messages_received                     value:PdelayReq Messages Received
		PdelayResp Messages Sent
			 key:[<handle.>].gen.pdelayresp_messages_sent                        value:PdelayResp Messages Sent
		PdelayResp Messages Received
			 key:[<handle.>].gen.pdelayrest_messages_received                    value:PdelayResp Messages Received
		PdelayRespFollowUp Messages Sent
			 key:[<handle.>].gen.pdelayrespfollowup_messages_sent                value:PdelayRespFollowUp Messages Sent
		PdelayRespFollowUp Messages Received
			 key:[<handle.>].gen.pdelayrespfollowup_messages_received            value:PdelayRespFollowUp Messages Received
		Signaling Messages Sent
			 key:[<handle.>].gen.signaling_messages_sent                         value:Signaling Messages Sent
		Signaling Messages Received
			 key:[<handle.>].gen.signaling_messages_received                     value:Signaling Messages Received
		Status
			 key:session.<session ID>.status                                     value:Status
		Configured Role
			 key:session.<session ID>.configured_role                            value:Configured Role
		PTP State
			 key:session.<session ID>.ptp_state                                  value:PTP State
		Offset [ns]
			 key:session.<session ID>.offset                                     value:Offset [ns]
		Max Offset [ns]
			 key:session.<session ID>.offset_max                                 value:Max Offset [ns]
		Min Offset [ns]
			 key:session.<session ID>.offset_min                                 value:Min Offset [ns]
		Avg Offset [ns]
			 key:session.<session ID>.offset_avg                                 value:Avg Offset [ns]
		Path Delay [ns]
			 key:session.<session ID>.path_delay                                 value:Path Delay [ns]
		Max Path Delay [ns]
			 key:session.<session ID>.path_delay_max                             value:Max Path Delay [ns]
		Min Path Delay [ns]
			 key:session.<session ID>.path_delay_min                             value:Min Path Delay [ns]
		Avg Path Delay [ns]
			 key:session.<session ID>.path_delay_avg                             value:Avg Path Delay [ns]
		Time Slope
			 key:session.<session ID>.time_slope                                 value:Time Slope
		Port Identity
			 key:session.<session ID>.port_identity                              value:Port Identity
		Master Port Identity
			 key:session.<session ID>.master_port_identity                       value:Master Port Identity
		Grandmaster Port Identity
			 key:session.<session ID>.grandmaster_port_identity                  value:Grandmaster Port Identity
		Local Clock Class
			 key:session.<session ID>.port_clock_class                           value:Local Clock Class
		Master Clock Class
			 key:session.<session ID>.master_clock_class                         value:Master Clock Class
		Local Clock Accuracy
			 key:session.<session ID>.port_clock_accuracy                        value:Local Clock Accuracy
		Master Clock Accuracy
			 key:session.<session ID>.master_clock_accuracy                      value:Master Clock Accuracy
		Current UTC Offset
			 key:session.<session ID>.current_utc_offset                         value:Current UTC Offset
		Steps Removed
			 key:session.<session ID>.steps_removed                              value:Steps Removed
		Leap59
			 key:session.<session ID>.leap59                                     value:Leap59
		Leap61
			 key:session.<session ID>.leap61                                     value:Leap61
		Frequency Traceable
			 key:session.<session ID>.frequency_traceable                        value:Frequency Traceable
		Time Traceable
			 key:session.<session ID>.time_traceable                             value:Time Traceable
		CF Sync [ns]
			 key:session.<session ID>.cf_sync                                    value:CF Sync [ns]
		CF Sync Max [ns]
			 key:session.<session ID>.cf_sync_max                                value:CF Sync Max [ns]
		CF Sync Min [ns]
			 key:session.<session ID>.cf_sync_min                                value:CF Sync Min [ns]
		CF FollowUp [ns]
			 key:session.<session ID>.cf_follow_up                               value:CF FollowUp [ns]
		CF FollowUp Max [ns]
			 key:session.<session ID>.cf_follow_up_max                           value:CF FollowUp Max [ns]
		CF FollowUp Min [ns]
			 key:session.<session ID>.cf_follow_up_min                           value:CF FollowUp Min [ns]
		CF DelayReq [ns]
			 key:session.<session ID>.cf_delay_req                               value:CF DelayReq [ns]
		CF DelayReq Max [ns]
			 key:session.<session ID>.cf_delay_req_max                           value:CF DelayReq Max [ns]
		CF DelayReq Min [ns]
			 key:session.<session ID>.cf_delay_req_min                           value:CF DelayReq Min [ns]
		CF PdelayReq [ns]
			 key:session.<session ID>.cf_pdelay_req                              value:CF PdelayReq [ns]
		CF PdelayReq Max [ns]
			 key:session.<session ID>.cf_pdelay_req_max                          value:CF PdelayReq Max [ns]
		CF PdelayReq Min [ns]
			 key:session.<session ID>.cf_pdelay_req_min                          value:CF PdelayReq Min [ns]
		CF DelayResp [ns]
			 key:session.<session ID>.cf_delay_resp                              value:CF DelayResp [ns]
		CF DelayResp Max [ns]
			 key:session.<session ID>.cf_delay_resp_max                          value:CF DelayResp Max [ns]
		CF DelayResp Min [ns]
			 key:session.<session ID>.cf_delay_resp_min                          value:CF DelayResp Min [ns]
		CF PdelayResp [ns]
			 key:session.<session ID>.cf_pdelay_resp                             value:CF PdelayResp [ns]
		CF PdelayResp Max [ns]
			 key:session.<session ID>.cf_pdelay_resp_max                         value:CF PdelayResp Max [ns]
		CF PdelayResp Min [ns]
			 key:session.<session ID>.cf_pdelay_resp_min                         value:CF PdelayResp Min [ns]
		CF PdelayRespFollowUp [ns]
			 key:session.<session ID>.cf_pdelay_resp_follow_up                   value:CF PdelayRespFollowUp [ns]
		CF PdelayRespFollowUp Max [ns]
			 key:session.<session ID>.cf_pdelay_resp_follow_up_max               value:CF PdelayRespFollowUp Max [ns]
		CF PdelayRespFollowUp Min [ns]
			 key:session.<session ID>.cf_pdelay_resp_follow_up_min               value:CF PdelayRespFollowUp Min [ns]
		FM 0 Identity
			 key:session.<session ID>.fm_identity_0                              value:FM 0 Identity
		FM 0 Port Number
			 key:session.<session ID>.fm_portNum_0                               value:FM 0 Port Number
		FM 1 Identity
			 key:session.<session ID>.fm_identity_1                              value:FM 1 Identity
		FM 1 Port Number
			 key:session.<session ID>.fm_port_num_1                              value:FM 1 Port Number
		FM 2 Identity
			 key:session.<session ID>.fm_identity_2                              value:FM 2 Identity
		FM 2 Port Number
			 key:session.<session ID>.fm_port_num_2                              value:FM 2 Port Number
		FM 3 Identity
			 key:session.<session ID>.fm_identity_3                              value:FM 3 Identity
		FM 3 Port Number
			 key:session.<session ID>.fm_port_num_3                              value:FM 3 Port Number
		FM 4 Identity
			 key:session.<session ID>.fm_identity_4                              value:FM 4 Identity
		FM 4 Port Number
			 key:session.<session ID>.fm_port_num_4                              value:FM 4 Port Number
		Time t1 [ns]
			 key:session.<session ID>.time_t1                                    value:Time t1 [ns]
		Time t2 [ns]
			 key:session.<session ID>.time_t2                                    value:Time t2 [ns]
		Time t3 [ns]
			 key:session.<session ID>.time_t3                                    value:Time t3 [ns]
		Time t4 [ns]
			 key:session.<session ID>.time_t4                                    value:Time t4 [ns]
		Time t1 UTC
			 key:session.<session ID>.t1_utc                                     value:Time t1 UTC
		Time t2 UTC
			 key:session.<session ID>.t2_utc                                     value:Time t2 UTC
		Time t3 UTC
			 key:session.<session ID>.t3_utc                                     value:Time t3 UTC
		Time t4 UTC
			 key:session.<session ID>.t4_utc                                     value:Time t4 UTC
		IA Announce [ns]
			 key:session.<session ID>.ia_announce                                value:IA Announce [ns]
		IA Announce Max [ns]
			 key:session.<session ID>.ia_announce_max                            value:IA Announce Max [ns]
		IA Announce Min [ns]
			 key:session.<session ID>.ia_announce_min                            value:IA Announce Min [ns]
		IA Sync [ns]
			 key:session.<session ID>.ia_sync                                    value:IA Sync [ns]
		IA Sync Max [ns]
			 key:session.<session ID>.ia_sync_max                                value:IA Sync Max [ns]
		IA Sync Min [ns]
			 key:session.<session ID>.ia_sync_min                                value:IA Sync Min [ns]
		IA FollowUp [ns]
			 key:session.<session ID>.ia_follow_up                               value:IA FollowUp [ns]
		IA FollowUp Max [ns]
			 key:session.<session ID>.ia_follow_up_max                           value:IA FollowUp Max [ns]
		IA FollowUp Min [ns]
			 key:session.<session ID>.ia_follow_up_min                           value:IA FollowUp Min [ns]
		IA DelayReq [ns]
			 key:session.<session ID>.ia_delay_req                               value:IA DelayReq [ns]
		IA DelayReq Max [ns]
			 key:session.<session ID>.ia_delay_req_max                           value:IA DelayReq Max [ns]
		IA DelayReq Min [ns]
			 key:session.<session ID>.ia_delay_req_min                           value:IA DelayReq Min [ns]
		IA DelayResp [ns]
			 key:session.<session ID>.ia_delay_resp                              value:IA DelayResp [ns]
		IA DelayResp Max [ns]
			 key:session.<session ID>.ia_delay_resp_max                          value:IA DelayResp Max [ns]
		IA DelayResp Min [ns]
			 key:session.<session ID>.ia_delay_resp_min                          value:IA DelayResp Min [ns]
		IA PdelayReq [ns]
			 key:session.<session ID>.ia_pdelay_req                              value:IA PdelayReq [ns]
		IA PdelayReq Max [ns]
			 key:session.<session ID>.ia_pdelay_req_max                          value:IA PdelayReq Max [ns]
		IA PdelayReq Min [ns]
			 key:session.<session ID>.ia_pdelay_req_min                          value:IA PdelayReq Min [ns]
		IA PdelayResp [ns]
			 key:session.<session ID>.ia_pdelay_resp                             value:IA PdelayResp [ns]
		IA PdelayResp Max [ns]
			 key:session.<session ID>.ia_pdelay_resp_max                         value:IA PdelayResp Max [ns]
		IA PdelayResp Min [ns]
			 key:session.<session ID>.ia_pdelay_resp_min                         value:IA PdelayResp Min [ns]
		IA PdelayRespFollowUp [ns]
			 key:session.<session ID>.ia_pdelay_resp_follow_up                   value:IA PdelayRespFollowUp [ns]
		IA PdelayRespFollowUp Max [ns]
			 key:session.<session ID>.ia_pdelay_resp_follow_up_max               value:IA PdelayRespFollowUp Max [ns]
		IA PdelayRespFollowUp Min [ns]
			 key:session.<session ID>.ia_pdelay_resp_follow_up_min               value:IA PdelayRespFollowUp Min [ns]
		Announce Messages Sent
			 key:session.<session ID>.announce_messages_sent                     value:Announce Messages Sent
		Announce Messages Received
			 key:session.<session ID>.announce_messages_received                 value:Announce Messages Received
		Sync Messages Sent
			 key:session.<session ID>.sync_messages_sent                         value:Sync Messages Sent
		Sync Messages Received
			 key:session.<session ID>.sync_messages_received                     value:Sync Messages Received
		FollowUp Messages Sent
			 key:session.<session ID>.followup_messages_sent                     value:FollowUp Messages Sent
		FollowUp Messages Received
			 key:session.<session ID>.followup_messages_received                 value:FollowUp Messages Received
		DelayReq Messages Sent
			 key:session.<session ID>.delayreq_messages_sent                     value:DelayReq Messages Sent
		DelayReq Messages Received
			 key:session.<session ID>.delayreq_messages_received                 value:DelayReq Messages Received
		DelayResp Messages Sent
			 key:session.<session ID>.delayresp_messages_sent                    value:DelayResp Messages Sent
		DelayResp Messages Received
			 key:session.<session ID>.delayresp_messages_received                value:DelayResp Messages Received
		PdelayReq Messages Sent
			 key:session.<session ID>.pdelayreq_messages_sent                    value:PdelayReq Messages Sent
		PdelayReq Messages Received
			 key:session.<session ID>.pdelayreq_messages_received                value:PdelayReq Messages Received
		PdelayResp Messages Sent
			 key:session.<session ID>.pdelayresp_messages_sent                   value:PdelayResp Messages Sent
		PdelayResp Messages Received
			 key:session.<session ID>.pdelayrest_messages_received               value:PdelayResp Messages Received
		PdelayRespFollowUp Messages Sent
			 key:session.<session ID>.pdelayrespfollowup_messages_sent           value:PdelayRespFollowUp Messages Sent
		PdelayRespFollowUp Messages Received
			 key:session.<session ID>.pdelayrespfollowup_messages_received       value:PdelayRespFollowUp Messages Received
		Signaling Messages Sent
			 key:session.<session ID>.signaling_messages_sent                    value:Signaling Messages Sent
		Signaling Messages Received
			 key:session.<session ID>.signaling_messages_received                value:Signaling Messages Received
		Sync Messages Received Rate
			 key:session.<session ID>.sync_messages_received_rate                value:Sync Messages Received Rate
		FollowUp Messages Received Rate
			 key:session.<session ID>.followup_messages_received_rate            value:FollowUp Messages Received Rate
		DelayReq Messages Received Rate
			 key:session.<session ID>.delayreq_messages_received_rate            value:DelayReq Messages Received Rate
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("ptp_over_ip_stats", kwargs)

	def ptp_over_mac_config(self, **kwargs):
		""" Performs ptp_over_mac configuration. Manages a device group of PTP clocks.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: ptp_over_mac_config
			x	-mode                                 CHOICES create add modify delete
			x	-parent_handle                        ANY
			x	[-handle                              ANY]
			x	[-style                               ANY]
			x	[-announce_current_utc_offset_valid   CHOICES 0 1]
			x	[-announce_drop_rate                  RANGE 0-100
			x                                      DEFAULT 0]
			x	[-announce_frequency_traceable        CHOICES 0 1
			x                                      DEFAULT 0]
			x	[-announce_leap59                     CHOICES 0 1
			x                                      DEFAULT 0]
			x	[-announce_leap61                     CHOICES 0 1
			x                                      DEFAULT 0]
			x	[-announce_ptp_timescale              CHOICES 0 1
			x                                      DEFAULT 0]
			x	[-announce_receipt_timeout            RANGE 0-128
			x                                      DEFAULT 3]
			x	[-announce_time_traceable             CHOICES 0 1
			x                                      DEFAULT 0]
			x	[-client_count                        ANY]
			x	[-client_ip_address                   ANY]
			x	[-client_ip_increment_by              ANY]
			x	[-client_mac_address                  ANY]
			x	[-client_mac_increment_by             ANY]
			x	[-clock_accuracy                      CHOICES 32
			x                                      CHOICES 33
			x                                      CHOICES 34
			x                                      CHOICES 35
			x                                      CHOICES 36
			x                                      CHOICES 37
			x                                      CHOICES 38
			x                                      CHOICES 39
			x                                      CHOICES 40
			x                                      CHOICES 41
			x                                      CHOICES 42
			x                                      CHOICES 43
			x                                      CHOICES 44
			x                                      CHOICES 45
			x                                      CHOICES 46
			x                                      CHOICES 47
			x                                      CHOICES 48
			x                                      CHOICES 49
			x                                      DEFAULT 47]
			x	[-clock_class                         RANGE 0-255
			x                                      DEFAULT 6]
			x	[-clock_increment                     ANY]
			x	[-communication_mode                  CHOICES multicast
			x                                      CHOICES unicast
			x                                      CHOICES mixedmode
			x                                      CHOICES g8265
			x                                      DEFAULT multicast]
			x	[-delay_mechanism                     CHOICES E2E P2P 1WAY
			x                                      DEFAULT E2E]
			x	[-delay_resp_drop_rate                RANGE 0-100
			x                                      DEFAULT 0]
			x	[-delay_resp_receipt_timeout          RANGE 1-1000
			x                                      DEFAULT 100]
			x	[-delay_response_delay                RANGE 0-1000000000
			x                                      DEFAULT 0]
			x	[-delay_response_delay_insertion_rate RANGE 0-100
			x                                      DEFAULT 0]
			x	[-domain                              RANGE 0-255
			x                                      DEFAULT 0]
			x	[-drop_signal_req_announce            CHOICES 0 1]
			x	[-drop_signal_req_delay_resp          CHOICES 0 1]
			x	[-drop_signal_req_sync                CHOICES 0 1]
			x	[-enabled                             ANY]
			x	[-first_clock                         ANY
			x                                      DEFAULT 00:00:00:00:00:00:11:11]
			x	[-follow_up_bad_crc_rate              RANGE 0-100
			x                                      DEFAULT 0]
			x	[-follow_up_delay                     RANGE 0-1000000000
			x                                      DEFAULT 0]
			x	[-follow_up_delay_insertion_rate      RANGE 0-100
			x                                      DEFAULT 0]
			x	[-follow_up_drop_rate                 RANGE 0-100
			x                                      DEFAULT 0]
			x	[-grant_delay_resp_duration_interval  RANGE 5-1200
			x                                      DEFAULT 300]
			x	[-grant_sync_duration_interval        RANGE 5-1200
			x                                      DEFAULT 300]
			x	[-grant_unicast_duration_interval     RANGE 5-1200
			x                                      DEFAULT 300]
			x	[-ip_tos                              RANGE 0-255
			x                                      DEFAULT 0]
			x	[-learn_port_id                       CHOICES 0 1]
			x	[-log_announce_interval               CHOICES 247
			x                                      CHOICES 248
			x                                      CHOICES 249
			x                                      CHOICES 250
			x                                      CHOICES 251
			x                                      CHOICES 252
			x                                      CHOICES 253
			x                                      CHOICES 254
			x                                      CHOICES 255
			x                                      CHOICES 0
			x                                      CHOICES 1
			x                                      CHOICES 2
			x                                      CHOICES 3
			x                                      CHOICES 4
			x                                      CHOICES 5
			x                                      CHOICES 6
			x                                      CHOICES 7
			x                                      CHOICES 8
			x                                      CHOICES 9
			x                                      DEFAULT 0]
			x	[-log_delay_req_interval              CHOICES 247
			x                                      CHOICES 248
			x                                      CHOICES 249
			x                                      CHOICES 250
			x                                      CHOICES 251
			x                                      CHOICES 252
			x                                      CHOICES 253
			x                                      CHOICES 254
			x                                      CHOICES 255
			x                                      CHOICES 0
			x                                      CHOICES 1
			x                                      CHOICES 2
			x                                      CHOICES 3
			x                                      CHOICES 4
			x                                      CHOICES 5
			x                                      CHOICES 6
			x                                      CHOICES 7
			x                                      CHOICES 8
			x                                      CHOICES 9
			x                                      DEFAULT 0]
			x	[-log_sync_interval                   CHOICES 247
			x                                      CHOICES 248
			x                                      CHOICES 249
			x                                      CHOICES 250
			x                                      CHOICES 251
			x                                      CHOICES 252
			x                                      CHOICES 253
			x                                      CHOICES 254
			x                                      CHOICES 255
			x                                      CHOICES 0
			x                                      CHOICES 1
			x                                      CHOICES 2
			x                                      CHOICES 3
			x                                      CHOICES 4
			x                                      CHOICES 5
			x                                      CHOICES 6
			x                                      CHOICES 7
			x                                      CHOICES 8
			x                                      CHOICES 9
			x                                      DEFAULT 0]
			x	[-master_count                        RANGE 1-500
			x                                      DEFAULT 1]
			x	[-master_ip_address                   ANY
			x                                      DEFAULT 10.10.0.1]
			x	[-master_ip_increment_by              ANY
			x                                      DEFAULT 0.0.0.1]
			x	[-master_ip_increment_inter_entity    ANY]
			x	[-master_mac_address                  ANY
			x                                      DEFAULT aa:bb:cd:00:00:00]
			x	[-master_mac_increment_by             ANY
			x                                      DEFAULT 00:00:00:00:00:01]
			x	[-master_mac_increment_inter_entity   ANY]
			x	[-name                                ALPHA]
			x	[-port_number                         RANGE 1-65535
			x                                      DEFAULT 1]
			x	[-port_number_increment               ANY]
			x	[-priority1                           RANGE 0-255
			x                                      DEFAULT 128]
			x	[-priority2                           RANGE 0-255
			x                                      DEFAULT 128]
			x	[-renewal_invited                     CHOICES 0 1]
			x	[-request_attempts                    RANGE 1-100
			x                                      DEFAULT 3]
			x	[-request_holddown                    RANGE 10-1000
			x                                      DEFAULT 60]
			x	[-request_interval                    RANGE 1-100
			x                                      DEFAULT 1]
			x	[-residence_time                      RANGE 0-1000000000
			x                                      DEFAULT 0]
			x	[-rx_calibration                      RANGE 0-10000
			x                                      DEFAULT 0]
			x	[-send_announce_multicast             CHOICES 0 1]
			x	[-send_announce_tlv                   CHOICES 0 1]
			x	[-send_cancel_tlv                     CHOICES 0 1]
			x	[-signal_interval                     RANGE 3-1200
			x                                      DEFAULT 64]
			x	[-signal_unicast_handling             CHOICES individually
			x                                      CHOICES allInOne
			x                                      CHOICES doNotSend
			x                                      DEFAULT individually]
			x	[-step_mode                           CHOICES two-step single-step
			x                                      DEFAULT two-step]
			x	[-steps_removed                       RANGE 0-655535
			x                                      DEFAULT 0]
			x	[-strict_grant                        CHOICES 0 1]
			x	[-sync_drop_rate                      RANGE 0-100
			x                                      DEFAULT 0]
			x	[-sync_receipt_timeout                RANGE 1-1000
			x                                      DEFAULT 100]
			x	[-time_source                         CHOICES 0X10
			x                                      CHOICES 0X20
			x                                      CHOICES 0X30
			x                                      CHOICES 0X40
			x                                      CHOICES 0X50
			x                                      CHOICES 0X60
			x                                      CHOICES 0X90
			x                                      CHOICES 0XA0
			x                                      DEFAULT 0X20]
			x	[-timestamp_offset                    RANGE 0-9223372036854775807
			x                                      DEFAULT 0]
			x	[-timestamp_offset_variation          ANY]
			x	[-tx_calibration                      RANGE 0-1000000
			x                                      DEFAULT 0]
			x	[-use_alternate_master_flag           CHOICES 0 1]
			x	[-use_clock_identity                  CHOICES 0 1]
			x	[-profile                             CHOICES ieee1588
			x                                      CHOICES g82651
			x                                      CHOICES g82751
			x                                      CHOICES ieee8021as]
			 	[-current_utc_offset                  RANGE 0-32767
			                                       DEFAULT 0]
			x	[-sync_receipt_timeout_gptp           RANGE 1-128
			x                                      DEFAULT 3]
			x	[-bmca                                CHOICES 0 1
			x                                      DEFAULT 1]
			x	[-reverse_sync                        CHOICES 0 1
			x                                      DEFAULT 0]
			x	[-reverse_sync_interval_percent       RANGE 0-4294967295
			x                                      DEFAULT 96]
			x	[-cumulative_scaled_rate_offset       ANY
			x                                      DEFAULT 0x0]
			x	[-gm_time_base_indicator              RANGE 0-65535
			x                                      DEFAULT 0]
			x	[-last_gm_phase_change                RANGE 0-9223372036854775807
			x                                      DEFAULT 0]
			x	[-scaled_last_gm_freq_change          RANGE 0-4294967295
			x                                      DEFAULT 0]
			x	[-update_time                         CHOICES 0 1
			x                                      DEFAULT 1]
			x	[-nanoseconds_per_second              RANGE 999023438-1000976562
			x                                      DEFAULT 1000000000]
			 	[-slave_count                         RANGE 1-500
			                                       DEFAULT 1]
			 	[-slave_ip_address                    ANY
			                                       DEFAULT 10.10.0.1]
			 	[-slave_ip_increment_by               ANY
			                                       DEFAULT 0.0.0.1]
			 	[-slave_mac_address                   ANY
			                                       DEFAULT aa:bb:cd:00:00:00]
			 	[-slave_mac_increment_by              ANY
			                                       DEFAULT 00:00:00:00:00:01]
			x	[-drop_malformed                      CHOICES 0 1]
			x	[-delay_req_drop_rate                 RANGE 0-100
			x                                      DEFAULT 0]
			x	[-delay_req_offset                    RANGE 50-200
			x                                      DEFAULT 100]
			x	[-delay_req_spread                    RANGE 0-50
			x                                      DEFAULT 0]
			x	[-multicastAddress                    CHOICES nonforwardable forwardable
			x                                      DEFAULT nonforwardable]
			x	[-not_slave                           CHOICES 0 1]
			x	[-path_trace_tlv                      CHOICES 0 1]
			x	[-tx_two_step_calibration             RANGE 0-1000000
			x                                      DEFAULT 0]
			x	[-one_way                             CHOICES 0 1]
			x	[-simulate_boundary                   CHOICES 0 1
			x                                      DEFAULT 0]
			x	[-grandmaster_identity                ANY
			x                                      DEFAULT 00:00:00:00:00:00:00:01]
			x	[-simulate_transparent                CHOICES 0 1]
			x	[-sync_residence_time                 ANY]
			x	[-follow_up_residence_time            ANY]
			x	[-delay_req_residence_time            ANY]
			x	[-delay_resp_residence_time           ANY]
			x	[-p_delay_follow_up_residence_time    ANY]
			x	[-offset_scaled_log_variance          ANY]
			x	[-role                                CHOICES slave master]
			x	[-master_ipv6_address                 ANY]
			x	[-master_ipv6_increment_by            ANY]
			x	[-slave_ipv6_address                  ANY]
			x	[-slave_ipv6_increment_by             ANY]
			 	[-mtu                                 RANGE 68-9216]
			x	[-mac_address_init                    MAC]
			x	[-mac_address_step                    MAC
			x                                      DEFAULT 0000.0000.0001]
			x	[-vlan                                CHOICES 0 1]
			 	[-vlan_id_mode                        CHOICES fixed increment
			                                       DEFAULT increment]
			 	[-vlan_id                             RANGE 0-4096]
			 	[-vlan_id_step                        RANGE 0-4096
			                                       DEFAULT 1]
			 	[-vlan_user_priority                  RANGE 0-7
			                                       DEFAULT 0]
			x	[-num_sessions                        RANGE 1-100000000
			x                                      DEFAULT 10]
		
		Arguments:
			x	-mode
			x		create - creates and configures a new object
			x		add - not supported in case of ::ixiangpf::ptp_over_mac_config.
			x		modify - modified attributes on the given object by the -handle param
			x		delete - deletes the object given by the -handle param
			x		Valid choices are:
			x   		create - Creates and configures a new object.
			x   		add - Not supported in case of ::ixiangpf::ptp_over_ip_config.
			x   		modify - Modified attributes on the given object by the -handle param.
			x   		delete - Deletes the object given by the -handle param.
			x	-parent_handle
			x		The parent handle used for creating this object. It can be a topology, or a device group, or an ethernet.
			x	-handle
			x		A handle returned via a ::ixiangpf::ptp_over_mac_config command. This is used for mode modify.
			x	-style
			x		The IxNetwork object typepath that is created after the command is run. Is optional in most cases. Only applies to modes create/add
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-announce_current_utc_offset_valid
			x		Set Announce currentUtcOffsetValid bit.
			x	-announce_drop_rate
			x		Percentage rate of the dropped Announce messages.
			x	-announce_frequency_traceable
			x		Set Announce frequency traceable bit.
			x	-announce_leap59
			x		Set Announce leap59 bit.
			x	-announce_leap61
			x		Set Announce leap61 bit.
			x	-announce_ptp_timescale
			x		Set Announce ptpTimescale bit.
			x	-announce_receipt_timeout
			x		The number of announceInterval that has to pass without receipt of an Announce message.
			x	-announce_time_traceable
			x		Set Announce time traceable bit.
			x	-client_count
			x		The total number of Unicast clients to be used for the range.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-client_ip_address
			x		Defines the base address to be used for enumerating all the addresses
			x		in the range.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-client_ip_increment_by
			x		Defines the increment to be used for enumerating all the addresses
			x		in the range.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-client_mac_address
			x		Defines the base address to be used for enumerating all the addresses
			x		in the range.
			x		This property is used in conjunction with 'clientMacIncrementBy' as an incrementor.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-client_mac_increment_by
			x		Defines the increment to be used for enumerating all the addresses
			x		in the range.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-clock_accuracy
			x		Clock accuracy.
			x		Valid choices are:
			x		32 - {The time is accurate to within 25 ns}
			x		33 - {The time is accurate to within 100 ns}
			x		34 - {The time is accurate to within 250 ns}
			x		35 - {The time is accurate to within 1 us}
			x		36 - {The time is accurate to within 2.5 us}
			x		37 - {The time is accurate to within 10 us}
			x		38 - {The time is accurate to within 25 us}
			x		39 - {The time is accurate to within 100 us}
			x		40 - {The time is accurate to within 250 us}
			x		41 - {The time is accurate to within 1 ms}
			x		42 - {The time is accurate to within 2.5 ms}
			x		43 - {The time is accurate to within 10 ms}
			x		44 - {The time is accurate to within 25 ms}
			x		45 - {The time is accurate to within 100 ms}
			x		46 - {The time is accurate to within 250 ms}
			x		47 - {The time is accurate to within 1 s}
			x		48 - {The time is accurate to within 10 s}
			x		49 - {The time is accurate to greater than 10 s}
			x		Valid choices are:
			x   		32 - The time is accurate to within 25 ns.
			x   		33 - The time is accurate to within 100 ns.
			x   		34 - The time is accurate to within 250 ns.
			x   		35 - The time is accurate to within 1 us.
			x   		36 - The time is accurate to within 2.5 us.
			x   		37 - The time is accurate to within 10 us.
			x   		38 - The time is accurate to within 25 us.
			x   		39 - The time is accurate to within 100 us.
			x   		40 - The time is accurate to within 250 us.
			x   		41 - The time is accurate to within 1 ms.
			x   		42 - The time is accurate to within 2.5 ms.
			x   		43 - The time is accurate to within 10 ms.
			x   		44 - The time is accurate to within 25 ms.
			x   		45 - The time is accurate to within 100 ms.
			x   		46 - The time is accurate to within 250 ms.
			x   		47 - The time is accurate to within 1 s.
			x   		48 - The time is accurate to within 10 s.
			x   		49 - The time is accurate to greater than 10 s.
			x	-clock_class
			x		Traceability of the time or frequency distributed by the grandmaster clock.
			x	-clock_increment
			x		Defines the ClockIdentity increment to be used in this range.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-communication_mode
			x		Communication mode (unicast/multicast/mixedmode).
			x		Valid choices are:
			x		multicast - Multicast
			x		unicast - Unicast
			x		mixedmode - MixedMode
			x		g8265 - deprecated for ixngpf command
			x		Valid choices are:
			x   		multicast - Multicast
			x   		unicast - Unicast
			x   		mixedmode - MixedMode
			x   		g8265 - DEPRECATED for ixngpf command.
			x	-delay_mechanism
			x		Clock delay mechanism.
			x		Valid choices are:
			x		E2E - RequestResponse
			x		P2P - PeerDelay
			x		1WAY - deprecated for ixngpf command
			x		Valid choices are:
			x   		E2E - RequestResponse
			x   		P2P - PeerDelay
			x   		1WAY - DEPRECATED for ixngpf command.
			x	-delay_resp_drop_rate
			x		Percentage rate of the dropped Delay_Resp messages.
			x	-delay_resp_receipt_timeout
			x		DelayResponse Receipt Timeout in seconds.
			x	-delay_response_delay
			x		Additional delay introduced in the Delay_Resp message timestamp (nanoseconds).
			x	-delay_response_delay_insertion_rate
			x		Percentage rate of the Delay_Resp messages in which the delay is introduced.
			x	-domain
			x		PTP Domain.
			x	-drop_signal_req_announce
			x		Select this check box to drop any Signal Request that contains Announce TLV.
			x	-drop_signal_req_delay_resp
			x		Select this check box to drop any Signal Request that contains DelayResp TLV.
			x	-drop_signal_req_sync
			x		Select this check box to drop any Signal Request that contains Sync TLV.
			x	-enabled
			x		Disabled ranges won't be configured nor validated.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x		Valid choices are:
			x   		true - Value is true
			x   		false - Value is false
			x	-first_clock
			x		Defines the ClockIdentity to be used by this device.
			x	-follow_up_bad_crc_rate
			x		Percentage rate of the bad crc Follow_Up messages.
			x	-follow_up_delay
			x		Additional delay introduced in the Follow_Up message timestamp (nanoseconds).
			x	-follow_up_delay_insertion_rate
			x		Percentage rate of the Follow_Up messages in which the delay is introduced.
			x	-follow_up_drop_rate
			x		Percentage rate of the dropped Follow_Up messages.
			x	-grant_delay_resp_duration_interval
			x		Value of DurationField in REQUEST_UNICAST_TRANSMISSION_TLV for DelayResp messages.
			x	-grant_sync_duration_interval
			x		Value of DurationField in REQUEST_UNICAST_TRANSMISSION_TLV for Sync messages.
			x	-grant_unicast_duration_interval
			x		Value of DurationField in REQUEST_UNICAST_TRANSMISSION_TLV.
			x	-ip_tos
			x		DEPRECATED - Use per port option for setting IP TOS or DS.
			x	-learn_port_id
			x		Slave learns Master Port ID.
			x	-log_announce_interval
			x		The log mean time interval between successive Announce messages.
			x		Valid choices are:
			x		minus 9 - {-9 (512 per second)}
			x		minus 8 - {-8 (256 per second)}
			x		minus 7 - {-7 (128 per second)}
			x		minus 6 - {-6 (64 per second)}
			x		minus 5 - {-5 (32 per second)}
			x		minus 4 - {-4 (16 per second)}
			x		minus 3 - {-3 (8 per second)}
			x		minus 2 - {-2 (4 per second)}
			x		minus 1 - {-1 (2 per second)}
			x		0 - {0 (1 per second)}
			x		1 - {1 (1 per 2 seconds)}
			x		2 - {2 (1 per 4 seconds)}
			x		3 - {3 (1 per 8 seconds)}
			x		4 - {4 (1 per 16 seconds)}
			x		5 - {5 (1 per 32 seconds)}
			x		6 - {6 (1 per 64 seconds)}
			x		7 - {7 (1 per 128 seconds)}
			x		8 - {8 (1 per 256 seconds)}
			x		9 - {9 (1 per 512 seconds)}
			x		Valid choices are:
			x   		247 - -9 (512 per second)
			x   		248 - -8 (256 per second)
			x   		249 - -7 (128 per second)
			x   		250 - -6 (64 per second)
			x   		251 - -5 (32 per second)
			x   		252 - -4 (16 per second)
			x   		253 - -3 (8 per second)
			x   		254 - -2 (4 per second)
			x   		255 - -1 (2 per second)
			x   		0 - 0 (1 per second)
			x   		1 - 1 (1 per 2 seconds)
			x   		2 - 2 (1 per 4 seconds)
			x   		3 - 3 (1 per 8 seconds)
			x   		4 - 4 (1 per 16 seconds)
			x   		5 - 5 (1 per 32 seconds)
			x   		6 - 6 (1 per 64 seconds)
			x   		7 - 7 (1 per 128 seconds)
			x   		8 - 8 (1 per 256 seconds)
			x   		9 - 9 (1 per 512 seconds)
			x	-log_delay_req_interval
			x		The log mean time interval between successive (P)Delay_Req messages.
			x		Valid choices are:
			x		minus 9 - {-9 (512 per second)}
			x		minus 8 - {-8 (256 per second)}
			x		minus 7 - {-7 (128 per second)}
			x		minus 6 - {-6 (64 per second)}
			x		minus 5 - {-5 (32 per second)}
			x		minus 4 - {-4 (16 per second)}
			x		minus 3 - {-3 (8 per second)}
			x		minus 2 - {-2 (4 per second)}
			x		minus 1 - {-1 (2 per second)}
			x		0 - {0 (1 per second)}
			x		1 - {1 (1 per 2 seconds)}
			x		2 - {2 (1 per 4 seconds)}
			x		3 - {3 (1 per 8 seconds)}
			x		4 - {4 (1 per 16 seconds)}
			x		5 - {5 (1 per 32 seconds)}
			x		6 - {6 (1 per 64 seconds)}
			x		7 - {7 (1 per 128 seconds)}
			x		8 - {8 (1 per 256 seconds)}
			x		9 - {9 (1 per 512 seconds)}
			x		Valid choices are:
			x   		247 - -9 (512 per second)
			x   		248 - -8 (256 per second)
			x   		249 - -7 (128 per second)
			x   		250 - -6 (64 per second)
			x   		251 - -5 (32 per second)
			x   		252 - -4 (16 per second)
			x   		253 - -3 (8 per second)
			x   		254 - -2 (4 per second)
			x   		255 - -1 (2 per second)
			x   		0 - 0 (1 per second)
			x   		1 - 1 (1 per 2 seconds)
			x   		2 - 2 (1 per 4 seconds)
			x   		3 - 3 (1 per 8 seconds)
			x   		4 - 4 (1 per 16 seconds)
			x   		5 - 5 (1 per 32 seconds)
			x   		6 - 6 (1 per 64 seconds)
			x   		7 - 7 (1 per 128 seconds)
			x   		8 - 8 (1 per 256 seconds)
			x   		9 - 9 (1 per 512 seconds)
			x	-log_sync_interval
			x		The log mean time interval between successive Sync messages.
			x		Valid choices are:
			x		minus 9 - {-9 (512 per second)}
			x		minus 8 - {-8 (256 per second)}
			x		minus 7 - {-7 (128 per second)}
			x		minus 6 - {-6 (64 per second)}
			x		minus 5 - {-5 (32 per second)}
			x		minus 4 - {-4 (16 per second)}
			x		minus 3 - {-3 (8 per second)}
			x		minus 2 - {-2 (4 per second)}
			x		minus 1 - {-1 (2 per second)}
			x		0 - {0 (1 per second)}
			x		1 - {1 (1 per 2 seconds)}
			x		2 - {2 (1 per 4 seconds)}
			x		3 - {3 (1 per 8 seconds)}
			x		4 - {4 (1 per 16 seconds)}
			x		5 - {5 (1 per 32 seconds)}
			x		6 - {6 (1 per 64 seconds)}
			x		7 - {7 (1 per 128 seconds)}
			x		8 - {8 (1 per 256 seconds)}
			x		9 - {9 (1 per 512 seconds)}
			x		Valid choices are:
			x   		247 - -9 (512 per second)
			x   		248 - -8 (256 per second)
			x   		249 - -7 (128 per second)
			x   		250 - -6 (64 per second)
			x   		251 - -5 (32 per second)
			x   		252 - -4 (16 per second)
			x   		253 - -3 (8 per second)
			x   		254 - -2 (4 per second)
			x   		255 - -1 (2 per second)
			x   		0 - 0 (1 per second)
			x   		1 - 1 (1 per 2 seconds)
			x   		2 - 2 (1 per 4 seconds)
			x   		3 - 3 (1 per 8 seconds)
			x   		4 - 4 (1 per 16 seconds)
			x   		5 - 5 (1 per 32 seconds)
			x   		6 - 6 (1 per 64 seconds)
			x   		7 - 7 (1 per 128 seconds)
			x   		8 - 8 (1 per 256 seconds)
			x   		9 - 9 (1 per 512 seconds)
			x	-master_count
			x		The total number of Unicast masters to be used.
			x	-master_ip_address
			x		Defines the base address to be used for enumerating all the addresses.
			x	-master_ip_increment_by
			x		Defines the increment to be used for enumerating all the addresses.
			x	-master_ip_increment_inter_entity
			x		Defines the increment to be used for the start address of Master
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-master_mac_address
			x		Defines the base address to be used for enumerating all the addresses.
			x	-master_mac_increment_by
			x		Defines the increment to be used for enumerating all the addresses.
			x	-master_mac_increment_inter_entity
			x		Defines the increment to be used for the start address of Master
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-name
			x		Name of protocol.
			x	-port_number
			x		Port number.
			x	-port_number_increment
			x		Port number increment
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-priority1
			x		PTP priority1.
			x	-priority2
			x		PTP priority2.
			x	-renewal_invited
			x		Set the Renewal Invited flag in Grant Unicast Transmission TLV.
			x	-request_attempts
			x		How many succesive requests a slave can request before entering into holddown.
			x	-request_holddown
			x		Time between succesive requests if denied/timeout for Signal Request.
			x	-request_interval
			x		Time between succesive requests if denied/timeout for Signal Request.
			x	-residence_time
			x		DEPRECATED - use per message setting of Residence Time.
			x	-rx_calibration
			x		The amount of time (in ns) that the Receive side timestamp needs to be offset to allow for error.
			x	-send_announce_multicast
			x		Send multicast Announce messages.
			x	-send_announce_tlv
			x		Send and respond to Announce TLV unicast requests in signal messages.
			x	-send_cancel_tlv
			x		Send and respond to Cancel TLV unicast requests in signal messages.
			x	-signal_interval
			x		Time between Signal Request messages, in seconds.
			x	-signal_unicast_handling
			x		Valid choices are:
			x		individually - {Send Individually}
			x		allInOne - {Send In One Message}
			x		doNotSend - {Do Not Send}
			x		Valid choices are:
			x   		individually - Send Individually
			x   		allInOne - Send In One Message
			x   		doNotSend - Do Not Send
			x	-step_mode
			x		Clock step mode.
			x		Valid choices are:
			x		two-step - TwoStep
			x		single-step - SingleStep
			x		Valid choices are:
			x   		two-step - TwoStep
			x   		single-step - SingleStep
			x	-steps_removed
			x		The number of hops between the Grandmaster Clock and the emulated clock. Valid values: 0 to 65,535.
			x	-strict_grant
			x		If selected, server will not grant values that are above maximum offered values.
			x	-sync_drop_rate
			x		Percentage rate of the dropped Sync messages.
			x	-sync_receipt_timeout
			x		Sync Receipt Timeout in seconds.
			x	-time_source
			x		Time source for the PTP device.
			x		Valid choices are:
			x		0X10 - AtomicClock
			x		0X20 - GPS
			x		0X30 - TerrestrialRadio
			x		0X40 - PTP
			x		0X50 - NTP
			x		0X60 - HandSet
			x		0X90 - Other
			x		0XA0 - InternalOscilator
			x		Valid choices are:
			x   		0X10 - AtomicClock
			x   		0X20 - GPS
			x   		0X30 - TerrestrialRadio
			x   		0X40 - PTP
			x   		0X50 - NTP
			x   		0X60 - HandSet
			x   		0X90 - Other
			x   		0XA0 - InternalOscilator
			x	-timestamp_offset
			x		Timestamp offset.
			x	-timestamp_offset_variation
			x		Timestamp offset variation.
			x		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x	-tx_calibration
			x		The amount of time (in ns) that the transmit timestamp of one step messages (Sync, PDelayResp) needs to be adjusted for error.
			x	-use_alternate_master_flag
			x		Select this check box to set the Alternate Master flag in all Announce and Sync messages.
			x	-use_clock_identity
			x		Use the ClockIdentity configured in the next column instead of MAC based generated one.
			x	-profile
			x		The profile used by this clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		ieee1588 -
			x   		g82651 -
			x   		g82751 -
			x   		ieee8021as -
			 	-current_utc_offset
			 		Set announced Current UTC Offset (seconds)
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-sync_receipt_timeout_gptp
			x		The number of Sync Intervals that have to pass without receipt of an Sync message to trigger timeout.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-bmca
			x		Run the Best Master Clock Algorithm for gPTP (if disabled can use a pre-defined Master or accept messages from any source)
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-reverse_sync
			x		As a slave, periodically send Reverse Sync messages with recovered clock.
			x		As a master, calculate the Offset of the Slave reported time to master time.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-reverse_sync_interval_percent
			x		The percentage of incoming Sync interval to use for Reverse Sync interval.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-cumulative_scaled_rate_offset
			x		Cumulative Scaled Rate Offset field set in the gPTP FollowUp TLV.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-gm_time_base_indicator
			x		GM Time Base Indicator field set in the gPTP FollowUp TLV.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-last_gm_phase_change
			x		Last GM Phase Change nanoseconds set in the gPTP FollowUp TLV.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-scaled_last_gm_freq_change
			x		Scaled Last GM Freq Change field set in the gPTP FollowUp TLV.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-update_time
			x		Clocks in Slave role will correct their time based on received Sync messages.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-nanoseconds_per_second
			x		The number of nanoseconds the emulated clock should effectively count for one second of hardware ticks.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-slave_count
			 		The total number of Unicast slaves to be used.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-slave_ip_address
			 		Defines the base address to be used for enumerating all the addresses.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-slave_ip_increment_by
			 		Defines the increment to be used for enumerating all the addresses.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-slave_mac_address
			 		Defines the base address to be used for enumerating all the addresses.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-slave_mac_increment_by
			 		Defines the increment to be used for enumerating all the addresses.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-drop_malformed
			x		Drop packets that for which fields like Domain, message rates, Clock Class, Clock Accuracy
			x		and Offset Scaled Log Variance are not respecting strict G8275.1 imposed intervals.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-delay_req_drop_rate
			x		Percentage rate of the dropped (P)DelayReq messages.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-delay_req_offset
			x		Percentage of the agreed (P)DelayReq Inter-arrival time to schedule between two subsequent DelayReq messages.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-delay_req_spread
			x		Distribute (P)DelayReq messages in an interval around the targeted Inter-arrival mean time (expressed as a % of targeted mean).
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-multicastAddress
			x		The destination multicast address for G8275.1:
			x		non-forwardable - 01:80:C2:00:00:0E (recommended)
			x		forwardable - 01:1B:19:00:00:00
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		nonforwardable - Non-forwardable
			x   		forwardable - Forwardable
			x	-not_slave
			x		When enabled for Master clocks it prevents a G8275.1 port from going into Slave state, by ignoring Announce messages.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-path_trace_tlv
			x		If selected, the master will append a Path Trace TLV to Announce messages.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-tx_two_step_calibration
			x		The amount of time (in ns) that the read transmit timestamp of sent messages (two-step Sync, DelayReq, PDelayReq, two-step PDelayResp) needs to be adjusted for error.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-one_way
			x		Do not send Delay Requests.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-simulate_boundary
			x		Simulate a transparent clock in front of this master clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-grandmaster_identity
			x		Defines the ClockIdentity of the Grandmaster behind this device.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-simulate_transparent
			x		Simulate a transparent clock in front of this master clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-sync_residence_time
			x		Master to slave residence time of Sync messages through an associated one-step
			x		transparent clock inserted in the correction field of Sync messages sent by this clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-follow_up_residence_time
			x		Master to slave residence of Sync messages through an associated two-step transparent clock
			x		inserted in the correction field of FollowUp messages sent by this clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-delay_req_residence_time
			x		Residence time of (P)DelayReq messages through an associated one-step end-to-end
			x		transparent clock inserted in the correction field of (P)DelayReq messages sent by this clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-delay_resp_residence_time
			x		Residence time of DelayReq messages through an associated two-step end-to-end transparent clock inserted
			x		in the correction field of DelayResp messages sent by this clock, or the residence time of PdelayResp messages
			x		through an associated one-step end-to-end transparent clock inserted in the correction field
			x		of PdelayResp messages sent by this clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-p_delay_follow_up_residence_time
			x		Total residence time of PdelayReq and PdelayResp messagews through an associated two-step end-to-end
			x		transparent clock inserted in the correction field of PdelayRespFollowUp messages sent by this clock
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-offset_scaled_log_variance
			x		Static Offset Scaled Log Variance of this clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-role
			x		The desired role of this clock.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		slave -
			x   		master -
			x	-master_ipv6_address
			x		Defines the base address to be used for enumerating all the addresses.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-master_ipv6_increment_by
			x		Defines the increment to be used for enumerating all the addresses.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-slave_ipv6_address
			x		Defines the base address to be used for enumerating all the addresses.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-slave_ipv6_increment_by
			x		Defines the increment to be used for enumerating all the addresses.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-mtu
			 		The advertised MTU value in database entries sent to other routers create on the Ixia interface. RANGE 68-9216.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-mac_address_init
			x		This option defines the MAC address that will be configured on
			x		the Ixia interface. This parameter is not valid on mode modify when
			x		IxTclProtocol is used.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-mac_address_step
			x		This option defines the incrementing step for the MAC address that
			x		will be configured on the Ixia interface.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x	-vlan
			x		Enables vlan.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			 	-vlan_id_mode
			 		If the user configures more than one interface on the Ixia with
			 		VLAN, he can choose to automatically increment the VLAN tag or
			 		leave it idle for each interface. CHOICES fixed increment.
			 		This parameter is not valid on mode modify when IxTclProtocol is used.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		fixed -
			    		increment -
			 	-vlan_id
			 		If VLAN is enable on the Ixia interface, this option will configure the VLAN number.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_id_step
			 		If the -vlan_id_mode is increment, this will be the step value by
			 		which the VLAN tags are incremented. RANGE 0-4095
			 		When vlan_id_step causes the vlan_id value to exceed it's maximum value the
			 		increment will be done modulo <number of possible vlan ids>.
			 		Examples: vlan_id = 4094; vlan_id_step = 2-> new vlan_id value = 0
			 		vlan_id = 4095; vlan_id_step = 11 -> new vlan_id value = 10
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-vlan_user_priority
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-num_sessions
			x		The number of PTP sessions to configure.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status      value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log         value:Error message if command returns {status 0}
		The returned handle(s) of the  config command.
			 key:handles     value:The returned handle(s) of the  config command.
		A list containing the ptp protocol stack handles that were added by the command (if any).
			xkey:ptp_handle  value:A list containing the ptp protocol stack handles that were added by the command (if any).
		A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
			xkey:handle      value:A list containing individual interface, session and/or router handles that were added by the command (if any). Please note that this key will be omitted if the current session or command were run with -return_detailed_handles 0.
		ptp_over_mac handles
			 key:handles     value:ptp_over_mac handles
		When status is failure, contains more information
			 key:log         value:When status is failure, contains more information
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		If the current session or command was run with -return_detailed_handles 0 the following keys will be omitted from the command response:  handle
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("ptp_over_mac_config", kwargs)

	def ptp_over_mac_control(self, **kwargs):
		""" Perform control plane operations on an endpoint created      by a ::ixiangpf::ptp_over_mac_config command
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: ptp_over_mac_control
			x	-handle  ANY
			x	-action  CHOICES abort
			x         CHOICES abort_async
			x         CHOICES start
			x         CHOICES connect
			x         CHOICES stop
			x         CHOICES disconnect
			x         CHOICES sendgPtpSignaling
		
		Arguments:
			x	-handle
			x		A handle returned via a ::<namespace>::ptp_over_mac_config
			x		command. This is the object on which the action will take place.
			x	-action
			x		Action to be executed. Valid choices are:
			x		abort- abort all sessions on the same port with the target
			x		endpoint designated by -handle. The control is
			x		returned when the operation is completed.
			x		abort_async- abort all sessions on the same port with the target
			x		endpoint designated by -handle. The control is
			x		returned immediately. The operation is executed in the background.
			x		start/connect - start and/or negotiate session for the target endpoint
			x		designated by -handle. Start and connect offer the same functionality.
			x		stop/disconnect - stop and/or release session for the target endpoint
			x		designated by -handle. Stop and disconnect offer the same functionality.
			x		Valid choices are:
			x   		abort - Aborts the PTP. The command returns when the operation is completed.
			x   		abort_async - Aborts the PTP. The command returns immediately and the operation is executed in the backgronud.
			x   		start - Start and connect offer the same functionality.
			x   		connect - Start and connect offer the same functionality.
			x   		stop - Stop and disconnect offer the same functionality.
			x   		disconnect - Stop and disconnect offer the same functionality.
			x   		sendgPtpSignaling - Send Signaling messages for the selected PTP IEEE 802.1AS sessions.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status         value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log            value:Error message if command returns {status 0}
		The result(s) of the  control action.
			 key:inner_results  value:The result(s) of the  control action.
		When status is failure, contains more information
			 key:log            value:When status is failure, contains more information
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		This command applies only to IxNetwork.
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("ptp_over_mac_control", kwargs)

	def ptp_over_mac_stats(self, **kwargs):
		""" Retrieve statistics plane on an endpoint created      by a ::ixiangpf::ptp_over_mac_config command
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: ptp_over_mac_stats
			x	[-port_handle ANY]
			 	[-handle      ANY]
			x	-mode         CHOICES aggregate session]
		
		Arguments:
			x	-port_handle
			x		The port handle for which the ptp_over_mac stats need to
			x		be retrieved
			 	-handle
			 		The PTP handle for which the PTP statistics are to be retrieved. Valid for -mode session.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			x	-mode
			x		Specifies statistics retrieval mode as either aggregate for all
			x		configured sessions or on a per session basis.
			x		This argument defined by Ixia is not supported for IxNetwork legacy implementation.
			x		Valid choices are:
			x   		aggregate - Retrieve statistics for all the sessions.
			x   		session - Retrieve statistics for each individual session.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                          value:$::SUCCESS | $::FAILURE
		Error message if command returns {status 0}
			 key:log                                                             value:Error message if command returns {status 0}
		Port Name
			 key:<port_handle>.gen.port_name                                     value:Port Name
		Sessions Initiated
			 key:<port_handle>.gen.sessions_initiated                            value:Sessions Initiated
		Sessions Succeeded
			 key:<port_handle>.gen.sessions_succeeded                            value:Sessions Succeeded
		Sessions Failed
			 key:<port_handle>.gen.sessions_failed                               value:Sessions Failed
		Sessions Active
			 key:<port_handle>.gen.sessions_active                               value:Sessions Active
		Initiated Sessions Rate
			 key:<port_handle>.gen.initiated_sessions_rate                       value:Initiated Sessions Rate
		Successful Sessions Rate
			 key:<port_handle>.gen.successful_sessions_rate                      value:Successful Sessions Rate
		Failed Sessions Rate
			 key:<port_handle>.gen.failed_sessions_rate                          value:Failed Sessions Rate
		Announce Messages Sent
			 key:<port_handle>.gen.announce_messages_sent                        value:Announce Messages Sent
		Announce Messages Received
			 key:<port_handle>.gen.announce_messages_received                    value:Announce Messages Received
		Sync Messages Sent
			 key:<port_handle>.gen.sync_messages_sent                            value:Sync Messages Sent
		Sync Messages Received
			 key:<port_handle>.gen.sync_messages_received                        value:Sync Messages Received
		FollowUp Messages Sent
			 key:<port_handle>.gen.followup_messages_sent                        value:FollowUp Messages Sent
		FollowUp Messages Received
			 key:<port_handle>.gen.followup_messages_received                    value:FollowUp Messages Received
		DelayReq Messages Sent
			 key:<port_handle>.gen.delayreq_messages_sent                        value:DelayReq Messages Sent
		DelayReq Messages Received
			 key:<port_handle>.gen.delayreq_messages_received                    value:DelayReq Messages Received
		DelayResp Messages Sent
			 key:<port_handle>.gen.delayresp_messages_sent                       value:DelayResp Messages Sent
		DelayResp Messages Received
			 key:<port_handle>.gen.delayresp_messages_received                   value:DelayResp Messages Received
		PdelayReq Messages Sent
			 key:<port_handle>.gen.pdelayreq_messages_sent                       value:PdelayReq Messages Sent
		PdelayReq Messages Received
			 key:<port_handle>.gen.pdelayreq_messages_received                   value:PdelayReq Messages Received
		PdelayResp Messages Sent
			 key:<port_handle>.gen.pdelayresp_messages_sent                      value:PdelayResp Messages Sent
		PdelayResp Messages Received
			 key:<port_handle>.gen.pdelayrest_messages_received                  value:PdelayResp Messages Received
		PdelayRespFollowUp Messages Sent
			 key:<port_handle>.gen.pdelayrespfollowup_messages_sent              value:PdelayRespFollowUp Messages Sent
		PdelayRespFollowUp Messages Received
			 key:<port_handle>.gen.pdelayrespfollowup_messages_received          value:PdelayRespFollowUp Messages Received
		Signaling Messages Sent
			 key:<port_handle>.gen.signaling_messages_sent                       value:Signaling Messages Sent
		Signaling Messages Received
			 key:<port_handle>.gen.signaling_messages_received                   value:Signaling Messages Received
		Sync Messages Received Rate
			 key:<port_handle>.gen.sync_messages_received_rate                   value:Sync Messages Received Rate
		FollowUp Messages Received Rate
			 key:<port_handle>.gen.followup_messages_received_rate               value:FollowUp Messages Received Rate
		DelayReq Messages Received Rate
			 key:<port_handle>.gen.delayreq_messages_received_rate               value:DelayReq Messages Received Rate
		DelayResp Messages Received Rate
			 key:<port_handle>.gen.delayresp_messages_received_rate              value:DelayResp Messages Received Rate
		GPS Unit Present
			 key:<port_handle>.gen.gps_unit_present                              value:GPS Unit Present
		GPS Synchronized
			 key:<port_handle>.gen.gps_synchronized                              value:GPS Synchronized
		When status is failure, contains more information
			 key:log                                                             value:When status is failure, contains more information
		Sessions Up
			 key:[<port_handle.>].gen.sessions_up                                value:Sessions Up
		Sessions Down
			 key:[<port_handle.>].gen.sessions_down                              value:Sessions Down
		Sessions Not Started
			 key:[<port_handle.>].gen.sessions_not_started                       value:Sessions Not Started
		Sessions Total
			 key:[<port_handle.>].gen.sessions_total                             value:Sessions Total
		Sessions Active
			 key:[<port_handle.>].gen.sessions_active                            value:Sessions Active
		Announce Messages Sent
			 key:[<port_handle.>].gen.announce_messages_sent                     value:Announce Messages Sent
		Announce Messages Received
			 key:[<port_handle.>].gen.announce_messages_received                 value:Announce Messages Received
		Sync Messages Sent
			 key:[<port_handle.>].gen.sync_messages_sent                         value:Sync Messages Sent
		Sync Messages Received
			 key:[<port_handle.>].gen.sync_messages_received                     value:Sync Messages Received
		FollowUp Messages Sent
			 key:[<port_handle.>].gen.followup_messages_sent                     value:FollowUp Messages Sent
		FollowUp Messages Received
			 key:[<port_handle.>].gen.followup_messages_received                 value:FollowUp Messages Received
		DelayReq Messages Sent
			 key:[<port_handle.>].gen.delayreq_messages_sent                     value:DelayReq Messages Sent
		DelayReq Messages Received
			 key:[<port_handle.>].gen.delayreq_messages_received                 value:DelayReq Messages Received
		DelayResp Messages Sent
			 key:[<port_handle.>].gen.delayresp_messages_sent                    value:DelayResp Messages Sent
		DelayResp Messages Received
			 key:[<port_handle.>].gen.delayresp_messages_received                value:DelayResp Messages Received
		PdelayReq Messages Sent
			 key:[<port_handle.>].gen.pdelayreq_messages_sent                    value:PdelayReq Messages Sent
		PdelayReq Messages Received
			 key:[<port_handle.>].gen.pdelayreq_messages_received                value:PdelayReq Messages Received
		PdelayResp Messages Sent
			 key:[<port_handle.>].gen.pdelayresp_messages_sent                   value:PdelayResp Messages Sent
		PdelayResp Messages Received
			 key:[<port_handle.>].gen.pdelayrest_messages_received               value:PdelayResp Messages Received
		PdelayRespFollowUp Messages Sent
			 key:[<port_handle.>].gen.pdelayrespfollowup_messages_sent           value:PdelayRespFollowUp Messages Sent
		PdelayRespFollowUp Messages Received
			 key:[<port_handle.>].gen.pdelayrespfollowup_messages_received       value:PdelayRespFollowUp Messages Received
		Signaling Messages Sent
			 key:[<port_handle.>].gen.signaling_messages_sent                    value:Signaling Messages Sent
		Signaling Messages Received
			 key:[<port_handle.>].gen.signaling_messages_received                value:Signaling Messages Received
		Sync Messages Received Rate
			 key:[<port_handle.>].gen.sync_messages_received_rate                value:Sync Messages Received Rate
		FollowUp Messages Received Rate
			 key:[<port_handle.>].gen.followup_messages_received_rate            value:FollowUp Messages Received Rate
		DelayReq Messages Received Rate
			 key:[<port_handle.>].gen.delayreq_messages_received_rate            value:DelayReq Messages Received Rate
		DelayResp Messages Received Rate
			 key:[<port_handle.>].gen.delayresp_messages_received_rate           value:DelayResp Messages Received Rate
		PdelayReq Messages Received Rate
			 key:[<port_handle.>].gen.pdelayreq_messages_received_rate           value:PdelayReq Messages Received Rate
		PdelayResp Messages Received Rate
			 key:[<port_handle.>].gen.pdelayresp_messages_received_rate          value:PdelayResp Messages Received Rate
		PdelayRespFollowUp Messages Received Rate
			 key:[<port_handle.>].gen.pdelayrespfollowup_messages_received_rate  value:PdelayRespFollowUp Messages Received Rate
		GPS Unit Present
			 key:[<port_handle.>].gen.gps_unit_present                           value:GPS Unit Present
		GPS Synchronized
			 key:[<port_handle.>].gen.gps_synchronized                           value:GPS Synchronized
		Sessions Up
			 key:[<handle.>].gen.sessions_up                                     value:Sessions Up
		Sessions Down
			 key:[<handle.>].gen.sessions_down                                   value:Sessions Down
		Sessions Not Started
			 key:[<handle.>].gen.sessions_not_started                            value:Sessions Not Started
		Sessions Total
			 key:[<handle.>].gen.sessions_total                                  value:Sessions Total
		Sessions Active
			 key:[<handle.>].gen.sessions_active                                 value:Sessions Active
		Announce Messages Sent
			 key:[<handle.>].gen.announce_messages_sent                          value:Announce Messages Sent
		Announce Messages Received
			 key:[<handle.>].gen.announce_messages_received                      value:Announce Messages Received
		Sync Messages Sent
			 key:[<handle.>].gen.sync_messages_sent                              value:Sync Messages Sent
		Sync Messages Received
			 key:[<handle.>].gen.sync_messages_received                          value:Sync Messages Received
		FollowUp Messages Sent
			 key:[<handle.>].gen.followup_messages_sent                          value:FollowUp Messages Sent
		FollowUp Messages Received
			 key:[<handle.>].gen.followup_messages_received                      value:FollowUp Messages Received
		DelayReq Messages Sent
			 key:[<handle.>].gen.delayreq_messages_sent                          value:DelayReq Messages Sent
		DelayReq Messages Received
			 key:[<handle.>].gen.delayreq_messages_received                      value:DelayReq Messages Received
		DelayResp Messages Sent
			 key:[<handle.>].gen.delayresp_messages_sent                         value:DelayResp Messages Sent
		DelayResp Messages Received
			 key:[<handle.>].gen.delayresp_messages_received                     value:DelayResp Messages Received
		PdelayReq Messages Sent
			 key:[<handle.>].gen.pdelayreq_messages_sent                         value:PdelayReq Messages Sent
		PdelayReq Messages Received
			 key:[<handle.>].gen.pdelayreq_messages_received                     value:PdelayReq Messages Received
		PdelayResp Messages Sent
			 key:[<handle.>].gen.pdelayresp_messages_sent                        value:PdelayResp Messages Sent
		PdelayResp Messages Received
			 key:[<handle.>].gen.pdelayrest_messages_received                    value:PdelayResp Messages Received
		PdelayRespFollowUp Messages Sent
			 key:[<handle.>].gen.pdelayrespfollowup_messages_sent                value:PdelayRespFollowUp Messages Sent
		PdelayRespFollowUp Messages Received
			 key:[<handle.>].gen.pdelayrespfollowup_messages_received            value:PdelayRespFollowUp Messages Received
		Signaling Messages Sent
			 key:[<handle.>].gen.signaling_messages_sent                         value:Signaling Messages Sent
		Signaling Messages Received
			 key:[<handle.>].gen.signaling_messages_received                     value:Signaling Messages Received
		Status
			 key:session.<session ID>.status                                     value:Status
		Configured Role
			 key:session.<session ID>.configured_role                            value:Configured Role
		PTP State
			 key:session.<session ID>.ptp_state                                  value:PTP State
		Offset [ns]
			 key:session.<session ID>.offset                                     value:Offset [ns]
		Max Offset [ns]
			 key:session.<session ID>.offset_max                                 value:Max Offset [ns]
		Min Offset [ns]
			 key:session.<session ID>.offset_min                                 value:Min Offset [ns]
		Avg Offset [ns]
			 key:session.<session ID>.offset_avg                                 value:Avg Offset [ns]
		Path Delay [ns]
			 key:session.<session ID>.path_delay                                 value:Path Delay [ns]
		Max Path Delay [ns]
			 key:session.<session ID>.path_delay_max                             value:Max Path Delay [ns]
		Min Path Delay [ns]
			 key:session.<session ID>.path_delay_min                             value:Min Path Delay [ns]
		Avg Path Delay [ns]
			 key:session.<session ID>.path_delay_avg                             value:Avg Path Delay [ns]
		Time Slope
			 key:session.<session ID>.time_slope                                 value:Time Slope
		Port Identity
			 key:session.<session ID>.port_identity                              value:Port Identity
		Master Port Identity
			 key:session.<session ID>.master_port_identity                       value:Master Port Identity
		Grandmaster Port Identity
			 key:session.<session ID>.grandmaster_port_identity                  value:Grandmaster Port Identity
		Local Clock Class
			 key:session.<session ID>.port_clock_class                           value:Local Clock Class
		Master Clock Class
			 key:session.<session ID>.master_clock_class                         value:Master Clock Class
		Local Clock Accuracy
			 key:session.<session ID>.port_clock_accuracy                        value:Local Clock Accuracy
		Master Clock Accuracy
			 key:session.<session ID>.master_clock_accuracy                      value:Master Clock Accuracy
		Current UTC Offset
			 key:session.<session ID>.current_utc_offset                         value:Current UTC Offset
		Steps Removed
			 key:session.<session ID>.steps_removed                              value:Steps Removed
		Leap59
			 key:session.<session ID>.leap59                                     value:Leap59
		Leap61
			 key:session.<session ID>.leap61                                     value:Leap61
		Frequency Traceable
			 key:session.<session ID>.frequency_traceable                        value:Frequency Traceable
		Time Traceable
			 key:session.<session ID>.time_traceable                             value:Time Traceable
		CF Sync [ns]
			 key:session.<session ID>.cf_sync                                    value:CF Sync [ns]
		CF Sync Max [ns]
			 key:session.<session ID>.cf_sync_max                                value:CF Sync Max [ns]
		CF Sync Min [ns]
			 key:session.<session ID>.cf_sync_min                                value:CF Sync Min [ns]
		CF FollowUp [ns]
			 key:session.<session ID>.cf_follow_up                               value:CF FollowUp [ns]
		CF FollowUp Max [ns]
			 key:session.<session ID>.cf_follow_up_max                           value:CF FollowUp Max [ns]
		CF FollowUp Min [ns]
			 key:session.<session ID>.cf_follow_up_min                           value:CF FollowUp Min [ns]
		CF DelayReq [ns]
			 key:session.<session ID>.cf_delay_req                               value:CF DelayReq [ns]
		CF DelayReq Max [ns]
			 key:session.<session ID>.cf_delay_req_max                           value:CF DelayReq Max [ns]
		CF DelayReq Min [ns]
			 key:session.<session ID>.cf_delay_req_min                           value:CF DelayReq Min [ns]
		CF PdelayReq [ns]
			 key:session.<session ID>.cf_pdelay_req                              value:CF PdelayReq [ns]
		CF PdelayReq Max [ns]
			 key:session.<session ID>.cf_pdelay_req_max                          value:CF PdelayReq Max [ns]
		CF PdelayReq Min [ns]
			 key:session.<session ID>.cf_pdelay_req_min                          value:CF PdelayReq Min [ns]
		CF DelayResp [ns]
			 key:session.<session ID>.cf_delay_resp                              value:CF DelayResp [ns]
		CF DelayResp Max [ns]
			 key:session.<session ID>.cf_delay_resp_max                          value:CF DelayResp Max [ns]
		CF DelayResp Min [ns]
			 key:session.<session ID>.cf_delay_resp_min                          value:CF DelayResp Min [ns]
		CF PdelayResp [ns]
			 key:session.<session ID>.cf_pdelay_resp                             value:CF PdelayResp [ns]
		CF PdelayResp Max [ns]
			 key:session.<session ID>.cf_pdelay_resp_max                         value:CF PdelayResp Max [ns]
		CF PdelayResp Min [ns]
			 key:session.<session ID>.cf_pdelay_resp_min                         value:CF PdelayResp Min [ns]
		CF PdelayRespFollowUp [ns]
			 key:session.<session ID>.cf_pdelay_resp_follow_up                   value:CF PdelayRespFollowUp [ns]
		CF PdelayRespFollowUp Max [ns]
			 key:session.<session ID>.cf_pdelay_resp_follow_up_max               value:CF PdelayRespFollowUp Max [ns]
		CF PdelayRespFollowUp Min [ns]
			 key:session.<session ID>.cf_pdelay_resp_follow_up_min               value:CF PdelayRespFollowUp Min [ns]
		FM 0 Identity
			 key:session.<session ID>.fm_identity_0                              value:FM 0 Identity
		FM 0 Port Number
			 key:session.<session ID>.fm_portNum_0                               value:FM 0 Port Number
		FM 1 Identity
			 key:session.<session ID>.fm_identity_1                              value:FM 1 Identity
		FM 1 Port Number
			 key:session.<session ID>.fm_port_num_1                              value:FM 1 Port Number
		FM 2 Identity
			 key:session.<session ID>.fm_identity_2                              value:FM 2 Identity
		FM 2 Port Number
			 key:session.<session ID>.fm_port_num_2                              value:FM 2 Port Number
		FM 3 Identity
			 key:session.<session ID>.fm_identity_3                              value:FM 3 Identity
		FM 3 Port Number
			 key:session.<session ID>.fm_port_num_3                              value:FM 3 Port Number
		FM 4 Identity
			 key:session.<session ID>.fm_identity_4                              value:FM 4 Identity
		FM 4 Port Number
			 key:session.<session ID>.fm_port_num_4                              value:FM 4 Port Number
		Time t1 [ns]
			 key:session.<session ID>.time_t1                                    value:Time t1 [ns]
		Time t2 [ns]
			 key:session.<session ID>.time_t2                                    value:Time t2 [ns]
		Time t3 [ns]
			 key:session.<session ID>.time_t3                                    value:Time t3 [ns]
		Time t4 [ns]
			 key:session.<session ID>.time_t4                                    value:Time t4 [ns]
		Time t1 UTC
			 key:session.<session ID>.t1_utc                                     value:Time t1 UTC
		Time t2 UTC
			 key:session.<session ID>.t2_utc                                     value:Time t2 UTC
		Time t3 UTC
			 key:session.<session ID>.t3_utc                                     value:Time t3 UTC
		Time t4 UTC
			 key:session.<session ID>.t4_utc                                     value:Time t4 UTC
		IA Announce [ns]
			 key:session.<session ID>.ia_announce                                value:IA Announce [ns]
		IA Announce Max [ns]
			 key:session.<session ID>.ia_announce_max                            value:IA Announce Max [ns]
		IA Announce Min [ns]
			 key:session.<session ID>.ia_announce_min                            value:IA Announce Min [ns]
		IA Sync [ns]
			 key:session.<session ID>.ia_sync                                    value:IA Sync [ns]
		IA Sync Max [ns]
			 key:session.<session ID>.ia_sync_max                                value:IA Sync Max [ns]
		IA Sync Min [ns]
			 key:session.<session ID>.ia_sync_min                                value:IA Sync Min [ns]
		IA FollowUp [ns]
			 key:session.<session ID>.ia_follow_up                               value:IA FollowUp [ns]
		IA FollowUp Max [ns]
			 key:session.<session ID>.ia_follow_up_max                           value:IA FollowUp Max [ns]
		IA FollowUp Min [ns]
			 key:session.<session ID>.ia_follow_up_min                           value:IA FollowUp Min [ns]
		IA DelayReq [ns]
			 key:session.<session ID>.ia_delay_req                               value:IA DelayReq [ns]
		IA DelayReq Max [ns]
			 key:session.<session ID>.ia_delay_req_max                           value:IA DelayReq Max [ns]
		IA DelayReq Min [ns]
			 key:session.<session ID>.ia_delay_req_min                           value:IA DelayReq Min [ns]
		IA DelayResp [ns]
			 key:session.<session ID>.ia_delay_resp                              value:IA DelayResp [ns]
		IA DelayResp Max [ns]
			 key:session.<session ID>.ia_delay_resp_max                          value:IA DelayResp Max [ns]
		IA DelayResp Min [ns]
			 key:session.<session ID>.ia_delay_resp_min                          value:IA DelayResp Min [ns]
		IA PdelayReq [ns]
			 key:session.<session ID>.ia_pdelay_req                              value:IA PdelayReq [ns]
		IA PdelayReq Max [ns]
			 key:session.<session ID>.ia_pdelay_req_max                          value:IA PdelayReq Max [ns]
		IA PdelayReq Min [ns]
			 key:session.<session ID>.ia_pdelay_req_min                          value:IA PdelayReq Min [ns]
		IA PdelayResp [ns]
			 key:session.<session ID>.ia_pdelay_resp                             value:IA PdelayResp [ns]
		IA PdelayResp Max [ns]
			 key:session.<session ID>.ia_pdelay_resp_max                         value:IA PdelayResp Max [ns]
		IA PdelayResp Min [ns]
			 key:session.<session ID>.ia_pdelay_resp_min                         value:IA PdelayResp Min [ns]
		IA PdelayRespFollowUp [ns]
			 key:session.<session ID>.ia_pdelay_resp_follow_up                   value:IA PdelayRespFollowUp [ns]
		IA PdelayRespFollowUp Max [ns]
			 key:session.<session ID>.ia_pdelay_resp_follow_up_max               value:IA PdelayRespFollowUp Max [ns]
		IA PdelayRespFollowUp Min [ns]
			 key:session.<session ID>.ia_pdelay_resp_follow_up_min               value:IA PdelayRespFollowUp Min [ns]
		Announce Messages Sent
			 key:session.<session ID>.announce_messages_sent                     value:Announce Messages Sent
		Announce Messages Received
			 key:session.<session ID>.announce_messages_received                 value:Announce Messages Received
		Sync Messages Sent
			 key:session.<session ID>.sync_messages_sent                         value:Sync Messages Sent
		Sync Messages Received
			 key:session.<session ID>.sync_messages_received                     value:Sync Messages Received
		FollowUp Messages Sent
			 key:session.<session ID>.followup_messages_sent                     value:FollowUp Messages Sent
		FollowUp Messages Received
			 key:session.<session ID>.followup_messages_received                 value:FollowUp Messages Received
		DelayReq Messages Sent
			 key:session.<session ID>.delayreq_messages_sent                     value:DelayReq Messages Sent
		DelayReq Messages Received
			 key:session.<session ID>.delayreq_messages_received                 value:DelayReq Messages Received
		DelayResp Messages Sent
			 key:session.<session ID>.delayresp_messages_sent                    value:DelayResp Messages Sent
		DelayResp Messages Received
			 key:session.<session ID>.delayresp_messages_received                value:DelayResp Messages Received
		PdelayReq Messages Sent
			 key:session.<session ID>.pdelayreq_messages_sent                    value:PdelayReq Messages Sent
		PdelayReq Messages Received
			 key:session.<session ID>.pdelayreq_messages_received                value:PdelayReq Messages Received
		PdelayResp Messages Sent
			 key:session.<session ID>.pdelayresp_messages_sent                   value:PdelayResp Messages Sent
		PdelayResp Messages Received
			 key:session.<session ID>.pdelayrest_messages_received               value:PdelayResp Messages Received
		PdelayRespFollowUp Messages Sent
			 key:session.<session ID>.pdelayrespfollowup_messages_sent           value:PdelayRespFollowUp Messages Sent
		PdelayRespFollowUp Messages Received
			 key:session.<session ID>.pdelayrespfollowup_messages_received       value:PdelayRespFollowUp Messages Received
		Signaling Messages Sent
			 key:session.<session ID>.signaling_messages_sent                    value:Signaling Messages Sent
		Signaling Messages Received
			 key:session.<session ID>.signaling_messages_received                value:Signaling Messages Received
		Sync Messages Received Rate
			 key:session.<session ID>.sync_messages_received_rate                value:Sync Messages Received Rate
		FollowUp Messages Received Rate
			 key:session.<session ID>.followup_messages_received_rate            value:FollowUp Messages Received Rate
		DelayReq Messages Received Rate
			 key:session.<session ID>.delayreq_messages_received_rate            value:DelayReq Messages Received Rate
		
		Examples:
		See files in the Samples subdirectory
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		This command applies only to IxNetwork
		External documentation on Tclx keyed lists
		
		"""
		return self._run_keyword("ptp_over_mac_stats", kwargs)

	def reboot_port_cpu(self, **kwargs):
		""" This command reboots a list of port cpus and reverts them to factory defaults
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: reboot_port_cpu
			 	[-port_list ANY]
		
		Arguments:
			 	-port_list
			 		List of port_handle items for which this command takes effect.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log     value:On status of failure, gives detailed information.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("reboot_port_cpu", kwargs)

	def reset_port(self, **kwargs):
		""" Resets the ports to factory defaults, removes specific protocol configuration or resets the port cpu
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: reset_port
			 	-mode         ANY
			 	-port_handle  ANY
			 	-protocol     ANY]
		
		Arguments:
			 	-mode
			 		Action to be taken on the port_handle selected.
			 		Valid choices are:
			    		set_factory_defaults-resets the port to factory default.
			    		remove_protocol- removes the protocol config on the port specified by the protocol argument
			    		reboot_port_cpu- reboots the CPU of the port specified
			 	-port_handle
			 		List of port_handles on which to act
			 	-protocol
			 		Name of the protocol which should be removed from the port Default is all. Valid Choices are:
			 		Valid choices are:
			    		bfd - Removes bfd protocol from the port.
			    		bgp - Removes bgp protocol from the port.
			    		cfm - Removes cfm protocol from the port.
			    		eigrp - Removes eigrp protocol from the port.
			    		igmp - Removes igmp protocol from the port.
			    		isis - Removes isis protocol from the port.
			    		lacp - Removes lacp protocol from the port.
			    		ldp - Removes ldp protocol from the port.
			    		efm - Removes efm protocol from the port.
			    		mld - Removes mld protocol from the port.
			    		mplstp - Removes mplstp protocol from the port.
			    		ospfv2 - Removes ospfv2 protocol from the port.
			    		ospfv3 - Removes ospfv3 protocol from the port.
			    		pim - Removes pim protocol from the port.
			    		rip - Removes rip protocol from the port.
			    		ripng - Removes ripng protocol from the port.
			    		rsvp - Removes rsvp protocol from the port.
			    		static - Removes static protocol from the port.
			    		stp - Removes stp protocol from the port.
			    		all - Removes all protocol from the port.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log     value:On status of failure, gives detailed information.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("reset_port", kwargs)

	def session_info(self, **kwargs):
		""" This command is used to retrieve session keys from IxNetwork. As opposed tosession resume functionality, it can be called at any point after ixia
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: session_info
			x	[-mode                        ANY]
			x	[-port_handle                 ANY]
			x	[-traffic_handle              ANY]
			x	[-session_keys_include_filter ANY]
		
		Arguments:
			x	-mode
			x   		get_session_keys- return current session keys. The keys may be filtered using -port_handle or -session_keys_include_filter
			x   		get_traffic_items- return the current traffic items
			x   		get_traffic_ce- return the config elements. The keys may be filtered using -traffic_handle
			x   		get_traffic_hls- return the high level streams (flows). The keys may be filtered using -traffic_handle
			x   		get_traffic_headers- return the packet headers. The keys may be filtered using -traffic_handle
			x   		get_traffic_application_profiles- return the application profile (for L47). The keys may be using -traffic_handle
			x	-port_handle
			x		Specifies a list of port handles. If this parameter exists, only the keys related to the given ports are returned.
			x	-traffic_handle
			x		Specifies which traffic elements should be used. Is a list.
			x		For modes get_traffic_ce/get_traffic_hls this needs to be a traffic item name (stream id). Because this parameter is a list,
			x		the traffic item names should be properly formatted (in case of containing spaces).
			x		For mode get_traffic_headers this needs to be a configElement/highLevelStream IxNetwork handle.
			x	-session_keys_include_filter
			x		May contains a list of value that specify an inclusion filter for the returned session keys. The keys that have items in &amp;amp;lt;typepath&amp;amp;gt; are dependent on the command that generated that kind of typepath. Generally the procedure that generated those objects has the same name as the first part in the key. <br>
			x		Eg.: in emulation_bgp_route_config.bgp_sites.&amp;amp;lt;vport/protocols/bgp/neighborRange/l2Site&amp;amp;gt; objects of type vport/protocols/bgp/neighborRange/l2Site are generated by the emulation_bgp_route_config command. <br>
			x		Valid values are: <br>
			x		connect
			x		connect.vport_list<br>
			x		interface_config<br>
			x		interface_config.interface_handle<br>
			x		interface_config.routed_interface_handle<br>
			x		interface_config.gre_interface_handle<br>
			x		interface_config.atm_endpoints<br>
			x		interface_config.fr_endpoints<br>
			x		interface_config.ip_endpoints<br>
			x		interface_config.lan_endpoints<br>
			x		interface_config.ig_endpoints<br>
			x		emulation_bfd_config<br>
			x		emulation_bfd_config.router_handles<br>
			x		emulation_bfd_config.router_interface_handles<br>
			x		emulation_bfd_config.router_interface_handles.&amp;amp;lt;vport/protocols/bfd/router&amp;amp;gt;<br>
			x		emulation_bfd_config.interface_handles<br>
			x		emulation_bfd_config.interface_handles.&amp;amp;lt;vport/protocols/bfd/router&amp;amp;gt;<br>
			x		emulation_bfd_session_config.session_handles<br>
			x		emulation_bgp_config<br>
			x		emulation_bgp_config.handles<br>
			x		emulation_bgp_route_config<br>
			x		emulation_bgp_route_config.bgp_routes<br>
			x		emulation_bgp_route_config.bgp_sites<br>
			x		emulation_bgp_route_config.bgp_sites.&amp;amp;lt;vport/protocols/bgp/neighborRange/l2Site&amp;amp;gt;<br>
			x		emulation_bgp_route_config.bgp_sites.&amp;amp;lt;vport/protocols/bgp/neighborRange/l3Site&amp;amp;gt;<br>
			x		emulation_cfm_config<br>
			x		emulation_cfm_config.handle<br>
			x		emulation_cfm_config.interface_handles<br>
			x		emulation_cfm_custom_tlv_config<br>
			x		emulation_cfm_custom_tlv_config.handle<br>
			x		emulation_cfm_links_config<br>
			x		emulation_cfm_links_config.handle<br>
			x		emulation_cfm_md_meg_config<br>
			x		emulation_cfm_md_meg_config.handle<br>
			x		emulation_cfm_mip_mep_config<br>
			x		emulation_cfm_mip_mep_config.handle<br>
			x		emulation_cfm_vlan_config<br>
			x		emulation_cfm_vlan_config.handle<br>
			x		emulation_cfm_vlan_config.mac_range_handles<br>
			x		emulation_cfm_vlan_config.mac_range_handles.&amp;amp;lt;vport/protocols/cfm/bridge/vlans&amp;amp;gt;<br>
			x		emulation_dhcp_config<br>
			x		emulation_dhcp_config.handle<br>
			x		emulation_dhcp_group_config<br>
			x		emulation_dhcp_group_config.handle<br>
			x		emulation_dhcp_server_config<br>
			x		emulation_dhcp_server_config.handle<br>
			x		dhcp_client_extension_config <br>
			x		dhcp_client_extension_config.handle <br>
			x		dhcp_server_extension_config <br>
			x		dhcp_server_extension_config.handle <br>
			x		emulation_efm_config<br>
			x		emulation_efm_config.information_oampdu_id<br>
			x		emulation_efm_config.event_notification_oampdu_id<br>
			x		emulation_efm_org_var_config<br>
			x		emulation_efm_org_var_config.handle<br>
			x		emulation_eigrp_config<br>
			x		emulation_eigrp_config.router_handles<br>
			x		emulation_eigrp_config.interface_handles<br>
			x		emulation_eigrp_route_config<br>
			x		emulation_eigrp_route_config.session_handles<br>
			x		emulation_elmi_config <br>
			x		emulation_elmi_config.interface_handles <br>
			x		emulation_elmi_config.uni_handles <br>
			x		emulation_elmi_config.uni_status_handles <br>
			x		emulation_elmi_config.bw_profile_handles <br>
			x		emulation_elmi_config.evc_handles <br>
			x		emulation_elmi_config.ce_vlan_id_range_handles <br>
			x		emulation_igmp_config<br>
			x		emulation_igmp_config.handle<br>
			x		emulation_igmp_group_config<br>
			x		emulation_igmp_group_config.handle<br>
			x		emulation_igmp_group_config.source_handle<br>
			x		emulation_isis_config<br>
			x		emulation_isis_config.handle<br>
			x		emulation_isis_topology_route_config<br>
			x		emulation_isis_topology_route_config.elem_handle<br>
			x		emulation_isis_topology_route_config.stub<br>
			x		emulation_isis_topology_route_config.external<br>
			x		emulation_isis_topology_route_config.grid<br>
			x		emulation_isis_topology_route_config.grid.connected_session.&amp;amp;lt;vport/protocols/isis/router&amp;amp;gt;.row <br>
			x		emulation_isis_topology_route_config.grid.connected_session.&amp;amp;lt;vport/protocols/isis/router&amp;amp;gt;.col <br>
			x		l2tp_config<br>
			x		l2tp_config.handles<br>
			x		emulation_lacp_link_config<br>
			x		emulation_lacp_link_config.handle<br>
			x		emulation_ldp_config<br>
			x		emulation_ldp_config.handle<br>
			x		emulation_ldp_route_config<br>
			x		emulation_ldp_route_config.lsp_handle<br>
			x		emulation_ldp_route_config.lsp_intf<br>
			x		emulation_ldp_route_config.lsp_vc_range_handles<br>
			x		emulation_ldp_route_config.lsp_vc_ip_range_handles<br>
			x		emulation_ldp_route_config.lsp_vc_mac_range_handles<br>
			x		emulation_mld_config<br>
			x		emulation_mld_config.handle<br>
			x		emulation_mld_group_config<br>
			x		emulation_mld_group_config.handle<br>
			x		emulation_ospf_config<br>
			x		emulation_ospf_config.handle<br>
			x		emulation_ospf_topology_route_config<br>
			x		emulation_ospf_topology_route_config.elem_handle<br>
			x		emulation_pbb_config<br>
			x		emulation_pbb_config.handle<br>
			x		emulation_pbb_config.interface_handles<br>
			x		emulation_pbb_trunk_config<br>
			x		emulation_pbb_trunk_config.trunk_handle<br>
			x		emulation_pbb_trunk_config.mr_handle<br>
			x		emulation_pim_config<br>
			x		emulation_pim_config.handle<br>
			x		emulation_pim_config.interfaces<br>
			x		emulation_pim_group_config<br>
			x		emulation_pim_group_config.handle<br>
			x		pppox_config<br>
			x		pppox_config.handles<br>
			x		emulation_rip_config<br>
			x		emulation_rip_config.handle<br>
			x		emulation_rip_route_config<br>
			x		emulation_rip_route_config.route_handle<br>
			x		emulation_rsvp_config<br>
			x		emulation_rsvp_config.handles<br>
			x		emulation_rsvp_tunnel_config<br>
			x		emulation_rsvp_tunnel_config.tunnel_handle<br>
			x		emulation_rsvp_tunnel_config.tunnel_leaves_handle<br>
			x		emulation_rsvp_tunnel_config.tunnel_leaves_handle.&amp;amp;lt;vport/protocols/rsvp/neighborPair/destinationRange&amp;amp;gt;<br>
			x		emulation_rsvp_tunnel_config.tunnel_leaves_handle.&amp;amp;lt;vport/protocols/rsvp/neighborPair/destinationRange&amp;amp;gt;/ingress<br>
			x		emulation_rsvp_tunnel_config.routed_interfaces<br>
			x		emulation_stp_msti_config<br>
			x		emulation_stp_msti_config.handle<br>
			x		emulation_stp_bridge_config<br>
			x		emulation_stp_bridge_config.bridge_handle<br>
			x		emulation_stp_bridge_config.bridge_interface_handles<br>
			x		emulation_stp_bridge_config.bridge_interface_handles.&amp;amp;lt;vport/protocols/stp/bridge&amp;amp;gt;<br>
			x		emulation_stp_bridge_config.interface_handles<br>
			x		emulation_stp_bridge_config.interface_handles.&amp;amp;lt;vport/protocols/stp/bridge&amp;amp;gt;<br>
			x		emulation_twamp_config<br>
			x		emulation_twamp_config.handle<br>
			x		emulation_twamp_control_range_config<br>
			x		emulation_twamp_control_range_config.handle<br>
			x		emulation_twamp_test_range_config<br>
			x		emulation_twamp_test_range_config.handle<br>
			x		emulation_twamp_server_range_config<br>
			x		emulation_twamp_server_range_config.handle<br>
			x		emulation_ancp_config<br>
			x		emulation_ancp_config.handle<br>
			x		emulation_ancp_subscriber_lines_config<br>
			x		emulation_ancp_subscriber_lines_config.handle<br>
			x		fc_client_config<br>
			x		fc_client_config.handle<br>
			x		fc_fport_config<br>
			x		fc_fport_config.handle<br>
			x		fc_fport_vnport_config<br>
			x		fc_fport_vnport_config.handle<br>
			x		traffic_config<br>
			x		traffic_config.stream_id<br>
			x		traffic_config.traffic_item <br>
			x		traffic_l47_config <br>
			x		traffic_l47_config.traffic_l47_handle.applib_profile <br>
			x		traffic_l47_config.traffic_l47_handle.applib_profile.applib_flow <br>
			x		traffic_l47_config.traffic_l47_handle.applib_profile.applib_flow.parameter <br>
			x		traffic_l47_config.traffic_l47_handle.applib_profile.applib_flow.connection <br>
			x		traffic_l47_config.traffic_l47_handle.applib_profile.applib_flow.connection.parameter <br>
			x		emulation_multicast_group_config<br>
			x		emulation_multicast_source_config
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                                                                         value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                                                                            value:On status of failure, gives detailed information.
		keyed list with the following keys "vport_list"
			 key:<port_handle>.connect                                                                          value:keyed list with the following keys "vport_list"
		keyed list with the following keys "router_handles router_interface_handles.<parent> interface_handles.<parent>". Where <parent> is an object of type /vport/protocols/bfd/router.
			 key:<port_handle>.emulation_bfd_config                                                             value:keyed list with the following keys "router_handles router_interface_handles.<parent> interface_handles.<parent>". Where <parent> is an object of type /vport/protocols/bfd/router.
		keyed list with the following keys "session_handles"
			 key:<port_handle>.emulation_bfd_session_config                                                     value:keyed list with the following keys "session_handles"
		keyed list with the following keys "handles"
			 key:<port_handle>.emulation_bgp_config                                                             value:keyed list with the following keys "handles"
		keyed list with the following keys "bgp_routes bgp_sites.<parent>". Where <parent> is an object of type /vport/protocols/bgp/neighborRange/l2Site, or /vport/protocols/bgp/neighborRange/l3Site.
			 key:<port_handle>.emulation_bgp_route_config                                                       value:keyed list with the following keys "bgp_routes bgp_sites.<parent>". Where <parent> is an object of type /vport/protocols/bgp/neighborRange/l2Site, or /vport/protocols/bgp/neighborRange/l3Site.
		keyed list with the following keys "handle interface_handles"
			 key:<port_handle>.emulation_cfm_config                                                             value:keyed list with the following keys "handle interface_handles"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_cfm_custom_tlv_config                                                  value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_cfm_links_config                                                       value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_cfm_md_meg_config                                                      value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_cfm_mip_mep_config                                                     value:keyed list with the following keys "handle"
		keyed list with the following keys "handle mac_range_handles.<parent>". Where <parent> is an object of type /vport/protocols/cfm/bridge/vlans.
			 key:<port_handle>.emulation_cfm_vlan_config                                                        value:keyed list with the following keys "handle mac_range_handles.<parent>". Where <parent> is an object of type /vport/protocols/cfm/bridge/vlans.
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_dhcp_config                                                            value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_dhcp_group_config                                                      value:keyed list with the following keys "handle"
		keyed list with the following keys "handle.dhcp_handle"
			 key:<port_handle>.emulation_dhcp_server_config                                                     value:keyed list with the following keys "handle.dhcp_handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.dhcp_client_extension_config                                                     value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.dhcp_server_extension_config                                                     value:keyed list with the following keys "handle"
		keyed list with the following keys "information_oampdu_id event_notification_oampdu_id"
			 key:<port_handle>.emulation_efm_config                                                             value:keyed list with the following keys "information_oampdu_id event_notification_oampdu_id"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_efm_org_var_config                                                     value:keyed list with the following keys "handle"
		keyed list with the following keys "router_handles interface_handles"
			 key:<port_handle>.emulation_eigrp_config                                                           value:keyed list with the following keys "router_handles interface_handles"
		keyed list with the following keys "session_handles"
			 key:<port_handle>.emulation_eigrp_route_config                                                     value:keyed list with the following keys "session_handles"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_igmp_config                                                            value:keyed list with the following keys "handle"
		keyed list with the following keys "handle source_handle"
			 key:<port_handle>.emulation_igmp_group_config                                                      value:keyed list with the following keys "handle source_handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_isis_config                                                            value:keyed list with the following keys "handle"
		keyed list with the following keys "elem_handle route_range stub.num_networks external.num_networks grid.connected_session<parent>.row grid.connected_session<parent>.col". Where <parent> is an object of type /vport/protocols/isis/router.
			 key:<port_handle>.emulation_isis_topology_route_config                                             value:keyed list with the following keys "elem_handle route_range stub.num_networks external.num_networks grid.connected_session<parent>.row grid.connected_session<parent>.col". Where <parent> is an object of type /vport/protocols/isis/router.
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_lacp_link_config                                                       value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_ldp_config                                                             value:keyed list with the following keys "handle"
		keyed list with the following keys "lsp_handle lsp_intf lsp_vc_range_handles lsp_vc_ip_range_handles lsp_vc_mac_range_handles"
			 key:<port_handle>.emulation_ldp_route_config                                                       value:keyed list with the following keys "lsp_handle lsp_intf lsp_vc_range_handles lsp_vc_ip_range_handles lsp_vc_mac_range_handles"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_mld_config                                                             value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_mld_group_config                                                       value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_ospf_config                                                            value:keyed list with the following keys "handle"
		keyed list with the following keys "elem_handle"
			 key:<port_handle>.emulation_ospf_topology_route_config                                             value:keyed list with the following keys "elem_handle"
		keyed list with the following keys "handle interface_handles"
			 key:<port_handle>.emulation_pbb_config                                                             value:keyed list with the following keys "handle interface_handles"
		keyed list with the following keys "trunk_handle mr_handle"
			 key:<port_handle>.emulation_pbb_trunk_config                                                       value:keyed list with the following keys "trunk_handle mr_handle"
		keyed list with the following keys "handle interfaces"
			 key:<port_handle>.emulation_pim_config                                                             value:keyed list with the following keys "handle interfaces"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_pim_group_config                                                       value:keyed list with the following keys "handle"
		keyed list with the following keys "handle handle"
			 key:<port_handle>.emulation_rip_config                                                             value:keyed list with the following keys "handle handle"
		keyed list with the following keys "route_handle"
			 key:<port_handle>.emulation_rip_route_config                                                       value:keyed list with the following keys "route_handle"
		keyed list with the following keys "handles"
			 key:<port_handle>.emulation_rsvp_config                                                            value:keyed list with the following keys "handles"
		keyed list with the following keys "tunnel_handle tunnel_leaves_handle.<parent>/ingress tunnel_leaves_handle.<parent>". Where <parent> is an object of type /vport/protocols/rsvp/neighborPair/destinationRange.
			 key:<port_handle>.emulation_rsvp_tunnel_config                                                     value:keyed list with the following keys "tunnel_handle tunnel_leaves_handle.<parent>/ingress tunnel_leaves_handle.<parent>". Where <parent> is an object of type /vport/protocols/rsvp/neighborPair/destinationRange.
		keyed list with the following keys "bridge_handle bridge_interface_handles.<parent> interface_handles.<parent>". Where <parent> is an object of type /vport/protocols/stp/bridge.
			 key:<port_handle>.emulation_stp_bridge_config                                                      value:keyed list with the following keys "bridge_handle bridge_interface_handles.<parent> interface_handles.<parent>". Where <parent> is an object of type /vport/protocols/stp/bridge.
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_stp_msti_config                                                        value:keyed list with the following keys "handle"
		keyed list with the following keys "interface_handle routed_interface_handle gre_interface_handle"
			 key:<port_handle>.interface_config                                                                 value:keyed list with the following keys "interface_handle routed_interface_handle gre_interface_handle"
		keyed list with the following keys "handles"
			 key:<port_handle>.l2tp_config                                                                      value:keyed list with the following keys "handles"
		keyed list with the following keys "handles"
			 key:<port_handle>.pppox_config                                                                     value:keyed list with the following keys "handles"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_twamp_config                                                           value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_twamp_control_range_config                                             value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_twamp_test_range_config                                                value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_twamp_server_range_config                                              value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.emulation_ancp_config                                                            value:keyed list with the following keys "handle"
		keyed list with the following keys "handle". These profiles are used on <port_handle>
			 key:<port_handle>.emulation_ancp_subscriber_lines_config                                           value:keyed list with the following keys "handle". These profiles are used on <port_handle>
		keyed list with the following keys "handle". These profiles are present in the configuration
			 key:globals.emulation_ancp_subscriber_lines_config                                                 value:keyed list with the following keys "handle". These profiles are present in the configuration
		keyed list with the following keys "handle"
			 key:<port_handle>.fc_client_config                                                                 value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.fc_fport_config                                                                  value:keyed list with the following keys "handle"
		keyed list with the following keys "handle"
			 key:<port_handle>.fc_fport_vnport_config                                                           value:keyed list with the following keys "handle"
		a list having as elements the names of the existing L23 traffic items (the name of the traffic item is normally returned when traffic_config creates a new traffic item by the stream_id key)
			 key:traffic_config                                                                                 value:a list having as elements the names of the existing L23 traffic items (the name of the traffic item is normally returned when traffic_config creates a new traffic item by the stream_id key)
		a list having as elements the names of the existing L47 traffic items (the name of the traffic item is normally returned when traffic_config creates a new traffic item by the stream_id key)
			 key:traffic_config_L47                                                                             value:a list having as elements the names of the existing L47 traffic items (the name of the traffic item is normally returned when traffic_config creates a new traffic item by the stream_id key)
		keyed list with all the keys that the traffic_config procedure would return when configuring the $stream_id traffic item
			 key:<stream_id>.traffic_config                                                                     value:keyed list with all the keys that the traffic_config procedure would return when configuring the $stream_id traffic item
		keyed list with the following keys "num_groups ip_addr_start ip_addr_step ip_prefix_len"
			 key:emulation_multicast_group_config                                                               value:keyed list with the following keys "num_groups ip_addr_start ip_addr_step ip_prefix_len"
		keyed list with the following keys "num_sources ip_addr_start ip_addr_step ip_prefix_len"
			 key:emulation_multicast_source_config                                                              value:keyed list with the following keys "num_sources ip_addr_start ip_addr_step ip_prefix_len"
		a list of traffic item handles of the existing L47 AppLib traffic items
			 key:traffic_l47_config.traffic_l47_handle                                                          value:a list of traffic item handles of the existing L47 AppLib traffic items
		a list of all the applib profiles under the <traffic_l47_handle>. Where <traffic_l47_handle> is an object of type /traffic/trafficItem.
			 key:traffic_l47_config.<traffic_l47_handle>.applib_profile                                         value:a list of all the applib profiles under the <traffic_l47_handle>. Where <traffic_l47_handle> is an object of type /traffic/trafficItem.
		a list of flows existing under the <applib_profile>. Where <applib_profile> is an object of type /traffic/trafficItem/appLibProfile.
			 key:traffic_l47_config.<traffic_l47_handle>.<applib_profile>.applib_flow                           value:a list of flows existing under the <applib_profile>. Where <applib_profile> is an object of type /traffic/trafficItem/appLibProfile.
		a list of parameters existing under the <applib_flow>. Where the <applib_flow> is an object of type /traffic/trafficItem/appLibProfile/appLibFlow.
			 key:traffic_l47_config.<traffic_l47_handle>.<applib_profile>.<applib_flow>.parameter               value:a list of parameters existing under the <applib_flow>. Where the <applib_flow> is an object of type /traffic/trafficItem/appLibProfile/appLibFlow.
		a list of conections existing under the <applib_flow>. Where the <applib_flow> is an object of type /traffic/trafficItem/appLibProfile/appLibFlow.
			 key:traffic_l47_config.<traffic_l47_handle>.<applib_profile>.<applib_flow>.connection              value:a list of conections existing under the <applib_flow>. Where the <applib_flow> is an object of type /traffic/trafficItem/appLibProfile/appLibFlow.
		a list of parameters existing under the <connection>. Where the <connection> is an object of type /traffic/trafficItem/appLibProfile/appLibFlow/connection.
			 key:traffic_l47_config.<traffic_l47_handle>.<applib_profile>.<applib_flow>.<connection>.parameter  value:a list of parameters existing under the <connection>. Where the <connection> is an object of type /traffic/trafficItem/appLibProfile/appLibFlow/connection.
		
		Examples:
		See session_info (FEA739869) files in the Samples subdirectory.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) This command is available only when using IxNetwork Tcl API.
		2) As with session resume feature, in order to have better performance the tclsh should haveaccess to the package tdom.
		3) -port_handle parameter isnt supported for IxNetwork versions lower than 7.10
		
		See Also:
		
		"""
		return self._run_keyword("session_info", kwargs)

	def test_control(self, **kwargs):
		""" This command gives more options to control the various operations for a test  session. Using this command all protocols configured in test sessions can be stop or start . This command gives more actions to control the QuickTest and also supports check_link_state. Valid only when using IxTclNetwork
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: test_control
			 	-action             CHOICES start_all_protocols
			                     CHOICES stop_all_protocols
			                     CHOICES restart_down
			                     CHOICES start_protocol
			                     CHOICES stop_protocol
			                     CHOICES abort_protocol
			                     CHOICES apply_on_the_fly_changes
			                     CHOICES check_link_state
			                     CHOICES get_all_qt_handles
			                     CHOICES get_available_qt_types
			                     CHOICES get_qt_handles_for_type
			                     CHOICES qt_remove_test
			                     CHOICES qt_apply_config
			                     CHOICES qt_start
			                     CHOICES qt_run
			                     CHOICES qt_stop
			                     CHOICES qt_wait_for_test
			                     CHOICES is_done
			                     CHOICES wait
			                     CHOICES get_result
			                     CHOICES qt_get_input_params
			                     CHOICES configure_all]
			 	[-port_handle       REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-handle            ANY]
			 	[-desired_status    CHOICES busy up down unassigned
			                     DEFAULT up]
			 	[-timeout           NUMERIC
			                     DEFAULT 60]
			 	[-qt_handle         ANY]
			 	[-result_handle     ANY]
			 	[-qt_type           ANY]
			 	[-input_params      ANY]
			 	[-action_mode       CHOICES sync async
			                     DEFAULT sync]
			 	[-action_on_failure CHOICES stop continue
			                     DEFAULT continue]
			 	[-args              ANY]
			 	[-mandatory_args    ANY]
		
		Arguments:
			 	-action
			 		This option specified the action to be taken based on the option provided.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		start_all_protocols - Starts all the protcols configured on the ports.
			    		stop_all_protocols - Stops all the protcols configured on the ports.
			    		restart_down - Restarts all the sessions that are down on the given handles.
			    		start_protocol - Starts protocols on given handles.
			    		stop_protocol - Stops protocols on given handles.
			    		abort_protocol - Aborts protocols on given handles.
			    		apply_on_the_fly_changes - Applies all pending on the fly changes
			    		check_link_state - Checks link state of all the ports used in the test.
			    		get_all_qt_handles - Returns handles for all the quick tests existing in the current configuration.
			    		get_available_qt_types - Return the list of all supportedquick tests types.
			    		get_qt_handles_for_type - Returns all the quick tests existing in the current configuraton of type specified in the parameter qt_type.
			    		qt_remove_test - Removes the test specifed from the list of available configurations.
			    		qt_apply_config - Apply the test configuration for the test specified in the parameter qt_handle.
			    		qt_start - Start the test synchronously / asynchronously, depending on action_mode.
			    		qt_run - Start the test synchronously/ asynchronously ,depending on action_mode, and wait for test finish or failure.
			    		qt_stop - Stop the test synchronously / asynchronously, depending on action_mode
			    		qt_wait_for_test - Waits for tests specified in the parameter qt_handle to finish or failure
			    		is_done - Provide the status of asynchronous operations whether it is completed or not.
			    		wait - Block/wait fortheasynchronous operations to complete.
			    		get_result - Provide detailed results of an asynchronous operation.
			    		qt_get_input_params - Returns the list of all -inputParameters for the tests mentioned in qt_handle.
			    		configure_all - Configures all the protcols on the ports.
			 	-port_handle
			 		List of ports for which to retrieve information.
			 		Valid when -action is check_link_state
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-handle
			 		List of handles to act on.
			 		Valid when -action is start_protocol or stop_protocol.
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-desired_status
			 		Valid when -action is check_link_state
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		busy - check whether the ports are in busy status.
			    		up - check whether the ports are in up status.
			    		down - check whether the ports are in down status.
			    		unassigned - check whether the ports are in unassigned status.
			 	-timeout
			 		Numeric value used to specify the timeout.
			 		Valid when -action is check_link_state
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-qt_handle
			 		List of handles for the quick test to perform commands
			 		Valid with the following -action values
			 		qt_start with -action_modesync
			 		qt_run with -action_modesync
			 		qt_apply_config -action_modesync
			 		qt_remove_test
			 		Instead of List of handles, only single handle is supported for the following -action values
			 		qt_start with -action_modeasync
			 		qt_run with -action_modeasync
			 		qt_apply_config -action_modeasync
			 		qt_stop
			 		qt_wait_for_test
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-result_handle
			 		List of result_handles returned by previously executed asynchronous operations
			 		Valid with the following -action values
			 		is_done
			 		get_result
			 		wait
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-qt_type
			 		List of qt types for which the available test handles to be returned.
			 		Valid when -action is get_qt_handles_for_type
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-input_params
			 		List of runtime Parameters for the quick test specified by qt_handle.
			 		Valid with the following -action values
			 		qt_start
			 		qt_run
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-action_mode
			 		Valid options are:
			 		sync- perform the operation specified in -action in synchronous mode
			 		async- perform the operation specified in -action in asynchronous mode
			 		(DEFAULT - sync)
			 		Valid when -action is qt_start, qt_stop, qt_run and qt_apply_config
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		sync -
			    		async -
			 	-action_on_failure
			 		(DEFAULT- continue)
			 		Valid when -action_mode sync and -action is qt_start, qt_stop, qt_run or qt_apply_config
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 		Valid choices are:
			    		stop - In case of failure in the current operation, stop the operation for remaining handles.
			    		continue - Even if a failure in the current operation, continue the operation for remaining handles.
			 	-args
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
			 	-mandatory_args
			 		This argument defined by Cisco is not supported for IxNetwork legacy implementation.
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                         value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                            value:On status of failure, gives detailed information.
		up, down, unassigned, busy
			 key:<port_handle>.state            value:up, down, unassigned, busy
		List of valid handles for all quick tests available in the config.
			 key:qt_handle                      value:List of valid handles for all quick tests available in the config.
		Gives detailed information about the test run.
			 key:<qt_handle>.log                value:Gives detailed information about the test run.
		$::SUCCESS | $::FAILURE
			 key:<qt_handle>.is_running         value:$::SUCCESS | $::FAILURE
		Based on the pass/fail criteria of the test execution, the values  none, pass or fail will be returned.
			 key:<qt_handle>.result             value:Based on the pass/fail criteria of the test execution, the values  none, pass or fail will be returned.
		The local path to the results folder for test specified in qt_handle.
			 key:<qt_handle>.result_path        value:The local path to the results folder for test specified in qt_handle.
		The result handle obtained with the -action_mode async for -action types qt_start, qt_stop, qt_run, qt_apply_config
			 key:<qt_handle>.result_handle      value:The result handle obtained with the -action_mode async for -action types qt_start, qt_stop, qt_run, qt_apply_config
		List of all supported input parameters for the test specified in qt_handle.
			 key:<qt_handle>.input_params       value:List of all supported input parameters for the test specified in qt_handle.
		$::SUCCESS | $::FAILURE, to indicate the asynchronous operation mentioned in result_handle is completed or not.
			 key:<result_handle>.status         value:$::SUCCESS | $::FAILURE, to indicate the asynchronous operation mentioned in result_handle is completed or not.
		On status of failure for a given result_handle, gives detailed information.
			 key:<result_handle>.log            value:On status of failure for a given result_handle, gives detailed information.
		Based on the pass/fail criteria of the test execution, the values  none, pass or fail will be returned.
			 key:<result_handle>.result         value:Based on the pass/fail criteria of the test execution, the values  none, pass or fail will be returned.
		The local path to the results folder for the test specified in qt_handle.
			 key:<result_handle>.result_path    value:The local path to the results folder for the test specified in qt_handle.
		List of all supported qt types.
			 key:qt_types                       value:List of all supported qt types.
		List of valid handles for all QuickTests available in the config.
			 key:qt_handle                      value:List of valid handles for all QuickTests available in the config.
		The local path to the results folder for test specified in qt_handle.
			 key:<qt_handle>.result_path        value:The local path to the results folder for test specified in qt_handle. 
		The result handle obtained with the -action_mode async for -action types qt_start, qt_stop, qt_run, qt_apply_config
			 key:<qt_handle>.result_handle      value:The result handle obtained with the -action_mode async for -action types qt_start, qt_stop, qt_run, qt_apply_config 
		[DEPRECATED] Please use input_params_list instead.
			 key:<qt_handle>.input_params       value:[DEPRECATED] Please use input_params_list instead.
		List of all supported input parameters for the test(s) specified in qt_handle.
			 key:<qt_handle>.input_params_list  value:List of all supported input parameters for the test(s) specified in qt_handle.
		
		Examples:
		See files starting with Action_ in the Samples subdirectory.Also see most of the other sample files for further examples of the usage.See Appendix A, "Example APIs," for further examples of the test_control usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("test_control", kwargs)

	def test_stats(self, **kwargs):
		""" This procedure will provide the various stats returned by QuickTest Run.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: test_stats
			 	-mode       ANY
			 	[-qt_handle ANY]
		
		Arguments:
			 	-mode
			 		This option specifies the action to be taken based on the option provided.
			 		Valid choices are:
			    		qt_currently_running - Get the handle for currently executing test.
			    		qt_running_status - Get the test running status.
			    		qt_progress - Get the test progress for the currently running test.
			    		qt_flow_view - Get the QuickTests supported Flow view stats.
			    		qt_result - Get the combined value of all test results in a keyed list.
			 	-qt_handle
			 		List of handles for the QuickTests to perform commands
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                               value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                  value:On status of failure, gives detailed information.
		Valid handle for a QuickTest.
			 key:qt_handle                            value:Valid handle for a QuickTest.
		$::SUCCESS | $::FAILURE
			 key:<qt_handle>.is_running               value:$::SUCCESS | $::FAILURE
		Provides trial #, iteration #, framesize #" or "" based on the test running status.
			 key:<qt_handle>.progress                 value:Provides trial #, iteration #, framesize #" or "" based on the test running status.
		The status of test execution and error messages in case of failure.
			 key:<qt_handle>.status                   value:The status of test execution and error messages in case of failure.
		Based on the pass/fail criteria, result of the test execution.
			 key:<qt_handle>.result                   value:Based on the pass/fail criteria, result of the test execution.
		The absolute path to the local folder where the result files are stored for a particular test execution.
			 key:<qt_handle>.result_path              value:The absolute path to the local folder where the result files are stored for a particular test execution.
		Start time of the test execution.
			 key:<qt_handle>.start_time               value:Start time of the test execution.
		Duration for the test execution.
			 key:<qt_handle>.duration                 value:Duration for the test execution.
		Number of rows in the Flow View Stats.
			 key:row_count                            value:Number of rows in the Flow View Stats.
		Tx Port for the given row of stat.
			 key:<row_count>.tx_port                  value:Tx Port for the given row of stat.
		Rx Port for the given row of stat.
			 key:<row_count>.rx_port                  value:Rx Port for the given row of stat.
		Traffic item name for the given row of stat.
			 key:<row_count>.traffic_item             value:Traffic item name for the given row of stat.
		Flow Group name for the given row of stat.
			 key:<row_count>.flow_group               value:Flow Group name for the given row of stat.
		Tx Frames stat value for the given row of stat.
			 key:<row_count>.tx_frames                value:Tx Frames stat value for the given row of stat.
		Rx Frames stat value for the given row of stat.
			 key:<row_count>.rx_frames                value:Rx Frames stat value for the given row of stat.          
		Frames Delta stat value for the given row of stat.
			 key:<row_count>.frames_delta             value:Frames Delta stat value for the given row of stat.
		Loss Percentage stat value for the given row of stat.
			 key:<row_count>.loss_percentage          value:Loss Percentage stat value for the given row of stat.
		Tx Frame Rate stat value for the given row of stat.
			 key:<row_count>.tx_frame_rate            value:Tx Frame Rate stat value for the given row of stat.
		Rx Frame Rate stat value for the given row of stat.
			 key:<row_count>.rx_frame_rate            value:Rx Frame Rate stat value for the given row of stat.
		Rx Bytes stat value for the given row of stat.
			 key:<row_count>.rx_bytes                 value:Rx Bytes stat value for the given row of stat.
		Tx Rate Bps stat value for the given row of stat.
			 key:<row_count>.tx_rate_Bps              value:Tx Rate Bps stat value for the given row of stat.
		Rx Rate Bps stat value for the given row of stat.
			 key:<row_count>.rx_rate_Bps              value:Rx Rate Bps stat value for the given row of stat.
		Tx Rate bps stat value for the given row of stat.
			 key:<row_count>.tx_rate_bps              value:Tx Rate bps stat value for the given row of stat.
		Rx Rate bps stat value for the given row of stat.
			 key:<row_count>.rx_rate_bps              value:Rx Rate bps stat value for the given row of stat.
		Tx Rate Kbps stat value for the given row of stat.
			 key:<row_count>.tx_rate_kbps             value:Tx Rate Kbps stat value for the given row of stat.
		Rx Rate Kbps stat value for the given row of stat.
			 key:<row_count>.rx_rate_kbps             value:Rx Rate Kbps stat value for the given row of stat.
		Tx Rate mbps stat value for the given row of stat.
			 key:<row_count>.tx_rate_mbps             value:Tx Rate mbps stat value for the given row of stat.
		Rx Rate mbps stat value for the given row of stat.
			 key:<row_count>.rx_rate_mbps             value:Rx Rate mbps stat value for the given row of stat.
		Avg Latency  stat value for the given row of stat.
			 key:<row_count>.avg_latency_cut_through  value:Avg Latency  stat value for the given row of stat.
		Min Latency stat value for the given row of stat.
			 key:<row_count>.min_latency_cut_through  value:Min Latency stat value for the given row of stat.
		Max Latency stat value for the given row of stat.
			 key:<row_count>.max_latency_cut_through  value:Max Latency stat value for the given row of stat.
		First Time Stamp stat value for the given row of stat.
			 key:<row_count>.first_time_stamp         value:First Time Stamp stat value for the given row of stat.
		Last Time Stamp stat value for the given row of stat.
			 key:<row_count>.last_time_stamp          value:Last Time Stamp stat value for the given row of stat.
		
		Examples:
		See files starting with Action_ in the Samples subdirectory.Also see most of the other sample files for further examples of the usage.See Appendix A, "Example APIs," for further examples of the test_control usage.
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("test_stats", kwargs)

	def tlv_config(self, **kwargs):
		""" This procedure will create, modify or remove a TLV template or a TLV. Using the TLV Templates editor, you can define multiple templates to store user-defined TLVs. These TLVs may have a complex structure that exceeds the common Type, Length, Value fields, meaning that you can add additional fields and sub-TLVs.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: tlv_config
			x	[-handle                        ANY]
			x	[-tlv_handle                    ANY]
			x	[-protocol                      CHOICES dhcp4_client
			x                                CHOICES dhcp4_server
			x                                CHOICES dhcp6_client
			x                                CHOICES dhcp6_server
			x                                CHOICES dhcp4_relay
			x                                CHOICES dhcp6_relay
			x                                CHOICES dhcp6_relay_light
			x                                CHOICES ancp
			x                                CHOICES pppox_client
			x                                CHOICES bondedGRE]
			x	-mode                           CHOICES create_template_group
			x                                CHOICES create_tlv
			x                                CHOICES create_tlv_container
			x                                CHOICES create_field
			x                                CHOICES modify
			x                                CHOICES delete
			x                                CHOICES delete_all]
			x	[-template_group_name           ALPHA]
			x	[-container_name                ALPHA]
			x	[-container_description         ALPHA]
			x	[-container_is_required         CHOICES 0 1]
			x	[-container_is_editable         CHOICES 0 1]
			x	[-container_is_enabled          CHOICES 0 1]
			x	[-container_is_repeatable       CHOICES 0 1]
			x	[-tlv_name                      ALPHA]
			x	[-tlv_description               ALPHA]
			x	[-tlv_is_enabled                CHOICES 0 1]
			x	[-tlv_is_repeatable             CHOICES 0 1]
			x	[-tlv_is_required               CHOICES 0 1]
			x	[-tlv_is_editable               CHOICES 0 1]
			x	[-tlv_include_in_messages       ANY]
			x	[-clear_tlv_include_in_messages FLAG]
			x	[-tlv_enable_per_session        CHOICES 0 1]
			x	[-field_name                    ALPHA]
			x	[-field_description             ALPHA]
			x	[-field_encoding                CHOICES bool
			x                                CHOICES decimal
			x                                CHOICES fcid
			x                                CHOICES hex
			x                                CHOICES float
			x                                CHOICES ipv4
			x                                CHOICES ipv6
			x                                CHOICES mac
			x                                CHOICES string
			x                                CHOICES varLenHex]
			x	[-field_size                    NUMERIC]
			x	[-field_value                   ALPHA]
			x	[-field_is_required             CHOICES 0 1]
			x	[-field_is_repeatable           CHOICES 0 1]
			x	[-field_is_enabled              CHOICES 0 1]
			x	[-field_is_editable             CHOICES 0 1]
			x	[-type_name                     ALPHA]
			x	[-type_is_editable              CHOICES 0 1]
			x	[-type_is_required              CHOICES 0 1]
			x	[-length_name                   ALPHA]
			x	[-length_description            ALPHA]
			x	[-length_encoding               CHOICES bool
			x                                CHOICES decimal
			x                                CHOICES fcid
			x                                CHOICES hex
			x                                CHOICES float
			x                                CHOICES ipv4
			x                                CHOICES ipv6
			x                                CHOICES mac
			x                                CHOICES string
			x                                CHOICES varLenHex]
			x	[-length_size                   NUMERIC]
			x	[-length_value                  ALPHA]
			x	[-length_is_required            CHOICES 0 1]
			x	[-length_is_editable            CHOICES 0 1]
			x	[-length_is_enabled             CHOICES 0 1]
			x	[-disable_name_matching         FLAG]
		
		Arguments:
			x	-handle
			x		The handle of a protocol stack or another handle returned by a prior tlv_config command.
			x	-tlv_handle
			x		The handle of a TLV from a default or custom TLV Template that will be used to define the structure of a new TLV that is added to the TLV Profile of a protocol.
			x	-protocol
			x		The type of protocol that the TLV applies to.
			x		Valid choices are:
			x   		dhcp4_client - TLV configuration for DHCPv4 Clients
			x   		dhcp4_server - TLV configuration for DHCPv4 Servers
			x   		dhcp6_client - TLV configuration for DHCPv6 Clients
			x   		dhcp6_server - TLV configuration for DHCPv6 Servers
			x   		dhcp4_relay - TLV configuration for DHCPv4 Relay Agents
			x   		dhcp6_relay - TLV configuration for DHCPv6 Relay Agents
			x   		dhcp6_relay_light - TLV configuration for lightweight DHCPv6 Relay Agents
			x   		ancp - TLV configuration for Ancp
			x   		pppox_client - TLV configuration for ppp client
			x   		bondedGRE - TLV configuration for BondedGRE client
			x	-mode
			x		The action that the command will execute.
			x		Valid choices are:
			x   		create_template_group - Create a new custom TLV Template group that will be used as a custom container for a series or TLVs.
			x   		create_tlv - Create a new TLV or sub TLV in a custom TLV Template or add a new TLV to the TLV Profile of a protocol.
			x   		create_tlv_container - Creates a new TLV container that can be used to add a group of nested sub TLVs to a custom TLV Template.
			x   		create_field - Creates a new field in a TLV from a TLV Template or the TLV Profile of a protocol.
			x   		modify - Modifies an existing custom TLV Template, container, field, TLV or sub TLV.
			x   		delete - Deletes an existing custom TLV Template, container, field, TLV or sub TLV.
			x   		delete_all - Deletes all existing TLVs from the TLV Profile of specified protocol.
			x	-template_group_name
			x		When the -mode is create_template_group the value of this argument will be used to specify the name of the new TLV Template group. When the -mode is create_tlv the value of this argument will be used to find an existing TLV Template group with a matching name.
			x	-container_name
			x		The name of the container.
			x	-container_description
			x		The description of the container.
			x	-container_is_required
			x		Flag indicating whether the container is required in the TLV definition from the TLV Template.
			x	-container_is_editable
			x		Flag indicating whether the container is editable in the TLV definition from the TLV Template.
			x	-container_is_enabled
			x		Flag indicating whether the container is enabled or not in the TLV Profile of the protocol.
			x	-container_is_repeatable
			x		Indicates whether the new container can be multiplied in the TLV definition from the TLV Template.
			x	-tlv_name
			x		The name of the TLV or subTLV.
			x	-tlv_description
			x		The description of the TLV or subTLV.
			x	-tlv_is_enabled
			x		Flag indicating whether the TLV or subTLV is enabled in the TLV profile of a protocol.
			x	-tlv_is_repeatable
			x		Indicates whether the current TLV or subTLV can be multiplied in the TLV definition from the TLV Template.
			x	-tlv_is_required
			x		Indicates whether the current TLV or subTLV is required in the TLV definition from the TLV Template.
			x	-tlv_is_editable
			x		Indicates whether the current TLV or subTLV from a TLV Template is editable when added to the TLV Profile of a protocol.
			x	-tlv_include_in_messages
			x		Include the TLV in these protocol messages. Partial names of the messages can be used.
			x	-clear_tlv_include_in_messages
			x		Clear all protocol messages that the TLV should be included in.
			x	-tlv_enable_per_session
			x		Enable this TLV or subTLV per session.
			x	-field_name
			x		The name of the TLV field.
			x	-field_description
			x		The description of the TLV field.
			x	-field_encoding
			x		The encoding of the TLV field's value. Any change via this argument will result in the field's value being reset unless a matching value is specified for field_value.
			x		Valid choices are:
			x   		bool - The field encodes a Bool value
			x   		decimal - The field encodes a Decimal value
			x   		fcid - The field encodes a FC_ID value
			x   		hex - The field encodes a Hex value
			x   		float - The field encodes a Float value
			x   		ipv4 - The field encodes an IPv4 value
			x   		ipv6 - The field encodes an IPv6 value
			x   		mac - The field encodes a MAC value
			x   		string - The field encodes a String value
			x   		varLenHex - The field encodes a varLenHex value
			x	-field_size
			x		The size of the TLV field's value. Any change via this argument will result in the field's value being reset unless a matching value is specified for field_value.
			x	-field_value
			x		The value of the field. This can be a handle returned by multivalue_config.
			x	-field_is_required
			x		Flag indicating whether the field is required in the TLV definition from the TLV Template.
			x	-field_is_repeatable
			x		Flag indicating whether the field is repeatable in the TLV definition from the TLV Template.
			x	-field_is_enabled
			x		Enables/disables the field in the TLV Profile of a protocol.
			x	-field_is_editable
			x		Enables/disables editing for the field.
			x	-type_name
			x		The name of the TLV type.
			x	-type_is_editable
			x		Enables/disables editing for the type.
			x	-type_is_required
			x		Flag indicating whether the type is required in the TLV definition.
			x	-length_name
			x		The name of the TLV length.
			x	-length_description
			x		The description of the TLV length.
			x	-length_encoding
			x		The encoding of the TLV length's value. Any change via this argument will result in the length's value being reset unless a matching value is specified for length_value.
			x		Valid choices are:
			x   		bool - The field encodes a Bool value
			x   		decimal - The field encodes a Decimal value
			x   		fcid - The field encodes a FC_ID value
			x   		hex - The field encodes a Hex value
			x   		float - The field encodes a Float value
			x   		ipv4 - The field encodes an IPv4 value
			x   		ipv6 - The field encodes an IPv6 value
			x   		mac - The field encodes a MAC value
			x   		string - The field encodes a String value
			x   		varLenHex - The field encodes a varLenHex value
			x	-length_size
			x		The size of the TLV length's value. Any change via this argument will result in the length's value being reset unless a matching value is specified for length_value.
			x	-length_value
			x		The value of the length. This can be a handle returned by multivalue_config.
			x	-length_is_required
			x		Flag indicating whether the length is required in the TLV definition from the TLV Template.
			x	-length_is_editable
			x		Enables/disables editing for the length.
			x	-length_is_enabled
			x		Enables/disables the length from the TLV Profile of a protocol.
			x	-disable_name_matching
			x		This flag can be used to disable the name matching algorithm that attempts to look for a TLV template to copy when tlv_name and/or template_group_name are specified.
		
		Return Values:
		A list containing the tlv template group protocol stack handles that were added by the command (if any).
			xkey:tlv_template_group_handle  value:A list containing the tlv template group protocol stack handles that were added by the command (if any).
		A list containing the tlv template protocol stack handles that were added by the command (if any).
			xkey:tlv_template_handle        value:A list containing the tlv template protocol stack handles that were added by the command (if any).
		A list containing the tlv value protocol stack handles that were added by the command (if any).
			xkey:tlv_value_handle           value:A list containing the tlv value protocol stack handles that were added by the command (if any).
		A list containing the subtlv template protocol stack handles that were added by the command (if any).
			xkey:subtlv_template_handle     value:A list containing the subtlv template protocol stack handles that were added by the command (if any).
		A list containing the tlv field protocol stack handles that were added by the command (if any).
			xkey:tlv_field_handle           value:A list containing the tlv field protocol stack handles that were added by the command (if any).
		A list containing the tlv container protocol stack handles that were added by the command (if any).
			xkey:tlv_container_handle       value:A list containing the tlv container protocol stack handles that were added by the command (if any).
		A list containing the tlv type protocol stack handles that were added by the command (if any).
			xkey:tlv_type_handle            value:A list containing the tlv type protocol stack handles that were added by the command (if any).
		A list containing the tlv length protocol stack handles that were added by the command (if any).
			xkey:tlv_length_handle          value:A list containing the tlv length protocol stack handles that were added by the command (if any).
		A list containing the tlv protocol stack handles that were added by the command (if any).
			xkey:tlv_handle                 value:A list containing the tlv protocol stack handles that were added by the command (if any).
		A list containing the default tlv protocol stack handles that were added by the command (if any).
			xkey:default_tlv_handle         value:A list containing the default tlv protocol stack handles that were added by the command (if any).
		A list containing the subtlv protocol stack handles that were added by the command (if any).
			xkey:subtlv_handle              value:A list containing the subtlv protocol stack handles that were added by the command (if any).
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		When -handle is provided with the /globals value the command will configure a TLV template.
		
		See Also:
		
		"""
		return self._run_keyword("tlv_config", kwargs)

	def topology_config(self, **kwargs):
		""" This procedure will create a topology and one or multiple device groups. This is the building block of creating a new scenario in IxNetwork.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: topology_config
			 	[-mode                    CHOICES config modify destroy
			                           DEFAULT config]
			x	[-topology_name           ALPHA]
			x	[-topology_handle         ANY]
			 	[-port_handle             REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			 	[-lag_handle              REGEXP ^[0-9]+/[0-9]+/[0-9]+$]
			x	[-device_group_name       ALPHA]
			x	[-device_group_multiplier NUMERIC
			x                          DEFAULT 10]
			x	[-device_group_enabled    CHOICES 0 1]
			x	[-device_group_handle     ANY]
			x	[-protocol_stacking_mode  CHOICES parallel sequential
			x                          DEFAULT sequential]
			x	[-protocol_rate_mode      CHOICES basic smooth
			x                          DEFAULT basic]
		
		Arguments:
			 	-mode
			 		Action to be taken on the interface selected.
			 		This option takes a list of values when -port_handle is a list of
			 		port handles.
			 		This option is valid for the old and the new APIs.
			 		When ::ixia::interface_config is provided with -port_handle
			 		parameter, -mode modify and other supported parameters,
			 		except -interface_handle, the modification is supported
			 		for L1 parameters only.
			 		When ::ixia::interface_config is provided with -port_handle
			 		parameter, -mode modify and other supported parameters,
			 		including -interface_handle, the modification is supported
			 		for L2-L3 parameters also, but only for protocol
			 		interfaces (-l23_config_type protocol_interface). This argument does not support lists.
			 		Valid choices are:
			    		config -
			    		modify - Valid only when using IxTclNetwork.
			    		destroy - Clear all interfaces before configuring new ones.
			x	-topology_name
			x		The name of the topology that will be shown in the IxNetwork GUI.
			x		You can create at most one topology with a topology_config command.
			x		This argument is optional and does not suuport lists.
			x	-topology_handle
			x		Handle for the topology that the user wants to modify or delete. This argument does not support lists.
			 	-port_handle
			 		List of ports to be added to the topology.
			 	-lag_handle
			 		List of ports as a lag to be added to the topology.
			x	-device_group_name
			x		The name of the device group that will be shown in the IxNetwork GUI.
			x		This argument is optional and does not support lists.
			x	-device_group_multiplier
			x		The number of devices that will be simulated for each port assigned to the
			x		parent topology or each device simulated in the parent device group. This argument does not support lists.
			x	-device_group_enabled
			x		This argument can be used to disable or enable individual devices within
			x		the specified device group. This argument does not support lists.
			x	-device_group_handle
			x		Handle for the device group that the user wants to modify,
			x		delete or use as a parent for a new device group. This argument does not support lists.
			x	-protocol_stacking_mode
			x		Decides whether NGPF sessions will be started sequentially or in parallel across the protocols layers.
			x		Valid choices are:
			x   		parallel - Start sessions in parallel across the layers. This behavior is only supported for certain access protocols.
			x   		sequential - Start sessions sequentially, layer by layer. This is the default behavior of NGPF protocols.
			x	-protocol_rate_mode
			x		Decides how the rate of starting and stopping NGPF sessions will be controlled.
			x		Valid choices are:
			x   		basic - This option is the default mode of starting sessions and it is supported for all NGPF protocols.
			x   		smooth - This option enables a finer control of how sessions are started. This option is currently supported only for certain NGPF access protocols.
		
		Return Values:
		A list containing the topology protocol stack handles that were added by the command (if any).
			xkey:topology_handle      value:A list containing the topology protocol stack handles that were added by the command (if any).
		A list containing the device group protocol stack handles that were added by the command (if any).
			xkey:device_group_handle  value:A list containing the device group protocol stack handles that were added by the command (if any).
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		When -handle is provided with the /globals value the arguments that configure global protocol
		setting accept both multivalue handles and simple values.
		When -handle is provided with a a protocol stack handle or a protocol session handle, the arguments
		that configure global settings will only accept simple values. In this situation, these arguments will
		configure only the settings of the parent device group or the ports associated with the parent topology.
		
		See Also:
		
		"""
		return self._run_keyword("topology_config", kwargs)

	def traffic_config(self, **kwargs):
		""" This generic procedure creates, modifies and removes L23 Data plane traffic. This API helps user to setup traffic source and destination endpoints, various field of IP datagram/frame, flow and flow group related configuration, frame rate and transmission and tracking options.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: traffic_config
			 	[-arp_dst_hw_addr                              ANY]
			 	[-arp_dst_hw_count                             ANY]
			 	[-arp_dst_hw_mode                              ANY]
			 	[-arp_operation                                ANY]
			 	[-arp_src_hw_addr                              ANY]
			 	[-arp_src_hw_count                             ANY]
			 	[-arp_src_hw_mode                              ANY]
			 	[-bidirectional                                ANY]
			 	[-burst_loop_count                             ANY]
			 	[-command_response                             ANY]
			 	[-emulation_dst_handle                         ANY]
			x	[-emulation_multicast_dst_handle               ANY]
			x	[-emulation_multicast_dst_handle_type          ANY]
			x	[-emulation_multicast_rcvr_handle              ANY]
			x	[-emulation_multicast_rcvr_port_index          ANY]
			x	[-emulation_multicast_rcvr_host_index          ANY]
			x	[-emulation_multicast_rcvr_mcast_index         ANY]
			 	[-emulation_src_handle                         ANY]
			 	[-fcs                                          ANY]
			 	[-icmp_checksum                                ANY]
			 	[-icmp_code                                    ANY]
			 	[-icmp_id                                      ANY]
			 	[-icmp_seq                                     ANY]
			 	[-icmp_type                                    ANY]
			 	[-igmp_group_addr                              ANY]
			 	[-igmp_group_count                             ANY]
			 	[-igmp_group_mode                              ANY]
			 	[-igmp_group_step                              ANY]
			 	[-igmp_max_response_time                       ANY]
			 	[-igmp_msg_type                                ANY]
			 	[-igmp_multicast_src                           ANY]
			 	[-igmp_qqic                                    ANY]
			 	[-igmp_qrv                                     ANY]
			 	[-igmp_record_type                             ANY]
			 	[-igmp_s_flag                                  ANY]
			 	[-igmp_type                                    ANY]
			 	[-igmp_valid_checksum                          ANY]
			 	[-igmp_version                                 ANY]
			 	[-inter_burst_gap                              ANY]
			x	[-inter_burst_gap_unit                         ANY]
			 	[-inter_stream_gap                             ANY]
			 	[-ip_checksum                                  ANY]
			 	[-ip_cu                                        ANY]
			 	[-ip_dscp                                      ANY]
			 	[-ip_dscp_count                                ANY]
			 	[-ip_dscp_step                                 ANY]
			 	[-ip_dst_addr                                  ANY]
			 	[-ip_dst_count                                 ANY]
			 	[-ip_dst_mode                                  ANY]
			 	[-ip_dst_step                                  ANY]
			 	[-ip_fragment                                  ANY]
			 	[-ip_fragment_last                             ANY]
			 	[-ip_fragment_offset                           ANY]
			 	[-ip_hdr_length                                ANY]
			 	[-ip_id                                        ANY]
			 	[-ip_precedence                                ANY]
			 	[-ip_protocol                                  ANY]
			 	[-ip_src_addr                                  ANY]
			 	[-ip_src_count                                 ANY]
			 	[-ip_src_mode                                  ANY]
			 	[-ip_src_step                                  ANY]
			 	[-ip_ttl                                       ANY]
			 	[-ipv6_dst_addr                                ANY]
			 	[-ipv6_dst_count                               ANY]
			 	[-ipv6_dst_mode                                ANY]
			 	[-ipv6_dst_step                                ANY]
			 	[-ipv6_flow_label                              ANY]
			 	[-ipv6_frag_id                                 ANY]
			 	[-ipv6_frag_more_flag                          ANY]
			 	[-ipv6_frag_offset                             ANY]
			 	[-ipv6_hop_limit                               ANY]
			 	[-ipv6_next_header                             ANY]
			 	[-ipv6_src_addr                                ANY]
			 	[-ipv6_src_count                               ANY]
			 	[-ipv6_src_mode                                ANY]
			 	[-ipv6_src_step                                ANY]
			 	[-ipv6_traffic_class                           ANY]
			 	[-l2_encap                                     ANY]
			 	[-l3_gaus1_avg                                 ANY]
			 	[-l3_gaus1_halfbw                              ANY]
			 	[-l3_gaus1_weight                              ANY]
			 	[-l3_gaus2_avg                                 ANY]
			 	[-l3_gaus2_halfbw                              ANY]
			 	[-l3_gaus2_weight                              ANY]
			 	[-l3_gaus3_avg                                 ANY]
			 	[-l3_gaus3_halfbw                              ANY]
			 	[-l3_gaus3_weight                              ANY]
			 	[-l3_gaus4_avg                                 ANY]
			 	[-l3_gaus4_halfbw                              ANY]
			 	[-l3_gaus4_weight                              ANY]
			 	[-l3_imix1_ratio                               ANY]
			 	[-l3_imix1_size                                ANY]
			 	[-l3_imix2_ratio                               ANY]
			 	[-l3_imix2_size                                ANY]
			 	[-l3_imix3_ratio                               ANY]
			 	[-l3_imix3_size                                ANY]
			 	[-l3_imix4_ratio                               ANY]
			 	[-l3_imix4_size                                ANY]
			 	[-l3_length                                    ANY]
			 	[-l3_length_max                                ANY]
			 	[-l3_length_min                                ANY]
			 	[-l3_protocol                                  ANY]
			 	[-l4_protocol                                  ANY]
			 	[-length_mode                                  ANY]
			 	[-mac_dst                                      ANY]
			 	[-mac_dst2                                     ANY]
			 	[-mac_dst_count                                ANY]
			 	[-mac_dst_mask                                 ANY]
			 	[-mac_dst_mode                                 ANY]
			 	[-mac_dst_seed                                 ANY]
			 	[-mac_dst_step                                 ANY]
			 	[-mac_src                                      ANY]
			 	[-mac_src2                                     ANY]
			 	[-mac_src_count                                ANY]
			 	[-mac_src_mask                                 ANY]
			 	[-mac_src_mode                                 ANY]
			 	[-mac_src_seed                                 ANY]
			 	[-mac_src_step                                 ANY]
			 	[-mode                                         ANY]
			 	[-mpls_labels                                  ANY]
			 	[-pkts_per_burst                               ANY]
			 	[-port_handle                                  ANY]
			 	[-port_handle2                                 ANY]
			 	[-rate_bps                                     ANY]
			 	[-rate_frame_gap                               ANY]
			 	[-rate_percent                                 ANY]
			 	[-rate_pps                                     ANY]
			 	[-stream_id                                    ANY]
			 	[-stack_index                                  ANY]
			 	[-tcp_ack_flag                                 ANY]
			 	[-tcp_ack_num                                  ANY]
			 	[-tcp_dst_port                                 ANY]
			 	[-tcp_fin_flag                                 ANY]
			 	[-tcp_psh_flag                                 ANY]
			 	[-tcp_reserved                                 ANY]
			 	[-tcp_rst_flag                                 ANY]
			 	[-tcp_seq_num                                  ANY]
			 	[-tcp_src_port                                 ANY]
			 	[-tcp_syn_flag                                 ANY]
			 	[-tcp_urg_flag                                 ANY]
			 	[-tcp_urgent_ptr                               ANY]
			 	[-tcp_window                                   ANY]
			 	[-transmit_mode                                ANY]
			 	[-udp_checksum                                 ANY]
			 	[-udp_dst_port                                 ANY]
			 	[-udp_src_port                                 ANY]
			 	[-vci                                          ANY]
			 	[-vci_count                                    ANY]
			 	[-vci_step                                     ANY]
			 	[-vlan_cfi                                     ANY]
			 	[-vlan_id                                      ANY]
			 	[-vlan_id_count                                ANY]
			 	[-vlan_id_mode                                 ANY]
			 	[-vlan_id_step                                 ANY]
			 	[-vlan_user_priority                           ANY]
			 	[-vpi                                          ANY]
			 	[-vpi_count                                    ANY]
			 	[-vpi_step                                     ANY]
			x	[-adjust_rate                                  ANY]
			x	[-allow_self_destined                          ANY]
			n	[-app_profile_type                             ANY]
			x	[-arp_dst_hw_step                              ANY]
			x	[-arp_dst_hw_tracking                          ANY]
			x	[-arp_hw_address_length                        ANY]
			x	[-arp_hw_address_length_count                  ANY]
			x	[-arp_hw_address_length_mode                   ANY]
			x	[-arp_hw_address_length_step                   ANY]
			x	[-arp_hw_address_length_tracking               ANY]
			x	[-arp_hw_type                                  ANY]
			x	[-arp_hw_type_count                            ANY]
			x	[-arp_hw_type_mode                             ANY]
			x	[-arp_hw_type_step                             ANY]
			x	[-arp_hw_type_tracking                         ANY]
			x	[-arp_operation_mode                           ANY]
			x	[-arp_operation_tracking                       ANY]
			x	[-arp_protocol_addr_length                     ANY]
			x	[-arp_protocol_addr_length_count               ANY]
			x	[-arp_protocol_addr_length_mode                ANY]
			x	[-arp_protocol_addr_length_step                ANY]
			x	[-arp_protocol_addr_length_tracking            ANY]
			x	[-arp_protocol_type                            ANY]
			x	[-arp_protocol_type_count                      ANY]
			x	[-arp_protocol_type_mode                       ANY]
			x	[-arp_protocol_type_step                       ANY]
			x	[-arp_protocol_type_tracking                   ANY]
			x	[-arp_src_hw_step                              ANY]
			x	[-arp_src_hw_tracking                          ANY]
			x	[-atm_counter_vci_data_item_list               ANY]
			x	[-atm_counter_vci_mask_select                  ANY]
			x	[-atm_counter_vci_mask_value                   ANY]
			x	[-atm_counter_vci_mode                         ANY]
			x	[-atm_counter_vci_type                         ANY]
			x	[-atm_counter_vpi_data_item_list               ANY]
			x	[-atm_counter_vpi_mask_select                  ANY]
			x	[-atm_counter_vpi_mask_value                   ANY]
			x	[-atm_counter_vpi_mode                         ANY]
			x	[-atm_counter_vpi_type                         ANY]
			x	[-atm_header_aal5error                         ANY]
			x	[-atm_header_cell_loss_priority                ANY]
			x	[-atm_header_cpcs_length                       ANY]
			x	[-atm_header_enable_auto_vpi_vci               ANY]
			x	[-atm_header_enable_cl                         ANY]
			x	[-atm_header_enable_cpcs_length                ANY]
			x	[-atm_header_encapsulation                     ANY]
			x	[-atm_header_generic_flow_ctrl                 ANY]
			x	[-atm_header_hec_errors                        ANY]
			x	[-atm_range_count                              ANY]
			x	[-becn                                         ANY]
			x	[-circuit_endpoint_type                        ANY]
			x	[-circuit_type                                 ANY]
			x	[-convert_to_raw                               ANY]
			x	[-custom_offset                                ANY]
			x	[-custom_values                                ANY]
			x	[-data_pattern                                 ANY]
			x	[-data_pattern_mode                            ANY]
			x	[-data_tos                                     ANY]
			x	[-data_tos_count                               ANY]
			x	[-data_tos_mode                                ANY]
			x	[-data_tos_step                                ANY]
			x	[-data_tos_tracking                            ANY]
			x	[-destination_filter                           ANY]
			x	[-tag_filter                                   ANY]
			x	[-dhcp_boot_filename                           ANY]
			x	[-dhcp_boot_filename_tracking                  ANY]
			x	[-dhcp_client_hw_addr                          ANY]
			x	[-dhcp_client_hw_addr_count                    ANY]
			x	[-dhcp_client_hw_addr_mode                     ANY]
			x	[-dhcp_client_hw_addr_step                     ANY]
			x	[-dhcp_client_hw_addr_tracking                 ANY]
			x	[-dhcp_client_ip_addr                          ANY]
			x	[-dhcp_client_ip_addr_count                    ANY]
			x	[-dhcp_client_ip_addr_mode                     ANY]
			x	[-dhcp_client_ip_addr_step                     ANY]
			x	[-dhcp_client_ip_addr_tracking                 ANY]
			x	[-dhcp_flags                                   ANY]
			x	[-dhcp_flags_mode                              ANY]
			x	[-dhcp_flags_tracking                          ANY]
			x	[-dhcp_hops                                    ANY]
			x	[-dhcp_hops_count                              ANY]
			x	[-dhcp_hops_mode                               ANY]
			x	[-dhcp_hops_step                               ANY]
			x	[-dhcp_hops_tracking                           ANY]
			x	[-dhcp_hw_len                                  ANY]
			x	[-dhcp_hw_len_count                            ANY]
			x	[-dhcp_hw_len_mode                             ANY]
			x	[-dhcp_hw_len_step                             ANY]
			x	[-dhcp_hw_len_tracking                         ANY]
			x	[-dhcp_hw_type                                 ANY]
			x	[-dhcp_hw_type_count                           ANY]
			x	[-dhcp_hw_type_mode                            ANY]
			x	[-dhcp_hw_type_step                            ANY]
			x	[-dhcp_hw_type_tracking                        ANY]
			x	[-dhcp_magic_cookie                            ANY]
			x	[-dhcp_magic_cookie_count                      ANY]
			x	[-dhcp_magic_cookie_mode                       ANY]
			x	[-dhcp_magic_cookie_step                       ANY]
			x	[-dhcp_magic_cookie_tracking                   ANY]
			x	[-dhcp_operation_code                          ANY]
			x	[-dhcp_operation_code_mode                     ANY]
			x	[-dhcp_operation_code_tracking                 ANY]
			x	[-dhcp_option                                  ANY]
			x	[-dhcp_option_data                             ANY]
			x	[-dhcp_relay_agent_ip_addr                     ANY]
			x	[-dhcp_relay_agent_ip_addr_count               ANY]
			x	[-dhcp_relay_agent_ip_addr_mode                ANY]
			x	[-dhcp_relay_agent_ip_addr_step                ANY]
			x	[-dhcp_relay_agent_ip_addr_tracking            ANY]
			x	[-dhcp_seconds                                 ANY]
			x	[-dhcp_seconds_count                           ANY]
			x	[-dhcp_seconds_mode                            ANY]
			x	[-dhcp_seconds_step                            ANY]
			x	[-dhcp_seconds_tracking                        ANY]
			x	[-dhcp_server_host_name                        ANY]
			x	[-dhcp_server_host_name_tracking               ANY]
			x	[-dhcp_server_ip_addr                          ANY]
			x	[-dhcp_server_ip_addr_count                    ANY]
			x	[-dhcp_server_ip_addr_mode                     ANY]
			x	[-dhcp_server_ip_addr_step                     ANY]
			x	[-dhcp_server_ip_addr_tracking                 ANY]
			x	[-dhcp_transaction_id                          ANY]
			x	[-dhcp_transaction_id_count                    ANY]
			x	[-dhcp_transaction_id_mode                     ANY]
			x	[-dhcp_transaction_id_step                     ANY]
			x	[-dhcp_transaction_id_tracking                 ANY]
			x	[-dhcp_your_ip_addr                            ANY]
			x	[-dhcp_your_ip_addr_count                      ANY]
			x	[-dhcp_your_ip_addr_mode                       ANY]
			x	[-dhcp_your_ip_addr_step                       ANY]
			x	[-dhcp_your_ip_addr_tracking                   ANY]
			x	[-discard_eligible                             ANY]
			x	[-dlci_core_enable                             ANY]
			x	[-dlci_core_value                              ANY]
			x	[-dlci_count_mode                              ANY]
			x	[-dlci_extended_address0                       ANY]
			x	[-dlci_extended_address1                       ANY]
			x	[-dlci_extended_address2                       ANY]
			x	[-dlci_extended_address3                       ANY]
			x	[-dlci_mask_select                             ANY]
			x	[-dlci_mask_value                              ANY]
			x	[-dlci_repeat_count                            ANY]
			x	[-dlci_size                                    ANY]
			x	[-dlci_value                                   ANY]
			x	[-duration                                     ANY]
			x	[-dynamic_update_fields                        ANY]
			x	[-egress_custom_offset                         ANY]
			x	[-egress_custom_width                          ANY]
			x	[-egress_custom_field_offset                   ANY]
			x	[-egress_tracking                              ANY]
			x	[-egress_tracking_encap                        ANY]
			x	[-emulation_dst_vlan_protocol_tag_id           ANY]
			x	[-emulation_override_ppp_ip_addr               ANY]
			x	[-emulation_src_vlan_protocol_tag_id           ANY]
			x	[-emulation_scalable_dst_handle                ANY]
			x	[-emulation_scalable_dst_port_start            ANY]
			x	[-emulation_scalable_dst_port_count            ANY]
			x	[-emulation_scalable_dst_intf_start            ANY]
			x	[-emulation_scalable_dst_intf_count            ANY]
			x	[-emulation_scalable_src_handle                ANY]
			x	[-emulation_scalable_src_port_start            ANY]
			x	[-emulation_scalable_src_port_count            ANY]
			x	[-emulation_scalable_src_intf_start            ANY]
			x	[-emulation_scalable_src_intf_count            ANY]
			x	[-enable_auto_detect_instrumentation           ANY]
			x	[-enable_ce_to_pe_traffic                      ANY]
			x	[-enable_data_integrity                        ANY]
			x	[-enable_dynamic_mpls_labels                   ANY]
			x	[-enable_override_value                        ANY]
			x	[-enable_pgid                                  ANY]
			x	[-enable_test_objective                        ANY]
			x	[-enable_time_stamp                            ANY]
			x	[-enable_udf1                                  ANY]
			x	[-enable_udf2                                  ANY]
			x	[-enable_udf3                                  ANY]
			x	[-enable_udf4                                  ANY]
			x	[-enable_udf5                                  ANY]
			x	[-endpointset_count                            ANY]
			x	[-enforce_min_gap                              ANY]
			x	[-ethernet_type                                ANY]
			x	[-ethernet_value                               ANY]
			x	[-ethernet_value_count                         ANY]
			x	[-ethernet_value_mode                          ANY]
			x	[-ethernet_value_step                          ANY]
			x	[-ethernet_value_tracking                      ANY]
			x	[-fcs_type                                     ANY]
			x	[-fecn                                         ANY]
			x	[-field_activeFieldChoice                      ANY]
			x	[-field_auto                                   ANY]
			x	[-field_countValue                             ANY]
			x	[-field_fieldValue                             ANY]
			x	[-field_fullMesh                               ANY]
			x	[-field_handle                                 ANY]
			x	[-field_linked                                 ANY]
			x	[-field_linked_to                              ANY]
			x	[-field_optionalEnabled                        ANY]
			x	[-field_singleValue                            ANY]
			x	[-field_startValue                             ANY]
			x	[-field_stepValue                              ANY]
			x	[-field_trackingEnabled                        ANY]
			x	[-field_valueList                              ANY]
			x	[-field_valueType                              ANY]
			x	[-frame_rate_distribution_port                 ANY]
			x	[-frame_rate_distribution_stream               ANY]
			x	[-frame_sequencing                             ANY]
			x	[-frame_sequencing_mode                        ANY]
			x	[-frame_sequencing_offset                      ANY]
			x	[-frame_size                                   ANY]
			x	[-frame_size_distribution                      ANY]
			x	[-frame_size_gauss                             ANY]
			x	[-frame_size_imix                              ANY]
			x	[-frame_size_max                               ANY]
			x	[-frame_size_min                               ANY]
			x	[-frame_size_step                              ANY]
			x	[-global_dest_mac_retry_count                  ANY]
			x	[-global_dest_mac_retry_delay                  ANY]
			x	[-global_enable_dest_mac_retry                 ANY]
			x	[-global_enable_mac_change_on_fly              ANY]
			x	[-global_enable_min_frame_size                 ANY]
			x	[-global_enable_staggered_transmit             ANY]
			x	[-global_enable_stream_ordering                ANY]
			x	[-global_large_error_threshhold                ANY]
			x	[-global_max_traffic_generation_queries        ANY]
			x	[-global_display_mpls_current_label_value      ANY]
			x	[-global_mpls_label_learning_timeout           ANY]
			x	[-global_refresh_learned_info_before_apply     ANY]
			x	[-global_stream_control                        ANY]
			x	[-global_stream_control_iterations             ANY]
			x	[-global_use_tx_rx_sync                        ANY]
			x	[-global_wait_time                             ANY]
			x	[-global_frame_ordering                        ANY]
			x	[-global_peak_loading_replication_count        ANY]
			x	[-global_detect_misdirected_packets            ANY]
			x	[-gre_checksum                                 ANY]
			x	[-gre_checksum_count                           ANY]
			x	[-gre_checksum_enable                          ANY]
			x	[-gre_checksum_enable_mode                     ANY]
			x	[-gre_checksum_enable_tracking                 ANY]
			x	[-gre_checksum_mode                            ANY]
			x	[-gre_checksum_step                            ANY]
			x	[-gre_checksum_tracking                        ANY]
			x	[-gre_key                                      ANY]
			x	[-gre_key_count                                ANY]
			x	[-gre_key_enable                               ANY]
			x	[-gre_key_enable_mode                          ANY]
			x	[-gre_key_enable_tracking                      ANY]
			x	[-gre_key_mode                                 ANY]
			x	[-gre_key_step                                 ANY]
			x	[-gre_key_tracking                             ANY]
			x	[-gre_reserved0                                ANY]
			x	[-gre_reserved0_count                          ANY]
			x	[-gre_reserved0_mode                           ANY]
			x	[-gre_reserved0_step                           ANY]
			x	[-gre_reserved0_tracking                       ANY]
			x	[-gre_reserved1                                ANY]
			x	[-gre_reserved1_count                          ANY]
			x	[-gre_reserved1_mode                           ANY]
			x	[-gre_reserved1_step                           ANY]
			x	[-gre_reserved1_tracking                       ANY]
			x	[-gre_seq_enable                               ANY]
			x	[-gre_seq_enable_mode                          ANY]
			x	[-gre_seq_enable_tracking                      ANY]
			x	[-gre_seq_number                               ANY]
			x	[-gre_seq_number_count                         ANY]
			x	[-gre_seq_number_mode                          ANY]
			x	[-gre_seq_number_step                          ANY]
			x	[-gre_seq_number_tracking                      ANY]
			x	[-gre_valid_checksum_enable                    ANY]
			x	[-gre_version                                  ANY]
			x	[-gre_version_count                            ANY]
			x	[-gre_version_mode                             ANY]
			x	[-gre_version_step                             ANY]
			x	[-gre_version_tracking                         ANY]
			x	[-header_handle                                ANY]
			x	[-hosts_per_net                                ANY]
			x	[-icmp_checksum_count                          ANY]
			x	[-icmp_checksum_mode                           ANY]
			x	[-icmp_checksum_step                           ANY]
			x	[-icmp_checksum_tracking                       ANY]
			x	[-icmp_code_count                              ANY]
			x	[-icmp_code_mode                               ANY]
			x	[-icmp_code_step                               ANY]
			x	[-icmp_code_tracking                           ANY]
			x	[-icmp_id_count                                ANY]
			x	[-icmp_id_mode                                 ANY]
			x	[-icmp_id_step                                 ANY]
			x	[-icmp_id_tracking                             ANY]
			x	[-icmp_max_response_delay_ms                   ANY]
			x	[-icmp_max_response_delay_ms_count             ANY]
			x	[-icmp_max_response_delay_ms_mode              ANY]
			x	[-icmp_max_response_delay_ms_step              ANY]
			x	[-icmp_max_response_delay_ms_tracking          ANY]
			x	[-icmp_mc_query_v2_interval_code               ANY]
			x	[-icmp_mc_query_v2_interval_code_count         ANY]
			x	[-icmp_mc_query_v2_interval_code_mode          ANY]
			x	[-icmp_mc_query_v2_interval_code_step          ANY]
			x	[-icmp_mc_query_v2_interval_code_tracking      ANY]
			x	[-icmp_mc_query_v2_robustness_var              ANY]
			x	[-icmp_mc_query_v2_robustness_var_count        ANY]
			x	[-icmp_mc_query_v2_robustness_var_mode         ANY]
			x	[-icmp_mc_query_v2_robustness_var_step         ANY]
			x	[-icmp_mc_query_v2_robustness_var_tracking     ANY]
			x	[-icmp_mc_query_v2_s_flag                      ANY]
			x	[-icmp_mc_query_v2_s_flag_mode                 ANY]
			x	[-icmp_mc_query_v2_s_flag_tracking             ANY]
			x	[-icmp_mobile_pam_m_bit                        ANY]
			x	[-icmp_mobile_pam_m_bit_mode                   ANY]
			x	[-icmp_mobile_pam_m_bit_tracking               ANY]
			x	[-icmp_mobile_pam_o_bit                        ANY]
			x	[-icmp_mobile_pam_o_bit_mode                   ANY]
			x	[-icmp_mobile_pam_o_bit_tracking               ANY]
			x	[-icmp_multicast_address                       ANY]
			x	[-icmp_multicast_address_count                 ANY]
			x	[-icmp_multicast_address_mode                  ANY]
			x	[-icmp_multicast_address_step                  ANY]
			x	[-icmp_multicast_address_tracking              ANY]
			x	[-icmp_ndp_nam_o_flag                          ANY]
			x	[-icmp_ndp_nam_o_flag_mode                     ANY]
			x	[-icmp_ndp_nam_o_flag_tracking                 ANY]
			x	[-icmp_ndp_nam_r_flag                          ANY]
			x	[-icmp_ndp_nam_r_flag_mode                     ANY]
			x	[-icmp_ndp_nam_r_flag_tracking                 ANY]
			x	[-icmp_ndp_nam_s_flag                          ANY]
			x	[-icmp_ndp_nam_s_flag_mode                     ANY]
			x	[-icmp_ndp_nam_s_flag_tracking                 ANY]
			x	[-icmp_ndp_ram_h_flag                          ANY]
			x	[-icmp_ndp_ram_h_flag_mode                     ANY]
			x	[-icmp_ndp_ram_h_flag_tracking                 ANY]
			x	[-icmp_ndp_ram_hop_limit                       ANY]
			x	[-icmp_ndp_ram_hop_limit_count                 ANY]
			x	[-icmp_ndp_ram_hop_limit_mode                  ANY]
			x	[-icmp_ndp_ram_hop_limit_step                  ANY]
			x	[-icmp_ndp_ram_hop_limit_tracking              ANY]
			x	[-icmp_ndp_ram_m_flag                          ANY]
			x	[-icmp_ndp_ram_m_flag_mode                     ANY]
			x	[-icmp_ndp_ram_m_flag_tracking                 ANY]
			x	[-icmp_ndp_ram_o_flag                          ANY]
			x	[-icmp_ndp_ram_o_flag_mode                     ANY]
			x	[-icmp_ndp_ram_o_flag_tracking                 ANY]
			x	[-icmp_ndp_ram_reachable_time                  ANY]
			x	[-icmp_ndp_ram_reachable_time_count            ANY]
			x	[-icmp_ndp_ram_reachable_time_mode             ANY]
			x	[-icmp_ndp_ram_reachable_time_step             ANY]
			x	[-icmp_ndp_ram_reachable_time_tracking         ANY]
			x	[-icmp_ndp_ram_retransmit_timer                ANY]
			x	[-icmp_ndp_ram_retransmit_timer_count          ANY]
			x	[-icmp_ndp_ram_retransmit_timer_mode           ANY]
			x	[-icmp_ndp_ram_retransmit_timer_step           ANY]
			x	[-icmp_ndp_ram_retransmit_timer_tracking       ANY]
			x	[-icmp_ndp_ram_router_lifetime                 ANY]
			x	[-icmp_ndp_ram_router_lifetime_count           ANY]
			x	[-icmp_ndp_ram_router_lifetime_mode            ANY]
			x	[-icmp_ndp_ram_router_lifetime_step            ANY]
			x	[-icmp_ndp_ram_router_lifetime_tracking        ANY]
			x	[-icmp_ndp_rm_dest_addr                        ANY]
			x	[-icmp_ndp_rm_dest_addr_count                  ANY]
			x	[-icmp_ndp_rm_dest_addr_mode                   ANY]
			x	[-icmp_ndp_rm_dest_addr_step                   ANY]
			x	[-icmp_ndp_rm_dest_addr_tracking               ANY]
			x	[-icmp_param_problem_message_pointer           ANY]
			x	[-icmp_param_problem_message_pointer_count     ANY]
			x	[-icmp_param_problem_message_pointer_mode      ANY]
			x	[-icmp_param_problem_message_pointer_step      ANY]
			x	[-icmp_param_problem_message_pointer_tracking  ANY]
			x	[-icmp_pkt_too_big_mtu                         ANY]
			x	[-icmp_pkt_too_big_mtu_count                   ANY]
			x	[-icmp_pkt_too_big_mtu_mode                    ANY]
			x	[-icmp_pkt_too_big_mtu_step                    ANY]
			x	[-icmp_pkt_too_big_mtu_tracking                ANY]
			x	[-icmp_seq_count                               ANY]
			x	[-icmp_seq_mode                                ANY]
			x	[-icmp_seq_step                                ANY]
			x	[-icmp_seq_tracking                            ANY]
			x	[-icmp_target_addr                             ANY]
			x	[-icmp_target_addr_count                       ANY]
			x	[-icmp_target_addr_mode                        ANY]
			x	[-icmp_target_addr_step                        ANY]
			x	[-icmp_target_addr_tracking                    ANY]
			x	[-icmp_type_count                              ANY]
			x	[-icmp_type_mode                               ANY]
			x	[-icmp_type_step                               ANY]
			x	[-icmp_type_tracking                           ANY]
			x	[-icmp_unused                                  ANY]
			x	[-icmp_unused_count                            ANY]
			x	[-icmp_unused_mode                             ANY]
			x	[-icmp_unused_step                             ANY]
			x	[-icmp_unused_tracking                         ANY]
			x	[-igmp_aux_data_length                         ANY]
			x	[-igmp_aux_data_length_count                   ANY]
			x	[-igmp_aux_data_length_mode                    ANY]
			x	[-igmp_aux_data_length_step                    ANY]
			x	[-igmp_aux_data_length_tracking                ANY]
			x	[-igmp_checksum                                ANY]
			x	[-igmp_checksum_count                          ANY]
			x	[-igmp_checksum_mode                           ANY]
			x	[-igmp_checksum_step                           ANY]
			x	[-igmp_checksum_tracking                       ANY]
			x	[-igmp_data_v3r                                ANY]
			x	[-igmp_data_v3r_count                          ANY]
			x	[-igmp_data_v3r_mode                           ANY]
			x	[-igmp_data_v3r_step                           ANY]
			x	[-igmp_data_v3r_tracking                       ANY]
			x	[-igmp_group_tracking                          ANY]
			x	[-igmp_length_v3r                              ANY]
			x	[-igmp_length_v3r_count                        ANY]
			x	[-igmp_length_v3r_mode                         ANY]
			x	[-igmp_length_v3r_step                         ANY]
			x	[-igmp_length_v3r_tracking                     ANY]
			x	[-igmp_max_response_time_count                 ANY]
			x	[-igmp_max_response_time_mode                  ANY]
			x	[-igmp_max_response_time_step                  ANY]
			x	[-igmp_max_response_time_tracking              ANY]
			x	[-igmp_msg_type_tracking                       ANY]
			x	[-igmp_multicast_src_count                     ANY]
			x	[-igmp_multicast_src_mode                      ANY]
			x	[-igmp_multicast_src_step                      ANY]
			x	[-igmp_multicast_src_tracking                  ANY]
			x	[-igmp_qqic_count                              ANY]
			x	[-igmp_qqic_mode                               ANY]
			x	[-igmp_qqic_step                               ANY]
			x	[-igmp_qqic_tracking                           ANY]
			x	[-igmp_qrv_count                               ANY]
			x	[-igmp_qrv_mode                                ANY]
			x	[-igmp_qrv_step                                ANY]
			x	[-igmp_qrv_tracking                            ANY]
			x	[-igmp_record_type_mode                        ANY]
			x	[-igmp_record_type_tracking                    ANY]
			x	[-igmp_reserved_v3q                            ANY]
			x	[-igmp_reserved_v3q_count                      ANY]
			x	[-igmp_reserved_v3q_mode                       ANY]
			x	[-igmp_reserved_v3q_step                       ANY]
			x	[-igmp_reserved_v3q_tracking                   ANY]
			x	[-igmp_reserved_v3r1                           ANY]
			x	[-igmp_reserved_v3r1_count                     ANY]
			x	[-igmp_reserved_v3r1_mode                      ANY]
			x	[-igmp_reserved_v3r1_step                      ANY]
			x	[-igmp_reserved_v3r1_tracking                  ANY]
			x	[-igmp_reserved_v3r2                           ANY]
			x	[-igmp_reserved_v3r2_count                     ANY]
			x	[-igmp_reserved_v3r2_mode                      ANY]
			x	[-igmp_reserved_v3r2_step                      ANY]
			x	[-igmp_reserved_v3r2_tracking                  ANY]
			x	[-igmp_s_flag_mode                             ANY]
			x	[-igmp_s_flag_tracking                         ANY]
			x	[-igmp_unused                                  ANY]
			x	[-igmp_unused_count                            ANY]
			x	[-igmp_unused_mode                             ANY]
			x	[-igmp_unused_step                             ANY]
			x	[-igmp_unused_tracking                         ANY]
			x	[-indirect                                     ANY]
			x	[-inner_ip_dst_addr                            ANY]
			x	[-inner_ip_dst_count                           ANY]
			x	[-inner_ip_dst_mode                            ANY]
			x	[-inner_ip_dst_step                            ANY]
			x	[-inner_ip_dst_tracking                        ANY]
			x	[-inner_ip_src_addr                            ANY]
			x	[-inner_ip_src_count                           ANY]
			x	[-inner_ip_src_mode                            ANY]
			x	[-inner_ip_src_step                            ANY]
			x	[-inner_ip_src_tracking                        ANY]
			x	[-inner_ipv6_dst_addr                          ANY]
			x	[-inner_ipv6_dst_count                         ANY]
			x	[-inner_ipv6_dst_mask                          ANY]
			x	[-inner_ipv6_dst_mode                          ANY]
			x	[-inner_ipv6_dst_step                          ANY]
			x	[-inner_ipv6_dst_tracking                      ANY]
			x	[-inner_ipv6_flow_label                        ANY]
			x	[-inner_ipv6_flow_label_count                  ANY]
			x	[-inner_ipv6_flow_label_mode                   ANY]
			x	[-inner_ipv6_flow_label_step                   ANY]
			x	[-inner_ipv6_flow_label_tracking               ANY]
			x	[-inner_ipv6_frag_id                           ANY]
			x	[-inner_ipv6_frag_id_count                     ANY]
			x	[-inner_ipv6_frag_id_mode                      ANY]
			x	[-inner_ipv6_frag_id_step                      ANY]
			x	[-inner_ipv6_frag_id_tracking                  ANY]
			x	[-inner_ipv6_frag_more_flag                    ANY]
			x	[-inner_ipv6_frag_more_flag_mode               ANY]
			x	[-inner_ipv6_frag_more_flag_tracking           ANY]
			x	[-inner_ipv6_frag_offset                       ANY]
			x	[-inner_ipv6_frag_offset_count                 ANY]
			x	[-inner_ipv6_frag_offset_mode                  ANY]
			x	[-inner_ipv6_frag_offset_step                  ANY]
			x	[-inner_ipv6_frag_offset_tracking              ANY]
			x	[-inner_ipv6_hop_limit                         ANY]
			x	[-inner_ipv6_hop_limit_count                   ANY]
			x	[-inner_ipv6_hop_limit_mode                    ANY]
			x	[-inner_ipv6_hop_limit_step                    ANY]
			x	[-inner_ipv6_hop_limit_tracking                ANY]
			x	[-inner_ipv6_src_addr                          ANY]
			x	[-inner_ipv6_src_count                         ANY]
			x	[-inner_ipv6_src_mask                          ANY]
			x	[-inner_ipv6_src_mode                          ANY]
			x	[-inner_ipv6_src_step                          ANY]
			x	[-inner_ipv6_src_tracking                      ANY]
			x	[-inner_ipv6_traffic_class                     ANY]
			x	[-inner_ipv6_traffic_class_count               ANY]
			x	[-inner_ipv6_traffic_class_mode                ANY]
			x	[-inner_ipv6_traffic_class_step                ANY]
			x	[-inner_ipv6_traffic_class_tracking            ANY]
			x	[-inner_protocol                               ANY]
			x	[-inner_protocol_count                         ANY]
			x	[-inner_protocol_mode                          ANY]
			x	[-inner_protocol_step                          ANY]
			x	[-inner_protocol_tracking                      ANY]
			x	[-integrity_signature                          ANY]
			x	[-integrity_signature_offset                   ANY]
			x	[-inter_frame_gap                              ANY]
			x	[-inter_frame_gap_unit                         ANY]
			x	[-ip_checksum_count                            ANY]
			x	[-ip_checksum_mode                             ANY]
			x	[-ip_checksum_step                             ANY]
			x	[-ip_checksum_tracking                         ANY]
			x	[-ip_cost                                      ANY]
			x	[-ip_cost_mode                                 ANY]
			x	[-ip_cost_tracking                             ANY]
			x	[-ip_cu_count                                  ANY]
			x	[-ip_cu_mode                                   ANY]
			x	[-ip_cu_step                                   ANY]
			x	[-ip_cu_tracking                               ANY]
			x	[-ip_delay                                     ANY]
			x	[-ip_delay_mode                                ANY]
			x	[-ip_delay_tracking                            ANY]
			x	[-ip_dscp_mode                                 ANY]
			x	[-ip_dscp_tracking                             ANY]
			x	[-ip_dst_tracking                              ANY]
			x	[-ip_fragment_last_mode                        ANY]
			x	[-ip_fragment_last_tracking                    ANY]
			x	[-ip_fragment_mode                             ANY]
			x	[-ip_fragment_offset_count                     ANY]
			x	[-ip_fragment_offset_mode                      ANY]
			x	[-ip_fragment_offset_step                      ANY]
			x	[-ip_fragment_offset_tracking                  ANY]
			x	[-ip_fragment_tracking                         ANY]
			x	[-ip_hdr_length_count                          ANY]
			x	[-ip_hdr_length_mode                           ANY]
			x	[-ip_hdr_length_step                           ANY]
			x	[-ip_hdr_length_tracking                       ANY]
			x	[-ip_id_count                                  ANY]
			x	[-ip_id_mode                                   ANY]
			x	[-ip_id_step                                   ANY]
			x	[-ip_id_tracking                               ANY]
			x	[-ip_length_override                           ANY]
			x	[-ip_length_override_mode                      ANY]
			x	[-ip_length_override_tracking                  ANY]
			x	[-ip_opt_loose_routing                         ANY]
			x	[-ip_opt_security                              ANY]
			x	[-ip_opt_strict_routing                        ANY]
			x	[-ip_opt_timestamp                             ANY]
			x	[-ip_precedence_count                          ANY]
			x	[-ip_precedence_mode                           ANY]
			x	[-ip_precedence_step                           ANY]
			x	[-ip_precedence_tracking                       ANY]
			x	[-ip_protocol_count                            ANY]
			x	[-ip_protocol_mode                             ANY]
			x	[-ip_protocol_step                             ANY]
			x	[-ip_protocol_tracking                         ANY]
			x	[-ip_reliability                               ANY]
			x	[-ip_reliability_mode                          ANY]
			x	[-ip_reliability_tracking                      ANY]
			x	[-ip_reserved                                  ANY]
			x	[-ip_reserved_mode                             ANY]
			x	[-ip_reserved_tracking                         ANY]
			x	[-ip_src_tracking                              ANY]
			x	[-ip_throughput                                ANY]
			x	[-ip_throughput_mode                           ANY]
			x	[-ip_throughput_tracking                       ANY]
			x	[-ip_total_length                              ANY]
			x	[-ip_total_length_count                        ANY]
			x	[-ip_total_length_mode                         ANY]
			x	[-ip_total_length_step                         ANY]
			x	[-ip_total_length_tracking                     ANY]
			x	[-ip_ttl_count                                 ANY]
			x	[-ip_ttl_mode                                  ANY]
			x	[-ip_ttl_step                                  ANY]
			x	[-ip_ttl_tracking                              ANY]
			x	[-ipv6_auth_next_header                        ANY]
			x	[-ipv6_auth_next_header_count                  ANY]
			x	[-ipv6_auth_next_header_mode                   ANY]
			x	[-ipv6_auth_next_header_step                   ANY]
			x	[-ipv6_auth_next_header_tracking               ANY]
			x	[-ipv6_auth_padding                            ANY]
			x	[-ipv6_auth_padding_count                      ANY]
			x	[-ipv6_auth_padding_mode                       ANY]
			x	[-ipv6_auth_padding_step                       ANY]
			x	[-ipv6_auth_padding_tracking                   ANY]
			x	[-ipv6_auth_payload_len                        ANY]
			x	[-ipv6_auth_payload_len_count                  ANY]
			x	[-ipv6_auth_payload_len_mode                   ANY]
			x	[-ipv6_auth_payload_len_step                   ANY]
			x	[-ipv6_auth_payload_len_tracking               ANY]
			x	[-ipv6_auth_reserved                           ANY]
			x	[-ipv6_auth_reserved_count                     ANY]
			x	[-ipv6_auth_reserved_mode                      ANY]
			x	[-ipv6_auth_reserved_step                      ANY]
			x	[-ipv6_auth_reserved_tracking                  ANY]
			x	[-ipv6_auth_seq_num                            ANY]
			x	[-ipv6_auth_seq_num_count                      ANY]
			x	[-ipv6_auth_seq_num_mode                       ANY]
			x	[-ipv6_auth_seq_num_step                       ANY]
			x	[-ipv6_auth_seq_num_tracking                   ANY]
			x	[-ipv6_auth_spi                                ANY]
			x	[-ipv6_auth_spi_count                          ANY]
			x	[-ipv6_auth_spi_mode                           ANY]
			x	[-ipv6_auth_spi_step                           ANY]
			x	[-ipv6_auth_spi_tracking                       ANY]
			x	[-ipv6_auth_string                             ANY]
			x	[-ipv6_auth_string_count                       ANY]
			x	[-ipv6_auth_string_mode                        ANY]
			x	[-ipv6_auth_string_step                        ANY]
			x	[-ipv6_auth_string_tracking                    ANY]
			x	[-ipv6_auth_type                               ANY]
			x	[-ipv6_auth_md5sha1_string                     ANY]
			x	[-ipv6_auth_md5sha1_string_count               ANY]
			x	[-ipv6_auth_md5sha1_string_mode                ANY]
			x	[-ipv6_auth_md5sha1_string_step                ANY]
			x	[-ipv6_auth_md5sha1_string_tracking            ANY]
			x	[-ipv6_dst_mask                                ANY]
			x	[-ipv6_dst_tracking                            ANY]
			x	[-ipv6_encap_seq_number                        ANY]
			x	[-ipv6_encap_seq_number_count                  ANY]
			x	[-ipv6_encap_seq_number_mode                   ANY]
			x	[-ipv6_encap_seq_number_step                   ANY]
			x	[-ipv6_encap_seq_number_tracking               ANY]
			x	[-ipv6_encap_spi                               ANY]
			x	[-ipv6_encap_spi_count                         ANY]
			x	[-ipv6_encap_spi_mode                          ANY]
			x	[-ipv6_encap_spi_step                          ANY]
			x	[-ipv6_encap_spi_tracking                      ANY]
			x	[-ipv6_extension_header                        ANY]
			x	[-ipv6_flow_label_count                        ANY]
			x	[-ipv6_flow_label_mode                         ANY]
			x	[-ipv6_flow_label_step                         ANY]
			x	[-ipv6_flow_label_tracking                     ANY]
			x	[-ipv6_flow_version                            ANY]
			x	[-ipv6_flow_version_count                      ANY]
			x	[-ipv6_flow_version_mode                       ANY]
			x	[-ipv6_flow_version_step                       ANY]
			x	[-ipv6_flow_version_tracking                   ANY]
			x	[-ipv6_frag_id_count                           ANY]
			x	[-ipv6_frag_id_mode                            ANY]
			x	[-ipv6_frag_id_step                            ANY]
			x	[-ipv6_frag_id_tracking                        ANY]
			x	[-ipv6_frag_more_flag_mode                     ANY]
			x	[-ipv6_frag_more_flag_tracking                 ANY]
			x	[-ipv6_frag_offset_count                       ANY]
			x	[-ipv6_frag_offset_mode                        ANY]
			x	[-ipv6_frag_offset_step                        ANY]
			x	[-ipv6_frag_offset_tracking                    ANY]
			x	[-ipv6_frag_res_2bit                           ANY]
			x	[-ipv6_frag_res_2bit_count                     ANY]
			x	[-ipv6_frag_res_2bit_mode                      ANY]
			x	[-ipv6_frag_res_2bit_step                      ANY]
			x	[-ipv6_frag_res_2bit_tracking                  ANY]
			x	[-ipv6_frag_res_8bit                           ANY]
			x	[-ipv6_frag_res_8bit_count                     ANY]
			x	[-ipv6_frag_res_8bit_mode                      ANY]
			x	[-ipv6_frag_res_8bit_step                      ANY]
			x	[-ipv6_frag_res_8bit_tracking                  ANY]
			x	[-ipv6_hop_by_hop_options                      ANY]
			x	[-ipv6_hop_limit_count                         ANY]
			x	[-ipv6_hop_limit_mode                          ANY]
			x	[-ipv6_hop_limit_step                          ANY]
			x	[-ipv6_hop_limit_tracking                      ANY]
			x	[-ipv6_next_header_count                       ANY]
			x	[-ipv6_next_header_mode                        ANY]
			x	[-ipv6_next_header_step                        ANY]
			x	[-ipv6_next_header_tracking                    ANY]
			x	[-ipv6_pseudo_dst_addr                         ANY]
			x	[-ipv6_pseudo_dst_addr_count                   ANY]
			x	[-ipv6_pseudo_dst_addr_mode                    ANY]
			x	[-ipv6_pseudo_dst_addr_step                    ANY]
			x	[-ipv6_pseudo_dst_addr_tracking                ANY]
			x	[-ipv6_pseudo_src_addr                         ANY]
			x	[-ipv6_pseudo_src_addr_count                   ANY]
			x	[-ipv6_pseudo_src_addr_mode                    ANY]
			x	[-ipv6_pseudo_src_addr_step                    ANY]
			x	[-ipv6_pseudo_src_addr_tracking                ANY]
			x	[-ipv6_pseudo_uppper_layer_pkt_length          ANY]
			x	[-ipv6_pseudo_uppper_layer_pkt_length_count    ANY]
			x	[-ipv6_pseudo_uppper_layer_pkt_length_mode     ANY]
			x	[-ipv6_pseudo_uppper_layer_pkt_length_step     ANY]
			x	[-ipv6_pseudo_uppper_layer_pkt_length_tracking ANY]
			x	[-ipv6_pseudo_zero_number                      ANY]
			x	[-ipv6_pseudo_zero_number_count                ANY]
			x	[-ipv6_pseudo_zero_number_mode                 ANY]
			x	[-ipv6_pseudo_zero_number_step                 ANY]
			x	[-ipv6_pseudo_zero_number_tracking             ANY]
			x	[-ipv6_routing_node_list                       ANY]
			x	[-ipv6_routing_res                             ANY]
			x	[-ipv6_routing_res_count                       ANY]
			x	[-ipv6_routing_res_mode                        ANY]
			x	[-ipv6_routing_res_step                        ANY]
			x	[-ipv6_routing_res_tracking                    ANY]
			x	[-ipv6_routing_type                            ANY]
			x	[-ipv6_routing_type_count                      ANY]
			x	[-ipv6_routing_type_mode                       ANY]
			x	[-ipv6_routing_type_step                       ANY]
			x	[-ipv6_routing_type_tracking                   ANY]
			x	[-ipv6_src_mask                                ANY]
			x	[-ipv6_src_tracking                            ANY]
			x	[-ipv6_traffic_class_count                     ANY]
			x	[-ipv6_traffic_class_mode                      ANY]
			x	[-ipv6_traffic_class_step                      ANY]
			x	[-ipv6_traffic_class_tracking                  ANY]
			x	[-isl                                          ANY]
			x	[-isl_bpdu                                     ANY]
			x	[-isl_bpdu_count                               ANY]
			x	[-isl_bpdu_mode                                ANY]
			x	[-isl_bpdu_step                                ANY]
			x	[-isl_bpdu_tracking                            ANY]
			x	[-isl_frame_type                               ANY]
			x	[-isl_frame_type_mode                          ANY]
			x	[-isl_frame_type_tracking                      ANY]
			x	[-isl_index                                    ANY]
			x	[-isl_index_count                              ANY]
			x	[-isl_index_mode                               ANY]
			x	[-isl_index_step                               ANY]
			x	[-isl_index_tracking                           ANY]
			x	[-isl_mac_dst                                  ANY]
			x	[-isl_mac_dst_count                            ANY]
			x	[-isl_mac_dst_mode                             ANY]
			x	[-isl_mac_dst_step                             ANY]
			x	[-isl_mac_dst_tracking                         ANY]
			x	[-isl_mac_src_high                             ANY]
			x	[-isl_mac_src_high_count                       ANY]
			x	[-isl_mac_src_high_mode                        ANY]
			x	[-isl_mac_src_high_step                        ANY]
			x	[-isl_mac_src_high_tracking                    ANY]
			x	[-isl_mac_src_low                              ANY]
			x	[-isl_mac_src_low_count                        ANY]
			x	[-isl_mac_src_low_mode                         ANY]
			x	[-isl_mac_src_low_step                         ANY]
			x	[-isl_mac_src_low_tracking                     ANY]
			x	[-isl_user_priority                            ANY]
			x	[-isl_user_priority_count                      ANY]
			x	[-isl_user_priority_mode                       ANY]
			x	[-isl_user_priority_step                       ANY]
			x	[-isl_user_priority_tracking                   ANY]
			x	[-isl_vlan_id                                  ANY]
			x	[-isl_vlan_id_count                            ANY]
			x	[-isl_vlan_id_mode                             ANY]
			x	[-isl_vlan_id_step                             ANY]
			x	[-isl_vlan_id_tracking                         ANY]
			x	[-l3_length_step                               ANY]
			x	[-lan_range_count                              ANY]
			x	[-latency_bins                                 ANY]
			x	[-latency_bins_enable                          ANY]
			x	[-latency_values                               ANY]
			x	[-loop_count                                   ANY]
			x	[-mac_dst_count_step                           ANY]
			x	[-mac_dst_tracking                             ANY]
			x	[-mac_src_tracking                             ANY]
			x	[-merge_destinations                           ANY]
			x	[-min_gap_bytes                                ANY]
			x	[-mpls                                         ANY]
			x	[-mpls_bottom_stack_bit                        ANY]
			x	[-mpls_bottom_stack_bit_count                  ANY]
			x	[-mpls_bottom_stack_bit_step                   ANY]
			x	[-mpls_bottom_stack_bit_mode                   ANY]
			x	[-mpls_bottom_stack_bit_tracking               ANY]
			x	[-mpls_exp_bit                                 ANY]
			x	[-mpls_exp_bit_count                           ANY]
			x	[-mpls_exp_bit_mode                            ANY]
			x	[-mpls_exp_bit_step                            ANY]
			x	[-mpls_exp_bit_tracking                        ANY]
			x	[-mpls_labels_count                            ANY]
			x	[-mpls_labels_mode                             ANY]
			x	[-mpls_labels_step                             ANY]
			x	[-mpls_labels_tracking                         ANY]
			x	[-mpls_ttl                                     ANY]
			x	[-mpls_ttl_count                               ANY]
			x	[-mpls_ttl_mode                                ANY]
			x	[-mpls_ttl_step                                ANY]
			x	[-mpls_ttl_tracking                            ANY]
			x	[-mpls_type                                    ANY]
			x	[-multiple_queues                              ANY]
			x	[-name                                         ANY]
			x	[-no_write                                     ANY]
			x	[-num_dst_ports                                ANY]
			x	[-number_of_packets_per_stream                 ANY]
			x	[-number_of_packets_tx                         ANY]
			x	[-override_value_list                          ANY]
			x	[-pause_control_time                           ANY]
			x	[-pending_operations_timeout                   ANY]
			x	[-pgid_offset                                  ANY]
			x	[-pgid_value                                   ANY]
			x	[-preamble_size_mode                           ANY]
			x	[-preamble_custom_size                         ANY]
			x	[-pt_handle                                    ANY]
			x	[-public_port_ip                               ANY]
			x	[-pvc_count                                    ANY]
			x	[-pvc_count_step                               ANY]
			x	[-qos_byte                                     ANY]
			x	[-qos_byte_count                               ANY]
			x	[-qos_byte_mode                                ANY]
			x	[-qos_byte_step                                ANY]
			x	[-qos_byte_tracking                            ANY]
			x	[-qos_ipv6_flow_label                          ANY]
			x	[-qos_ipv6_traffic_class                       ANY]
			x	[-qos_type_ixn                                 ANY]
			x	[-qos_value_ixn                                ANY]
			x	[-qos_value_ixn_count                          ANY]
			x	[-qos_value_ixn_mode                           ANY]
			x	[-qos_value_ixn_step                           ANY]
			x	[-qos_value_ixn_tracking                       ANY]
			x	[-queue_id                                     ANY]
			x	[-ramp_up_percentage                           ANY]
			x	[-range_per_spoke                              ANY]
			x	[-rate_kbps                                    ANY]
			x	[-rate_mbps                                    ANY]
			x	[-rate_byteps                                  ANY]
			x	[-rate_kbyteps                                 ANY]
			x	[-rate_mbyteps                                 ANY]
			x	[-rate_mode                                    ANY]
			x	[-return_to_id                                 ANY]
			x	[-rip_command                                  ANY]
			x	[-rip_command_mode                             ANY]
			x	[-rip_command_tracking                         ANY]
			x	[-rip_rte_addr_family_id                       ANY]
			x	[-rip_rte_addr_family_id_count                 ANY]
			x	[-rip_rte_addr_family_id_mode                  ANY]
			x	[-rip_rte_addr_family_id_step                  ANY]
			x	[-rip_rte_addr_family_id_tracking              ANY]
			x	[-rip_rte_ipv4_addr                            ANY]
			x	[-rip_rte_ipv4_addr_count                      ANY]
			x	[-rip_rte_ipv4_addr_mode                       ANY]
			x	[-rip_rte_ipv4_addr_step                       ANY]
			x	[-rip_rte_ipv4_addr_tracking                   ANY]
			x	[-rip_rte_metric                               ANY]
			x	[-rip_rte_metric_count                         ANY]
			x	[-rip_rte_metric_mode                          ANY]
			x	[-rip_rte_metric_step                          ANY]
			x	[-rip_rte_metric_tracking                      ANY]
			x	[-rip_rte_v1_unused2                           ANY]
			x	[-rip_rte_v1_unused2_count                     ANY]
			x	[-rip_rte_v1_unused2_mode                      ANY]
			x	[-rip_rte_v1_unused2_step                      ANY]
			x	[-rip_rte_v1_unused2_tracking                  ANY]
			x	[-rip_rte_v1_unused3                           ANY]
			x	[-rip_rte_v1_unused3_count                     ANY]
			x	[-rip_rte_v1_unused3_mode                      ANY]
			x	[-rip_rte_v1_unused3_step                      ANY]
			x	[-rip_rte_v1_unused3_tracking                  ANY]
			x	[-rip_rte_v1_unused4                           ANY]
			x	[-rip_rte_v1_unused4_count                     ANY]
			x	[-rip_rte_v1_unused4_mode                      ANY]
			x	[-rip_rte_v1_unused4_step                      ANY]
			x	[-rip_rte_v1_unused4_tracking                  ANY]
			x	[-rip_rte_v2_next_hop                          ANY]
			x	[-rip_rte_v2_next_hop_count                    ANY]
			x	[-rip_rte_v2_next_hop_mode                     ANY]
			x	[-rip_rte_v2_next_hop_step                     ANY]
			x	[-rip_rte_v2_next_hop_tracking                 ANY]
			x	[-rip_rte_v2_route_tag                         ANY]
			x	[-rip_rte_v2_route_tag_count                   ANY]
			x	[-rip_rte_v2_route_tag_mode                    ANY]
			x	[-rip_rte_v2_route_tag_step                    ANY]
			x	[-rip_rte_v2_route_tag_tracking                ANY]
			x	[-rip_rte_v2_subnet_mask                       ANY]
			x	[-rip_rte_v2_subnet_mask_count                 ANY]
			x	[-rip_rte_v2_subnet_mask_mode                  ANY]
			x	[-rip_rte_v2_subnet_mask_step                  ANY]
			x	[-rip_rte_v2_subnet_mask_tracking              ANY]
			x	[-rip_unused                                   ANY]
			x	[-rip_unused_count                             ANY]
			x	[-rip_unused_mode                              ANY]
			x	[-rip_unused_step                              ANY]
			x	[-rip_unused_tracking                          ANY]
			x	[-rip_version                                  ANY]
			x	[-route_mesh                                   ANY]
			x	[-session_aware_traffic                        ANY]
			x	[-signature                                    ANY]
			x	[-signature_length                             ANY]
			x	[-signature_offset                             ANY]
			x	[-site_id                                      ANY]
			x	[-site_id_enable                               ANY]
			x	[-site_id_step                                 ANY]
			x	[-skip_frame_size_validation                   ANY]
			x	[-source_filter                                ANY]
			x	[-src_dest_mesh                                ANY]
			x	[-stream_packing                               ANY]
			x	[-table_udf_column_name                        ANY]
			x	[-table_udf_column_offset                      ANY]
			x	[-table_udf_column_size                        ANY]
			x	[-table_udf_column_type                        ANY]
			x	[-table_udf_rows                               ANY]
			x	[-tcp_ack_flag_mode                            ANY]
			x	[-tcp_ack_flag_tracking                        ANY]
			x	[-tcp_ack_num_count                            ANY]
			x	[-tcp_ack_num_mode                             ANY]
			x	[-tcp_ack_num_step                             ANY]
			x	[-tcp_ack_num_tracking                         ANY]
			x	[-tcp_checksum                                 ANY]
			x	[-tcp_checksum_count                           ANY]
			x	[-tcp_checksum_mode                            ANY]
			x	[-tcp_checksum_step                            ANY]
			x	[-tcp_checksum_tracking                        ANY]
			x	[-tcp_cwr_flag                                 ANY]
			x	[-tcp_cwr_flag_mode                            ANY]
			x	[-tcp_cwr_flag_tracking                        ANY]
			x	[-tcp_data_offset                              ANY]
			x	[-tcp_data_offset_count                        ANY]
			x	[-tcp_data_offset_mode                         ANY]
			x	[-tcp_data_offset_step                         ANY]
			x	[-tcp_data_offset_tracking                     ANY]
			x	[-tcp_dst_port_count                           ANY]
			x	[-tcp_dst_port_mode                            ANY]
			x	[-tcp_dst_port_step                            ANY]
			x	[-tcp_dst_port_tracking                        ANY]
			x	[-tcp_ecn_echo_flag                            ANY]
			x	[-tcp_ecn_echo_flag_mode                       ANY]
			x	[-tcp_ecn_echo_flag_tracking                   ANY]
			x	[-tcp_fin_flag_mode                            ANY]
			x	[-tcp_fin_flag_tracking                        ANY]
			x	[-tcp_ns_flag                                  ANY]
			x	[-tcp_ns_flag_mode                             ANY]
			x	[-tcp_ns_flag_tracking                         ANY]
			x	[-tcp_psh_flag_mode                            ANY]
			x	[-tcp_psh_flag_tracking                        ANY]
			x	[-tcp_reserved_count                           ANY]
			x	[-tcp_reserved_mode                            ANY]
			x	[-tcp_reserved_step                            ANY]
			x	[-tcp_reserved_tracking                        ANY]
			x	[-tcp_rst_flag_mode                            ANY]
			x	[-tcp_rst_flag_tracking                        ANY]
			x	[-tcp_seq_num_count                            ANY]
			x	[-tcp_seq_num_mode                             ANY]
			x	[-tcp_seq_num_step                             ANY]
			x	[-tcp_seq_num_tracking                         ANY]
			x	[-tcp_src_port_count                           ANY]
			x	[-tcp_src_port_mode                            ANY]
			x	[-tcp_src_port_step                            ANY]
			x	[-tcp_src_port_tracking                        ANY]
			x	[-tcp_syn_flag_mode                            ANY]
			x	[-tcp_syn_flag_tracking                        ANY]
			x	[-tcp_urg_flag_mode                            ANY]
			x	[-tcp_urg_flag_tracking                        ANY]
			x	[-tcp_urgent_ptr_count                         ANY]
			x	[-tcp_urgent_ptr_mode                          ANY]
			x	[-tcp_urgent_ptr_step                          ANY]
			x	[-tcp_urgent_ptr_tracking                      ANY]
			x	[-tcp_window_count                             ANY]
			x	[-tcp_window_mode                              ANY]
			x	[-tcp_window_step                              ANY]
			x	[-tcp_window_tracking                          ANY]
			x	[-test_objective_value                         ANY]
			x	[-track_by                                     ANY]
			x	[-traffic_generate                             ANY]
			x	[-traffic_generator                            ANY]
			x	[-transmit_distribution                        ANY]
			x	[-tx_delay                                     ANY]
			x	[-tx_delay_unit                                ANY]
			x	[-tx_mode                                      ANY]
			x	[-udf1_cascade_type                            ANY]
			x	[-udf1_chain_from                              ANY]
			x	[-udf1_counter_init_value                      ANY]
			x	[-udf1_counter_mode                            ANY]
			x	[-udf1_counter_repeat_count                    ANY]
			x	[-udf1_counter_step                            ANY]
			x	[-udf1_counter_type                            ANY]
			x	[-udf1_counter_up_down                         ANY]
			x	[-udf1_enable_cascade                          ANY]
			x	[-udf1_inner_repeat_count                      ANY]
			x	[-udf1_inner_repeat_value                      ANY]
			x	[-udf1_inner_step                              ANY]
			x	[-udf1_mask_select                             ANY]
			x	[-udf1_mask_val                                ANY]
			x	[-udf1_mode                                    ANY]
			x	[-udf1_offset                                  ANY]
			x	[-udf1_skip_mask_bits                          ANY]
			x	[-udf1_skip_zeros_and_ones                     ANY]
			x	[-udf1_value_list                              ANY]
			x	[-udf2_cascade_type                            ANY]
			x	[-udf2_chain_from                              ANY]
			x	[-udf2_counter_init_value                      ANY]
			x	[-udf2_counter_mode                            ANY]
			x	[-udf2_counter_repeat_count                    ANY]
			x	[-udf2_counter_step                            ANY]
			x	[-udf2_counter_type                            ANY]
			x	[-udf2_counter_up_down                         ANY]
			x	[-udf2_enable_cascade                          ANY]
			x	[-udf2_inner_repeat_count                      ANY]
			x	[-udf2_inner_repeat_value                      ANY]
			x	[-udf2_inner_step                              ANY]
			x	[-udf2_mask_select                             ANY]
			x	[-udf2_mask_val                                ANY]
			x	[-udf2_mode                                    ANY]
			x	[-udf2_offset                                  ANY]
			x	[-udf2_skip_mask_bits                          ANY]
			x	[-udf2_skip_zeros_and_ones                     ANY]
			x	[-udf2_value_list                              ANY]
			x	[-udf3_cascade_type                            ANY]
			x	[-udf3_chain_from                              ANY]
			x	[-udf3_counter_init_value                      ANY]
			x	[-udf3_counter_mode                            ANY]
			x	[-udf3_counter_repeat_count                    ANY]
			x	[-udf3_counter_step                            ANY]
			x	[-udf3_counter_type                            ANY]
			x	[-udf3_counter_up_down                         ANY]
			x	[-udf3_enable_cascade                          ANY]
			x	[-udf3_inner_repeat_count                      ANY]
			x	[-udf3_inner_repeat_value                      ANY]
			x	[-udf3_inner_step                              ANY]
			x	[-udf3_mask_select                             ANY]
			x	[-udf3_mask_val                                ANY]
			x	[-udf3_mode                                    ANY]
			x	[-udf3_offset                                  ANY]
			x	[-udf3_skip_mask_bits                          ANY]
			x	[-udf3_skip_zeros_and_ones                     ANY]
			x	[-udf3_value_list                              ANY]
			x	[-udf4_cascade_type                            ANY]
			x	[-udf4_chain_from                              ANY]
			x	[-udf4_counter_init_value                      ANY]
			x	[-udf4_counter_mode                            ANY]
			x	[-udf4_counter_repeat_count                    ANY]
			x	[-udf4_counter_step                            ANY]
			x	[-udf4_counter_type                            ANY]
			x	[-udf4_counter_up_down                         ANY]
			x	[-udf4_enable_cascade                          ANY]
			x	[-udf4_inner_repeat_count                      ANY]
			x	[-udf4_inner_repeat_value                      ANY]
			x	[-udf4_inner_step                              ANY]
			x	[-udf4_mask_select                             ANY]
			x	[-udf4_mask_val                                ANY]
			x	[-udf4_mode                                    ANY]
			x	[-udf4_offset                                  ANY]
			x	[-udf4_skip_mask_bits                          ANY]
			x	[-udf4_skip_zeros_and_ones                     ANY]
			x	[-udf4_value_list                              ANY]
			x	[-udf5_cascade_type                            ANY]
			x	[-udf5_chain_from                              ANY]
			x	[-udf5_counter_init_value                      ANY]
			x	[-udf5_counter_mode                            ANY]
			x	[-udf5_counter_repeat_count                    ANY]
			x	[-udf5_counter_step                            ANY]
			x	[-udf5_counter_type                            ANY]
			x	[-udf5_counter_up_down                         ANY]
			x	[-udf5_enable_cascade                          ANY]
			x	[-udf5_inner_repeat_count                      ANY]
			x	[-udf5_inner_repeat_value                      ANY]
			x	[-udf5_inner_step                              ANY]
			x	[-udf5_mask_select                             ANY]
			x	[-udf5_mask_val                                ANY]
			x	[-udf5_mode                                    ANY]
			x	[-udf5_offset                                  ANY]
			x	[-udf5_skip_mask_bits                          ANY]
			x	[-udf5_skip_zeros_and_ones                     ANY]
			x	[-udf5_value_list                              ANY]
			x	[-udp_checksum_value                           ANY]
			x	[-udp_checksum_value_tracking                  ANY]
			x	[-udp_dst_port_count                           ANY]
			x	[-udp_dst_port_mode                            ANY]
			x	[-udp_dst_port_step                            ANY]
			x	[-udp_dst_port_tracking                        ANY]
			x	[-udp_length                                   ANY]
			x	[-udp_length_count                             ANY]
			x	[-udp_length_mode                              ANY]
			x	[-udp_length_step                              ANY]
			x	[-udp_length_tracking                          ANY]
			x	[-udp_src_port_count                           ANY]
			x	[-udp_src_port_mode                            ANY]
			x	[-udp_src_port_step                            ANY]
			x	[-udp_src_port_tracking                        ANY]
			x	[-use_all_ip_subnets                           ANY]
			x	[-use_cp_size                                  ANY]
			x	[-use_cp_rate                                  ANY]
			x	[-vci_increment                                ANY]
			x	[-vci_increment_step                           ANY]
			x	[-vlan                                         ANY]
			x	[-vlan_cfi_count                               ANY]
			x	[-vlan_cfi_mode                                ANY]
			x	[-vlan_cfi_step                                ANY]
			x	[-vlan_cfi_tracking                            ANY]
			x	[-vlan_enable                                  ANY]
			x	[-vlan_id_tracking                             ANY]
			x	[-vlan_protocol_tag_id                         ANY]
			x	[-vlan_protocol_tag_id_count                   ANY]
			x	[-vlan_protocol_tag_id_mode                    ANY]
			x	[-vlan_protocol_tag_id_step                    ANY]
			x	[-vlan_protocol_tag_id_tracking                ANY]
			x	[-vlan_user_priority_count                     ANY]
			x	[-vlan_user_priority_mode                      ANY]
			x	[-vlan_user_priority_step                      ANY]
			x	[-vlan_user_priority_tracking                  ANY]
			x	[-vpi_increment                                ANY]
			x	[-vpi_increment_step                           ANY]
			n	[-csrc_list                                    ANY]
			n	[-dlci_repeat_count_step                       ANY]
			n	[-dlci_value_step                              ANY]
			n	[-fr_range_count                               ANY]
			n	[-intf_handle                                  ANY]
			n	[-ip_bit_flags                                 ANY]
			n	[-ip_dst_count_step                            ANY]
			n	[-ip_dst_increment                             ANY]
			n	[-ip_dst_increment_step                        ANY]
			n	[-ip_dst_prefix_len                            ANY]
			n	[-ip_dst_prefix_len_step                       ANY]
			n	[-ip_dst_range_step                            ANY]
			n	[-ip_dst_skip_broadcast                        ANY]
			n	[-ip_dst_skip_multicast                        ANY]
			n	[-ip_mbz                                       ANY]
			n	[-ip_range_count                               ANY]
			n	[-ip_src_skip_broadcast                        ANY]
			n	[-ip_src_skip_multicast                        ANY]
			n	[-ip_tos_count                                 ANY]
			n	[-ip_tos_field                                 ANY]
			n	[-ip_tos_step                                  ANY]
			n	[-ipv6_checksum                                ANY]
			n	[-ipv6_frag_next_header                        ANY]
			n	[-ipv6_length                                  ANY]
			n	[-mac_discovery_gw                             ANY]
			n	[-mac_dst2_count                               ANY]
			n	[-mac_dst2_mode                                ANY]
			n	[-mac_dst2_step                                ANY]
			n	[-mac_src2_count                               ANY]
			n	[-mac_src2_mode                                ANY]
			n	[-mac_src2_step                                ANY]
			n	[-ppp_session_id                               ANY]
			n	[-rtp_csrc_count                               ANY]
			n	[-rtp_payload_type                             ANY]
			n	[-ssrc                                         ANY]
			n	[-timestamp_initial_value                      ANY]
			n	[-enable_egress_only_tracking                  ANY]
			 	[-egress_only_tracking_port                    ANY]
			x	[-egress_only_tracking_signature_value         ANY]
			x	[-egress_only_tracking_signature_offset        ANY]
			x	[-egress1_offset                               ANY]
			x	[-egress1_mask                                 ANY]
			x	[-egress2_offset                               ANY]
			x	[-egress2_mask                                 ANY]
			x	[-egress3_offset                               ANY]
			x	[-egress3_mask                                 ANY]
		
		Arguments:
			 	-arp_dst_hw_addr
			 		Value of the destination MAC address for arp packets from a particular stream.
			 	-arp_dst_hw_count
			 		Number of destination MAC addresses used in ARP packets in a particular stream.
			 	-arp_dst_hw_mode
			 		This parameter configures the behavior for arp_dst_hw_addr.
			 		Valid choices are:
			    		fixed - the value is left unchanged for all packets.
			    		increment - the value is incremented as specified with arp_dst_hw_step and arp_dst_hw_count.
			    		decrement - the value is decremented as specified with arp_dst_hw_step and arp_dst_hw_count.
			    		list - Parameter -arp_dst_hw contains a list of values. Each packet will use one of the values from the list.
			 	-arp_operation
			 		Type of ARP operation given to a particular ARP packet from a particular stream.Valid options are:
			 		<choices><choice><choiceName>arpRequest</choiceName><choiceText>Arp request.</choiceText></choice><choice><choiceName>arpReply</choiceName><choiceText>Arp reply.</choiceText></choice><choice><choiceName>rarpRequest</choiceName><choiceText>Reverse Arp request.</choiceText></choice><choice><choiceName>rarpReply</choiceName><choiceText>Reverse Arp reply.</choiceText></choice></choices>
			 	-arp_src_hw_addr
			 		Value of the source MAC address for arp packets from a particular stream.
			 	-arp_src_hw_count
			 		Number of source MAC addresses used in ARP packets in a particular stream.
			 	-arp_src_hw_mode
			 		Behavior of the source MAC address for ARP packets from a particular stream. Valid options are:
			 		<choices><choice><choiceName>fixed</choiceName><choiceText>DEFAULT</choiceText></choice><choice><choiceName>increment</choiceName><choiceText>the value is incremented as specified with arp_src_hw_step and arp_src_hw_count.</choiceText></choice><choice><choiceName>decrement</choiceName><choiceText>the value is decremented as specified with arp_src_hw_step and arp_src_hw_count.</choiceText></choice><choice><choiceName>list</choiceName><choiceText>Parameter -arp_src_hw contains a list of values. Each packet will use one of the values from the list.</choiceText></choice></choices>
			 	-bidirectional
			 		Whether traffic is setup to transmit in both directions. When -traffic_generator is set to ixos:
			 		The two ports receiving and transmitting are specified by options port_handle and port_handle2.
			 		Option "l3_protocol" source and destination addresses are swapped to get the traffic flowing in both directions.
			 		The parameters are based on the port associated with port_handle and are swapped for the port associated with port_handle2.
			 		MAC addresses can be handled in two ways. First, if the MAC destination addresses are not provided, ARP is used to get the next hop MAC address based on the gateway IP address set in the command interface_config.
			 		Second, use option "mac_dst" and "mac_dst2" addresses provided by this command. Option "mac_dst2" applies to the port associated with option "port_handle2". Option "stream_id" is the same for both directions. As for the source MAC, you can use option "mac_src2" to configure the MAC on the second port, and option "mac_dst2" to configure the destination MAC on the second port if you are not using L2 next hop.
			 		When using subports (this is valid only for PPP/L2TP emulations), the traffic flow direction (upstream or downstream) is set per port, not per subport. Allthe subports created must have the traffic flow set in the same direction (upstream or downstream). If subports have different traffic flow direction, the traffic will be bidirectional.
			 		When -traffic_generator is set to ixnetwork: Two traffic items will be configured. The first traffic item will have:
			 		source - the emulation specified by emulation_src_handle
			 		destination - the destination specified by emulation_dst_handle
			 		The second traffic item will have:
			 		source - the emulation specified by emulation_dst_handle
			 		destination - the destination specified by emulation_src_handle
			 		The rest of the specified options will be set on both traffic items.
			 		Valid options are:
			 		<choices><choice><choiceName>0 </choiceName><choiceText>Disabled.</choiceText></choice><choice><choiceName>1 </choiceName><choiceText>Enabled.</choiceText></choice></choices>
			 	-burst_loop_count
			 		Number of times to transmit a burst.
			 	-command_response
			 	-emulation_dst_handle
			    		The handle used to retrieve information for L2 or L3 dst addresses and use them to configure the destinations for traffic.
			    		This should be the emulation handle that was obtained after configuring PPP/L2TP protocols with IxTclAccess or routing protocols with IxTclNetwork (BGP, OSPF, ISIS, LDP, RSVP, etc). This parameter can be provided with a list or with a list of lists elements. The following list will create one endpointset with n elements: {<endpoint_1> <endpoint_2> ... <endpoint_n>}
			    		The following list of lists will create multiple endpointsets with m,n,...,p elements: { {endpointset <endpoint_1.1> <endpoint_1.2> ... <endpoint_1.m>} {endpointset <endpoint_2.1> <endpoint_2.2> ... <endpoint_1.n>} ...{endpointset <endpoint_2.1> <endpoint_2.2> ... <endpoint_1.p>} }
			    		Note that in this combination the first item in the list is endpointset. This string is optional. The parameter -endpointset_count should be equal to the number of list elements provided to -emulation_src_handle and -emulation_dst_handle. Example 1: endpointset_count 1 emulation_src_handle{<endpoint_1.1> <endpoint_1.2> <endpoint_1.3>} emulation_dst_handle{<endpoint_2.1> <endpoint_2.2> <endpoint_2.3>} Example 2: endpointset_count 1 emulation_src_handle {{endpointset <endpoint_1.1> <endpoint_1.2> <endpoint_1.3>}} emulation_dst_handle{{endpointset <endpoint_2.1> <endpoint_2.2> <endpoint_2.3>}} Example 3: endpointset_count 3 emulation_src_handle{ {endpointset <endpoint_src_1.1> <endpoint_src_1.2> <endpoint_src_1.3> <endpoint_src_1.4>} {endpointset <endpoint_src_2.1> <endpoint_src_2.2> <endpoint_src_2.3>} {endpointset <endpoint_src_3.1> <endpoint_src_3.2> <endpoint_src_3.3> <endpoint_src_3.4> <endpoint_src_3.5>} } emulation_src_handle{ {endpointset <endpoint_dst_1.1> <endpoint_dst_1.2> <endpoint_dst_1.3> <endpoint_dst_1.4>} {endpointset <endpoint_dst_2.1> <endpoint_dst_2.2> <endpoint_dst_2.3>} {endpointset <endpoint_dst_3.1> <endpoint_dst_3.2> <endpoint_dst_3.3> <endpoint_dst_3.4> <endpoint_dst_3.5>} }
			x	-emulation_multicast_dst_handle
			x   		A list of multicast destination handles in the address/step/count format or one of the following special keywords: all_multicast_ranges (this mean all multicast ranges will be used as a destination), none or an empty list (this means no multicast destination will be used for the current endpoint). The number of elements in this list needs to match the number of endpoints.
			x   		If l3_protocol type is ipv4 then igmp multicast destination will be used (example: 224.0.0.0/0.0.0.1/1).
			x   		If the l3_protocol type is ipv6 then mld destination will be used (example: 224:0:0:0:0:0:0:0/0:0:0:0:0:0:1:0/1).
			x   		Sample value for an igmp traffic item with 3 endpoints: [list [list 224.0.0.0/0.0.0.1/1 225.0.0.0/0.0.0.1/1] none all_multicast_ranges]. 
			x   		In the above example endpointset 1 has 2 multicast destinations: 224.0.0.0/0.0.0.1/1 and 225.0.0.0/0.0.0.1/1, endpointset 2 has no multicast destination and endpointset3 has all the multicast destinations available in the IGMP host protocol.
			x   		Sample value for an ipv6 mld traffic item with 2 endpoints: [list 226:0:0:0:0:0:0:0/0:0:0:0:0:0:1:0/1 224:0:0:0:0:0:0:0/0:0:0:0:0:0:1:0/1].
			x   		In the above example each endpoint has only one mld destination.
			x	-emulation_multicast_dst_handle_type
			x   		A list of multicast destination handles types. Valid values can be: none, igmp, mld.
			x   		The number of elements in this list needs to match the number of endpoints and emulation_multicast_dst_handle.When emulation_multicast_dst_handle is "all_multicast_ranges" the type is ignored.
			x	-emulation_multicast_rcvr_handle
			x   		A list of virtual multicast receivers. Each list item consists of a multicast receiver object reference.
			x   		Sample value for pim multicast traffic: "/topology:2/deviceGroup:1/ethernet:1/ipv4:1/pimV4Interface:1/pimV4JoinPruneList".
			x	-emulation_multicast_rcvr_port_index
			x   		A list of virtual multicast receiver port indexes.
			x	-emulation_multicast_rcvr_host_index
			x   		A list of virtual multicast receiver host indexes.
			x	-emulation_multicast_rcvr_mcast_index
			x   		A list of virtual multicast receiver group or join/prune indexes depending on the type of object refecence given in emulation_multicast_rcvr_handle.
			 	-emulation_src_handle
			    		The handle used to retrieve information for L2 or L3 src addresses and use them to configure the sources for traffic.
			    		This should be the emulation handle that was obtained after configuring PPP/L2TP protocols with IxTclAccess or routing protocols with IxTclNetwork (BGP, OSPF, ISIS, LDP, RSVP, etc). This parameter can be provided with a list or with a list of lists elements. The following list will create one endpointset with n elements: {<endpoint_1> <endpoint_2> ... <endpoint_n>}The following list of lists will create multiple endpointsets with m,n,...,p elements: { {endpointset <endpoint_1.1> <endpoint_1.2> ... <endpoint_1.m>} {endpointset <endpoint_2.1> <endpoint_2.2> ... <endpoint_1.n>} ...{endpointset <endpoint_q.1> <endpoint_q.2> ... <endpoint_q.p>} }
			    		Note that in this combination the first item in the list is endpointset. This string is optional. The parameter -endpointset_count should be equal to the number of list elements provided to -emulation_src_handle and -emulation_dst_handle. Example 1: endpointset_count1 emulation_src_handle{<endpoint_1.1> <endpoint_1.2> <endpoint_1.3>} emulation_dst_handle {<endpoint_2.1> <endpoint_2.2> <endpoint_2.3>} Example 2: endpointset_count 1 emulation_src_handle {{endpointset <endpoint_1.1> <endpoint_1.2> <endpoint_1.3>}} emulation_dst_handle {{endpointset <endpoint_2.1> <endpoint_2.2> <endpoint_2.3>}} Example 3: endpointset_count 3 emulation_src_handle { {endpointset <endpoint_src_1.1> <endpoint_src_1.2> <endpoint_src_1.3> <endpoint_src_1.4>} {endpointset <endpoint_src_2.1> <endpoint_src_2.2> <endpoint_src_2.3>} {endpointset <endpoint_src_3.1> <endpoint_src_3.2> <endpoint_src_3.3> <endpoint_src_3.4> <endpoint_src_3.5>} } emulation_src_handle { {endpointset <endpoint_dst_1.1> <endpoint_dst_1.2> <endpoint_dst_1.3> <endpoint_dst_1.4>} {endpointset <endpoint_dst_2.1> <endpoint_dst_2.2> <endpoint_dst_2.3>} {endpointset <endpoint_dst_3.1> <endpoint_dst_3.2> <endpoint_dst_3.3> <endpoint_dst_3.4> <endpoint_dst_3.5>} }
			 	-fcs
			    		Whether to insert an fcs error in the frame.Valid choices are: 0 - Disabled.1 - Enable. The fcs error type can be specified with -fcs_type option.
			 	-icmp_checksum
			    		Valid only for traffic_generator ixnetwork_540 and ICMPv4. Configure 2 byte HEX "Checksum" field.
			 	-icmp_code
			    		Code for each ICMP message type. Valid choices are between 0 and 255, inclusive. Valid only for ICMPv4 with traffic_generator is ixos.
			 	-icmp_id
			    		ID for each ping command, i.e. echoRequest. Valid choices are between 0 and 65535, inclusive. Valid only for ICMPv4.
			 	-icmp_seq
			    		Sequence number for each ping command, i.e. EchoRequest. Valid choices are between 0 and 65535, inclusive.Valid only for ICMPv4 when traffic_generator is 'ixos'.
			 	-icmp_type
			    		ICMP message type. Valid choices are between 0 and 255, inclusive.
			 	-igmp_group_addr
			    		IP Multicast group address of the group being joined or left. Use a list of values when configuring multiple Group Records on IGMPv3 Messages. In case of IGMPv3 Memebership Report messages, the number of addresses from the igmp_group_addr field must match the number of lists of addresses from igmp_multicast_src parameter.
			 	-igmp_group_count
			    		Number of IGMP message to be sent. For option "igmp_group_mode" set to increment or decrement, this is the address range of the IGMP message.
			 	-igmp_group_mode
			    		How the Group Address varies when the repeat count is greater than 1. Valid choices are:
			    		<choices><choice><choiceName>fixed </choiceName><choiceText> Group IP address is the same for all packets.</choiceText></choice><choice><choiceName>increment </choiceName><choiceText>Group IP address increments.</choiceText></choice><choice><choiceName>decrement </choiceName><choiceText>Group IP address decrements.</choiceText></choice><choice><choiceName>list</choiceName><choiceText>Parameter -igmp_group_addr contains a list of values. Each packet will use one of the values from the list.</choiceText></choice></choices>
			 	-igmp_group_step
			    		Step value used to modify igmp_group_addr when igmp_group_mode is incr or decr.
			 	-igmp_max_response_time
			    		Maximum allowed time before sending a responding report in units of Valid only for traffic_generator ixos/ixnetwork_540 with IGMPv2 and IGMPv3 Membership Query messages.
			 	-igmp_msg_type
			    		This parameter takes priority over igmp_type parameter when igmp_version is 3.
			    		Valid choices are:
			        		query - Membership Query
			        		report - Membership Report
			 	-igmp_multicast_src
			    		(Only for IGMPv3 messages) A list of IPv4 source addresses for the group in the case of Membership Queries and a list of lists of IPv4 source addresses in the case of Membership Reports.
			 	-igmp_qqic
			    		This option is only used for an IGMP v.3 group membership query. The querier's query interval code, expressed in second. Values from 0 to 127 are represented exactly, values from 128 to 255 are encoded into a floating point number with three bits of exponent and 4 bits of mantissa. A value higher than 255 will be silently forced to 255.
			 	-igmp_qrv
			    		This option is only used for an IGMP v.3 group membership queries. The querier's robustness value, as a value from 0 to 7.
			 	-igmp_record_type
			    		The type of IGMP message to be sent.Valid choices are:
			    		<choices><choice><choiceName>mode_is_include</choiceName><choiceText>A current-state-record which indicates that the interface has a filter mode of INCLUDE for the specified multicast address. The Source Address fields in this Group Record contain the interface's source list for the multicast address.</choiceText></choice><choice><choiceName>mode_is_exclude</choiceName><choiceText>As in mode_is_include, except that the filter mode is EXCLUDE.</choiceText></choice><choice><choiceName>change_to_include_mode </choiceName><choiceText>A filter-mode-change record that indicates that the interface has changed to INCLUDE filter mode for the specified multicast address. The Source Address fields in this Group Record contain the interface's new source list for the multicast address.</choiceText></choice><choice><choiceName>change_to_exclude_mode</choiceName><choiceText>As in change_to_include_mode, except that the filter mode is EXCLUDE.</choiceText></choice><choice><choiceName>allow_new_sources</choiceName><choiceText>A source-list-change that indicates that the Source Address fields in this Group Record contain a list of the additional sources that the system wishes to hear from, for packets sent to the multicast address. If the change was to an INCLUDE source list, these are the addresses that were added to the list; otherwise these are the addresses that were deleted from the list.</choiceText></choice><choice><choiceName>block_old_sources </choiceName><choiceText>A source-list-change that indicates that the Source Address fields in this Group Record contain a list of the sources that the system no longer wishes to hear from, for packets sent to the multicast address. If the change was to an INCLUDE source list, these are the addresses that were deleted from the list; otherwise these are the addresses that were added to the list.</choiceText></choice></choices>
			 	-igmp_s_flag
			    		This option is only used for an IGMP v.3 group membership query. It is the suppress router-side processing flag. If set, receiving multicast routers will not send timer updates in the normal manner when a query is received.
			 	-igmp_type
			    		The type of IGMP message to be sent. dvmrp - Distance-Vector Multicast Routing Protocol message. Not supported with traffic_generator ixnetwork_540 and will be silently set to membership_query.leave_group - An IGMPv2 message sent by client to inform the DUT of its interest to leave a group. Not supported with traffic_generator ixnetwork_540 for IGMPv1 and will be silently set to membership_query.membership_query - General or group specific query messages sent by the DUT.membership_report - Message sent by client to inform the DUT of its interest to join a group.
			 	-igmp_valid_checksum
			    		If set, this causes a valid header checksum to be generated. If unchecked, then the one's complement of the correct checksum is generated.
			 	-igmp_version
			        		1 - IGMPv1
			        		2 - IGMPv2
			        		3 - IGMPv3
			 	-inter_burst_gap
			    		Number of bytes or milliseconds between each burst in the loop count.
			x	-inter_burst_gap_unit
			x   		This argument can be used to specify the inter burst unit for inter_burst_gap
			x   		Valid choices are:
			x       		bytes - bytes.
			x       		ns - nano seconds.
			 	-inter_stream_gap
			    		Number milliseconds between each stream configured.
			 	-ip_checksum
			    		Checksum for IPv4 packet.
			 	-ip_cu
			    		Configures 2-bit Diff-serv currently unused field in IP header.
			 	-ip_dscp
			    		and 63, inclusive.
			 	-ip_dscp_count
			    		Numeric value which configures the number of times the ip_dscp is incremeneted or decremented when ip_dscp_mode is incr or decr.
			 	-ip_dscp_step
			    		Step value used to modify ip_dscp when ip_dscp_mode is incr or decr.
			 	-ip_dst_addr
			    		Depending on the traffic_generator value, this option has different meanings:
			    		ixos/ixnetwork_540: Destination IP address of the packet.
			    		ixnetwork: This option is used to specify the value of the first IP of the first IP static endpoint range for L2VPN traffic. (Not supported in this release.)
			 	-ip_dst_count
			    		Depending on the traffic_generator value, this option has different meanings:
			    		ixos/ixnetwork_540: Number of destination IP addresses when option "ip_dst_mode" is set to increment or decrement.
			    		ixnetwork: This option is used to specify the value of the IP count of the first IP static endpoint range for L2VPN traffic.
			    		(Not supported in this release.)
			    		When traffic_generator is ixos the maximum value is 4294967295. When traffic_generator is ixnetwork_540 the maximum value is 2147483647.
			 	-ip_dst_mode
			    		<choices><choice><choiceName>fixed </choiceName><choiceText>The destination IP address is the same for all packets.</choiceText></choice><choice><choiceName>increment </choiceName><choiceText> The destination IP address increments.</choiceText></choice><choice><choiceName>decrement</choiceName><choiceText>The destination IP address decrements. Valid only for traffic_generator ixos/ixnetwork_540.</choiceText></choice><choice><choiceName>random</choiceName><choiceText>The destination IP address is random. Valid only for traffic_generator ixos. With traffic_generator ixnetwork_540 this will be silently ignored and configured to 'fixed'.</choiceText></choice><choice><choiceName>emulation</choiceName><choiceText>Destination IP derived from the emulation handle. Valid only for traffic_generator ixos/ixnetwork_540.</choiceText></choice><choice><choiceName>list </choiceName><choiceText>Parameter -ip_dst_addr contains a list of values. Each packet will use one of the values from the list. Valid only for traffic_generator ixnetwork_540.</choiceText></choice></choices>
			 	-ip_dst_step
			    		The modifier for the increment and decrement choices of "-ip_dst_mode" which requires that only one field contain a non-zero value.When ip_dst_mode is random, this acts as a mask if traffic_generator is ixos.
			 	-ip_fragment
			    		Whether this is a fragmented datagram. This option is used in conjuction with option "ip_id" and "ip_fragment_last".Valid choices are:
			    		<choices><choice><choiceName>0</choiceName><choiceText>This is not a fragmented datagram.</choiceText></choice><choice><choiceName>1</choiceName><choiceText>This is a fragmented datagram.</choiceText></choice></choices>
			 	-ip_fragment_last
			    		Controls whether there are additional fragments used to assemble this datagram.
			    		<choices><choice><choiceName>0</choiceName><choiceText>More fragments to come.</choiceText></choice><choice><choiceName>1</choiceName><choiceText>DEFAULT) No more fragments.</choiceText></choice></choices>
			 	-ip_fragment_offset
			    		Where in the datagram this fragment belongs. The offset is measured inclusive.
			 	-ip_hdr_length
			    		Configure header length field in IP header.
			 	-ip_id
			    		Identifying value assigned by the sender to aid in assembling the
			 	-ip_precedence
			    		Part of the Type of Service byte of the IP header datagram that 7, inclusive. With traffic_generator ixnetwork_540 this parameter configures QOS for IPv6 traffic only for ixaccess backwards compatibility mode (details in description for traffic_generator ixnetwork_540) and if qos_ipv6_traffic_class and ipv6_traffic_class parameters are missing.
			 	-ip_protocol
			    		0 and 255.
			 	-ip_src_addr
			    		Source IP address of the packet.
			 	-ip_src_count
			    		Number of source IP addresses when option "ip_src_mode" is set to increment or decrement. When traffic_generator is ixos the maximum value is 4294967295. When traffic_generator is ixnetwork_540 the maximum value is 2147483647.
			 	-ip_src_mode
			    		Valid options are:
			    		<choices><choice><choiceName>fixed</choiceName><choiceText>The source IP address is the same for all packets.</choiceText></choice><choice><choiceName>increment</choiceName><choiceText>The source IP address increments. Valid only for traffic_generator ixos/ixnetwork_540.</choiceText></choice><choice><choiceName>decrement</choiceName><choiceText>The source IP address decrements. Valid only for traffic_generator ixos/ixnetwork_540.</choiceText></choice><choice><choiceName>random</choiceName><choiceText>The source IP address is random. Valid only for traffic_generator ixos. With traffic_generator ixnetwork_540 this will be silently ignored and configured to 'fixed'.</choiceText></choice><choice><choiceName>emulation</choiceName><choiceText>Source IP derived from the emulation handle. Valid only for traffic_generator ixos/ixnetwork_540.</choiceText></choice><choice><choiceName>list </choiceName><choiceText>Parameter -ip_src_addr contains a list of values. Each packet will use one of the values from the list. Valid only for traffic_generator ixnetwork_540.</choiceText></choice></choices>
			 	-ip_src_step
			    		The modifier for the increment and decrement choices of -ip_src_mode which requires that only one field contain a non-zero value.When the ip_src_mode is random, then this acts as a mask if traffic_generator is ixos.
			 	-ip_ttl
			    	-ipv6_dst_addr
			        		Destination IPv6 address of the packet.
			    	-ipv6_dst_count
			        		Number of destination IPv6 addresses when option "ipv6_dst_mode" is set to increment or decrement. When traffic_generator is ixos the maximum value is 4294967295. When traffic_generator is ixnetwork_540 the maximum value is 2147483647.
			    	-ipv6_dst_mode
			        		ipv6_dst_mode specifies how and if the ipv6_dst_addr is incremented.
			        		The following is valid only for traffic_generator ixnetwork_540:Valid options are:
			        		incrementdecrementfixedlistFor backwards compatibility all modes starting with 'incr' will be configured as increment and all modes starting with 'decr' will be configured as decrement. Incrementing and decrementing depends only on ipv6_dst_step and ipv6_dst_count.
			        		The following is valid only for traffic_generator ixos:
			        		The ipv6_dst_mode depends on the IPv6 address type specified with ipv6_dst_addr parameter when traffic_generator is ixos.
			        		Each ipv6_dst_mode allows a mask from a Mask range to be configured. The mask is configured using the ipv6_dst_mask attributeThe step used for incrementing or decrementing is configued using the ipv6_dst_step attribute which has the form of an IPv6 address.
			        		The ipv6_dst_mask attribute specifies which part of the ipv6_dst_step address is used for incrementing as follows:
			        		Mask range 4-4, incr_global_top_level decr_global_top_level: xxxx::0
			        		Mask range 24-24, incr_global_next_level decr_global_next_level: 0:0xx:xxxx::0
			        		Mask range 48-48, incr_global_site_level decr_global_site_level incr_local_site_subnet decr_local_site_subnet: 0:0:0:xxxx::0
			        		Mask range 96-96, incr_mcast_group decr_mcast_group: 0::xxxx:xxxx
			        		Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx:xxxx (when mask is 96)
			        		Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx(when mask is 112)
			        		Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0:0 (when mask is 96)
			        		Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0(when mask is 112)
			        		HEX values marked with 'x' in the format above are the ipv6_dst_step HEX values that are used for increment or decrement; HEX values marked with '0' are ignored.
			        		The step is limited to a 32 bit counter. Example:
			        		ipv6_dst_mode incr_network
			        		ipv6_dst_mask 64inner_ipv6_dst_step address portion that is used for incrementing will be
			        		:0000:0000:xxxx:xxxx:0000:0000:00000:0000
			        		32bit limitNetwork Mask 64
			        		0000:0000:xxxx:xxxx is the mask.
			        		0000:0000 is the 32 bits that will NOT be incremented because of the limitation.
			        		xxxx:xxxx is what gets incremented.
			        		Valid choices are:
			            		type - User Defined
			            		address - Mask range 0-128
			            		value - Mask range 0-128
			            		Allocation - .
			            		Addresses - .
			            		ID - Mask range 96-128
			    	-ipv6_dst_step
			        		Step size of the IPv6 addresses. ipv6_dst_mode specifies how and if the ipv6_dst_addr is incremented.
			        		The following is valid only for traffic_generator ixnetwork_540:
			        		Any IPv6 step is accepted. Incrementing and decrementing depends only on ipv6_dst_step and ipv6_dst_count.
			        		The following is valid only for traffic_generator ixos:
			        		The ipv6_dst_mode depends on the IPv6 address type specified with ipv6_dst_addr parameter.
			        		Each ipv6_dst_mode allows a mask from a Mask range to be configured.
			        		The mask is configured using the ipv6_dst_mask attribute
			        		The step used for incrementing or decrementing is configued using the ipv6_dst_step attribute which has the form of an IPv6 address.
			        		The ipv6_dst_mask attribute specifies which part of the ipv6_dst_step address is used for incrementing as follows:
			        		Mask range 4-4, incr_global_top_level decr_global_top_level: xxxx::0
			        		Mask range 24-24, incr_global_next_level decr_global_next_level: 0:0xx:xxxx::0
			        		Mask range 48-48, incr_global_site_level decr_global_site_level incr_local_site_subnet decr_local_site_subnet: 0:0:0:xxxx::0
			        		Mask range 96-96, incr_mcast_group decr_mcast_group: 0::xxxx:xxxx
			        		Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx:xxxx (when mask is 96)
			        		Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx(when mask is 112)
			        		Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0:0 (when mask is 96)
			        		Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0(when mask is 112)
			        		HEX values marked with 'x' in the format above are the ipv6_dst_step HEX values that are used for increment or decrement; 
			        		HEX values marked with '0' are ignored.
			    	-ipv6_flow_label
			        		Flow label value of the IPv6 stream.
			    	-ipv6_frag_id
			        		This can be used in two ways. If "-ipv6_extension_header fragment" is present then an IPv6 extension frament is added along with other IPv6 extension headers mentioned in ipv6_extension_header list. Also these option can be a list. If -ipv6_extension_header is not present then only one IPv6 fragment can be added and these option can only have one element. Identification field in the fragment extension header of an IPv6 stream.
			    	-ipv6_frag_more_flag
			        		This can be used in two ways. If "-ipv6_extension_header fragment" is present then an IPv6 extension frament is added along with other IPv6 extension headers mentioned in -ipv6_extension_header list. Also these option can be a list. If -ipv6_extension_header is not present then only one IPv6 fragment can be added and these option can only have one element. Whether the M Flag in the fragment extension header of an IPv6 stream is set.
			    	-ipv6_frag_offset
			        		This can be used in two ways. If "-ipv6_extension_header fragment" is present then an IPv6 extension frament is added along with other IPv6 extension headers mentioned in -ipv6_extension_header list. Also these option can be a list. If -ipv6_extension_header is not present then only one IPv6 fragment can be added and these option can only have one element. Fragment offset in the fragment extension header of an IPv6 stream.
			    	-ipv6_hop_limit
			        		Hop limit value of the IPv6 stream.
			    	-ipv6_next_header
			        		Configures the 1-byte next header field in the IPv6 header.
			    	-ipv6_src_addr
			        		Source IPv6 address of the packet.
			    	-ipv6_src_count
			        		Number of source IP address when option "ipv6_src_mode" is set to increment or decrement. When traffic_generator is ixos the maximum value is 4294967295. When traffic_generator is ixnetwork_540 the maximum value is 2147483647.
			    	-ipv6_src_mode
			        		The following is valid only for traffic_generator ixnetwork_540:
			        		Valid options are:
			        		increment
			        		decrement
			        		fixed
			        		list
			        		For backwards compatibility all modes starting with 'incr' will be configured as increment and all modes starting with 'decr' will be configured as decrement. Incrementing and decrementing depends only on ipv6_src_step and ipv6_src_count.
			        		The following is valid only for traffic_generator ixos:
			        		Source IP address mode. 
			        		ipv6_src_mode specifies how and if the ipv6_src_addr is incremented.
			        		The ipv6_src_mode depends on the IPv6 address type specified with ipv6_src_addr parameter.
			        		Each ipv6_src_mode allows a mask from a Mask range to be configured.
			        		The mask is configured using the ipv6_src_mask attribute
			        		The step used for incrementing or decrementing is configued using the ipv6_src_step attribute which has the form of an IPv6 address.
			        		The ipv6_src_mask attribute specifies which part of the ipv6_src_step address is used for incrementing as follows:
			        		Mask range 4-4, incr_global_top_level decr_global_top_level: xxxx::0
			        		Mask range 24-24, incr_global_next_level decr_global_next_level: 0:0xx:xxxx::0
			        		Mask range 48-48, incr_global_site_level decr_global_site_level incr_local_site_subnet decr_local_site_subnet: 0:0:0:xxxx::0
			        		Mask range 96-96, incr_mcast_group decr_mcast_group: 0::xxxx:xxxx
			        		Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx:xxxx (when mask is 96)
			        		Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx(when mask is 112)
			        		Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0:0 (when mask is 96)
			        		Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0(when mask is 112)
			        		HEX values marked with 'x' in the format above are the ipv6_src_step HEX values that are used for increment or decrement; HEX values marked with '0' are ignored.
			        		Valid choices are:
			            		type - User Defined
			            		address - Mask range 0-128
			            		value - Mask range 0-128
			            		Reserved - .
			            		Allocation - .
			            		Addresses - .
			            		ID - Mask range 96-128
			    	-ipv6_src_step
			        		Step size of the source IP address. ipv6_src_mode specifies how and if the ipv6_src_addr is incremented.
			        		The following is valid only for traffic_generator ixnetwork_540:
			        		Any IPv6 step is accepted. Incrementing and decrementing depends only on ipv6_src_step and ipv6_src_count.
			        		The following is valid only for traffic_generator ixos:
			        		The ipv6_src_mode depends on the IPv6 address type specified with ipv6_src_addr parameter.
			        		Each ipv6_src_mode allows a mask from a Mask range to be configured. The mask is configured using the ipv6_src_mask attribute.
			        		The step used for incrementing or decrementing is configued using the ipv6_src_step attribute which has the form of an IPv6 address.
			        		The ipv6_src_mask attribute specifies which part of the ipv6_src_step address is used for incrementing as follows:Mask range 4-4, incr_global_top_level decr_global_top_level: xxxx::0Mask range 24-24, incr_global_next_level decr_global_next_level: 0:0xx:xxxx::0Mask range 48-48, incr_global_site_level decr_global_site_level incr_local_site_subnet decr_local_site_subnet: 0:0:0:xxxx::0Mask range 96-96, incr_mcast_group decr_mcast_group: 0::xxxx:xxxxMask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx:xxxx (when mask is 96)Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx(when mask is 112)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0:0 (when mask is 96)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0(when mask is 112)HEX values marked with 'x' in the format above are the ipv6_src_step HEX values that are used for increment or decrement; HEX values marked with '0' are ignored.
			    	-ipv6_traffic_class
			        		Traffic class value of the IPv6 stream.
			    	-l2_encap
			        		Set level 2 encapsulation. Valid only for traffic_generator ixos and ixnetwork_540. Valid options with traffic_generator ixos are:
			        		atm_vc_muxatm_vc_mux_ethernet_iiatm_vc_mux_802.3snapatm_vc_mux_802.3snap_nofcsatm_vc_mux_pppatm_vc_mux_pppoeatm_snapatm_snap_ethernet_iiatm_snap_802.3snapatm_snap_802.3snap_nofcsatm_snap_pppatm_snap_pppoehdlc_unicasthdlc_broadcasthdlc_unicast_mplshdlc_multicast_mplsethernet_iiethernet_ii_unicast_mplsethernet_ii_multicast_mplsethernet_ii_vlanethernet_ii_vlan_unicast_mplsethernet_ii_vlan_multicast_mpls12ethernet_ii_pppoeethernet_ii_vlan_pppoeppp_linkietf_framerelaycisco_framerelayValid options with traffic_generator ixnetwork_540 are:ethernet_iiethernet_ii_unicast_mplsethernet_ii_vlanethernet_ii_vlan_unicast_mpls
			    	-l3_gaus1_avg
			        		The center of the first curve. Used if length_mode is set to gaussian or quad.
			    	-l3_gaus1_halfbw
			        		The width at half of the first curve. Used if length_mode is set to gaussian or quad.
			    	-l3_gaus1_weight
			        		The weigth of the first curve. Used if length_mode is set to gaussian or quad.
			    	-l3_gaus2_avg
			        		The center of the second curve. Used if length_mode is set to gaussian or quad.
			    	-l3_gaus2_halfbw
			        		The width at half of the second curve. Used if length_mode is set to gaussian or quad.
			    	-l3_gaus2_weight
			        		The weigth of the second curve. Used if length_mode is set to gaussian or quad.
			    	-l3_gaus3_avg
			        		The center of the third curve. Used if length_mode is set to gaussian or quad.
			    	-l3_gaus3_halfbw
			        		The width at half of the third curve. Used if length_mode is set to gaussian or quad.
			    	-l3_gaus3_weight
			        		The weigth of the third curve. Used if length_mode is set to gaussian or quad.
			    	-l3_gaus4_avg
			        		The center of the fourth curve. Used if length_mode is set to gaussian or quad.
			    	-l3_gaus4_halfbw
			        		The width at half of the fourth curve. Used if length_mode is set to gaussian or quad.
			    	-l3_gaus4_weight
			        		The weigth of the fourth curve. Used if length_mode is set to gaussian or quad.
			    	-l3_imix1_ratio
			        		Ratio of first packet size. Used if length_mode set to imix.The sum of all ratio (l3_imix1_ratio, l3_imix2_ratio, l3_imix3_ratio, l3_imix4_ratio) must be between 0 and 262,144.
			    	-l3_imix1_size
			        		First Packet size in bytes. Used if length_mode set to imix.
			    	-l3_imix2_ratio
			        		Ratio of second packet size. Used if length_mode set to imix.The sum of all ratio (l3_imix1_ratio, l3_imix2_ratio, l3_imix3_ratio, l3_imix4_ratio) must be between 0 and 262,144.
			    	-l3_imix2_size
			        		Second Packet size in bytes. Used if length_mode set to imix.
			    	-l3_imix3_ratio
			        		Ratio of third packet size. Used if length_mode set to imix.The sum of all ratio (l3_imix1_ratio, l3_imix2_ratio, l3_imix3_ratio, l3_imix4_ratio) must be between 0 and 262,144.
			    	-l3_imix3_size
			        		Third Packet size in bytes. Used if length_mode set to imix.
			    	-l3_imix4_ratio
			        		Ratio of fourth packet size. Used if length_mode set to imix.The sum of all ratio (l3_imix1_ratio, l3_imix2_ratio, l3_imix3_ratio, l3_imix4_ratio) must be between 0 and 262,144.
			    	-l3_imix4_size
			        		Fourth Packet size in bytes. Used if length_mode set to imix.
			    	-l3_length
			        		Packet size in bytes.Use this option in conjunction with option inclusive. If frame_size parameter is used, this option is ignored.
			    	-l3_length_max
			        		Maximum packet size for the specified stream in bytes.Use this option in conjunction with option "length_mode" set to increment.If frame_size_max parameter is used, this option is ignored.
			    	-l3_length_min
			        		Minimum packet size for the specified stream in bytes.Use this option in conjunction with option "length_mode" set to increment.If frame_size_min parameter is used, this option is ignored.
			    	-l3_protocol
			        		Configures a layer 3 protocol header. Depending on the traffic_generator ixos - ipv4, ipv6, arp, pause_control, ipx, noneixnetwork (not supported in this release) - ipv4, ipv6ixnetwork_540 - ipv4, ipv6, arp
			    	-l4_protocol
			        		In the Layer4 header in the IP-based packet, the Layer4 protocol. l4_protocol parameter should be added in mode create or modify for l4 parameters to be considered. If -mode is modify and traffic_generator is ixnetwork_540, it is only possible to modify headers that already exist in the packet.To replace the entire l4 header one must use traffic_config -mode replace_header. Valid options are:
			        		Valid choices are:
			            		gre - For IPv4 and IPv6 (IxNetwork and IxOS).
			            		icmp - For IPv4 and IPv6 (IxNetwork). For IxOS, only the IPv4 stack is valid.
			            		igmp - For IPv4 and IPv6 (IxNetwork). For IxOS, only the IPv4 stack is valid.
			            		tcp - For IPv4 and IPv6 (IxNetwork and IxOS).
			            		udp - For IPv4 and IPv6 (IxNetwork and IxOS).
			            		rip - For IPv4 and IPv6 (IxNetwork). For IxOS, only the IPv4 stack is valid.
			            		dhcp - For IPv4 and IPv6 (IxNetwork). For IxOS, only the IPv4 stack is valid.
			            		ospf - For IPv4 and IPv6 (IxNetwork). For IxOS, only the IPv4 stack is valid.
			            		ip - For IPv4 and IPv6 (IxNetwork). For IxOS, only the IPv4 stack is valid.
			    	-length_mode
			        		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>. The choices that are supported for dynamic_update are 'fixed' and 'random'. Behavior of the frame/packet size for a particular stream. Parameters l3_length* are ignored when frame_size* parameters are used.fixed - The frame/packet size is fixed. Dependencies: l3_length/frame_size when traffic_generator is set to ixos and ixnetwork_540, and only through parameter frame_size when traffic_generator is set to ixnetwork. PPPoX with traffic_generator ixnetwork supports only -length_mode fixed. increment - The frame/packet size will be incremented using a step from a minimum size to a maximum size. Dependencies: The incrementing step and minimum/maximum framesize/packet size must be specified using: l3_length_step/frame_size_step, l3_length_min/frame_size_min, l3_length_max/frame_size_max when traffic_generator is set to ixos and ixnetwork_540, and only through parameters frame_size_step, frame_size_min, frame_size_max when traffic_generator is set to ixnetwork.random - The frame/packet size is random, but limited by a minimum and maximum value. Dependencies: The minimum and maximum framesize/packet size must be specified using: l3_length_min/frame_size_min, l3_length_max/frame_size_max when traffic_generator is set to ixos and ixnetwork_540, and only through parameters frame_size_min, frame_size_max when traffic_generator is set to ixnetwork.auto - The frame/packet size is set automatically in order to have a valid frame, without overlapping headers and fields. Dependencies: This choice is valid only when traffic_generator is set to ixos and ixnetwork_540.imix -Mix of frame/packet sizes are generated during transmission. Dependencies: Imix settings must be specified using parameters:traffic_generator ixos - l3_imix<i>_size, l3_imix<i>_ratio(<i> is from 1 to 4).traffic generator is ixnetwork_540 - l3_imix<i>_size, l3_imix<i>_ratio(<i> is from 1 to 4) or frame_size_imix. Parameter frame_size_imix has priority over l3_imix* parameters.traffic generator is ixnetwork - Imix settings must be specified using parameter frame_size_imix.gaussian, quad - Frame/packet sizes are specified as gaussian/quad curves. Dependencies: traffic_generator ixos -these curves must be specified using options l3_gaus<i>_avg, l3_gaus<i>_halfbw, l3_gaus<i>_weight, where <i> is a number from 1 to 4. traffic_generator ixnetwork - these curves must be specified using option frame_size_gauss.traffic_generator ixnetwork_540 - these curves must be specified using options l3_gaus<i>_avg, l3_gaus<i>_halfbw, l3_gaus<i>_weight, where <i> is a number from 1 to 4 OR frame_size_gauss. Parameter frame_size_gauss has priority over l3_gaus* parameters.distribution - Frame size is specified with a predefined distribution. Dependencies: For IxTclNetwork, this choice is valid only when traffic_generator is set to ixnetwork/ixnetwork_540 and the distribution must be set using option frame_size_distribution.
			    	-mac_dst
			        		Destination MAC address for a particular stream. For traffic_generator ixnetwork, can only be used for L2VPN traffic, but is not supported in this release. Valid formats are:11:11:11:11:11:112222.2222.2222{33 33 33 33 33 33}
			    	-mac_dst2
			        	-mac_dst_count
			            		Depending on the traffic_generator value, this option has different ixos - Number of destination MAC addresses used in a particular stream. ixnetwork_540 - Number of destination MAC addresses used in a particular stream. ixnetwork - MAC address count in the first LAN static endpoint range. It can take decimal values in the 1-4294967295 range. Also, it can be used just for L2VPN traffic, but is not supported in this release.
			        	-mac_dst_mask
			            		Select this attribute to use random mask bit values. This parameter is available only when -mac_dst_mode is repeatable_random.
			        	-mac_dst_mode
			            		Behavior of the destination MAC address for a particular stream. For traffic_generator ixnetwork, this option can only be used for L2VPN traffic, but is not supported in this release. For traffic_generator ixnetwork_540 will have the same behavior. Valid options are:
			            		Valid choices are:
			                		fixed - The destination MAC will be idle (same for all packets). Valid only for all values of traffic_generator.
			                		increment - The Destination MAC will increment for all packets. Valid only for all values of traffic_generator.
			                		decrement - The Destination MAC will be decrement for all packets. Valid only for traffic_generator ixos and ixnetwork_540.
			                		random - The Destination MAC will be random far all packets. Valid only for traffic_generator ixos.
			                		discovery - The Destination MAC will match the MAC address received from the ARP request. Valid only for traffic_generator ixos.
			                		list - Parameter -mac_dst contains a list of values. The Destination MAC will be selected in order from the list passed with -mac_dst. Valid only for traffic_generator ixnetwork_540.
			                		repeatable_random - The Source MAC will be random for all packets, but you can use mac_dst_mask, mac_dst_seed and mac_dst_count.
			        	-mac_dst_seed
			            		Value for setting the seed attribute. This parameter is available onlywhen -mac_dst_mode is repeatable_random.
			        	-mac_dst_step
			            		Value by which the destination MAC Address is incremented.For traffic_generator ixnetwork, this option is used to specify the step between the value of the first MAC address of each the LAN static endpoint range and can only be used for L2VPN traffic, but is not supported in this release.For traffic_generator ixos the value for this parameter can also be given as apositive integer number. For example, the values 1 and 00:00:00:00:00:01 areequivalent.
			        	-mac_src
			            		Source MAC address for a particular stream.Valid formats are:11:11:11:11:11:112222.2222.2222{33 33 33 33 33 33}
			        	-mac_src2
			            	-mac_src_count
			                		Number of source MAC addresses used in a particular stream.
			            	-mac_src_mask
			                		Select this attribute to use random mask bit values. This parameter is available only when -mac_src_mode is repeatable_random.
			            	-mac_src_mode
			                		Behavior of the source MAC address for a particular stream. Valid choices for traffic_generator ixos are:
			                		<choices><choice><choiceName>fixed </choiceName><choiceText>The Source MAC will be idle (same fo all packets).</choiceText></choice><choice><choiceName>increment</choiceName><choiceText>The Source MAC will be incremented for all packets.</choiceText></choice><choice><choiceName>decrement </choiceName><choiceText>The Source MAC will be decremented for all packets.</choiceText></choice><choice><choiceName>random </choiceName><choiceText>The Source MAC will be random far all packets.</choiceText></choice><choice><choiceName>emulation</choiceName><choiceText>Not implemented.Valid choices for traffic_generator ixnetwork_540 are:</choiceText></choice><choice><choiceName>fixed </choiceName><choiceText>The Source MAC will be idle (same fo all packets).</choiceText></choice><choice><choiceName>increment </choiceName><choiceText>The Source MAC will be incremented for all packets.</choiceText></choice><choice><choiceName>decrement </choiceName><choiceText>The Source MAC will be decremented for all packets.</choiceText></choice><choice><choiceName>list </choiceName><choiceText>Parameter -mac_src contains a list of values. The Source MAC will be selected in order from the list passed with -mac_src.</choiceText></choice><choice><choiceName>random </choiceName><choiceText>The Source MAC will be random for all packets.</choiceText></choice><choice><choiceName>repeatable_random </choiceName><choiceText>The Source MAC will be random for all packets, but you can use mac_src_mask, mac_src_seed and mac_src_count.</choiceText></choice></choices>
			            	-mac_src_seed
			                		Value for setting the seed attribute. This parameter is available onlywhen -mac_src_mode is repeatable_random.
			            	-mac_src_step
			                		Value by which the Source MAC address is incremented. For traffic_generator ixos the value for this parameter can also be given aspositive integer number. For example, the values 1 and 00:00:00:00:00:01 areequivalent.
			            	-mode
			                		This option defines the action to be taken.
			                		Valid choices are:
			                    		create- Create only one stream/traffic item. Dependencies: When traffic_generator is ixos, the port_handle must also be provided when mode is create.
			                    		modify- Modify only one existing stream/traffic item. Dependencies: traffic_generator must be ixos/ixnetwork/ixnetwork_540 and stream_id must be provided. NOTE: modify mode is not supported for streams originating in PPPoX endpoints when -traffic_generator is ixos. When traffic_generator ixnetwork_540 is used stream_id can also be a header handle.
			                    		remove- Remove/disable an existing stream/traffic item. Dependencies: traffic_generator must be ixos/ixnetwork/ixnetwork_540 and stream_id must be provided. When traffic_generator is ixos, it disables the stream, when traffic_generator is ixnetwork it removes the traffic item. When traffic_generator is ixnetwork_540: if stream_id is a traffic_item it removes it; if stream_id is a high level stream it suspends it; if stream_id is a header handle it removes it.
			                    		reset- Remove all existing traffic setups.
			                    		enable- Enables an existing stream. Dependencies: traffic_generator must be ixos/ixnetwork/ixnetwork_540 and stream_id must be provided.
			                    		disable- Disables an existing stream/traffic item. Dependencies: traffic_generator must be ixnetwork/ixnetwork_540 and stream_id must be provided. Flow Groups will go to suspend state when use it for high level stream
			                    		enable_flow_group- Enables an existing Flow Groups. Dependencies: traffic_generator must be ixos/ixnetwork/ixnetwork_540 and stream_id must be provided which is high level stream
			                    		disable_flow_group- Disables an existing Flow Groups. Dependencies: traffic_generator must be ixos/ixnetwork/ixnetwork_540 and stream_id must be provided which is high level stream
			                    		append_header - Append headers. Dependencies: traffic_generator must be ixnetwork_540 and stream_id must be a header handle.
			                    		prepend_header - Prepend headers. Dependencies: traffic_generator must be ixnetwork_540 and stream_id must be a header handle.
			                    		replace_header -Replace a header. Dependencies: traffic_generator must be ixnetwork_540 and stream_id must be a header handle.
			                    		modify_or_insert - modifies or inserts a header, using the -stack_index parameter.
			                    		dynamic_update - With traffic_generator 'ixnetwork_540' some rate and framesize parameters can be changed while the traffic is running. To do this use -mode 'dynamic_update' and -stream_id <traffic_item_handle>. The parameters that will be used for this mode are: frame_size, frame_size_max, frame_size_min, length_mode (only fixed or random), rate_bps, rate_kbps, rate_mbps, rate_byteps, rate_kbyteps, rate_mbyteps, rate_percent, rate_pps, inter_frame_gap, inter_frame_gap_unit and enforce_min_gap. Any other parameters will be silently ignored. Dependencies: traffic_generator must be ixnetwork_540 and stream_id must be a traffic item handle.
			                    		get_available_protocol_templates - Returns a list of all available protocol templates in a user-friendly format. The elements from the list (or the entire list) can be used as pt_handle object(s). Returns key "pt_handle". Dependencies: traffic_generator must be ixnetwork_540.
			                    		get_available_fields - Returns a list of all available fields specific to the provided header handle (in user friendly format). The "header_handle" must be a stack object over a high level stream or a config element. Returns key "handle". Dependencies: traffic_generator must be ixnetwork_540.
			                    		get_available_dynamic_update_fields- Returns a list of all available dynamic update fields for the provided stream_id.Returns key "available_dynamic_update_fields"Dependencies: traffic_generator must be ixnetwork_540.
			                    		get_available_session_aware_traffic - Returns a list of all availablesession aware traffic fields for the provided stream_id.Returns key "available_session_aware_traffic_fields" Dependencies: traffic_generator must be ixnetwork_540.
			                    		get_available_fields_for_link - Returns a list of all availablevalid stack link fields for the provided stream_id.Returns key "available_fields_for_link". Valid only for IxNetwork greater than 7.0. Dependencies: traffic_generator must be ixnetwork_540.
			                    		get_field_values- Returns the values for the provided field handle. The field handle can be obtained using mode "get_available_fields". The header handle must also be provided. List of returned keys: field_activeFieldChoice field_auto field_countValue field_defaultValue field_displayName field_enumValues field_fieldChoice field_fieldValue field_fullMesh field_id field_length field_level field_name field_offset field_offsetFromRoot field_optional field_optionalEnabled field_rateVaried field_readOnly field_requiresUdf field_singleValue field_startValue field_stepValue field_trackingEnabled field_valueFormat field_valueList field_valueType Dependencies: traffic_generator must be ixnetwork_540.
			                    		set_field_values- Sets the specified values for the given field handle. Not all values provided by "get_field_values" are available for set. Some of them are read-only. Valid fields: field_activeFieldChoice field_auto field_countValue field_fieldValue field_fullMesh field_optionalEnabled field_singleValue field_startValue field_stepValue field_trackingEnabled field_valueList field_valueType Dependencies: traffic_generator must be ixnetwork_540.
			                    		add_field_level - Adds a new field level for the specified header if multiple levels are supported. The "header_handle" and the "field_handle" must be provided. Returns the new field handlers associated with the new level (key: handle). Dependencies: traffic_generator must be ixnetwork_540.
			                    		remove_field_level - Removed the specified field level on the given header. The "header_handle" and the "field_handle" must be provided. Dependencies: traffic_generator must be ixnetwork_540.
			                    		get_available_egress_tracking_field_offset - Returns a list of all availableegress tracking custom field offsets specific for the provided stream_id.Returns key "available_egress_tracking_field_offset".
			            	-mpls_labels
			                		MPLS labels in the packets for each stream. Ixia supports multiple MPLS labels in a single packet. For example, to stack three labels in one packet, use -mpls_labels {14 18 78}, where 14, 18 and 78 are the label IDs in the packet.
			            	-pkts_per_burst
			                		Number of packets to include in one burst.
			            	-port_handle
			                		Depending on the traffic_generator value, this option has different meanings. If traffic_generator ixnetwork_540 is used this parameter is used ixos/ixnetwork_540 - The port for which to configure traffic. Mandatory for -mode create/reset when -traffic_generator is set to ixos. For traffic_generator ixnetwork_540 this is mandatory on mode create only if parameter -emulation_src_handle is missing.ixnetwork/ixnetwork_540 - The port_handle parameter is not necessary anymore. When using IxNetwork, traffic configurations will be done using previously created handles (IP interfaces, PPP ranges, L2TP ranges, Protocol Route Ranges etc.) as sources (parameter -emulation_src_handle) and destinations (-emulation_dst_handle).
			            	-port_handle2
			                		A second port for which to configure traffic configuration when option "bidirectional" is enabled. For traffic_generator ixnetwork_540 this parameter is used only if emulation_src_handle and emulation_dst_handle parameters are missing. For traffic_generator ixnetwork_540 this parameter can be used as destination port for the unidirectional traffic too.
			            	-rate_bps
			                		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>. Traffic rate to send in bps.
			            	-rate_frame_gap
			                	-rate_percent
			                    		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>. Traffic rate in percent of line rate for the specified stream.Valid choices are between 0.00 and 100.00, inclusive.
			                	-rate_pps
			                    		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>. Traffic rate to send in pps.
			                	-stream_id
			                    		Required for -mode modify/remove/enable/disable/append_header/prepend_header/replace_header/dynamic_update calls. Stream ID is not required for configuring a stream for the first time. In this case, the stream ID is returned from the call.
			                	-stack_index
			                    		Required for -mode modify_or_insert. It represents the stack index in the highLevelStream / configElement.
			                	-tcp_ack_flag
			                    		Whether the "acknowledge flag" in the TCP header is enabled.Valid choices are:
			                        		0 - Disabled
			                        		1 - Enabled
			                	-tcp_ack_num
			                    		TCP tcp_window size field for this particular stream. Valid choices are between 0 and 65535, inclusive.
			                	-tcp_dst_port
			                    		between 0 and 65535, inclusive.
			                	-tcp_fin_flag
			                    		Whether the "finished flag" in the TCP header is enabled.Valid choices are:
			                        		0- Disabled
			                        		1- Enabled
			                	-tcp_psh_flag
			                    		Whether the "psh flag" in the TCP header is enabled.Valid choices are:
			                        		0 - Disabled
			                        		1 - Enabled
			                	-tcp_reserved
			                    		Configure the TCP reserved field (0-7).
			                	-tcp_rst_flag
			                    		Whether the "reset flag" in the TCP header is enabled.Valid choices are:
			                        		0- Disabled
			                        		1- Enabled
			                	-tcp_seq_num
			                    		between 0 and 4294967295, inclusive.
			                	-tcp_src_port
			                    		0 and 65535, inclusive.
			                	-tcp_syn_flag
			                    		Whether the "synchronize flag" in the TCP header is enabled.
			                    		Valid choices are:
			                        		0- Disabled
			                        		1- Enabled
			                	-tcp_urg_flag
			                    		Whether the "urgent flag" in the TCP header is enabled.Valid choices are:
			                        		0 - Disabled
			                        		1 - Enabled
			                	-tcp_urgent_ptr
			                    		TCP Urgent Pointer value for this particular stream. Valid choices are between 0 and 65535, inclusive.
			                	-tcp_window
			                    		TCP tcp_window size field for this particular stream. Valid choices are between 0 and 65535, inclusive.
			                	-transmit_mode
			                    		Type of transmit mode to use.Note that all transmit modes need to have one value set in either rate_pps, rate_bps, or rate_percent. Also, not all choices may be available for a stream, depending on the ::<namespace>::interface_config -transmit_mode argument. Valid Options are:
			                    		<choices><choice><choiceName>advance</choiceName><choiceText>after all the frames are sent from the current stream, the frames from the next stream on the port are transmitted.</choiceText></choice><choice><choiceName>continuous</choiceName><choiceText>continuously transmit the frames on this stream.</choiceText></choice><choice><choiceName>continuous_burst</choiceName><choiceText>continuously transmit bursts of frames on this stream. Valid only for traffic_generator ixos/ixnetwork_540.</choiceText></choice><choice><choiceName>multi_burst</choiceName><choiceText>transmit multiple bursts and then stop all transmission from the port where this stream resides regardless of existence of other streams on this port. Valid only for traffic_generator ixos/ixnetwork_540.</choiceText></choice><choice><choiceName>return_to_id </choiceName><choiceText>the last stream on the port is set to this mode to begin transmission of frames of the first stream in the list. Parameter return_to_id can be used to specify the stream number to begin with. Valid only for traffic_generator ixos/ixnetwork_540.</choiceText></choice><choice><choiceName>return_to_id_for_count </choiceName><choiceText>the last stream on the port is set to this mode to begin transmission of the first stream in the list for -loop_count intervals. Parameter return_to_id can be used to specify the stream number to begin with. Valid only for traffic_generator ixos/ixnetwork/ixnetwork_540.</choiceText></choice><choice><choiceName>random_spaced </choiceName><choiceText>transmit random spaced frames. Valid only for traffic_generator ixos/ixnetwork_540.</choiceText></choice><choice><choiceName>single_burst </choiceName><choiceText>transmit one burst and then stop all transmission from the port where this stream resides regardless of existence of other streams on this port. Valid only for traffic_generator ixos/ixnetwork_540.</choiceText></choice><choice><choiceName>single_pkt</choiceName><choiceText>transmit one packet and then stop all transmission from the port where this stream resides regardless of existence of other streams on this port. Valid only for traffic_generator ixos/ixnetwork_540.</choiceText></choice></choices>
			                	-udp_checksum
			                    		1 - the UDP checksum is set as current checksum for UDP data0 - If parameter udp_checksum_value is specified, the UDP checksum will be overriten by the value supplied through udp_checksum_value. If udp_checksum_value is not present, an invalid checksum will be set as the UDP checksum.Valid only for traffic_generator ixos/ixnetwork_540 and when -l4_protocol is udp.
			                	-udp_dst_port
			                    		between 0 and 65535, inclusive. The port number needs to be different than the port number used for RIP and DHCP. Valid only for traffic_generator ixos/ixnetwork_540 and when -l4_protocol is udp.
			                	-udp_src_port
			                    		0 and 65535, inclusive. The port number needs to be different than the port number used for RIP and DHCP. Valid only for traffic_generator ixos/ixnetwork_540 and when -l4_protocol is udp.
			                	-vci
			                    		The virtual circuit identifier. Depending on the traffic_generator value, this option has different ixnetwork - This option is used to specify the value of the first VCI of the first ATM static endpoint range. It can take any value in the 0-4294967295 range. Can be used only for L2VPN traffic, but is not supported in this release.
			                	-vci_count
			                    		If -atm_counter_vci_type is set to counter and atm_counter_vci_mode is set to incr or decr, then this is the number of times to increment the VCI value before repeating from the start value.
			                	-vci_step
			                    		Depending on the traffic_generator value, this option has different ixos/ixnetwork_540 - If -atm_counter_vci_type is set to counter, then this is the value added/substractedbetween successive vci values ixnetwork - This option is used to specify the step between the value of the first VCI of each the ATM static endpoint range. It can take any numeric value. Can be used only for L2VPN traffic, but is not supported in this release.
			                	-vlan_cfi
			                    		Whether VLAN CFI bit is set or unset for a particular stream. For stacked VLAN (QinQ) this parameter will be provided as a list of values, each of them representing whether VLAN CFI bit is set or unset for each VLAN from the stack. Example: {1 0 1 1}Valid options are:0 - Unset1 - Set
			                	-vlan_id
			                    		4095, inclusive. For stacked VLAN (QinQ) this parameter will be provided as a list of values, each of them representing the id a VLAN from the stack.Example: {10 13 14 20}. If emulation_src_handle or emulation_dst_handle are present and traffic_generator argument is "ixos", the traffic will be configured over PPPoX sessions using IxOS. In this case the vlan parameters apply only to the downstream (traffic sent from IP/Network port to PPPoE access port). Upstream traffic will use vlan information from the PPPoE handle.Downstream traffic will use vlan information set through this parameter.For traffic generator ixnetwork is used only for L2VPN traffic, but is not supported in this release.
			                	-vlan_id_count
			                    		Number of VLANs to be used for a particular stream. Option "vlan_id_mode" must be set to increment or decrement. Valid choices are between 1 and 4096, inclusive.For stacked VLAN (QinQ) this parameter will be provided as a list of values, each of them representing the number of VLANs for each vlan_id from the stack.Example: {2 5 1 13}
			                	-vlan_id_mode
			                    		Behavior of the VLAN tag in packets for a particular stream. For stacked VLAN (QinQ) this parameter will be provided as a list of values, each of them representing the Behavior of each VLAN from the stack. Only the top two VLAN elements in a stacked VLAN may use values different from "fixed". For traffic_generator ixnetwork is used only for L2VPN traffic, but is not supported in this release.For traffic_generator ixnetwork_540 the behavior is the same as for traffic_generator ixos.Example: {increment nested_incr fixed fixed}. Valid options are:
			                    		<choices><choice><choiceName>fixed</choiceName><choiceText>Will set the VLAN tag to be in idle mode. Available when using traffic_generator ixnetwork and ixos and ixnetwork_540.</choiceText></choice><choice><choiceName>increment </choiceName><choiceText> Will set the VLAN tag to be in increment mode.Available when using traffic_generator ixnetwork and ixos and ixnetwork_540.It is the default when using the ixos/ixnetwork_540 traffic generator.</choiceText></choice><choice><choiceName>decrement</choiceName><choiceText>Will set the VLAN tag to be in decrement mode. Available when using traffic_generator ixos and ixnetwork_540.</choiceText></choice><choice><choiceName>random </choiceName><choiceText> Will set the VLAN tag to be in random mode. Available when using traffic_generator ixos.</choiceText></choice><choice><choiceName>nested_incr </choiceName><choiceText>For the second VLAN in a stackedVlan, this may be used to performed nested increment with respect to the first stack element. Available when using traffic_generator ixos.</choiceText></choice><choice><choiceText>nested_decr - For the second VLAN in a stackedVlan, this may be used to performed nested decrement with respect to the first stack element. Available when using traffic_generator ixos.</choiceText></choice><choice><choiceName>list </choiceName><choiceText> Will set the VLAN tag to be a list of values. Available when using traffic_generator ixnetwork_540 with mode append_header/modify_header.</choiceText></choice></choices>
			                	-vlan_id_step
			                    		The step value for a VLAN ID when the mode is increment or decrement For stacked VLAN (QinQ) this parameter will be provided as a list of values, each of them representing the step value for each VLAN ID from the stack.Example: {2 4 6 1}. For traffic_generator ixnetwork is used only for L2VPN traffic, but is not supported in this release.
			                	-vlan_user_priority
			                    		inclusive.For stacked VLAN (QinQ) this parameter will be provided as a list of values, each of them representing the user priority for each VLAN ID from the stack.Example: {2 4 6 0}.
			                	-vpi
			                    		Depending on the traffic_generator value, this option has different ixnetwork - This option is used to specify the value of the first VPI of the first ATM static endpoint range. It can take any value in the 0-4294967295 range. Can be used only for L2VPN traffic, but is not supported in this release.
			                	-vpi_count
			                    		If -atm_counter_vpi_type is set to counter and atm_counter_vpi_mode is set to incr or decr, then this is the number of times to increment the VPI value before repeating from the start value.
			                	-vpi_step
			                    		Depending on the traffic_generator value, this option has different ixos/ixnetwork_540 - If -atm_counter_vpi_type is set to counter, then this is the value added/substractedbetween successive vpi values ixnetwork - This option is used to specify the step between the value of the first VPI of each the ATM static endpoint range. It can take any numeric value. Can be used only for L2VPN traffic, but is not supported in this release.
			x               	-adjust_rate
			x                   	-allow_self_destined
			x                       		This argument can be used to specify if it is allowed to send traffic from routes on an Ixia port to other routes on the same Ixia port. When using traffic_generator ixnetwork_540, mode create and -port_handle parameter but without -port_handle2 this parameter will be forced to '1'. and the source
			n                   	-app_profile_type
			n                       		Deprecated Argument. It was used for Legacy AppLib.
			x                   	-arp_dst_hw_step
			x                       		Step value used to modify arp_dst_hw when arp_dst_hw_mode is incr or decr.
			x                   	-arp_dst_hw_tracking
			x                           		0 - disable tracking by arp_dst_hw_addr
			x                           		1 - enable tracking by arp_dst_hw_addr
			x                   	-arp_hw_address_length
			x                       		Configure 1 byte HEX value for ARP Hardware Address Length.
			x                   	-arp_hw_address_length_count
			x                       		Numeric value which configures the number of times the arp_hw_address_length is incremeneted or decremented when arp_hw_address_length_mode is incr or decr.
			x                   	-arp_hw_address_length_mode
			x                       		This parameter configures
			x                       		Valid choices are:
			x                           		fixed - the value is left unchanged for all packets.
			x                           		incr - the value is incremented as specified with arp_hw_address_length_step and arp_hw_address_length_count.
			x                           		decr - the value is decremented as specified with arp_hw_address_length_step and arp_hw_address_length_count.
			x                           		list - Parameter -arp_hw_address_length contains a list of values. Each packet will use one of the values from the list.
			x                   	-arp_hw_address_length_step
			x                       		Step value used to modify arp_hw_address_length when arp_hw_address_length_mode is incr or decr.
			x                   	-arp_hw_address_length_tracking
			x                           		0 - disable tracking by arp_hw_address_length
			x                           		1 - enable tracking by arp_hw_address_length
			x                   	-arp_hw_type
			x                       		Configure 2 bytes HEX value for ARP Hardware Type.
			x                   	-arp_hw_type_count
			x                       		Numeric value which configures the number of times the arp_hw_type is incremeneted or decremented when arp_hw_type_mode is incr or decr.
			x                   	-arp_hw_type_mode
			x                       		This parameter configures
			x                       		Valid choices are:
			x                           		fixed - the value is left unchanged for all packets.
			x                           		incr - the value is incremented as specified with arp_hw_type_step and arp_hw_type_count.
			x                           		decr - the value is decremented as specified with arp_hw_type_step and arp_hw_type_count.
			x                           		list - Parameter -arp_hw_type contains a list of values. Each packet will use one of the values from the list.
			x                   	-arp_hw_type_step
			x                       		Step value used to modify arp_hw_type when arp_hw_type_mode is incr or decr.
			x                   	-arp_hw_type_tracking
			x                           		0 - disable tracking by arp_hw_type
			x                           		1 - enable tracking by arp_hw_type
			x                   	-arp_operation_mode
			x                       		This parameter configures
			x                       		Valid choices are:
			x                           		fixed - the value is left unchanged for all packets.
			x                           		list - Parameter -arp_operation contains a list of values. Each packet will use one of the values from the list.
			x                   	-arp_operation_tracking
			x                           		0 - disable tracking by arp_operation
			x                           		1 - enable tracking by arp_operation
			x                   	-arp_protocol_addr_length
			x                       		Configure 1 byte HEX value for ARP Protocol Address Length.
			x                   	-arp_protocol_addr_length_count
			x                       		Numeric value which configures the number of times the arp_protocol_addr_length is incremeneted or decremented when arp_protocol_addr_length_mode is incr or decr.
			x                   	-arp_protocol_addr_length_mode
			x                       		This parameter configures
			x                       		Valid choices are:
			x                           		fixed - the value is left unchanged for all packets.
			x                           		incr - the value is incremented as specified with arp_protocol_addr_length_step and arp_protocol_addr_length_count.
			x                           		decr - the value is decremented as specified with arp_protocol_addr_length_step and arp_protocol_addr_length_count.
			x                           		list - Parameter -arp_protocol_addr_length contains a list of values. Each packet will use one of the values from the list.
			x                   	-arp_protocol_addr_length_step
			x                       		Step value used to modify arp_protocol_addr_length when arp_protocol_addr_length_mode is incr or decr.
			x                   	-arp_protocol_addr_length_tracking
			x                           		0 - disable tracking by arp_protocol_addr_length
			x                           		1 - enable tracking by arp_protocol_addr_length
			x                   	-arp_protocol_type
			x                       		Configure 2 bytes HEX value for ARP Protocol Type.
			x                   	-arp_protocol_type_count
			x                       		Numeric value which configures the number of times the arp_protocol_type is incremeneted or decremented when arp_protocol_type_mode is incr or decr.
			x                   	-arp_protocol_type_mode
			x                       		This parameter configures
			x                       		Valid choices are:
			x                           		fixed - the value is left unchanged for all packets.
			x                           		incr - the value is incremented as specified with arp_protocol_type_step and arp_protocol_type_count.
			x                           		decr - the value is decremented as specified with arp_protocol_type_step and arp_protocol_type_count.
			x                           		list - Parameter -arp_protocol_type contains a list of values. Each packet will use one of the values from the list.
			x                   	-arp_protocol_type_step
			x                       		Step value used to modify arp_protocol_type when arp_protocol_type_mode is incr or decr.
			x                   	-arp_protocol_type_tracking
			x                           		0 - disable tracking by arp_protocol_type
			x                           		1 - enable tracking by arp_protocol_type
			x                   	-arp_src_hw_step
			x                       		Step value used to modify arp_src_hw_addr when arp_src_hw_mode is incr or decr.
			x                   	-arp_src_hw_tracking
			x                           		0 - disable tracking by arp_src_hw_addr
			x                           		1 - enable tracking by arp_src_hw_addr
			x                   	-atm_counter_vci_data_item_list
			x                       		If the -atm_counter_vci_type option is set to table, this list is used used for the set of values.
			x                   	-atm_counter_vci_mask_select
			x                       	-atm_counter_vci_mask_value
			x                           		If the -atm_counter_vci_type option is set to random, this 16-bit value indicates the values that the bits indicated in the atm_counter_vci_mask_select option should have.
			x                       	-atm_counter_vci_mode
			x                           		If the -atm_counter_vci_type option is set to counter, this indicates what counter mode should be used. Currently only the incr and decr mode are supported.
			x                       	-atm_counter_vci_type
			x                           		The type of counter to use on the vci. fixed - DEFAULTrandom - not supported with traffic_generator ixnetwork_540. Parameters atm_counter_vci_mask_select and atm_counter_vci_mask_value are also involved when setting this type.counter - parameter vci_count is also involved when setting this type.table - parameter atm_counter_vci_data_item_list is also involved when setting this type.
			x                       	-atm_counter_vpi_data_item_list
			x                           		If the -atm_counter_vpi_type option is set to table, this list is used used for the set of values.
			x                       	-atm_counter_vpi_mask_select
			x                           	-atm_counter_vpi_mask_value
			x                               		If the -atm_counter_vpi_type option is set to random, this 16-bit value indicates the values that the bits indicated in the atm_counter_vpi_mask_select option should have.
			x                           	-atm_counter_vpi_mode
			x                               		If the -atm_counter_vpi_type option is set to counter, this indicates what counter mode should be used. Currently only the incr and decr mode are supported.
			x                           	-atm_counter_vpi_type
			x                               		The type of counter to use on the vpi. Currently only fixed, counter, and table are supported.
			x                           	-atm_header_aal5error
			x                               	-atm_header_cell_loss_priority
			x                                   	-atm_header_cpcs_length
			x                                       	-atm_header_enable_auto_vpi_vci
			x                                           	-atm_header_enable_cl
			x                                               	-atm_header_enable_cpcs_length
			x                                                   	-atm_header_encapsulation
			x                                                       		The type of header encapsulation. Depending on the traffic_generator value, this option has different value choices.For ixnetwork traffic generator the parameter can be used only for ixos - vcc_mux_ipv4_routed, vcc_mux_bridged_eth_fcs, vcc_mux_bridged_eth_no_fcs, vcc_mux_ipv6_routed,vcc_mux_mpls_routed, llc_routed_clip, llc_bridged_eth_fcs, llc_bridged_eth_no_fcs, llc_pppoa, vcc_mux_ppoa, llc_nlpid_routed ixnetwork - llc_bridged_eth_fcs, llc_bridged_eth_no_fcs,llc_ppp, llc_routed_snap, vcc_mux_bridged_eth_fcs, vcc_mux_bridged_eth_no_fcs, vcc_mux_ppp, vcc_mux_routedixnetwork_540 - vcc_mux_ipv4_routed, vcc_mux_bridged_eth_fcs, vcc_mux_bridged_eth_no_fcs, vcc_mux_ipv6_routed, vcc_mux_mpls_routed, llc_routed_clip, llc_bridged_eth_fcs, llc_bridged_eth_no_fcs, llc_pppoa, vcc_mux_ppoa, llc_ppp, llc_routed_snap, vcc_mux_ppp, vcc_mux_routed
			x                                                   	-atm_header_generic_flow_ctrl
			x                                                       	-atm_header_hec_errors
			x                                                           	-atm_range_count
			x                                                               		This option is used to specify the number of ATM static endpoint ranges. It can take any numeric value.
			x                                                           	-becn
			x                                                               		Backward Explicit Congestion Notification.
			x                                                           	-circuit_endpoint_type
			x                                                               		This argument can be used to specify the endpoint type that will be used to generate traffic. Valid options are:
			x                                                               		<choices><choice><choiceName>atm</choiceName><choiceText>Select this option if the endpoint supports ATM.</choiceText></choice><choice><choiceName>ethernet_vlan </choiceName><choiceText>Select this option if the endpoint supports Ethernet/VLAN (MAC addressing).</choiceText></choice><choice><choiceName>ethernet_vlan_arp </choiceName><choiceText>Select this option if the endpoint supports Ethernet/VLAN (MAC addressing) and ARP.frame_relay- Select this option if the endpoint supports Frame Relay.</choiceText></choice><choice><choiceName>hdlc</choiceName><choiceText>Select this option if the endpoint supports HDLC/POS.</choiceText></choice><choice><choiceName>ipv4 </choiceName><choiceText>Select this option if the endpoint supports IPv4.</choiceText></choice><choice><choiceName>ipv4_arp </choiceName><choiceText>Select this option if the endpoint supports IPv4 and ARP.</choiceText></choice><choice><choiceName>ipv4_application_traffic </choiceName><choiceText>Select this option if the endpoint supports IPv4 application traffic generation.</choiceText></choice><choice><choiceName>ipv6</choiceName><choiceText>Select this option if the endpoint supports IPv6.</choiceText></choice><choice><choiceName>ipv6_application_traffic </choiceName><choiceText> Select this option if the endpoint supports IPv6 application traffic generation.</choiceText></choice><choice><choiceName>ppp</choiceName><choiceText>Select this option if the endpoint supports PPP/POS.</choiceText></choice><choice><choiceName>fcoe</choiceName><choiceText>Select this options if the endpoint supports fcoe.</choiceText></choice><choice><choiceName>fc</choiceName><choiceText>Select this options if the endpoint supports fc.</choiceText></choice><choice><choiceName>multicast_igmp</choiceName><choiceText>Use this option only if -emulation_src_handle or -emulation_dst_handle is represented by IP handles. Eg: 20.0.1.2/50.0.1.5/0.0.0.1/3. Valid only for IxTclNetwork.</choiceText></choice></choices>
			x                                                           	-circuit_type
			x                                                               		This argument can be used to specify the circuit type that will be used to transmit traffic.For traffic_generator ixnetwork_540:If the parameter is configured as raw the traffic endpoints must be raw. If it is configured to anything else it will accept all the endpoint types. For example, if circuit_type is vpls and emulation_src_handle is a pppox handle it will ignore the 'vpls' restriction and use the pppox handle as source. For traffic_generator ixnetwork the valid choices are:
			x                                                               		Valid choices are:
			x                                                                   		vpls - VPLS traffic will be sent by the transmit port.
			x                                                                   		l2vpn - L2VPN encapsulated traffic will be sent by the transmit port.
			x                                                                   		l3vpn - L3VPN encapsulated traffic will be sent by the transmit port.
			x                                                                   		mpls - MPLS encapsulated traffic will be sent by the transmit port.
			x                                                                   		6pe - 6PE encapsulated traffic will be sent by the transmit port.
			x                                                                   		6vpe - 6VPE encapsulated traffic will be sent by the transmit port.
			x                                                                   		none - no MPLS encapsulation will be used by the transmit port.
			x                                                                   		stp - L2 with 802.1q encapsulated traffic will be sent by the transmit port.
			x                                                                   		mac_in_mac - stacked vlan encapsulation will be used by the transmit port.
			x                                                                   		raw - if selected, traffic is sent on a port-to-port basis, without the use of protocol interfaces. Configuration of source and destination addresses and other information is manually configured. If this type of circuit is selected, the configuration of the -src_dest_mesh and -route_mesh arguments is disabled.
			x                                                                   		quick_flows - if selected, the traffic configuration will use IxNetwork quick flow streams instead of L2L3 streams. This option also allows the configuration and use of UDFs. Note that when using quick flows there are some tracking limitations to be considered: 1. The tracking option operates across ALL quick flows (per traffic item) 2. The track_by field can only support values: none, all custom modes, endpoint_pair, source_dest_value_pair, dest_endpoint, source_endpoint, source_dest_port_pair, source_port.
			x                                                                   		application - Deprecated value. It was used to set Applib Legacy Traffic.
			x                                                           	-convert_to_raw
			x                                                               		If this parameter is 1 the traffic item being created will be transformed into a raw traffic item allowing to modify fields of the packet that are normally configured from the learned info of the traffic endpoitns. For example, if two IPv4 interfaces are used as traffic endpoints, ip_src_addr and ip_dst_addr cannot be configured
			x                                                               		Valid choices are:
			x                                                                   		0 - disable
			x                                                                   		1 - enable
			x                                                           	-custom_offset
			x                                                               		This argument can be used to specify the offset from the beginning of the packet where the custom-defined value will be inserted (in bytes). Valid only for traffic_generator ixnetwork/ixnetwork_540 and track_by custom_8bit/custom_16bit/custom_24bit/custom_32bit.
			x                                                           	-custom_values
			x                                                               		Configure the values to be inserted at custom_offset. A list of values is accepted. Valid only for traffic_generator ixnetwork_540 and track_by custom_8bit/custom_16bit/custom_24bit/custom_32bit.
			x                                                           	-data_pattern
			x                                                               		Payload value in bytes. For example, you can specify a custom payload pattern like the following using option "data_pattern":00 44 00 44
			x                                                           	-data_pattern_mode
			x                                                               		<choices><choice><choiceName>incr_byte</choiceName><choiceText>Data patterm increments each byte in the packet payload.</choiceText></choice><choice><choiceName>decr_byte </choiceName><choiceText>Data patterm decrements each byte in the packet payload. Valid only for traffic_generator ixos/ixnetwork/ixnetwork_540.</choiceText></choice><choice><choiceName>incr_word </choiceName><choiceText>Data patterm increments each word in the packet payload. Valid only for traffic_generator ixnetwork/ixnetwork_540.</choiceText></choice><choice><choiceName>decr_byte </choiceName><choiceText>Data patterm decrements each word in the packet payload. Valid only for traffic_generator ixnetwork/ixnetwork_540.</choiceText></choice><choice><choiceName>fixed </choiceName><choiceText>Data patterm is idle for each byte in the packet payload. Valid only for traffic_generator ixos/ixnetwork/ixnetwork_540. For traffic_generator ixnetwork, you can set data_pattern as one of the predefined patterns "00 FF 00 FF", "DE AD BE EF", "00 11 22 33", "AA 77 AA 77", or you can set any other type of pattern which will pass as a user defined pattern.</choiceText></choice><choice><choiceName>random </choiceName><choiceText>Data patterm is random for the packet payload. Valid only for traffic_generator ixos/ixnetwork_540.</choiceText></choice><choice><choiceName>repeating </choiceName><choiceText>Data patterm repeats for the packet payload. Valid only for traffic_generator ixos/ixnetwork/ixnetwork_540.</choiceText></choice></choices>
			x                                                           	-data_tos
			x                                                               		The TOS value when -enable_data is enabled.
			x                                                           	-data_tos_count
			x                                                               		Numeric value which configures the number of times the data_tos is incremeneted or decremented when data_tos_mode is incr or decr.
			x                                                           	-data_tos_mode
			x                                                               		This parameter configures
			x                                                               		Valid choices are:
			x                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                   		incr - the value is incremented as specified with data_tos_step and data_tos_count.
			x                                                                   		decr - the value is decremented as specified with data_tos_step and data_tos_count.
			x                                                                   		list - Parameter -data_tos contains a list of values. Each packet will use one of the values from the list.
			x                                                           	-data_tos_step
			x                                                               		Step value used to modify data_tos when data_tos_mode is incr or decr.
			x                                                           	-data_tos_tracking
			x                                                                   		0 - disable tracking by data_tos
			x                                                                   		1 - enable tracking by data_tos
			x                                                           	-destination_filter
			x                                                               		This parameter filter on the available destination endpoints that can be provided with emulation_dst_handle.
			x                                                               		Valid choices are:
			x                                                                   		all - There are no filters applied
			x                                                                   		ethernet - Ethernet endpoints only (for raw trafic only)
			x                                                                   		atm - ATM endpoints only (for raw trafic only)
			x                                                                   		framerelay - Frame Relay endpoints only (for raw trafic only)
			x                                                                   		hdlc - HDLC endpoints only (for raw trafic only)
			x                                                                   		ppp - PPP endpoints only (for raw trafic only)
			x                                                                   		none - non MPLS endpoints only
			x                                                                   		l2vpn - L2VPN endpoints only
			x                                                                   		l3vpn - L3VPN endpoints only
			x                                                                   		mpls - MPLS endpoints only
			x                                                                   		6pe - 6PE endpoints only
			x                                                                   		6vpe - 6VPE endpoints only
			x                                                                   		bgpvpls - VPLS endpoints only
			x                                                                   		mac_in_mac - MAC in MAC endpoints only
			x                                                                   		data_center_bridging - Data Center and Bridging endpoints only
			x                                                           	-tag_filter
			x                                                               		This parameter specifies the filter regarding which tagged scenario items will be used to run traffic. Has the following format (for each endpoint set): tagname:id1,id2,id3 Eg. [list [list ip1:1,2 ip2:1] [list ip1:1,3 ip2:2]]
			x                                                           	-dhcp_boot_filename
			x                                                               		Boot file name, null terminated string; "generic" name or null in DHCPDISCOVER, fully qualified directory-path name DHCPOFFER.(DEFAULT = "")
			x                                                           	-dhcp_boot_filename_tracking
			x                                                                   		0 - disable tracking by dhcp_boot_filename
			x                                                                   		1 - enable tracking by dhcp_boot_filename
			x                                                           	-dhcp_client_hw_addr
			x                                                               		Client hardware address.Must be in the form of a string of hex data.
			x                                                           	-dhcp_client_hw_addr_count
			x                                                               		Numeric value which configures the number of times the dhcp_client_hw_addr is incremeneted or decremented when dhcp_client_hw_addr_mode is incr or decr.
			x                                                           	-dhcp_client_hw_addr_mode
			x                                                               		This parameter configures
			x                                                               		Valid choices are:
			x                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                   		incr - the value is incremented as specified with dhcp_client_hw_addr_step and dhcp_client_hw_addr_count.
			x                                                                   		decr - the value is decremented as specified with dhcp_client_hw_addr_step and dhcp_client_hw_addr_count.
			x                                                                   		list - Parameter -dhcp_client_hw_addr contains a list of values. Each packet will use one of the values from the list.
			x                                                           	-dhcp_client_hw_addr_step
			x                                                               		Step value used to modify dhcp_client_hw_addr when dhcp_client_hw_addr_mode is incr or decr.
			x                                                           	-dhcp_client_hw_addr_tracking
			x                                                                   		0 - disable tracking by dhcp_client_hw_addr
			x                                                                   		1 - enable tracking by dhcp_client_hw_addr
			x                                                           	-dhcp_client_ip_addr
			x                                                               		Client IP address.Only filled in if client is in BOUND, RENEW, or REBINDING state and can respond to ARP requests.
			x                                                           	-dhcp_client_ip_addr_count
			x                                                               		Numeric value which configures the number of times the dhcp_client_ip_addr is incremeneted or decremented when dhcp_client_ip_addr_mode is incr or decr.
			x                                                           	-dhcp_client_ip_addr_mode
			x                                                               		This parameter configures
			x                                                               		Valid choices are:
			x                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                   		incr - the value is incremented as specified with dhcp_client_ip_addr_step and dhcp_client_ip_addr_count.
			x                                                                   		decr - the value is decremented as specified with dhcp_client_ip_addr_step and dhcp_client_ip_addr_count.
			x                                                                   		list - Parameter -dhcp_client_ip_addr contains a list of values. Each packet will use one of the values from the list.
			x                                                           	-dhcp_client_ip_addr_step
			x                                                               		Step value used to modify dhcp_client_ip_addr when dhcp_client_ip_addr_mode is incr or decr.
			x                                                           	-dhcp_client_ip_addr_tracking
			x                                                                   		0 - disable tracking by dhcp_client_ip_addr
			x                                                                   		1 - enable tracking by dhcp_client_ip_addr
			x                                                           	-dhcp_flags
			x                                                               		Tells whether to broadcast or not.
			x                                                               		Valid choices are:
			x                                                                   		broadcast - broadcast
			x                                                                   		no_broadcast - no_broadcast
			x                                                           	-dhcp_flags_mode
			x                                                               		This parameter configures
			x                                                               		Valid choices are:
			x                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                   		list - Parameter -dhcp_flags contains a list of values. Each packet will use one of the values from the list.
			x                                                           	-dhcp_flags_tracking
			x                                                                   		0 - disable tracking by dhcp_flags
			x                                                                   		1 - enable tracking by dhcp_flags
			x                                                           	-dhcp_hops
			x                                                               		Set to zero by client.
			x                                                           	-dhcp_hops_count
			x                                                               		Numeric value which configures the number of times the dhcp_hops is incremeneted or decremented when dhcp_hops_mode is incr or decr.
			x                                                           	-dhcp_hops_mode
			x                                                               		This parameter configures
			x                                                               		Valid choices are:
			x                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                   		incr - the value is incremented as specified with dhcp_hops_step and dhcp_hops_count.
			x                                                                   		decr - the value is decremented as specified with dhcp_hops_step and dhcp_hops_count.
			x                                                                   		list - Parameter -dhcp_hops contains a list of values. Each packet will use one of the values from the list.
			x                                                           	-dhcp_hops_step
			x                                                               		Step value used to modify dhcp_hops when dhcp_hops_mode is incr or decr.
			x                                                           	-dhcp_hops_tracking
			x                                                                   		0 - disable tracking by dhcp_hops
			x                                                                   		1 - enable tracking by dhcp_hops
			x                                                           	-dhcp_hw_len
			x                                                               		Hardware address length.
			x                                                           	-dhcp_hw_len_count
			x                                                               		Numeric value which configures the number of times the dhcp_hw_len is incremeneted or decremented when dhcp_hw_len_mode is incr or decr.
			x                                                           	-dhcp_hw_len_mode
			x                                                               		This parameter configures
			x                                                               		Valid choices are:
			x                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                   		incr - the value is incremented as specified with dhcp_hw_len_step and dhcp_hw_len_count.
			x                                                                   		decr - the value is decremented as specified with dhcp_hw_len_step and dhcp_hw_len_count.
			x                                                                   		list - Parameter -dhcp_hw_len contains a list of values. Each packet will use one of the values from the list.
			x                                                           	-dhcp_hw_len_step
			x                                                               		Step value used to modify dhcp_hw_len when dhcp_hw_len_mode is incr or decr.
			x                                                           	-dhcp_hw_len_tracking
			x                                                                   		0 - disable tracking by dhcp_hw_len
			x                                                                   		1 - enable tracking by dhcp_hw_len
			x                                                           	-dhcp_hw_type
			x                                                               		Hardware address types.
			x                                                           	-dhcp_hw_type_count
			x                                                               		Numeric value which configures the number of times the dhcp_hw_type is incremeneted or decremented when dhcp_hw_type_mode is incr or decr.
			x                                                           	-dhcp_hw_type_mode
			x                                                               		This parameter configures
			x                                                               		Valid choices are:
			x                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                   		incr - the value is incremented as specified with dhcp_hw_type_step and dhcp_hw_type_count.
			x                                                                   		decr - the value is decremented as specified with dhcp_hw_type_step and dhcp_hw_type_count.
			x                                                                   		list - Parameter -dhcp_hw_type contains a list of values. Each packet will use one of the values from the list.
			x                                                           	-dhcp_hw_type_step
			x                                                               		Step value used to modify dhcp_hw_type when dhcp_hw_type_mode is incr or decr.
			x                                                           	-dhcp_hw_type_tracking
			x                                                                   		0 - disable tracking by dhcp_hw_type
			x                                                                   		1 - enable tracking by dhcp_hw_type
			x                                                           	-dhcp_magic_cookie
			x                                                               		Valid only for traffic_generator ixnetwork_540 and l4_protocol 'dhcp'.Configure the 4 bytes HEX number for the 'Magic Cookie' field.
			x                                                           	-dhcp_magic_cookie_count
			x                                                               		Numeric value which configures the number of times the dhcp_magic_cookie is incremeneted or decremented when dhcp_magic_cookie_mode is incr or decr.
			x                                                           	-dhcp_magic_cookie_mode
			x                                                               		This parameter configures
			x                                                               		Valid choices are:
			x                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                   		incr - the value is incremented as specified with dhcp_magic_cookie_step and dhcp_magic_cookie_count.
			x                                                                   		decr - the value is decremented as specified with dhcp_magic_cookie_step and dhcp_magic_cookie_count.
			x                                                                   		list - Parameter -dhcp_magic_cookie contains a list of values. Each packet will use one of the values from the list.
			x                                                           	-dhcp_magic_cookie_step
			x                                                               		Step value used to modify dhcp_magic_cookie when dhcp_magic_cookie_mode is incr or decr.
			x                                                           	-dhcp_magic_cookie_tracking
			x                                                                   		0 - disable tracking by dhcp_magic_cookie
			x                                                                   		1 - enable tracking by dhcp_magic_cookie
			x                                                           	-dhcp_operation_code
			x                                                               		Operation codes. Valid options are: replyrequest
			x                                                           	-dhcp_operation_code_mode
			x                                                               		This parameter configures
			x                                                               		Valid choices are:
			x                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                   		list - Parameter -dhcp_operation_code contains a list of values. Each packet will use one of the values from the list.
			x                                                           	-dhcp_operation_code_tracking
			x                                                                   		0 - disable tracking by dhcp_operation_code
			x                                                                   		1 - enable tracking by dhcp_operation_code
			x                                                           	-dhcp_option
			x                                                               	-dhcp_option_data
			x                                                                   	-dhcp_relay_agent_ip_addr
			x                                                                       		Relay agent IP address, used in booting via a relay agent.
			x                                                                   	-dhcp_relay_agent_ip_addr_count
			x                                                                       		Numeric value which configures the number of times the dhcp_relay_agent_ip_addr is incremeneted or decremented when dhcp_relay_agent_ip_addr_mode is incr or decr.
			x                                                                   	-dhcp_relay_agent_ip_addr_mode
			x                                                                       		This parameter configures
			x                                                                       		Valid choices are:
			x                                                                           		fixed - the value is left unchanged for all packets.
			x                                                                           		incr - the value is incremented as specified with dhcp_relay_agent_ip_addr_step and dhcp_relay_agent_ip_addr_count.
			x                                                                           		decr - the value is decremented as specified with dhcp_relay_agent_ip_addr_step and dhcp_relay_agent_ip_addr_count.
			x                                                                           		list - Parameter -dhcp_relay_agent_ip_addr contains a list of values. Each packet will use one of the values from the list.
			x                                                                   	-dhcp_relay_agent_ip_addr_step
			x                                                                       		Step value used to modify dhcp_relay_agent_ip_addr when dhcp_relay_agent_ip_addr_mode is incr or decr.
			x                                                                   	-dhcp_relay_agent_ip_addr_tracking
			x                                                                           		0 - disable tracking by dhcp_relay_agent_ip_addr
			x                                                                           		1 - enable tracking by dhcp_relay_agent_ip_addr
			x                                                                   	-dhcp_seconds
			x                                                                       		Seconds elapsed since client began address acquisition or renewal process.
			x                                                                   	-dhcp_seconds_count
			x                                                                       		Numeric value which configures the number of times the dhcp_seconds is incremeneted or decremented when dhcp_seconds_mode is incr or decr.
			x                                                                   	-dhcp_seconds_mode
			x                                                                       		This parameter configures
			x                                                                       		Valid choices are:
			x                                                                           		fixed - the value is left unchanged for all packets.
			x                                                                           		incr - the value is incremented as specified with dhcp_seconds_step and dhcp_seconds_count.
			x                                                                           		decr - the value is decremented as specified with dhcp_seconds_step and dhcp_seconds_count.
			x                                                                           		list - Parameter -dhcp_seconds contains a list of values. Each packet will use one of the values from the list.
			x                                                                   	-dhcp_seconds_step
			x                                                                       		Step value used to modify dhcp_seconds when dhcp_seconds_mode is incr or decr.
			x                                                                   	-dhcp_seconds_tracking
			x                                                                           		0 - disable tracking by dhcp_seconds
			x                                                                           		1 - enable tracking by dhcp_seconds
			x                                                                   	-dhcp_server_host_name
			x                                                                       		Optional server host name, null terminated string.(DEFAULT = "").
			x                                                                   	-dhcp_server_host_name_tracking
			x                                                                           		0 - disable tracking by dhcp_server_host_name
			x                                                                           		1 - enable tracking by dhcp_server_host_name
			x                                                                   	-dhcp_server_ip_addr
			x                                                                       		IP address of next server to use in bootstrap; returned in DHCPOFFER, DHCPACK by server.
			x                                                                   	-dhcp_server_ip_addr_count
			x                                                                       		Numeric value which configures the number of times the dhcp_server_ip_addr is incremeneted or decremented when dhcp_server_ip_addr_mode is incr or decr.
			x                                                                   	-dhcp_server_ip_addr_mode
			x                                                                       		This parameter configures
			x                                                                       		Valid choices are:
			x                                                                           		fixed - the value is left unchanged for all packets.
			x                                                                           		incr - the value is incremented as specified with dhcp_server_ip_addr_step and dhcp_server_ip_addr_count.
			x                                                                           		decr - the value is decremented as specified with dhcp_server_ip_addr_step and dhcp_server_ip_addr_count.
			x                                                                           		list - Parameter -dhcp_server_ip_addr contains a list of values. Each packet will use one of the values from the list.
			x                                                                   	-dhcp_server_ip_addr_step
			x                                                                       		Step value used to modify dhcp_server_ip_addr when dhcp_server_ip_addr_mode is incr or decr.
			x                                                                   	-dhcp_server_ip_addr_tracking
			x                                                                           		0 - disable tracking by dhcp_server_ip_addr
			x                                                                           		1 - enable tracking by dhcp_server_ip_addr
			x                                                                   	-dhcp_transaction_id
			x                                                                       		Random number chosen by client and used by the client and server to associate messages and responses between a client and a server.
			x                                                                   	-dhcp_transaction_id_count
			x                                                                       		Numeric value which configures the number of times the dhcp_transaction_id is incremeneted or decremented when dhcp_transaction_id_mode is incr or decr.
			x                                                                   	-dhcp_transaction_id_mode
			x                                                                       		This parameter configures
			x                                                                       		Valid choices are:
			x                                                                           		fixed - the value is left unchanged for all packets.
			x                                                                           		incr - the value is incremented as specified with dhcp_transaction_id_step and dhcp_transaction_id_count.
			x                                                                           		decr - the value is decremented as specified with dhcp_transaction_id_step and dhcp_transaction_id_count.
			x                                                                           		list - Parameter -dhcp_transaction_id contains a list of values. Each packet will use one of the values from the list.
			x                                                                   	-dhcp_transaction_id_step
			x                                                                       		Step value used to modify dhcp_transaction_id when dhcp_transaction_id_mode is incr or decr.
			x                                                                   	-dhcp_transaction_id_tracking
			x                                                                           		0 - disable tracking by dhcp_transaction_id
			x                                                                           		1 - enable tracking by dhcp_transaction_id
			x                                                                   	-dhcp_your_ip_addr
			x                                                                       		"Your" (client) IP address.
			x                                                                   	-dhcp_your_ip_addr_count
			x                                                                       		Numeric value which configures the number of times the dhcp_your_ip_addr is incremeneted or decremented when dhcp_your_ip_addr_mode is incr or decr.
			x                                                                   	-dhcp_your_ip_addr_mode
			x                                                                       		This parameter configures
			x                                                                       		Valid choices are:
			x                                                                           		fixed - the value is left unchanged for all packets.
			x                                                                           		incr - the value is incremented as specified with dhcp_your_ip_addr_step and dhcp_your_ip_addr_count.
			x                                                                           		decr - the value is decremented as specified with dhcp_your_ip_addr_step and dhcp_your_ip_addr_count.
			x                                                                           		list - Parameter -dhcp_your_ip_addr contains a list of values. Each packet will use one of the values from the list.
			x                                                                   	-dhcp_your_ip_addr_step
			x                                                                       		Step value used to modify dhcp_your_ip_addr when dhcp_your_ip_addr_mode is incr or decr.
			x                                                                   	-dhcp_your_ip_addr_tracking
			x                                                                           		0 - disable tracking by dhcp_your_ip_addr
			x                                                                           		1 - enable tracking by dhcp_your_ip_addr
			x                                                                   	-discard_eligible
			x                                                                       	-dlci_core_enable
			x                                                                           	-dlci_core_value
			x                                                                               	-dlci_count_mode
			x                                                                                   		Count mode of dlci_value. When using the traffic_generator ixnetwork, it can take only take the 'fixed' or 'increment' values and can be used only for L2VPN traffic, but is not supported in this release.This option is not supported for traffic_generator ixnetwork in this release.
			x                                                                               	-dlci_extended_address0
			x                                                                                   	-dlci_extended_address1
			x                                                                                       	-dlci_extended_address2
			x                                                                                           	-dlci_extended_address3
			x                                                                                               	-dlci_mask_select
			x                                                                                                   	-dlci_mask_value
			x                                                                                                       	-dlci_repeat_count
			x                                                                                                           		Repeat count for dlci_value. Depending on the traffic_generator value, this option has different value ranges:ixos:0-65535 range.ixnetwork (not supported in this release): 0-4294967295 range. When traffic_generator is ixnetwork, the option can only be used for L2VPN traffic, but is not supported in this release.
			x                                                                                                       	-dlci_size
			x                                                                                                           	-dlci_value
			x                                                                                                               		Data Link Connection Identifier value. Depending on the traffic_generator value, this option has different ixos - Valid range is 0-65535ixnetwork/ixnetwork_540 - Valid range is 0-4294967295. The option can only be used for L2VPN traffic.
			x                                                                                                           	-duration
			x                                                                                                               		This parameter is available withtraffic_generator ixnetwork_540 - The parameter should be used only when tx_mode has been configured as interleaved. Along with this parameter you can also set tx_delay and tx_delay_unit. You can also use ::<namespace>::traffic_control to set the duration for all traffic items. The parameter transmit_mode should not be specified along with duration parameter (duration parameter implies fixed duration traffic mode).
			x                                                                                                           	-dynamic_update_fields
			x                                                                                                               		ppp - enables dynamic update of PPP header fields for the respective traffic item; mpls_label_value - enables dynamic update of MPLS label values for the respective traffic item. This is the same functionality provided by parameter enable_dynamic_mpls_labels. Adding dynamic_update_field parameter when creating/modifying a traffic item the allows IxNetwork to update the corresponding traffic packet fields on the fly with the information learned from protocols. This parameter can be provided with ppp value, mpls_label_value value or both {ppp mpls_label_value} as a list.If this parameter is provided with mpls_label_value only, the session aware traffic fields will be automatically unset.
			x                                                                                                           	-egress_custom_offset
			x                                                                                                               		Can be a list of positive integer values, or 'NA' strings in case it is not definedfor the corresponding -egress_tracking element. Valid only for traffic_generator ixnetwork/ixnetwork_540 and if the corresponding -egress_tracking element is set to 'custom'. Configure the offset in bits from the beginning of the packet.
			x                                                                                                           	-egress_custom_width
			x                                                                                                               		Can be a list of numbers, or 'NA' string in case it is not defined for the corresponding -egress_tracking element. Valid only for traffic_generator ixnework/ixnetwork_540 and if the corresponding -egress_tracking element is set to 'custom'. The maximum number that can be set depends on the card type that is used. If you specify a higher number than supported, IxNetwork will set the value to the highest number supported. Configure the number of bits that will be tracked on the egress side of the traffic.
			x                                                                                                           	-egress_custom_field_offset
			x                                                                                                               		Can be a list of egress tracking field offsets, or 'NA' strings in case it is not defined for the corresponding -egress_tracking element. Valid only for traffic_generator ixnetwork/ixnetwork_540 and if the corresponding -egress_tracking element is set to 'custom_by_field'.The entire list of available egress tracking field offsets for a traffic item can be obtained by calling the traffic_config procedure with mode 'get_available_egress_tracking_field_offset.'
			x                                                                                                           	-egress_tracking
			x                                                                                                               		Configures one or multiple egress tracking items. Egress tracking cannot be configured if no tracking was configured with -track_by parameter. Can be a list of one or multiple elements.
			x                                                                                                               		Valid choices are:
			x                                                                                                                   		-
			x                                                                                                                   		dscp - Enable egress tracking on this traffic item. The egress tracking offset will be configured to the predefined IPv4 DSCP (6 bits) offset.
			x                                                                                                                   		ipv6TC - Enable egress tracking on this traffic item. The egress tracking offset willwill be configured to the predefined IPv6 Traffic Class (8 bits) offset.
			x                                                                                                                   		mplsExp - Enable egress tracking on this traffic item. The egress tracking offset will be configured to the predefined MPLS Exp (3 bits) offset.
			x                                                                                                                   		custom - Enable egress tracking on this traffic item. The egress tracking offset willbe configured manually with the parameters -egress_ custom_offset and egress_custom_width
			x                                                                                                                   		custom_by_field - Enable egress tracking on this traffic item. The egress tracking offset will be configured manually with the parameter -egress_custom_field_offset.
			x                                                                                                                   		outer_vlan_priority - Enable egress tracking on this traffic item. The egress tracking offset will be configured to the predefined Outer VLAN Priority (3 bits) offset. This choice is supported only on Ethernet load modules.
			x                                                                                                                   		outer_vlan_id_4 - Enable egress tracking on this traffic item. The egress tracking offset will be configured to the predefined Outer VLAN ID (4 bits) offset. his choice is supported only on Ethernetload modules.
			x                                                                                                                   		outer_vlan_id_6 - Enable egress tracking on this traffic item. The egress tracking offset will be configured to the predefined Outer VLAN ID (6 bits) offset. This choice is supported only on Ethernet load modules
			x                                                                                                                   		outer_vlan_id_8 - Enable egress tracking on this traffic item. The egress tracking offset willbe configured to the predefined Outer VLAN ID (8 bits) offset. This choice is supported only on Ethernet load modules.
			x                                                                                                                   		outer_vlan_id_10 - Enable egress tracking on this traffic item. The egress tracking offset willbe configured to the predefined Outer VLAN ID (10 bits) offset. his choice is supported only on Ethernetload modules.
			x                                                                                                                   		outer_vlan_id_12 - Enable egress tracking on this traffic item. The egress tracking offset will be configured to the predefined Outer VLAN ID (12 bits) offset. This choice is supported only on Ethernet load modules.
			x                                                                                                                   		inner_vlan_priority - Enable egress tracking on this traffic item. The egress tracking offset will be configured to the predefined Inner VLAN Priority (3 bits) offset. This choice is supported only on Ethernet load modules.
			x                                                                                                                   		inner_vlan_id_4 - Enable egress tracking on this traffic item. The egress tracking offset will be configured to the predefined Inner VLAN ID (4 bits) offset. This choice is supported only on Ethernet load modules.
			x                                                                                                                   		inner_vlan_id_6 - Enable egress tracking on this traffic item. The egress tracking offset willbe configured to the predefined Inner VLAN ID (6 bits) offset. This choice is supported only on Ethernet load modules.
			x                                                                                                                   		inner_vlan_id_8 - Enable egress tracking on this traffic item. The egress tracking offset will be configured to the predefined Inner VLAN ID (8 bits) offset. This choice is supported only on Ethernet load modules.
			x                                                                                                                   		inner_vlan_id_10 - Enable egress tracking on this traffic item. The egress tracking offset willbe configured to the predefined Inner VLAN ID (10 bits) offset. This choice is supported only on Ethernet load modules.
			x                                                                                                                   		inner_vlan_id_12 - Enable egress tracking on this traffic item. The egress tracking offset willbe configured to the predefined Inner VLAN ID (12 bits) offset. This choice is supported only on Ethernet load modules.
			x                                                                                                                   		tos_precedence - Enable egress tracking on this traffic item. The egress tracking offset willbe configured to the predefined IPv4 TOS Precedence (3 bits) offset.
			x                                                                                                                   		ipv6TC_bits_0_2 - Enable egress tracking on this traffic item. The egress tracking offset will be configured to the predefined IPv6 Traffic Class Bits 0-2 (3 bits) offset.
			x                                                                                                                   		ipv6TC_bits_0_5 - Enable egress tracking on this traffic item. The egress tracking offset will be configured to the predefined IPv6 Traffic Class Bits 0-5 (6 bits) offset.
			x                                                                                                                   		vnTag_direction_bit - Enable egress tracking on this traffic item. The egress tracking offset will be configured to the predefined VNTag Direction Bit (1 bit) offset.
			x                                                                                                                   		vnTag_pointer_bit - Enable egress tracking on this traffic item. The egress tracking offset will be configured to the predefined VNTag Pointer Bit (1 bit) offset.
			x                                                                                                                   		vnTag_looped_bit - Enable egress tracking on this traffic item. The egress tracking offset will be configured to the predefined VNTag Looped Bit (1 bit) offset.
			x                                                                                                           	-egress_tracking_encap
			x                                                                                                               		Configures the encapsulations used for the egress_tracking elements.Valid only for traffic_generator ixnetwork/ixnetwork_540 and egress_tracking not void.For each card type there is a default value defined:- if the card is ATM the default is 'LLCRoutedCLIP'- if the card is POS the default is 'pos_hdlc'- otherwise, the default value is 'ethernet'It can be a list of one or more of the following valid options:customethernetLLCRoutedCLIPLLCPPPoALLCBridgedEthernetFCSLLCBridgedEthernetNoFCSVccMuxPPPoAVccMuxIPV4RoutedVccMuxBridgedEthernetFCSVccMuxBridgedEthernetNoFCSpos_ppppos_hdlcframe_relay1490frame_relay2427frame_relay_cisco
			x                                                                                                           	-emulation_dst_vlan_protocol_tag_id
			x                                                                                                               	-emulation_override_ppp_ip_addr
			x                                                                                                                   		This parameter should be used when configuring ixos traffic over PPP sessions in order to override the IP address distributed through PPP with the address provided through ip_src_addr. Valid only for traffic_generator ixos/ixnetwork_540 and if emulation_src_handle or emulation_dst_handle is present. With traffic_generator ixnetwork_540 any value (except none) will have the same efect as '-convert_to_raw' and any field from the packet can be modified.
			x                                                                                                                   		Valid choices are:
			x                                                                                                                       		upstream - when setting this option, the PPP IP address will be overridden in the stream going from the access port (where the PPP emulation is configured) to the network port (the IP port)
			x                                                                                                                       		downstream - when setting this option, the PPP IP address will be overridden in the stream going from the network port (the IP port) to the access port (where the PPP emulation is configured)
			x                                                                                                                       		both - when setting this option, the PPP IP address will be overridden at both ends if the traffic is bidirectional, or at the corresponding end if the traffic is unidirectional.
			x                                                                                                                       		none - the PPP IP address will be used when configuring the streams.
			x                                                                                                               	-emulation_src_vlan_protocol_tag_id
			x                                                                                                                   	-emulation_scalable_dst_handle
			x                                                                                                                       		An array which contains lists of handles used to retrieve information for L3dst addresses, indexed by the endpointset to which they correspond. This should be a handle that was obtained after configuring protocols with commands from the ::ixiangpf:: namespace. This parameter can be used in conjunction with emulation_dst_handle. In the case where NGPF handles are specified in the emulation_dst_handle parameter (legacy backwards compatibility scenario), this parameter should not be used.
			x                                                                                                                   	-emulation_scalable_dst_port_start
			x                                                                                                                       		An array which contains lists of numbers that encode the index of the firstport on which the corresponding endpointset will be configured.This parameter will be ignored if no corresponding value is specified for emulation_scalable_dst_handle.
			x                                                                                                                   	-emulation_scalable_dst_port_count
			x                                                                                                                       		An array which contains lists of numbers that encode the number of ports onwhich the corresponding endpointset will be configured.This parameter will be ignored if no corresponding value is specified for emulation_scalable_dst_handle.
			x                                                                                                                   	-emulation_scalable_dst_intf_start
			x                                                                                                                       		An array which contains lists of numbers that encode the index of the firstinterface on which the corresponding endpointset will be configured.This parameter will be ignored if no corresponding value is specified for emulation_scalable_dst_handle.
			x                                                                                                                   	-emulation_scalable_dst_intf_count
			x                                                                                                                       		An array which contains lists of numbers that encode the number of interfaceson which the corresponding endpointset will be configured.This parameter will be ignored if no corresponding value is specified for emulation_scalable_dst_handle.
			x                                                                                                                   	-emulation_scalable_src_handle
			x                                                                                                                       		An array which contains lists of handles used to retrieve information for L3dst addresses, indexed by the endpointset to which they correspond. This should be a handle that was obtained after configuring protocols with commands from the ::ixiangpf:: namespace. This parameter can be used in conjunction with emulation_src_handle. In the case where NGPF handles are specified in the emulation_src_handle parameter (legacy backwards compatibility scenario), this parameter should not be used.
			x                                                                                                                   	-emulation_scalable_src_port_start
			x                                                                                                                       		An array which contains lists of numbers that encode the index of the firstport on which the corresponding endpointset will be configured.This parameter will be ignored if no corresponding value is specified for emulation_scalable_src_handle.
			x                                                                                                                   	-emulation_scalable_src_port_count
			x                                                                                                                       		An array which contains lists of numbers that encode the number of ports onwhich the corresponding endpointset will be configured.This parameter will be ignored if no corresponding value is specified for emulation_scalable_src_handle.
			x                                                                                                                   	-emulation_scalable_src_intf_start
			x                                                                                                                       		An array which contains lists of numbers that encode the index of the firstinterface on which the corresponding endpointset will be configured.This parameter will be ignored if no corresponding value is specified for emulation_scalable_src_handle.
			x                                                                                                                   	-emulation_scalable_src_intf_count
			x                                                                                                                       		An array which contains lists of numbers that encode the number of interfaceson which the corresponding endpointset will be configured.This parameter will be ignored if no corresponding value is specified for emulation_scalable_src_handle.
			x                                                                                                                   	-enable_auto_detect_instrumentation
			x                                                                                                                       	-enable_ce_to_pe_traffic
			x                                                                                                                           		Enables sending traffic from PE to CE in MPLS setups.
			x                                                                                                                       	-enable_data_integrity
			x                                                                                                                           		Whether data integrity checking is enabled.With traffic_generator ixnetwork_540 this parameter applies globally, not per traffic_item. 0 - Disabled.1 - Enabled.
			x                                                                                                                       	-enable_dynamic_mpls_labels
			x                                                                                                                           		Whether dynamic MPLS label binding is enabled or not.0 - Disabled.1 - Enabled. This is the same functionality provided by parameter -dynamic_update_field with the following value: mpls_label_value.
			x                                                                                                                       	-enable_override_value
			x                                                                                                                           		This argument can be used to specify if the custom-defined values will be added to the packets for tracking on the receiving side.Valid only for traffic_generator ixnetwork and with the assured_forwarding_phb, class_selector_phb, default_phb, expedited_forwarding_phb, tos, raw_priority or inner_vlan choices of the -track_by argument.
			x                                                                                                                       	-enable_pgid
			x                                                                                                                           	-enable_test_objective
			x                                                                                                                               	-enable_time_stamp
			x                                                                                                                                   		Whether time stamp insertion is enabled.
			x                                                                                                                                   		Valid choices are:
			x                                                                                                                                       		0 - Disabled
			x                                                                                                                                       		1 - Enabled
			x                                                                                                                               	-enable_udf1
			x                                                                                                                                   		If this option is set to true (1), then the UDF 1 counter will be inserted into the frame. If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                               	-enable_udf2
			x                                                                                                                                   		See description for this item as udf1
			x                                                                                                                               	-enable_udf3
			x                                                                                                                                   		See description for this item as udf1
			x                                                                                                                               	-enable_udf4
			x                                                                                                                                   		See description for this item as udf1
			x                                                                                                                               	-enable_udf5
			x                                                                                                                                   		See description for this item as udf1
			x                                                                                                                               	-endpointset_count
			x                                                                                                                                   		The number of endpointset to be created. The parameters -emulation_src_handle and -emulation_dst_handle should be provided with a number of list elements equal to endpointset_count.
			x                                                                                                                               	-enforce_min_gap
			x                                                                                                                                   		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>. This argument can be used to specify the smallest inter-packet gap that will be allowed.
			x                                                                                                                               	-ethernet_type
			x                                                                                                                                   	-ethernet_value
			x                                                                                                                                       		For ethernet ports with the ethernet encapsulation type ethernetII, a hex value can be specified as the Ethernet Type value.
			x                                                                                                                                   	-ethernet_value_count
			x                                                                                                                                       		Numeric value which configures the number of times the ethernet_value is incremeneted or decremented when ethernet_value_mode is incr or decr.
			x                                                                                                                                   	-ethernet_value_mode
			x                                                                                                                                       		This parameter configures
			x                                                                                                                                       		Valid choices are:
			x                                                                                                                                           		-
			x                                                                                                                                           		incr - the value is incremented as specified with ethernet_value_step and ethernet_value_count.
			x                                                                                                                                           		decr - the value is decremented as specified with ethernet_value_step and ethernet_value_count.
			x                                                                                                                                           		list - Parameter -ethernet_value contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                   	-ethernet_value_step
			x                                                                                                                                       		Hex step value used to modify ethernet_value when ethernet_value_mode is incr or decr.
			x                                                                                                                                   	-ethernet_value_tracking
			x                                                                                                                                           		-
			x                                                                                                                                           		1 - enable tracking by ethernet_value
			x                                                                                                                                   	-fcs_type
			x                                                                                                                                       		The FCS error to be inserted in the frame. Valid only for traffic_generator ixos/ixnetwork/ixnetwork_540 and when -fcs is 1. Valid choices with traffic_generator ixos are:
			x                                                                                                                                       		<choices><choice><choiceName>alignment </choiceName><choiceText>An alignment error to be inserted in the frame (only valid for 10/100).</choiceText></choice><choice><choiceName>dribble </choiceName><choiceText>A dribble error to be inserted in the frame.</choiceText></choice><choice><choiceName>bad_CRC </choiceName><choiceText>A bad FCS error to be inserted in the frame.</choiceText></choice><choice><choiceName>no_CRC </choiceName><choiceText>No FCS error to be inserted in the frame.Valid choices with traffic_generator ixnetwork are:</choiceText></choice><choice><choiceName>bad_CRC </choiceName><choiceText>A bad FCS error to be inserted in the frame.</choiceText></choice><choice><choiceName>no_CRC </choiceName><choiceText>No FCS error to be inserted in the frame.Valid choices with traffic_generator ixnetwork_540 are:</choiceText></choice><choice><choiceName>bad_CRC </choiceName><choiceText> A bad FCS error to be inserted in the frame.</choiceText></choice></choices>
			x                                                                                                                                   	-fecn
			x                                                                                                                                       	-field_activeFieldChoice
			x                                                                                                                                           		Determines the involvement of the field in the current active configuration. It is considered only if fieldchoice is true and can be used to pick and choose certain parameters, for example between diff services and ToS.Field attribute available for set when mode is "set_field_values".
			x                                                                                                                                       	-field_auto
			x                                                                                                                                           		Determines the automatic population of the field when chaining with other fields where possible.Field attribute available for set when mode is "set_field_values".
			x                                                                                                                                       	-field_countValue
			x                                                                                                                                           		Sets the number of steps for the incremental value types.Field attribute available for set when mode is "set_field_values".
			x                                                                                                                                       	-field_fieldValue
			x                                                                                                                                           		The actual value of the field (which depends on the value type and the indicated value).Field attribute available for set when mode is "set_field_values".
			x                                                                                                                                       	-field_fullMesh
			x                                                                                                                                           		Describes the behavior of the field in relation with other fields giving all combinations of values.Field attribute available for set when mode is "set_field_values".
			x                                                                                                                                       	-field_handle
			x                                                                                                                                           		Provides the field name (stack object fields) on which specific operations are made. It is obtained when mode is "get_available_fields". Valid when mode is "get_field_values", "set_field_values", "add_field_level" or "remove_field_level".
			x                                                                                                                                       	-field_linked
			x                                                                                                                                           		This parameter is used as the source field linked. In order for the stack provided to this parameter to be valid for linking, you must set increment/decrement/list mode for this field. Valid only for IxNetwork greater than 7.0.
			x                                                                                                                                       	-field_linked_to
			x                                                                                                                                           		This parameter is used as the destination field linked. In order for the stack provided to this parameter to be valid for linking, you must set increment/decrement/list mode for this field. Valid only for IxNetwork greater than 7.0.
			x                                                                                                                                       	-field_optionalEnabled
			x                                                                                                                                           		Field attribute available for set when mode is "set_field_values".
			x                                                                                                                                       	-field_singleValue
			x                                                                                                                                           		Controls the value of the field when field_valueType is "singleValue".Field attribute available for set when mode is "set_field_values".
			x                                                                                                                                       	-field_startValue
			x                                                                                                                                           		Controls the starting value of the field when field_valueType is"increment" or "decrement".Field attribute available for set when mode is "set_field_values".
			x                                                                                                                                       	-field_stepValue
			x                                                                                                                                           		Sets the step applied to field_startValue for incremental value types.Field attribute available for set when mode is "set_field_values".
			x                                                                                                                                       	-field_trackingEnabled
			x                                                                                                                                           		Controls the tracking option for this item.Field attribute available for set when mode is "set_field_values".
			x                                                                                                                                       	-field_valueList
			x                                                                                                                                           		Sets multiple values for the current field when field_valueType is "valueList".Field attribute available for set when mode is "set_field_values".
			x                                                                                                                                       	-field_valueType
			x                                                                                                                                           		Indicates the type of this field. This parameter determines what value parameter will give the actual field value.Field attribute available for set when mode is "set_field_values".
			x                                                                                                                                       	-frame_rate_distribution_port
			x                                                                                                                                           		Configure how frame rate will be distributed.
			x                                                                                                                                           		Valid choices are:
			x                                                                                                                                               		apply_to_all - Apply rate to all ports.
			x                                                                                                                                               		split_evenly - Split rate evenly among ports.
			x                                                                                                                                       	-frame_rate_distribution_stream
			x                                                                                                                                           		Configure how frame rate will be distributed.
			x                                                                                                                                           		Valid choices are:
			x                                                                                                                                               		apply_to_all - Apply rate to all flow groups.
			x                                                                                                                                               		split_evenly - Split rate evenly among flow groups.
			x                                                                                                                                       	-frame_sequencing
			x                                                                                                                                           		Inserts a sequence signature into the packet.
			x                                                                                                                                       	-frame_sequencing_mode
			x                                                                                                                                           		Valid options are: rx_switched_pathrx_switched_path_fixedrx_threshold advanced
			x                                                                                                                                       	-frame_sequencing_offset
			x                                                                                                                                           	-frame_size
			x                                                                                                                                               		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>. Actual total frame size coming out of the interface on the wire in is ignored if frame_size is present.
			x                                                                                                                                           	-frame_size_distribution
			x                                                                                                                                               		This argument can be used to specify the predefined distribution of the frames' length when length_mode = distribution. When IxTclNetwork path is used,this parameter is valid only for traffic_generator ixnetwork/ixnetwork_540, mode create/modify, and length_mode distribution. When IxTclProtocol path is used, this parameter is valid only when -length_mode is set to distribution.
			x                                                                                                                                               		<choices><choice><choiceName>cisco </choiceName><choiceText>A pre-programmed distribution, according to Cisco standards: 64:7, 594:4, and 1518:1.</choiceText></choice><choice><choiceName>imix</choiceName><choiceText>A pre-programmed distribution, according to IMIX standards: 64:7, 570:4, and 1518:1.</choiceText></choice><choice><choiceName>quadmodal </choiceName><choiceText>A pre-programmed distribution: 512:20, 1518:20, and 9000:20.</choiceText></choice><choice><choiceName>tolly</choiceName><choiceText> A pre-programmed distribution, according to Tolly testing group standards: 64:55, 78:5, 576:17, and 1518:23.</choiceText></choice><choice><choiceName>trimodal </choiceName><choiceText>A pre-programmed distribution: 64:60, 512:20,and 1518:20.</choiceText></choice><choice><choiceName>imix_ipsec </choiceName><choiceText> A pre-programmed distribution: 90:58, 92:2, 594:23 and 1418:15. </choiceText></choice><choice><choiceName>imix_ipv6 </choiceName><choiceText> A pre-programmed distribution: 60:58, 496:2, 594:23 and 1518:15. Valid only for traffic_generator ixnetwork_540.</choiceText></choice><choice><choiceName>imix_std </choiceName><choiceText> A pre-programmed distribution: 58:58, 62:2, 594:23, 1518:15. Valid only for traffic_generator ixnetwork_540.Valid only for traffic_generator ixnetwork_540.</choiceText></choice><choice><choiceName>imix_tcp </choiceName><choiceText>A pre-programmed distribution: 90:58, 92:2, 594:23, 1518:15. Valid only for traffic_generator ixnetwork_540.Valid only for traffic_generator ixnetwork_540.</choiceText></choice></choices>
			x                                                                                                                                           	-frame_size_gauss
			x                                                                                                                                               		This argument can be used to specify a list of maximum 4 options which describe a Quad Gauss distribution. The individual options which characterize the Quad Gauss distributions have the following structure: <center>:<width_at_half>:<weight>This argument has meaning only when mode is create/modify and length_mode is gass|quad and traffic_generator is ixnetwork/ixnetwork_540.
			x                                                                                                                                           	-frame_size_imix
			x                                                                                                                                               		This argument can be used to specify a list of lists, which, each of them, describe a weight pair: <weight>:<framesize>.This argument has meaning only when mode is create/modify and length_mode is imix and traffic_generator is ixnetwork/ixnetwork_540.
			x                                                                                                                                           	-frame_size_max
			x                                                                                                                                               		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>. Actual maximum total frame size coming out of the interface on the wire in bytes when option "length_mode" is set to random. Valid choices are between 12 and 13312. Parameter l3_length_max is ignored if this parameter is used.
			x                                                                                                                                           	-frame_size_min
			x                                                                                                                                               		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>. Actual minimal total frame size coming out of the interface on the wire in bytes when option "length_mode" is set to random. Valid choices are between 12 and 13312. Parameter l3_length_min is ignored if this parameter is used.
			x                                                                                                                                           	-frame_size_step
			x                                                                                                                                               		Actual increment by which the actual total frame size in bytes coming out of the interface on the wire will be incremented. Valid choices are between 0 and 13292. Parameter l3_length_step is ignored if this parameter is used.
			x                                                                                                                                           	-global_dest_mac_retry_count
			x                                                                                                                                               		Configure the number of times to attempt to obtain the destination MAC address. This parameter applies globally, not per traffic item.
			x                                                                                                                                           	-global_dest_mac_retry_delay
			x                                                                                                                                               		The number of seconds to wait between attempts to obtain the destination MAC address. This parameter applies globally, not per traffic item.
			x                                                                                                                                           	-global_enable_dest_mac_retry
			x                                                                                                                                               		Enables the destination MAC address retry function. This parameter applies globally, not per traffic item.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable
			x                                                                                                                                                   		1 - enable
			x                                                                                                                                           	-global_enable_mac_change_on_fly
			x                                                                                                                                               		When 1, enables IxNetwork's gratuitous ARP capability and IxNetwork listens for gratuitous ARP messages from its neighbors This parameter applies globally, not per traffic item.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable
			x                                                                                                                                                   		1 - enable
			x                                                                                                                                           	-global_enable_min_frame_size
			x                                                                                                                                               		When this option is enabled, IxNetwork will allow the stream to use smaller packet sizes. In the case of IPv4 and Ethernet, 64 bytes will be allowed. This is achieved by reducing the size of the instrumentation tag, which will be identified by receiving ports. Please note, reducing the size of the instrumentation tag will increase the risk of mistaking it for user data at the receiving port. This parameter applies globally, not per traffic item.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable
			x                                                                                                                                                   		1 - enable
			x                                                                                                                                           	-global_enable_staggered_transmit
			x                                                                                                                                               		If 1, the start of transmit is staggered across ports. A 25-30 ms delay is introduced between the time one port begins transmitting and the time next port begins transmitting. This parameter applies globally, not per traffic item.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable
			x                                                                                                                                                   		1 - enable
			x                                                                                                                                           	-global_enable_stream_ordering
			x                                                                                                                                               		When this option is enabled, IxNetwork will allow stream ordering per RFC 2889. This parameter applies globally, not per traffic item.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable
			x                                                                                                                                                   		1 - enable
			x                                                                                                                                           	-global_large_error_threshhold
			x                                                                                                                                               		The user-configurable threshold value - used to determine error levels for outof-sequence, received packets. This parameter applies globally, not per traffic item.
			x                                                                                                                                           	-global_max_traffic_generation_queries
			x                                                                                                                                               		Maximum number of traffic generation queries. This parameter applies globally, not per traffic item.
			x                                                                                                                                           	-global_display_mpls_current_label_value
			x                                                                                                                                               		Enable display MPLS current label value when tracking by MPLS flow descriptor. This parameter applies globally, not per traffic item.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable
			x                                                                                                                                                   		1 - enable
			x                                                                                                                                           	-global_mpls_label_learning_timeout
			x                                                                                                                                               		This parameter controls the timeout in seconds for the MPLS Label learning database during traffic generation. It helps to increase the timeout value, so that traffic generation does not time out and all packets are generated for this traffic item This parameter applies globally, not per traffic item.
			x                                                                                                                                           	-global_refresh_learned_info_before_apply
			x                                                                                                                                               		This attribute refreshes the learned information from the DUT. This parameter applies globally, not per traffic item.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable
			x                                                                                                                                                   		1 - enable
			x                                                                                                                                           	-global_stream_control
			x                                                                                                                                               		This parameter applies globally, not per traffic item.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		continuous - continuous
			x                                                                                                                                                   		iterations - iterations
			x                                                                                                                                           	-global_stream_control_iterations
			x                                                                                                                                               		This parameter applies globally, not per traffic item.
			x                                                                                                                                           	-global_use_tx_rx_sync
			x                                                                                                                                               		Synchronize Tx/Rx traffic ports. Disable this option when using multiple chassis without sync cable (including GPS chassis chain). This parameter applies globally, not per traffic item.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable
			x                                                                                                                                                   		1 - enable
			x                                                                                                                                           	-global_wait_time
			x                                                                                                                                               		The time (in seconds) to wait after Stop Transmit before stopping Latency Measurement. This parameter applies globally, not per traffic item.
			x                                                                                                                                           	-global_frame_ordering
			x                                                                                                                                               		Frame ordering is done when data is transmitted as a sequence of frames in a network comprising multiple terminal stations. Each terminal has a provision for arranging the received messages in the order of reception of frames. Within each frame, the received messages are arranged in a predetermined order of frames received.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		none - If you select this option, no specific ordering is followed when packets are transmitted.
			x                                                                                                                                                   		flow_group_setup- The Ordering by Flow Group option under Traffic Options ordering arranges the Flow Groups across the ports, such that no destination value is encountered.
			x                                                                                                                                                   		rfc2889 - If you select this option, the frame ordering is done by RFC2889.
			x                                                                                                                                                   		peak_loading - If you select this option, the frame ordering is done by Peak Loading - similar (but opposite) to rfc2889.
			x                                                                                                                                           	-global_peak_loading_replication_count
			x                                                                                                                                               		Replication count for Peak Loading. This option is valid only if -global_frame_ordering is set to "peak_loading".
			x                                                                                                                                           	-global_detect_misdirected_packets
			x                                                                                                                                               		Detect misdirected packet count on all ports.
			x                                                                                                                                           	-gre_checksum
			x                                                                                                                                               		Specify checksum for the GRE header.
			x                                                                                                                                           	-gre_checksum_count
			x                                                                                                                                               		Numeric value which configures the number of times the gre_checksum is incremeneted or decremented when gre_checksum_mode is incr or decr.
			x                                                                                                                                           	-gre_checksum_enable
			x                                                                                                                                               		Enable checksum for the GRE header.
			x                                                                                                                                           	-gre_checksum_enable_mode
			x                                                                                                                                               		This parameter configures
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                   		list - Parameter -gre_checksum_enable contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                           	-gre_checksum_enable_tracking
			x                                                                                                                                               		Enables or disables tracking by gre.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable tracking by gre_checksum_enable
			x                                                                                                                                                   		1 - enable tracking by gre_checksum_enable
			x                                                                                                                                           	-gre_checksum_mode
			x                                                                                                                                               		This parameter configures
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                   		incr - the value is incremented as specified with gre_checksum_step and gre_checksum_count.
			x                                                                                                                                                   		decr - the value is decremented as specified with gre_checksum_step and gre_checksum_count.
			x                                                                                                                                                   		list - Parameter -gre_checksum contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                           	-gre_checksum_step
			x                                                                                                                                               		Step value used to modify gre_checksum when gre_checksum_mode is incr or decr.
			x                                                                                                                                           	-gre_checksum_tracking
			x                                                                                                                                               		Enables or disables tracking by gre_checksum.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable tracking by gre_checksum
			x                                                                                                                                                   		1 - enable tracking by gre_checksum
			x                                                                                                                                           	-gre_key
			x                                                                                                                                               		Specify the key for the GRE header.
			x                                                                                                                                           	-gre_key_count
			x                                                                                                                                               		Numeric value which configures the number of times the gre_key is incremeneted or decremented when gre_key_mode is incr or decr.
			x                                                                                                                                           	-gre_key_enable
			x                                                                                                                                               		Enable key for the the GRE header.
			x                                                                                                                                           	-gre_key_enable_mode
			x                                                                                                                                               		This parameter configures
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                   		list - Parameter -gre_key_enable contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                           	-gre_key_enable_tracking
			x                                                                                                                                               		Enables or disables gre_key_enable_tracking.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable tracking by gre_key_enable
			x                                                                                                                                                   		1 - enable tracking by gre_key_enable
			x                                                                                                                                           	-gre_key_mode
			x                                                                                                                                               		This parameter configures
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                   		incr - the value is incremented as specified with gre_key_step and gre_key_count.
			x                                                                                                                                                   		decr - the value is decremented as specified with gre_key_step and gre_key_count.
			x                                                                                                                                                   		list - Parameter -gre_key contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                           	-gre_key_step
			x                                                                                                                                               		Step value used to modify gre_key when gre_key_mode is incr or decr.
			x                                                                                                                                           	-gre_key_tracking
			x                                                                                                                                               		Enables or disables by gre_key_tracking.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable tracking by gre_key
			x                                                                                                                                                   		1 - enable tracking by gre_key
			x                                                                                                                                           	-gre_reserved0
			x                                                                                                                                               		Specify first reserved field of the GRE header.
			x                                                                                                                                           	-gre_reserved0_count
			x                                                                                                                                               		Numeric value which configures the number of times the gre_reserved0 is incremeneted or decremented when gre_reserved0_mode is incr or decr.
			x                                                                                                                                           	-gre_reserved0_mode
			x                                                                                                                                               		This parameter configures
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                   		incr - the value is incremented as specified with gre_reserved0_step and gre_reserved0_count.
			x                                                                                                                                                   		decr - the value is decremented as specified with gre_reserved0_step and gre_reserved0_count.
			x                                                                                                                                                   		list - Parameter -gre_reserved0 contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                           	-gre_reserved0_step
			x                                                                                                                                               		Step value used to modify gre_reserved0 when gre_reserved0_mode is incr or decr.
			x                                                                                                                                           	-gre_reserved0_tracking
			x                                                                                                                                               		Enables or disables tracking by gre_reserved0_tracking.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable tracking by gre_reserved0
			x                                                                                                                                                   		1 - enable tracking by gre_reserved0
			x                                                                                                                                           	-gre_reserved1
			x                                                                                                                                               		Specify second reserved field of the GRE header.
			x                                                                                                                                           	-gre_reserved1_count
			x                                                                                                                                               		Numeric value which configures the number of times the gre_reserved1 is incremeneted or decremented when gre_reserved1_mode is incr or decr.
			x                                                                                                                                           	-gre_reserved1_mode
			x                                                                                                                                               		This parameter configures
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                   		incr - the value is incremented as specified with gre_reserved1_step and gre_reserved1_count.
			x                                                                                                                                                   		decr - the value is decremented as specified with gre_reserved1_step and gre_reserved1_count.
			x                                                                                                                                                   		list - Parameter -gre_reserved1 contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                           	-gre_reserved1_step
			x                                                                                                                                               		Step value used to modify gre_reserved1 when gre_reserved1_mode is incr or decr.
			x                                                                                                                                           	-gre_reserved1_tracking
			x                                                                                                                                               		Enables or disables tracking by gre_reserved1_tracking.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable tracking by gre_reserved1
			x                                                                                                                                                   		1 - enable tracking by gre_reserved1
			x                                                                                                                                           	-gre_seq_enable
			x                                                                                                                                               		Enable sequence checking for the the GRE header.
			x                                                                                                                                           	-gre_seq_enable_mode
			x                                                                                                                                               		This parameter configures
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                   		list - Parameter -gre_seq_enable contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                           	-gre_seq_enable_tracking
			x                                                                                                                                               		Enables or disables tracking by gre_seq_enable_tracking.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable tracking by gre_seq_enable
			x                                                                                                                                                   		1 - enable tracking by gre_seq_enable
			x                                                                                                                                           	-gre_seq_number
			x                                                                                                                                               		Specify the sequence number for the GRE header.
			x                                                                                                                                           	-gre_seq_number_count
			x                                                                                                                                               		Numeric value which configures the number of times the gre_seq_number is incremeneted or decremented when gre_seq_number_mode is incr or decr.
			x                                                                                                                                           	-gre_seq_number_mode
			x                                                                                                                                               		This parameter configures
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                   		incr - the value is incremented as specified with gre_seq_number_step and gre_seq_number_count.
			x                                                                                                                                                   		decr - the value is decremented as specified with gre_seq_number_step and gre_seq_number_count.
			x                                                                                                                                                   		list - Parameter -gre_seq_number contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                           	-gre_seq_number_step
			x                                                                                                                                               		Step value used to modify gre_seq_number when gre_seq_number_mode is incr or decr.
			x                                                                                                                                           	-gre_seq_number_tracking
			x                                                                                                                                               		Enables or disables tracking by gre_seq_number_tracking.
			x                                                                                                                                               		Valid choices are:
			x                                                                                                                                                   		0 - disable tracking by gre_seq_number
			x                                                                                                                                                   		1 - enable tracking by gre_seq_number
			x                                                                                                                                           	-gre_valid_checksum_enable
			x                                                                                                                                               	-gre_version
			x                                                                                                                                                   		Specify version for GRE header.
			x                                                                                                                                               	-gre_version_count
			x                                                                                                                                                   		Numeric value which configures the number of times the gre_version is incremeneted or decremented when gre_version_mode is incr or decr.
			x                                                                                                                                               	-gre_version_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with gre_version_step and gre_version_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with gre_version_step and gre_version_count.
			x                                                                                                                                                       		list - Parameter -gre_version contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-gre_version_step
			x                                                                                                                                                   		Step value used to modify gre_version when gre_version_mode is incr or decr.
			x                                                                                                                                               	-gre_version_tracking
			x                                                                                                                                                   		Enables or disables tracking by gre_version_tracking.
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		0 - disable tracking by gre_version
			x                                                                                                                                                       		1 - enable tracking by gre_version
			x                                                                                                                                               	-header_handle
			x                                                                                                                                                   		The header handle for which all the available fields will be analyzed.
			x                                                                                                                                               	-hosts_per_net
			x                                                                                                                                                   		This argument specifies the number of hosts from each route for whom traffic will be generated.
			x                                                                                                                                               	-icmp_checksum_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_checksum is incremeneted or decremented when icmp_checksum_mode is incr or decr.
			x                                                                                                                                               	-icmp_checksum_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_checksum_step and icmp_checksum_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_checksum_step and icmp_checksum_count.
			x                                                                                                                                                       		list - Parameter -icmp_checksum contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_checksum_step
			x                                                                                                                                                   		Step value used to modify icmp_checksum when icmp_checksum_mode is incr or decr.
			x                                                                                                                                               	-icmp_checksum_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_checksum
			x                                                                                                                                                       		1 - enable tracking by icmp_checksum
			x                                                                                                                                               	-icmp_code_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_code is incremeneted or decremented when icmp_code_mode is incr or decr.
			x                                                                                                                                               	-icmp_code_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_code_step and icmp_code_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_code_step and icmp_code_count.
			x                                                                                                                                                       		list - Parameter -icmp_code contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_code_step
			x                                                                                                                                                   		Step value used to modify icmp_code when icmp_code_mode is incr or decr.
			x                                                                                                                                               	-icmp_code_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_code
			x                                                                                                                                                       		1 - enable tracking by icmp_code
			x                                                                                                                                               	-icmp_id_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_id is incremeneted or decremented when icmp_id_mode is incr or decr.
			x                                                                                                                                               	-icmp_id_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_id_step and icmp_id_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_id_step and icmp_id_count.
			x                                                                                                                                                       		list - Parameter -icmp_id contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_id_step
			x                                                                                                                                                   		Step value used to modify icmp_id when icmp_id_mode is incr or decr.
			x                                                                                                                                               	-icmp_id_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_id
			x                                                                                                                                                       		1 - enable tracking by icmp_id
			x                                                                                                                                               	-icmp_max_response_delay_ms
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure Maximum response delay (milliseconds) field for 'Multicast Listener Query Message Version 1' (-icmp_type 130), 'Multicast Listener Report Message Version 1' (-icmp_type 131), 'Multicast Listener Done Message' (-icmp_type 132) or 'Multicast Listener Query Message Version 2' (-icmp_type 130) message types.
			x                                                                                                                                               	-icmp_max_response_delay_ms_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_max_response_delay_ms is incremeneted or decremented when icmp_max_response_delay_ms_mode is incr or decr.
			x                                                                                                                                               	-icmp_max_response_delay_ms_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_max_response_delay_ms_step and icmp_max_response_delay_ms_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_max_response_delay_ms_step and icmp_max_response_delay_ms_count.
			x                                                                                                                                                       		list - Parameter -icmp_max_response_delay_ms contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_max_response_delay_ms_step
			x                                                                                                                                                   		Step value used to modify icmp_max_response_delay_ms when icmp_max_response_delay_ms_mode is incr or decr.
			x                                                                                                                                               	-icmp_max_response_delay_ms_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_max_response_delay_ms
			x                                                                                                                                                       		1 - enable tracking by icmp_max_response_delay_ms
			x                                                                                                                                               	-icmp_mc_query_v2_interval_code
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure 1 byte HEX "Querier's Query Interval Code" fieldfor 'Multicast Listener Query Message Version 2' (-icmp_type 130) message type.
			x                                                                                                                                               	-icmp_mc_query_v2_interval_code_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_mc_query_v2_interval_code is incremeneted or decremented when icmp_mc_query_v2_interval_code_mode is incr or decr.
			x                                                                                                                                               	-icmp_mc_query_v2_interval_code_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_mc_query_v2_interval_code_step and icmp_mc_query_v2_interval_code_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_mc_query_v2_interval_code_step and icmp_mc_query_v2_interval_code_count.
			x                                                                                                                                                       		list - Parameter -icmp_mc_query_v2_interval_code contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_mc_query_v2_interval_code_step
			x                                                                                                                                                   		Step value used to modify icmp_mc_query_v2_interval_code when icmp_mc_query_v2_interval_code_mode is incr or decr.
			x                                                                                                                                               	-icmp_mc_query_v2_interval_code_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_mc_query_v2_interval_code
			x                                                                                                                                                       		1 - enable tracking by icmp_mc_query_v2_interval_code
			x                                                                                                                                               	-icmp_mc_query_v2_robustness_var
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure "Querier's Robustness Variable" field (0-7) for 'Multicast Listener Query Message Version 2' (-icmp_type 130) message type.
			x                                                                                                                                               	-icmp_mc_query_v2_robustness_var_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_mc_query_v2_robustness_var is incremeneted or decremented when icmp_mc_query_v2_robustness_var_mode is incr or decr.
			x                                                                                                                                               	-icmp_mc_query_v2_robustness_var_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_mc_query_v2_robustness_var_step and icmp_mc_query_v2_robustness_var_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_mc_query_v2_robustness_var_step and icmp_mc_query_v2_robustness_var_count.
			x                                                                                                                                                       		list - Parameter -icmp_mc_query_v2_robustness_var contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_mc_query_v2_robustness_var_step
			x                                                                                                                                                   		Step value used to modify icmp_mc_query_v2_robustness_var when icmp_mc_query_v2_robustness_var_mode is incr or decr.
			x                                                                                                                                               	-icmp_mc_query_v2_robustness_var_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_mc_query_v2_robustness_var
			x                                                                                                                                                       		1 - enable tracking by icmp_mc_query_v2_robustness_var
			x                                                                                                                                               	-icmp_mc_query_v2_s_flag
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure 'Supress router-side processing' flag for 'Multicast Listener Query Message Version 2'
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		0 - Supress router-side processing
			x                                                                                                                                                       		1 - Do not suppress router-side processing
			x                                                                                                                                               	-icmp_mc_query_v2_s_flag_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		list - Parameter -icmp_mc_query_v2_s_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_mc_query_v2_s_flag_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_mc_query_v2_s_flag
			x                                                                                                                                                       		1 - enable tracking by icmp_mc_query_v2_s_flag
			x                                                                                                                                               	-icmp_mobile_pam_m_bit
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure the "M Bit" bit for 'Mobile Prefix Advertisement Message' (-icmp_type 147) message type.
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		0 - bit is 0
			x                                                                                                                                                       		1 - bit is 1
			x                                                                                                                                               	-icmp_mobile_pam_m_bit_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		list - Parameter -icmp_mobile_pam_m_bit contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_mobile_pam_m_bit_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_mobile_pam_m_bit
			x                                                                                                                                                       		1 - enable tracking by icmp_mobile_pam_m_bit
			x                                                                                                                                               	-icmp_mobile_pam_o_bit
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure the "O Bit" bit for 'Mobile Prefix Advertisement Message' (-icmp_type 147) message type.
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		0 - bit is 0
			x                                                                                                                                                       		1 - bit is 1
			x                                                                                                                                               	-icmp_mobile_pam_o_bit_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		list - Parameter -icmp_mobile_pam_o_bit contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_mobile_pam_o_bit_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_mobile_pam_o_bit
			x                                                                                                                                                       		1 - enable tracking by icmp_mobile_pam_o_bit
			x                                                                                                                                               	-icmp_multicast_address
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure IPv6 Multicast address field for 'Multicast Listener Query Message Version 1' (-icmp_type 130), 'Multicast Listener Report Message Version 1' (-icmp_type 131), 'Multicast Listener Done Message' (-icmp_type 132) or 'Multicast Listener Query Message Version 2' (-icmp_type 130) message types.
			x                                                                                                                                               	-icmp_multicast_address_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_multicast_address is incremeneted or decremented when icmp_multicast_address_mode is incr or decr.
			x                                                                                                                                               	-icmp_multicast_address_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_multicast_address_step and icmp_multicast_address_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_multicast_address_step and icmp_multicast_address_count.
			x                                                                                                                                                       		list - Parameter -icmp_multicast_address contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_multicast_address_step
			x                                                                                                                                                   		Step value used to modify icmp_multicast_address when icmp_multicast_address_mode is incr or decr.
			x                                                                                                                                               	-icmp_multicast_address_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_multicast_address
			x                                                                                                                                                       		1 - enable tracking by icmp_multicast_address
			x                                                                                                                                               	-icmp_ndp_nam_o_flag
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure the "Override existing cache entry" flag for 'Neighbor Advertisement' (-icmp_type 136) message type.
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		0 - disable O-Flag
			x                                                                                                                                                       		1 - enable O-Flag
			x                                                                                                                                               	-icmp_ndp_nam_o_flag_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		list - Parameter -icmp_ndp_nam_o_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_ndp_nam_o_flag_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_ndp_nam_o_flag
			x                                                                                                                                                       		1 - enable tracking by icmp_ndp_nam_o_flag
			x                                                                                                                                               	-icmp_ndp_nam_r_flag
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure the "Router" flag for 'Neighbor Advertisement' (-icmp_type 136) message type.
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		0 - disable Router flag
			x                                                                                                                                                       		1 - enable Router flag
			x                                                                                                                                               	-icmp_ndp_nam_r_flag_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		list - Parameter -icmp_ndp_nam_r_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_ndp_nam_r_flag_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_ndp_nam_r_flag
			x                                                                                                                                                       		1 - enable tracking by icmp_ndp_nam_r_flag
			x                                                                                                                                               	-icmp_ndp_nam_s_flag
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure the "Neighbor Solicitation" flag for 'Neighbor Advertisement' (-icmp_type 136) message type.
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		0 - disable Neighbor Solicitation flag
			x                                                                                                                                                       		1 - enable Neighbor Solicitation flag
			x                                                                                                                                               	-icmp_ndp_nam_s_flag_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		list - Parameter -icmp_ndp_nam_s_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_ndp_nam_s_flag_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_ndp_nam_s_flag
			x                                                                                                                                                       		1 - enable tracking by icmp_ndp_nam_s_flag
			x                                                                                                                                               	-icmp_ndp_ram_h_flag
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure "Home Agent" flag for 'NDP Router Advertisement Message'
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		0 - disable H-Flag
			x                                                                                                                                                       		1 - enable H-Flag
			x                                                                                                                                               	-icmp_ndp_ram_h_flag_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		list - Parameter -icmp_ndp_ram_h_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_ndp_ram_h_flag_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_ndp_ram_h_flag
			x                                                                                                                                                       		1 - enable tracking by icmp_ndp_ram_h_flag
			x                                                                                                                                               	-icmp_ndp_ram_hop_limit
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure "Current hop limit" field (0-255) for 'NDP Router Advertisement Message' (-icmp_type 134) message type.
			x                                                                                                                                               	-icmp_ndp_ram_hop_limit_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_ndp_ram_hop_limit is incremeneted or decremented when icmp_ndp_ram_hop_limit_mode is incr or decr.
			x                                                                                                                                               	-icmp_ndp_ram_hop_limit_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_ndp_ram_hop_limit_step and icmp_ndp_ram_hop_limit_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_ndp_ram_hop_limit_step and icmp_ndp_ram_hop_limit_count.
			x                                                                                                                                                       		list - Parameter -icmp_ndp_ram_hop_limit contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_ndp_ram_hop_limit_step
			x                                                                                                                                                   		Step value used to modify icmp_ndp_ram_hop_limit when icmp_ndp_ram_hop_limit_mode is incr or decr.
			x                                                                                                                                               	-icmp_ndp_ram_hop_limit_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_ndp_ram_hop_limit
			x                                                                                                                                                       		1 - enable tracking by icmp_ndp_ram_hop_limit
			x                                                                                                                                               	-icmp_ndp_ram_m_flag
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure "Managed address configuration" flag for 'NDP Router Advertisement Message'
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		0 - disable M-Flag
			x                                                                                                                                                       		1 - enable M-Flag
			x                                                                                                                                               	-icmp_ndp_ram_m_flag_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		list - Parameter -icmp_ndp_ram_m_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_ndp_ram_m_flag_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_ndp_ram_m_flag
			x                                                                                                                                                       		1 - enable tracking by icmp_ndp_ram_m_flag
			x                                                                                                                                               	-icmp_ndp_ram_o_flag
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure "Other stateful configuration" flag for 'NDP Router Advertisement Message'
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		0 - disable O-Flag
			x                                                                                                                                                       		1 - enable O-Flag
			x                                                                                                                                               	-icmp_ndp_ram_o_flag_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		list - Parameter -icmp_ndp_ram_o_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_ndp_ram_o_flag_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_ndp_ram_o_flag
			x                                                                                                                                                       		1 - enable tracking by icmp_ndp_ram_o_flag
			x                                                                                                                                               	-icmp_ndp_ram_reachable_time
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure "Reachable time" field (0-4294967295) for 'NDP Router Advertisement Message' (-icmp_type 134) message type.
			x                                                                                                                                               	-icmp_ndp_ram_reachable_time_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_ndp_ram_reachable_time is incremeneted or decremented when icmp_ndp_ram_reachable_time_mode is incr or decr.
			x                                                                                                                                               	-icmp_ndp_ram_reachable_time_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_ndp_ram_reachable_time_step and icmp_ndp_ram_reachable_time_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_ndp_ram_reachable_time_step and icmp_ndp_ram_reachable_time_count.
			x                                                                                                                                                       		list - Parameter -icmp_ndp_ram_reachable_time contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_ndp_ram_reachable_time_step
			x                                                                                                                                                   		Step value used to modify icmp_ndp_ram_reachable_time when icmp_ndp_ram_reachable_time_mode is incr or decr.
			x                                                                                                                                               	-icmp_ndp_ram_reachable_time_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_ndp_ram_reachable_time
			x                                                                                                                                                       		1 - enable tracking by icmp_ndp_ram_reachable_time
			x                                                                                                                                               	-icmp_ndp_ram_retransmit_timer
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure "Retransmission timer" field (0-4294967295) for 'NDP Router Advertisement Message' (-icmp_type 134) message type.
			x                                                                                                                                               	-icmp_ndp_ram_retransmit_timer_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_ndp_ram_retransmit_timer is incremeneted or decremented when icmp_ndp_ram_retransmit_timer_mode is incr or decr.
			x                                                                                                                                               	-icmp_ndp_ram_retransmit_timer_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_ndp_ram_retransmit_timer_step and icmp_ndp_ram_retransmit_timer_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_ndp_ram_retransmit_timer_step and icmp_ndp_ram_retransmit_timer_count.
			x                                                                                                                                                       		list - Parameter -icmp_ndp_ram_retransmit_timer contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_ndp_ram_retransmit_timer_step
			x                                                                                                                                                   		Step value used to modify icmp_ndp_ram_retransmit_timer when icmp_ndp_ram_retransmit_timer_mode is incr or decr.
			x                                                                                                                                               	-icmp_ndp_ram_retransmit_timer_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_ndp_ram_retransmit_timer
			x                                                                                                                                                       		1 - enable tracking by icmp_ndp_ram_retransmit_timer
			x                                                                                                                                               	-icmp_ndp_ram_router_lifetime
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure "Router lifetime" field (0-65535) for 'NDP Router Advertisement Message' (-icmp_type 134) message type.
			x                                                                                                                                               	-icmp_ndp_ram_router_lifetime_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_ndp_ram_router_lifetime is incremeneted or decremented when icmp_ndp_ram_router_lifetime_mode is incr or decr.
			x                                                                                                                                               	-icmp_ndp_ram_router_lifetime_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_ndp_ram_router_lifetime_step and icmp_ndp_ram_router_lifetime_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_ndp_ram_router_lifetime_step and icmp_ndp_ram_router_lifetime_count.
			x                                                                                                                                                       		list - Parameter -icmp_ndp_ram_router_lifetime contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_ndp_ram_router_lifetime_step
			x                                                                                                                                                   		Step value used to modify icmp_ndp_ram_router_lifetime when icmp_ndp_ram_router_lifetime_mode is incr or decr.
			x                                                                                                                                               	-icmp_ndp_ram_router_lifetime_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_ndp_ram_router_lifetime
			x                                                                                                                                                       		1 - enable tracking by icmp_ndp_ram_router_lifetime
			x                                                                                                                                               	-icmp_ndp_rm_dest_addr
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure the IPv6 "Destination address" field for 'NDP Redirect' (-icmp_type 137) message type.
			x                                                                                                                                               	-icmp_ndp_rm_dest_addr_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_ndp_rm_dest_addr is incremeneted or decremented when icmp_ndp_rm_dest_addr_mode is incr or decr.
			x                                                                                                                                               	-icmp_ndp_rm_dest_addr_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_ndp_rm_dest_addr_step and icmp_ndp_rm_dest_addr_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_ndp_rm_dest_addr_step and icmp_ndp_rm_dest_addr_count.
			x                                                                                                                                                       		list - Parameter -icmp_ndp_rm_dest_addr contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_ndp_rm_dest_addr_step
			x                                                                                                                                                   		Step value used to modify icmp_ndp_rm_dest_addr when icmp_ndp_rm_dest_addr_mode is incr or decr.
			x                                                                                                                                               	-icmp_ndp_rm_dest_addr_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_ndp_rm_dest_addr
			x                                                                                                                                                       		1 - enable tracking by icmp_ndp_rm_dest_addr
			x                                                                                                                                               	-icmp_param_problem_message_pointer
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure 'Pointer' field for 'Parameter Problem' message (-icmp_type 4).
			x                                                                                                                                               	-icmp_param_problem_message_pointer_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_param_problem_message_pointer is incremeneted or decremented when icmp_param_problem_message_pointer_mode is incr or decr.
			x                                                                                                                                               	-icmp_param_problem_message_pointer_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_param_problem_message_pointer_step and icmp_param_problem_message_pointer_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_param_problem_message_pointer_step and icmp_param_problem_message_pointer_count.
			x                                                                                                                                                       		list - Parameter -icmp_param_problem_message_pointer contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_param_problem_message_pointer_step
			x                                                                                                                                                   		Step value used to modify icmp_param_problem_message_pointer when icmp_param_problem_message_pointer_mode is incr or decr.
			x                                                                                                                                               	-icmp_param_problem_message_pointer_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_param_problem_message_pointer
			x                                                                                                                                                       		1 - enable tracking by icmp_param_problem_message_pointer
			x                                                                                                                                               	-icmp_pkt_too_big_mtu
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure MTU for 'Packet Too Big' messages (-icmp_type 2)
			x                                                                                                                                               	-icmp_pkt_too_big_mtu_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_pkt_too_big_mtu is incremeneted or decremented when icmp_pkt_too_big_mtu_mode is incr or decr.
			x                                                                                                                                               	-icmp_pkt_too_big_mtu_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_pkt_too_big_mtu_step and icmp_pkt_too_big_mtu_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_pkt_too_big_mtu_step and icmp_pkt_too_big_mtu_count.
			x                                                                                                                                                       		list - Parameter -icmp_pkt_too_big_mtu contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_pkt_too_big_mtu_step
			x                                                                                                                                                   		Step value used to modify icmp_pkt_too_big_mtu when icmp_pkt_too_big_mtu_mode is incr or decr.
			x                                                                                                                                               	-icmp_pkt_too_big_mtu_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_pkt_too_big_mtu
			x                                                                                                                                                       		1 - enable tracking by icmp_pkt_too_big_mtu
			x                                                                                                                                               	-icmp_seq_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_seq is incremeneted or decremented when icmp_seq_mode is incr or decr.
			x                                                                                                                                               	-icmp_seq_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_seq_step and icmp_seq_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_seq_step and icmp_seq_count.
			x                                                                                                                                                       		list - Parameter -icmp_seq contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_seq_step
			x                                                                                                                                                   		Step value used to modify icmp_seq when icmp_seq_mode is incr or decr.
			x                                                                                                                                               	-icmp_seq_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_seq
			x                                                                                                                                                       		1 - enable tracking by icmp_seq
			x                                                                                                                                               	-icmp_target_addr
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure the IPv6 "Target address" field for 'Neighbor Solicitation' (-icmp_type 135), 'Neighbor Advertisement' (-icmp_type 136), 'NDP Redirect' (-icmp_type 137) message types.
			x                                                                                                                                               	-icmp_target_addr_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_target_addr is incremeneted or decremented when icmp_target_addr_mode is incr or decr.
			x                                                                                                                                               	-icmp_target_addr_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_target_addr_step and icmp_target_addr_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_target_addr_step and icmp_target_addr_count.
			x                                                                                                                                                       		list - Parameter -icmp_target_addr contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_target_addr_step
			x                                                                                                                                                   		Step value used to modify icmp_target_addr when icmp_target_addr_mode is incr or decr.
			x                                                                                                                                               	-icmp_target_addr_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_target_addr
			x                                                                                                                                                       		1 - enable tracking by icmp_target_addr
			x                                                                                                                                               	-icmp_type_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_type is incremeneted or decremented when icmp_type_mode is incr or decr.
			x                                                                                                                                               	-icmp_type_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_type_step and icmp_type_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_type_step and icmp_type_count.
			x                                                                                                                                                       		list - Parameter -icmp_type contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_type_step
			x                                                                                                                                                   		Step value used to modify icmp_type when icmp_type_mode is incr or decr.
			x                                                                                                                                               	-icmp_type_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_type
			x                                                                                                                                                       		1 - enable tracking by icmp_type
			x                                                                                                                                               	-icmp_unused
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540 and ICMPv6. Configure 4 byte HEX "Unused" field for 'Destination Unreachable' (-icmp_type 2), 'Time Exceeded' (-icmp_type 3) message types.
			x                                                                                                                                               	-icmp_unused_count
			x                                                                                                                                                   		Numeric value which configures the number of times the icmp_unused is incremeneted or decremented when icmp_unused_mode is incr or decr.
			x                                                                                                                                               	-icmp_unused_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with icmp_unused_step and icmp_unused_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with icmp_unused_step and icmp_unused_count.
			x                                                                                                                                                       		list - Parameter -icmp_unused contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-icmp_unused_step
			x                                                                                                                                                   		Step value used to modify icmp_unused when icmp_unused_mode is incr or decr.
			x                                                                                                                                               	-icmp_unused_tracking
			x                                                                                                                                                       		0 - disable tracking by icmp_unused
			x                                                                                                                                                       		1 - enable tracking by icmp_unused
			x                                                                                                                                               	-igmp_aux_data_length
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540, l4_protocol igmp, IGMPv3.Configure the Auxiliary data length field (0-255) from the Group Record. Use a list of values when configuring multiple Group Records.
			x                                                                                                                                               	-igmp_aux_data_length_count
			x                                                                                                                                                   		Numeric value which configures the number of times the igmp_aux_data_length is incremeneted or decremented when igmp_aux_data_length_mode is incr or decr.
			x                                                                                                                                               	-igmp_aux_data_length_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with igmp_aux_data_length_step and igmp_aux_data_length_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with igmp_aux_data_length_step and igmp_aux_data_length_count.
			x                                                                                                                                               	-igmp_aux_data_length_step
			x                                                                                                                                                   		Step value used to modify igmp_aux_data_length when igmp_aux_data_length_mode is incr or decr.
			x                                                                                                                                               	-igmp_aux_data_length_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_aux_data_length
			x                                                                                                                                                       		1 - enable tracking by igmp_aux_data_length
			x                                                                                                                                               	-igmp_checksum
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540, l4_protocol igmp, igmp_valid_checksum 0.Configure 2 byte HEX Checksum field for IGMP message.
			x                                                                                                                                               	-igmp_checksum_count
			x                                                                                                                                                   		Numeric value which configures the number of times the igmp_checksum is incremeneted or decremented when igmp_checksum_mode is incr or decr.
			x                                                                                                                                               	-igmp_checksum_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with igmp_checksum_step and igmp_checksum_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with igmp_checksum_step and igmp_checksum_count.
			x                                                                                                                                                       		list - Parameter -igmp_checksum contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-igmp_checksum_step
			x                                                                                                                                                   		Step value used to modify igmp_checksum when igmp_checksum_mode is incr or decr.
			x                                                                                                                                               	-igmp_checksum_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_checksum
			x                                                                                                                                                       		1 - enable tracking by igmp_checksum
			x                                                                                                                                               	-igmp_data_v3r
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540, l4_protocol igmp, IGMPv3 Membership Report.Configure the data in auxiliary data field (HEX). Use a list of values when configuring multiple Group records.
			x                                                                                                                                               	-igmp_data_v3r_count
			x                                                                                                                                                   		Numeric value which configures the number of times the igmp_data_v3r is incremeneted or decremented when igmp_data_v3r_mode is incr or decr.
			x                                                                                                                                               	-igmp_data_v3r_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with igmp_data_v3r_step and igmp_data_v3r_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with igmp_data_v3r_step and igmp_data_v3r_count.
			x                                                                                                                                               	-igmp_data_v3r_step
			x                                                                                                                                                   		Step value used to modify igmp_data_v3r when igmp_data_v3r_mode is incr or decr.
			x                                                                                                                                               	-igmp_data_v3r_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_data_v3r
			x                                                                                                                                                       		1 - enable tracking by igmp_data_v3r
			x                                                                                                                                               	-igmp_group_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_group_addr
			x                                                                                                                                                       		1 - enable tracking by igmp_group_addr
			x                                                                                                                                               	-igmp_length_v3r
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540, l4_protocol igmp, IGMPv3 Membership Report.Configure the length of the data from the auxiliary data field (0-255). Use a list of values when configuring multiple Group Records.
			x                                                                                                                                               	-igmp_length_v3r_count
			x                                                                                                                                                   		Numeric value which configures the number of times the igmp_length_v3r is incremeneted or decremented when igmp_length_v3r_mode is incr or decr.
			x                                                                                                                                               	-igmp_length_v3r_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with igmp_length_v3r_step and igmp_length_v3r_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with igmp_length_v3r_step and igmp_length_v3r_count.
			x                                                                                                                                               	-igmp_length_v3r_step
			x                                                                                                                                                   		Step value used to modify igmp_length_v3r when igmp_length_v3r_mode is incr or decr.
			x                                                                                                                                               	-igmp_length_v3r_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_length_v3r
			x                                                                                                                                                       		1 - enable tracking by igmp_length_v3r
			x                                                                                                                                               	-igmp_max_response_time_count
			x                                                                                                                                                   		Numeric value which configures the number of times the igmp_max_response_time is incremeneted or decremented when igmp_max_response_time_mode is incr or decr.
			x                                                                                                                                               	-igmp_max_response_time_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with igmp_max_response_time_step and igmp_max_response_time_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with igmp_max_response_time_step and igmp_max_response_time_count.
			x                                                                                                                                                       		list - Parameter -igmp_max_response_time contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-igmp_max_response_time_step
			x                                                                                                                                                   		Step value used to modify igmp_max_response_time when igmp_max_response_time_mode is incr or decr.
			x                                                                                                                                               	-igmp_max_response_time_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_max_response_time
			x                                                                                                                                                       		1 - enable tracking by igmp_max_response_time
			x                                                                                                                                               	-igmp_msg_type_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_msg_type
			x                                                                                                                                                       		1 - enable tracking by igmp_msg_type
			x                                                                                                                                               	-igmp_multicast_src_count
			x                                                                                                                                                   		Numeric value which configures the number of times the igmp_multicast_src is incremeneted or decremented when igmp_multicast_src_mode is incr or decr.
			x                                                                                                                                               	-igmp_multicast_src_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with igmp_multicast_src_step and igmp_multicast_src_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with igmp_multicast_src_step and igmp_multicast_src_count.
			x                                                                                                                                               	-igmp_multicast_src_step
			x                                                                                                                                                   		Step value used to modify igmp_multicast_src when igmp_multicast_src_mode is incr or decr.
			x                                                                                                                                               	-igmp_multicast_src_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_multicast_src
			x                                                                                                                                                       		1 - enable tracking by igmp_multicast_src
			x                                                                                                                                               	-igmp_qqic_count
			x                                                                                                                                                   		Numeric value which configures the number of times the igmp_qqic is incremeneted or decremented when igmp_qqic_mode is incr or decr.
			x                                                                                                                                               	-igmp_qqic_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with igmp_qqic_step and igmp_qqic_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with igmp_qqic_step and igmp_qqic_count.
			x                                                                                                                                                       		list - Parameter -igmp_qqic contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-igmp_qqic_step
			x                                                                                                                                                   		Step value used to modify igmp_qqic when igmp_qqic_mode is incr or decr.
			x                                                                                                                                               	-igmp_qqic_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_qqic
			x                                                                                                                                                       		1 - enable tracking by igmp_qqic
			x                                                                                                                                               	-igmp_qrv_count
			x                                                                                                                                                   		Numeric value which configures the number of times the igmp_qrv is incremeneted or decremented when igmp_qrv_mode is incr or decr.
			x                                                                                                                                               	-igmp_qrv_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with igmp_qrv_step and igmp_qrv_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with igmp_qrv_step and igmp_qrv_count.
			x                                                                                                                                                       		list - Parameter -igmp_qrv contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-igmp_qrv_step
			x                                                                                                                                                   		Step value used to modify igmp_qrv when igmp_qrv_mode is incr or decr.
			x                                                                                                                                               	-igmp_qrv_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_qrv
			x                                                                                                                                                       		1 - enable tracking by igmp_qrv
			x                                                                                                                                               	-igmp_record_type_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with igmp_record_type_step and igmp_record_type_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with igmp_record_type_step and igmp_record_type_count.
			x                                                                                                                                               	-igmp_record_type_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_record_type
			x                                                                                                                                                       		1 - enable tracking by igmp_record_type
			x                                                                                                                                               	-igmp_reserved_v3q
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540, l4_protocol igmp for IGMPv3 Membership Query Messages. Configure the reserved field (0-15).
			x                                                                                                                                               	-igmp_reserved_v3q_count
			x                                                                                                                                                   		Numeric value which configures the number of times the igmp_reserved_v3q is incremeneted or decremented when igmp_reserved_v3q_mode is incr or decr.
			x                                                                                                                                               	-igmp_reserved_v3q_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with igmp_reserved_v3q_step and igmp_reserved_v3q_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with igmp_reserved_v3q_step and igmp_reserved_v3q_count.
			x                                                                                                                                                       		list - Parameter -igmp_reserved_v3q contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-igmp_reserved_v3q_step
			x                                                                                                                                                   		Step value used to modify igmp_reserved_v3q when igmp_reserved_v3q_mode is incr or decr.
			x                                                                                                                                               	-igmp_reserved_v3q_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_reserved_v3q
			x                                                                                                                                                       		1 - enable tracking by igmp_reserved_v3q
			x                                                                                                                                               	-igmp_reserved_v3r1
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540, l4_protocol igmp for IGMPv3 Membership Report Messages. Configure the reserved1 field (0-255).
			x                                                                                                                                               	-igmp_reserved_v3r1_count
			x                                                                                                                                                   		Numeric value which configures the number of times the igmp_reserved_v3r1 is incremeneted or decremented when igmp_reserved_v3r1_mode is incr or decr.
			x                                                                                                                                               	-igmp_reserved_v3r1_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with igmp_reserved_v3r1_step and igmp_reserved_v3r1_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with igmp_reserved_v3r1_step and igmp_reserved_v3r1_count.
			x                                                                                                                                                       		list - Parameter -igmp_reserved_v3r1 contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-igmp_reserved_v3r1_step
			x                                                                                                                                                   		Step value used to modify igmp_reserved_v3r1 when igmp_reserved_v3r1_mode is incr or decr.
			x                                                                                                                                               	-igmp_reserved_v3r1_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_reserved_v3r1
			x                                                                                                                                                       		1 - enable tracking by igmp_reserved_v3r1
			x                                                                                                                                               	-igmp_reserved_v3r2
			x                                                                                                                                                   		Valid only for traffic_generator ixnetwork_540, l4_protocol igmp for IGMPv3 Membership Report Messages. Configure the reserved2 field (0-65535).
			x                                                                                                                                               	-igmp_reserved_v3r2_count
			x                                                                                                                                                   		Numeric value which configures the number of times the igmp_reserved_v3r2 is incremeneted or decremented when igmp_reserved_v3r2_mode is incr or decr.
			x                                                                                                                                               	-igmp_reserved_v3r2_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with igmp_reserved_v3r2_step and igmp_reserved_v3r2_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with igmp_reserved_v3r2_step and igmp_reserved_v3r2_count.
			x                                                                                                                                                       		list - Parameter -igmp_reserved_v3r2 contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-igmp_reserved_v3r2_step
			x                                                                                                                                                   		Step value used to modify igmp_reserved_v3r2 when igmp_reserved_v3r2_mode is incr or decr.
			x                                                                                                                                               	-igmp_reserved_v3r2_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_reserved_v3r2
			x                                                                                                                                                       		1 - enable tracking by igmp_reserved_v3r2
			x                                                                                                                                               	-igmp_s_flag_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		list - Parameter -igmp_s_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-igmp_s_flag_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_s_flag
			x                                                                                                                                                       		1 - enable tracking by igmp_s_flag
			x                                                                                                                                               	-igmp_unused
			x                                                                                                                                                   		Configure 1 byte HEX IGMPv1 Unused field when traffic_genrator is ixnetwork_540 andigmp_version is 1.
			x                                                                                                                                               	-igmp_unused_count
			x                                                                                                                                                   		Numeric value which configures the number of times the igmp_unused is incremeneted or decremented when igmp_unused_mode is incr or decr.
			x                                                                                                                                               	-igmp_unused_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with igmp_unused_step and igmp_unused_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with igmp_unused_step and igmp_unused_count.
			x                                                                                                                                                       		list - Parameter -igmp_unused contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-igmp_unused_step
			x                                                                                                                                                   		Step value used to modify igmp_unused when igmp_unused_mode is incr or decr.
			x                                                                                                                                               	-igmp_unused_tracking
			x                                                                                                                                                       		0 - disable tracking by igmp_unused
			x                                                                                                                                                       		1 - enable tracking by igmp_unused
			x                                                                                                                                               	-indirect
			x                                                                                                                                                   		This option can be used to specify whether a LAN static endpoint is going to be connected through an ATM or Frame Relay endpoint or not. This option is available only when using the ixnetwork traffic generator for L2VPN traffic.
			x                                                                                                                                               	-inner_ip_dst_addr
			x                                                                                                                                                   		Destination IP address for inner GRE IPv4 header.
			x                                                                                                                                               	-inner_ip_dst_count
			x                                                                                                                                                   		Number of destination IP addresses when option "-inner_ip_dst_mode" is set to increment or decrement. When traffic_generator is ixos the maximum value is 4294967295. When traffic_generator is ixnetwork_540 the maximum value is 2147483647.
			x                                                                                                                                               	-inner_ip_dst_mode
			x                                                                                                                                                   		Destination IP address mode for inner GRE IPv4 header.
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed- The destination IP address is the same for all packets.
			x                                                                                                                                                       		increment-The destination IP address increments.
			x                                                                                                                                                       		decrement-The destination IP address decrements.
			x                                                                                                                                                       		random-The destination IP address is random. With traffic_generator ixnetwork_540 this will be silently ignored and configured to 'fixed'.list - Parameter -inner_ip_dst_addr contains a list of values. Each packet will use one of the values from the list. Valid only for traffic_generator ixnetwork_540.
			x                                                                                                                                               	-inner_ip_dst_step
			x                                                                                                                                                   		The modifier for the increment and decrement choices of "-inner_ip_dst_mode". When traffic_generator is ixnetwork_540 it is required that only one field contain a non-zero value.
			x                                                                                                                                               	-inner_ip_dst_tracking
			x                                                                                                                                                       		0 - disable tracking by inner_ip_dst_addr.
			x                                                                                                                                                       		1 - enable tracking by inner_ip_dst_addr.
			x                                                                                                                                               	-inner_ip_src_addr
			x                                                                                                                                                   		Source IP address for inner GRE IPv4 header. Valid only for traffic_generator ixos/ixnetworK_540.
			x                                                                                                                                               	-inner_ip_src_count
			x                                                                                                                                                   		Number of source IP addresses when option "inner_ip_src_mode" is set to increment or decrement. When traffic_generator is ixos the maximum value is 4294967295. When traffic_generator is ixnetwork_540 the maximum value is 2147483647.
			x                                                                                                                                               	-inner_ip_src_mode
			x                                                                                                                                                   		Source IP address mode for inner GRE IPv4 header.
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed-The source IP address is the same for all packets.
			x                                                                                                                                                       		increment-The source IP address increments.
			x                                                                                                                                                       		decrement-The source IP address decrements.
			x                                                                                                                                                       		random- The source IP address is random. With traffic_generator ixnetwork_540 this will be silently ignored and configured to 'fixed'.
			x                                                                                                                                                       		list-Parameter -inner_ip_src_addr contains a list of values. Each packet will use one of the values from the list. Valid only for traffic_generator ixnetwork_540.
			x                                                                                                                                               	-inner_ip_src_step
			x                                                                                                                                                   		The modifier for the increment and decrement choices of inner_ip_src_mode which requires that only one field contain a non-zero value.
			x                                                                                                                                               	-inner_ip_src_tracking
			x                                                                                                                                                       		0 - disable tracking by inner_ip_src_addr.
			x                                                                                                                                                       		1 - enable tracking by inner_ip_src_addr.
			x                                                                                                                                               	-inner_ipv6_dst_addr
			x                                                                                                                                                   		Destination IP address for inner GRE IPv6 header.
			x                                                                                                                                               	-inner_ipv6_dst_count
			x                                                                                                                                                   		Number of destination IPv6 addresses when option "inner_ipv6_dst_mode" is set to increment or decrement. When traffic_generator is ixos the maximum value is 4294967295. When traffic_generator is ixnetwork_540 the maximum value is 2147483647.
			x                                                                                                                                               	-inner_ipv6_dst_mask
			x                                                                                                                                                   		Specify IPv6 mask to be used for inner_ipv6_dst_addr to increment. This parameter is ignored with traffic_generator ixnetwork_540. Incrementing and decrementing can be done with any step value with traffic_generator ixnetwork_540.Default value is specific to the inner_ipv6_dst_mode as follows:incr_global_top_level decr_global_top_level: Default 4incr_global_next_level decr_global_next_level: Default 24incr_global_site_level decr_global_site_level incr_local_site_subnet decr_local_site_subnet: Default 48incr_mcast_group decr_mcast_group: Default 96incr_host decr_host incr_intf_id decr_intf_id: Default 96incr_network decr_network: Default 96inner_ipv6_dst_mode specifies how and if the inner_ipv6_dst_addr is incremented.The inner_ipv6_dst_mode depends on the IPv6 address type specified with inner_ipv6_dst_addr parameter.Each inner_ipv6_dst_mode allows a mask from a Mask range to be configured.The mask is configured using the inner_ipv6_dst_mask attributeThe step used for incrementing or decrementing is configued using the inner_ipv6_dst_step attribute which has the form of an IPv6 address.The inner_ipv6_dst_mask attribute specifies which part of the inner_ipv6_dst_step address is used for incrementing as follows:Mask range 4-4, incr_global_top_level decr_global_top_level: xxxx::0Mask range 24-24, incr_global_next_level decr_global_next_level: 0:0xx:xxxx::0Mask range 48-48, incr_global_site_level decr_global_site_level incr_local_site_subnet decr_local_site_subnet: 0:0:0:xxxx::0Mask range 96-96, incr_mcast_group decr_mcast_group: 0::xxxx:xxxxMask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx:xxxx (when mask is 96)Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx(when mask is 112)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0:0 (when mask is 96)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0(when mask is 112)HEX values marked with 'x' in the format above are the inner_ipv6_dst_step HEX values that are used for increment or decrement; HEX values marked with '0' are ignored.
			x                                                                                                                                               	-inner_ipv6_dst_mode
			x                                                                                                                                                   		Destination IPv6 address mode. Valid only for traffic_generator ixos/ixnetwork_540.The following is valid only for traffic_generator ixnetwork_540:Valid options are:incrementdecrementfixedlistFor backwards compatibility all modes starting with 'incr' will be configured as increment and all modes starting with 'decr' will be configured as decrement. Incrementing and decrementing depends only on inner_ipv6_dst_step and inner_ipv6_dst_count.The following is valid only for traffic_generator ixos: inner_ipv6_dst_mode specifies how and if the inner_ipv6_dst_addr is incremented.The inner_ipv6_dst_mode depends on the IPv6 address type specified with inner_ipv6_dst_addr parameter.Each inner_ipv6_dst_mode allows a mask from a Mask range to be configured.The mask is configured using the inner_ipv6_dst_mask attributeThe step used for incrementing or decrementing is configued using the inner_ipv6_dst_step attribute which has the form of an IPv6 address.The inner_ipv6_dst_mask attribute specifies which part of the inner_ipv6_dst_step address is used for incrementing as follows:Mask range 4-4, incr_global_top_level decr_global_top_level: xxxx::0Mask range 24-24, incr_global_next_level decr_global_next_level: 0:0xx:xxxx::0Mask range 48-48, incr_global_site_level decr_global_site_level incr_local_site_subnet decr_local_site_subnet: 0:0:0:xxxx::0Mask range 96-96, incr_mcast_group decr_mcast_group: 0::xxxx:xxxxMask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx:xxxx (when mask is 96)Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx(when mask is 112)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0:0 (when mask is 96)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0(when mask is 112)HEX values marked with 'x' in the format above are the inner_ipv6_dst_step HEX values that are used for increment or decrement; HEX values marked with '0' are ignored.The step is limited to a 32 bit counter. Example:inner_ipv6_dst_mode incr_networkinner_ipv6_dst_mask 64inner_ipv6_dst_step address portion that is used for incrementing will be:0000:0000:xxxx:xxxx:0000:0000:00000:000032bit limitNetwork Mask 640000:0000:xxxx:xxxx is the mask.0000:0000 is the 32 bits that will NOT be incremented because of the limitation.xxxx:xxxx is what gets incremented.
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		type - User Defined
			x                                                                                                                                                       		address - Mask range 0-128
			x                                                                                                                                                       		value - Mask range 0-128
			x                                                                                                                                                       		Reserved - .
			x                                                                                                                                                       		Allocation - .
			x                                                                                                                                                       		Addresses - .
			x                                                                                                                                                       		ID - Mask range 96-128
			x                                                                                                                                               	-inner_ipv6_dst_step
			x                                                                                                                                                   		Step size of the IPv6 addresseswhen option "inner_ipv6_dst_mode" is set to increment or decrement. The following is valid only for traffic_generator ixnetwork_540:Any IPv6 step is accepted. Incrementing and decrementing depends only on inner_ipv6_dst_step and inner_ipv6_dst_count.The following is valid only for traffic_generator ixos:inner_ipv6_dst_mode specifies how and if the inner_ipv6_dst_addr is incremented.The inner_ipv6_dst_mode depends on the IPv6 address type specified with inner_ipv6_dst_addr parameter.Each inner_ipv6_dst_mode allows a mask from a Mask range to be configured.The mask is configured using the inner_ipv6_dst_mask attributeThe step used for incrementing or decrementing is configued using the inner_ipv6_dst_step attribute which has the form of an IPv6 address.The inner_ipv6_dst_mask attribute specifies which part of the inner_ipv6_dst_step address is used for incrementing as follows:Mask range 4-4, incr_global_top_level decr_global_top_level: xxxx::0Mask range 24-24, incr_global_next_level decr_global_next_level: 0:0xx:xxxx::0Mask range 48-48, incr_global_site_level decr_global_site_level incr_local_site_subnet decr_local_site_subnet: 0:0:0:xxxx::0Mask range 96-96, incr_mcast_group decr_mcast_group: 0::xxxx:xxxxMask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx:xxxx (when mask is 96)Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx(when mask is 112)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0:0 (when mask is 96)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0(when mask is 112)HEX values marked with 'x' in the format above are the inner_ipv6_dst_step HEX values that are used for increment or decrement; HEX values marked with '0' are ignored.
			x                                                                                                                                               	-inner_ipv6_dst_tracking
			x                                                                                                                                                       		0 - disable tracking by inner_ipv6_dst_addr
			x                                                                                                                                                       		1 - enable tracking by inner_ipv6_dst_addr
			x                                                                                                                                               	-inner_ipv6_flow_label
			x                                                                                                                                                   		Flow label value of the IPv6 inner header.
			x                                                                                                                                               	-inner_ipv6_flow_label_count
			x                                                                                                                                                   		Numeric value which configures the number of times the inner_ipv6_flow_label is incremeneted or decremented when inner_ipv6_flow_label_mode is incr or decr.
			x                                                                                                                                               	-inner_ipv6_flow_label_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with inner_ipv6_flow_label_step and inner_ipv6_flow_label_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with inner_ipv6_flow_label_step and inner_ipv6_flow_label_count.
			x                                                                                                                                                       		list - Parameter -inner_ipv6_flow_label contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-inner_ipv6_flow_label_step
			x                                                                                                                                                   		Step value used to modify inner_ipv6_flow_label when inner_ipv6_flow_label_mode is incr or decr.
			x                                                                                                                                               	-inner_ipv6_flow_label_tracking
			x                                                                                                                                                       		0 - disable tracking by inner_ipv6_flow_label
			x                                                                                                                                                       		1 - enable tracking by inner_ipv6_flow_label
			x                                                                                                                                               	-inner_ipv6_frag_id
			x                                                                                                                                                   		Identification field in the fragment extension header of an IPv6 header.
			x                                                                                                                                               	-inner_ipv6_frag_id_count
			x                                                                                                                                                   		Numeric value which configures the number of times the inner_ipv6_frag_id is incremeneted or decremented when inner_ipv6_frag_id_mode is incr or decr.
			x                                                                                                                                               	-inner_ipv6_frag_id_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with inner_ipv6_frag_id_step and inner_ipv6_frag_id_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with inner_ipv6_frag_id_step and inner_ipv6_frag_id_count.
			x                                                                                                                                                       		list - Parameter -inner_ipv6_frag_id contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-inner_ipv6_frag_id_step
			x                                                                                                                                                   		Step value used to modify inner_ipv6_frag_id when inner_ipv6_frag_id_mode is incr or decr.
			x                                                                                                                                               	-inner_ipv6_frag_id_tracking
			x                                                                                                                                                       		0 - disable tracking by inner_ipv6_frag_id
			x                                                                                                                                                       		1 - enable tracking by inner_ipv6_frag_id
			x                                                                                                                                               	-inner_ipv6_frag_more_flag
			x                                                                                                                                                   		Whether the M Flag in the fragment extension header of an IPv6 header is set.
			x                                                                                                                                               	-inner_ipv6_frag_more_flag_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		list - Parameter -inner_ipv6_frag_more_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-inner_ipv6_frag_more_flag_tracking
			x                                                                                                                                                       		0 - disable tracking by inner_ipv6_frag_more_flag
			x                                                                                                                                                       		1 - enable tracking by inner_ipv6_frag_more_flag
			x                                                                                                                                               	-inner_ipv6_frag_offset
			x                                                                                                                                                   		Fragment offset in the fragment extension header of an IPv6 header.
			x                                                                                                                                               	-inner_ipv6_frag_offset_count
			x                                                                                                                                                   		Numeric value which configures the number of times the inner_ipv6_frag_offset is incremeneted or decremented when inner_ipv6_frag_offset_mode is incr or decr.
			x                                                                                                                                               	-inner_ipv6_frag_offset_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with inner_ipv6_frag_offset_step and inner_ipv6_frag_offset_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with inner_ipv6_frag_offset_step and inner_ipv6_frag_offset_count.
			x                                                                                                                                                       		list - Parameter -inner_ipv6_frag_offset contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-inner_ipv6_frag_offset_step
			x                                                                                                                                                   		Step value used to modify inner_ipv6_frag_offset when inner_ipv6_frag_offset_mode is incr or decr.
			x                                                                                                                                               	-inner_ipv6_frag_offset_tracking
			x                                                                                                                                                       		0 - disable tracking by inner_ipv6_frag_offset
			x                                                                                                                                                       		1 - enable tracking by inner_ipv6_frag_offset
			x                                                                                                                                               	-inner_ipv6_hop_limit
			x                                                                                                                                                   		Hop limit value of the IPv6 inner header.
			x                                                                                                                                               	-inner_ipv6_hop_limit_count
			x                                                                                                                                                   		Numeric value which configures the number of times the inner_ipv6_hop_limit is incremeneted or decremented when inner_ipv6_hop_limit_mode is incr or decr.
			x                                                                                                                                               	-inner_ipv6_hop_limit_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with inner_ipv6_hop_limit_step and inner_ipv6_hop_limit_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with inner_ipv6_hop_limit_step and inner_ipv6_hop_limit_count.
			x                                                                                                                                                       		list - Parameter -inner_ipv6_hop_limit contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-inner_ipv6_hop_limit_step
			x                                                                                                                                                   		Step value used to modify inner_ipv6_hop_limit when inner_ipv6_hop_limit_mode is incr or decr.
			x                                                                                                                                               	-inner_ipv6_hop_limit_tracking
			x                                                                                                                                                       		0 - disable tracking by inner_ipv6_hop_limit
			x                                                                                                                                                       		1 - enable tracking by inner_ipv6_hop_limit
			x                                                                                                                                               	-inner_ipv6_src_addr
			x                                                                                                                                                   		Source IP address for inner GRE IPv6 header.
			x                                                                                                                                               	-inner_ipv6_src_count
			x                                                                                                                                                   		Number of source IP address when option "inner_ipv6_src_mode" is set to increment or decrement. When traffic_generator is ixos the maximum value is 4294967295. When traffic_generator is ixnetwork_540 the maximum value is 2147483647.
			x                                                                                                                                               	-inner_ipv6_src_mask
			x                                                                                                                                                   		This parameter is ignored with traffic_generator ixnetwork_540. Incrementing and decrementing can be done with any step value with traffic_generator ixnetwork_540.Specify IPv6 mask to be used for inner_ipv6_src_addr to increment. Default value is minimum value specified in inner_ipv6_dst_mode (it depends on address type and increment mode).inner_ipv6_src_mode specifies how and if the inner_ipv6_src_addr is incremented.The inner_ipv6_src_mode depends on the IPv6 address type specified with inner_ipv6_src_addr parameter.Each inner_ipv6_src_mode allows a mask from a Mask range to be configured.The mask is configured using the inner_ipv6_src_mask attributeThe step used for incrementing or decrementing is configued using the inner_ipv6_src_step attribute which has the form of an IPv6 address.The inner_ipv6_src_mask attribute specifies which part of the inner_ipv6_src_step address is used for incrementing as follows:Mask range 4-4, incr_global_top_level decr_global_top_level: xxxx::0Mask range 24-24, incr_global_next_level decr_global_next_level: 0:0xx:xxxx::0Mask range 48-48, incr_global_site_level decr_global_site_level incr_local_site_subnet decr_local_site_subnet: 0:0:0:xxxx::0Mask range 96-96, incr_mcast_group decr_mcast_group: 0::xxxx:xxxxMask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx:xxxx (when mask is 96)Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx(when mask is 112)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0:0 (when mask is 96)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0(when mask is 112)HEX values marked with 'x' in the format above are the inner_ipv6_src_step HEX values that are used for increment or decrement; HEX values marked with '0' are ignored.
			x                                                                                                                                               	-inner_ipv6_src_mode
			x                                                                                                                                                   		Source IP address mode for inner GRE IPv6 header. The following is valid only for traffic_generator ixnetwork_540:Valid options are:incrementdecrementfixedlistFor backwards compatibility all modes starting with 'incr' will be configured as increment and all modes starting with 'decr' will be configured as decrement. Incrementing and decrementing depends only on ipv6_src_step and ipv6_src_count.The following is valid only for traffic_generator ixos: inner_ipv6_src_mode specifies how and if the inner_ipv6_src_addr is incremented.The inner_ipv6_src_mode depends on the IPv6 address type specified with inner_ipv6_src_addr parameter.Each inner_ipv6_src_mode allows a mask from a Mask range to be configured.The mask is configured using the inner_ipv6_src_mask attributeThe step used for incrementing or decrementing is configued using the inner_ipv6_src_step attribute which has the form of an IPv6 address.The inner_ipv6_src_mask attribute specifies which part of the inner_ipv6_src_step address is used for incrementing as follows:Mask range 4-4, incr_global_top_level decr_global_top_level: xxxx::0Mask range 24-24, incr_global_next_level decr_global_next_level: 0:0xx:xxxx::0Mask range 48-48, incr_global_site_level decr_global_site_level incr_local_site_subnet decr_local_site_subnet: 0:0:0:xxxx::0Mask range 96-96, incr_mcast_group decr_mcast_group: 0::xxxx:xxxxMask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx:xxxx (when mask is 96)Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx(when mask is 112)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0:0 (when mask is 96)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0(when mask is 112)HEX values marked with 'x' in the format above are the inner_ipv6_src_step HEX values that are used for increment or decrement; HEX values marked with '0' are ignored.
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		type - User Defined
			x                                                                                                                                                       		address - Mask range 0-128
			x                                                                                                                                                       		value - Mask range 0-128
			x                                                                                                                                                       		Reserved - .
			x                                                                                                                                                       		Allocation - .
			x                                                                                                                                                       		Addresses - .
			x                                                                                                                                                       		ID - Mask range 96-128
			x                                                                                                                                               	-inner_ipv6_src_step
			x                                                                                                                                                   		Step size of the source IP address when option "inner_ipv6_src_mode" is set to increment or decrement. The following is valid only for traffic_generator ixnetwork_540:Any IPv6 step is accepted. Incrementing and decrementing depends only on ipv6_src_step and ipv6_src_count.The following is valid only for traffic_generator ixos:inner_ipv6_src_mode specifies how and if the inner_ipv6_src_addr is incremented.The inner_ipv6_src_mode depends on the IPv6 address type specified with inner_ipv6_src_addr parameter.Each inner_ipv6_src_mode allows a mask from a Mask range to be configured.The mask is configured using the inner_ipv6_src_mask attributeThe step used for incrementing or decrementing is configued using the inner_ipv6_src_step attribute which has the form of an IPv6 address.The inner_ipv6_src_mask attribute specifies which part of the inner_ipv6_src_step address is used for incrementing as follows:Mask range 4-4, incr_global_top_level decr_global_top_level: xxxx::0Mask range 24-24, incr_global_next_level decr_global_next_level: 0:0xx:xxxx::0Mask range 48-48, incr_global_site_level decr_global_site_level incr_local_site_subnet decr_local_site_subnet: 0:0:0:xxxx::0Mask range 96-96, incr_mcast_group decr_mcast_group: 0::xxxx:xxxxMask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx:xxxx (when mask is 96)Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx(when mask is 112)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0:0 (when mask is 96)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0(when mask is 112)HEX values marked with 'x' in the format above are the inner_ipv6_src_step HEX values that are used for increment or decrement; HEX values marked with '0' are ignored.
			x                                                                                                                                               	-inner_ipv6_src_tracking
			x                                                                                                                                                       		0 - disable tracking by inner_ipv6_src_addr.
			x                                                                                                                                                       		1 - enable tracking by inner_ipv6_src_addr.
			x                                                                                                                                               	-inner_ipv6_traffic_class
			x                                                                                                                                                   		Traffic class value of the IPv6 inner header.
			x                                                                                                                                               	-inner_ipv6_traffic_class_count
			x                                                                                                                                                   		Numeric value which configures the number of times the inner_ipv6_traffic_class is incremeneted or decremented when inner_ipv6_traffic_class_mode is incr or decr.
			x                                                                                                                                               	-inner_ipv6_traffic_class_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with inner_ipv6_traffic_class_step and inner_ipv6_traffic_class_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with inner_ipv6_traffic_class_step and inner_ipv6_traffic_class_count.
			x                                                                                                                                                       		list - Parameter -inner_ipv6_traffic_class contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-inner_ipv6_traffic_class_step
			x                                                                                                                                                   		Step value used to modify inner_ipv6_traffic_class when inner_ipv6_traffic_class_mode is incr or decr.
			x                                                                                                                                               	-inner_ipv6_traffic_class_tracking
			x                                                                                                                                                       		0 - disable tracking by inner_ipv6_traffic_class
			x                                                                                                                                                       		1 - enable tracking by inner_ipv6_traffic_class
			x                                                                                                                                               	-inner_protocol
			x                                                                                                                                                   		Configures a layer 3 protocol header. This option specifies whether to setup an IPv4 or IPv6 header (only used when l4_protocol is gre).Valid options are:ipv4ipv6none<hex value>
			x                                                                                                                                               	-inner_protocol_count
			x                                                                                                                                                   		Numeric value which configures the number of times the inner_protocol is incremeneted or decremented when inner_protocol_mode is incr or decr.
			x                                                                                                                                               	-inner_protocol_mode
			x                                                                                                                                                   		This parameter configures
			x                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                       		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                       		incr - the value is incremented as specified with inner_protocol_step and inner_protocol_count.
			x                                                                                                                                                       		decr - the value is decremented as specified with inner_protocol_step and inner_protocol_count.
			x                                                                                                                                                       		list - Parameter -inner_protocol contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                               	-inner_protocol_step
			x                                                                                                                                                   		Step value used to modify inner_protocol when inner_protocol_mode is incr or decr.
			x                                                                                                                                               	-inner_protocol_tracking
			x                                                                                                                                                       		0 - disable tracking by inner_protocol
			x                                                                                                                                                       		1 - enable tracking by inner_protocol
			x                                                                                                                                               	-integrity_signature
			x                                                                                                                                                   	-integrity_signature_offset
			x                                                                                                                                                       	-inter_frame_gap
			x                                                                                                                                                           		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>. This argument can be used to specify the time gap in clock ticks between transmitted frames.
			x                                                                                                                                                       	-inter_frame_gap_unit
			x                                                                                                                                                           		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>.
			x                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                               		bytes - bytes
			x                                                                                                                                                               		ns - nanoseconds
			x                                                                                                                                                       	-ip_checksum_count
			x                                                                                                                                                           		Numeric value which configures the number of times the ip_checksum is incremeneted or decremented when ip_checksum_mode is incr or decr.
			x                                                                                                                                                       	-ip_checksum_mode
			x                                                                                                                                                           		This parameter configures
			x                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                               		incr - the value is incremented as specified with ip_checksum_step and ip_checksum_count.
			x                                                                                                                                                               		decr - the value is decremented as specified with ip_checksum_step and ip_checksum_count.
			x                                                                                                                                                               		list - Parameter -ip_checksum contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                       	-ip_checksum_step
			x                                                                                                                                                           		Step value used to modify ip_checksum when ip_checksum_mode is incr or decr.
			x                                                                                                                                                       	-ip_checksum_tracking
			x                                                                                                                                                               		0 - disable tracking by ip_checksum
			x                                                                                                                                                               		1 - enable tracking by ip_checksum
			x                                                                                                                                                       	-ip_cost
			x                                                                                                                                                           		Part of the Type of Service byte of the IP header datagram (bit 6). With traffic generator ixnetwork_540, this parameter configures QOS for IPv6 traffic only for ixaccess backwards compatibility mode (details in description for traffic_generator ixnetwork_540) and if qos_ipv6_traffic_class and ipv6_traffic_class parameters are missing.
			x                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                               		0 - Normal cost
			x                                                                                                                                                               		1 - Low cost
			x                                                                                                                                                       	-ip_cost_mode
			x                                                                                                                                                           		This parameter configures
			x                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                               		list - Parameter -ip_cost contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                       	-ip_cost_tracking
			x                                                                                                                                                               		0 - disable tracking by ip_cost
			x                                                                                                                                                               		1 - enable tracking by ip_cost
			x                                                                                                                                                       	-ip_cu_count
			x                                                                                                                                                           		Numeric value which configures the number of times the ip_cu is incremeneted or decremented when ip_cu_mode is incr or decr.
			x                                                                                                                                                       	-ip_cu_mode
			x                                                                                                                                                           		This parameter configures
			x                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                               		incr - the value is incremented as specified with ip_cu_step and ip_cu_count.
			x                                                                                                                                                               		decr - the value is decremented as specified with ip_cu_step and ip_cu_count.
			x                                                                                                                                                               		list - Parameter -ip_cu contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                       	-ip_cu_step
			x                                                                                                                                                           		Step value used to modify ip_cu when ip_cu_mode is incr or decr.
			x                                                                                                                                                       	-ip_cu_tracking
			x                                                                                                                                                               		0 - disable tracking by ip_cu
			x                                                                                                                                                               		1 - enable tracking by ip_cu
			x                                                                                                                                                       	-ip_delay
			x                                                                                                                                                           		Part of the Type of Service byte of the IP header datagram (bit 3). With traffic_generator ixnetwork_540 this parameter configures QOS for IPv6 traffic only for ixaccess backwards compatibility mode (details in description for traffic_generator ixnetwork_540) and if qos_ipv6_traffic_class and ipv6_traffic_class parameters are missing.
			x                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                               		0 - Normal delay
			x                                                                                                                                                               		1 - Low delay
			x                                                                                                                                                       	-ip_delay_mode
			x                                                                                                                                                           		This parameter configures
			x                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                               		list - Parameter -ip_delay contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                       	-ip_delay_tracking
			x                                                                                                                                                               		0 - disable tracking by ip_delay
			x                                                                                                                                                               		1 - enable tracking by ip_delay
			x                                                                                                                                                       	-ip_dscp_mode
			x                                                                                                                                                           		This parameter configures
			x                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                               		incr - the value is incremented as specified with ip_dscp_step and ip_dscp_count.
			x                                                                                                                                                               		decr - the value is decremented as specified with ip_dscp_step and ip_dscp_count.
			x                                                                                                                                                               		list - Parameter -ip_dscp contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                       	-ip_dscp_tracking
			x                                                                                                                                                               		0 - disable tracking by ip_dscp
			x                                                                                                                                                               		1 - enable tracking by ip_dscp
			x                                                                                                                                                       	-ip_dst_tracking
			x                                                                                                                                                               		0 - disable tracking by ip_dst_addr.
			x                                                                                                                                                               		1 - enable tracking by ip_dst_addr.
			x                                                                                                                                                       	-ip_fragment_last_mode
			x                                                                                                                                                           		This parameter configures
			x                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                               		list - Parameter -ip_fragment_last contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                       	-ip_fragment_last_tracking
			x                                                                                                                                                               		0 - disable tracking by ip_fragment_last
			x                                                                                                                                                               		1 - enable tracking by ip_fragment_last
			x                                                                                                                                                       	-ip_fragment_mode
			x                                                                                                                                                           		This parameter configures
			x                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                               		list - Parameter -ip_fragment contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                       	-ip_fragment_offset_count
			x                                                                                                                                                           		Numeric value which configures the number of times the ip_fragment_offset is incremeneted or decremented when ip_fragment_offset_mode is incr or decr.
			x                                                                                                                                                       	-ip_fragment_offset_mode
			x                                                                                                                                                           		This parameter configures
			x                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                               		incr - the value is incremented as specified with ip_fragment_offset_step and ip_fragment_offset_count.
			x                                                                                                                                                               		decr - the value is decremented as specified with ip_fragment_offset_step and ip_fragment_offset_count.
			x                                                                                                                                                               		list - Parameter -ip_fragment_offset contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                       	-ip_fragment_offset_step
			x                                                                                                                                                           		Step value used to modify ip_fragment_offset when ip_fragment_offset_mode is incr or decr.
			x                                                                                                                                                       	-ip_fragment_offset_tracking
			x                                                                                                                                                               		0 - disable tracking by ip_fragment_offset
			x                                                                                                                                                               		1 - enable tracking by ip_fragment_offset
			x                                                                                                                                                       	-ip_fragment_tracking
			x                                                                                                                                                               		0 - disable tracking by ip_fragment
			x                                                                                                                                                               		1 - enable tracking by ip_fragment
			x                                                                                                                                                       	-ip_hdr_length_count
			x                                                                                                                                                           		Numeric value which configures the number of times the ip_hdr_length is incremeneted or decremented when ip_hdr_length_mode is incr or decr.
			x                                                                                                                                                       	-ip_hdr_length_mode
			x                                                                                                                                                           		This parameter configures
			x                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                               		incr - the value is incremented as specified with ip_hdr_length_step and ip_hdr_length_count.
			x                                                                                                                                                               		decr - the value is decremented as specified with ip_hdr_length_step and ip_hdr_length_count.
			x                                                                                                                                                               		list - Parameter -ip_hdr_length contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                       	-ip_hdr_length_step
			x                                                                                                                                                           		Step value used to modify ip_hdr_length when ip_hdr_length_mode is incr or decr.
			x                                                                                                                                                       	-ip_hdr_length_tracking
			x                                                                                                                                                               		0 - disable tracking by ip_hdr_length
			x                                                                                                                                                               		1 - enable tracking by ip_hdr_length
			x                                                                                                                                                       	-ip_id_count
			x                                                                                                                                                           		Numeric value which configures the number of times the ip_id is incremeneted or decremented when ip_id_mode is incr or decr.
			x                                                                                                                                                       	-ip_id_mode
			x                                                                                                                                                           		This parameter configures
			x                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                               		incr - the value is incremented as specified with ip_id_step and ip_id_count.
			x                                                                                                                                                               		decr - the value is decremented as specified with ip_id_step and ip_id_count.
			x                                                                                                                                                               		list - Parameter -ip_id contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                       	-ip_id_step
			x                                                                                                                                                           		Step value used to modify ip_id when ip_id_mode is incr or decr.
			x                                                                                                                                                       	-ip_id_tracking
			x                                                                                                                                                               		0 - disable tracking by ip_id
			x                                                                                                                                                               		1 - enable tracking by ip_id
			x                                                                                                                                                       	-ip_length_override
			x                                                                                                                                                           		Allows to change the length in ip header.
			x                                                                                                                                                       	-ip_length_override_mode
			x                                                                                                                                                           		This parameter configures
			x                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                               		list - Parameter -ip_length_override contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                       	-ip_length_override_tracking
			x                                                                                                                                                               		0 - disable tracking by ip_length_override
			x                                                                                                                                                               		1 - enable tracking by ip_length_override
			x                                                                                                                                                       	-ip_opt_loose_routing
			x                                                                                                                                                           	-ip_opt_security
			x                                                                                                                                                               	-ip_opt_strict_routing
			x                                                                                                                                                                   	-ip_opt_timestamp
			x                                                                                                                                                                       	-ip_precedence_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ip_precedence is incremeneted or decremented when ip_precedence_mode is incr or decr.
			x                                                                                                                                                                       	-ip_precedence_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ip_precedence_step and ip_precedence_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ip_precedence_step and ip_precedence_count.
			x                                                                                                                                                                               		list - Parameter -ip_precedence contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ip_precedence_step
			x                                                                                                                                                                           		Step value used to modify ip_precedence when ip_precedence_mode is incr or decr.
			x                                                                                                                                                                       	-ip_precedence_tracking
			x                                                                                                                                                                               		0 - disable tracking by ip_precedence
			x                                                                                                                                                                               		1 - enable tracking by ip_precedence
			x                                                                                                                                                                       	-ip_protocol_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ip_protocol is incremeneted or decremented when ip_protocol_mode is incr or decr.
			x                                                                                                                                                                       	-ip_protocol_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ip_protocol_step and ip_protocol_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ip_protocol_step and ip_protocol_count.
			x                                                                                                                                                                               		list - Parameter -ip_protocol contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ip_protocol_step
			x                                                                                                                                                                           		Step value used to modify ip_protocol when ip_protocol_mode is incr or decr.
			x                                                                                                                                                                       	-ip_protocol_tracking
			x                                                                                                                                                                               		0 - disable tracking by ip_protocol
			x                                                                                                                                                                               		1 - enable tracking by ip_protocol
			x                                                                                                                                                                       	-ip_reliability
			x                                                                                                                                                                           		Part of the Type of Service byte of the IP header datagram (bit 5). With traffic generator ixnetwork_540, this parameter configures QOS for IPv6 traffic only for ixaccess backwards compatibility mode (details in description for traffic_generator ixnetwork_540) and if qos_ipv6_traffic_class and ipv6_traffic_class parameters are missing.
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		0 - Normal reliability
			x                                                                                                                                                                               		1 - High reliability
			x                                                                                                                                                                       	-ip_reliability_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		list - Parameter -ip_reliability contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ip_reliability_tracking
			x                                                                                                                                                                               		0 - disable tracking by ip_reliability
			x                                                                                                                                                                               		1 - enable tracking by ip_reliability
			x                                                                                                                                                                       	-ip_reserved
			x                                                                                                                                                                           		Part of the Type of Service byte of the IP header datagram (bit 7).Valid options are:0 - (default)1
			x                                                                                                                                                                       	-ip_reserved_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		list - Parameter -ip_reserved contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ip_reserved_tracking
			x                                                                                                                                                                               		0 - disable tracking by ip_reserved
			x                                                                                                                                                                               		1 - enable tracking by ip_reserved
			x                                                                                                                                                                       	-ip_src_tracking
			x                                                                                                                                                                               		0 - disable tracking by ip_src_addr.
			x                                                                                                                                                                               		1 - enable tracking by ip_src_addr.
			x                                                                                                                                                                       	-ip_throughput
			x                                                                                                                                                                           		Part of the Type of Service byte of the IP header datagram (bit 4). With traffic generator ixnetwork_540, this parameter configures QOS for IPv6 traffic only for ixaccess backwards compatibility mode (details in description for traffic_generator ixnetwork_540) and if qos_ipv6_traffic_class and ipv6_traffic_class parameters are missing.
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		0 - Normal throughput
			x                                                                                                                                                                               		1 - High throughput
			x                                                                                                                                                                       	-ip_throughput_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		list - Parameter -ip_throughput contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ip_throughput_tracking
			x                                                                                                                                                                               		0 - disable tracking by ip_throughput
			x                                                                                                                                                                               		1 - enable tracking by ip_throughput
			x                                                                                                                                                                       	-ip_total_length
			x                                                                                                                                                                           		Total Length is the length of the datagram, measured in octets, including internet header and data.
			x                                                                                                                                                                       	-ip_total_length_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ip_total_length is incremeneted or decremented when ip_total_length_mode is incr or decr.
			x                                                                                                                                                                       	-ip_total_length_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ip_total_length_step and ip_total_length_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ip_total_length_step and ip_total_length_count.
			x                                                                                                                                                                               		list - Parameter -ip_total_length contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                               		auto - the length of the datagram, measured in octets is autoset. Parameter ip_total_length is ignored if present.
			x                                                                                                                                                                       	-ip_total_length_step
			x                                                                                                                                                                           		Step value used to modify ip_total_length when ip_total_length_mode is incr or decr.
			x                                                                                                                                                                       	-ip_total_length_tracking
			x                                                                                                                                                                               		0 - disable tracking by ip_total_length
			x                                                                                                                                                                               		1 - enable tracking by ip_total_length
			x                                                                                                                                                                       	-ip_ttl_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ip_ttl is incremeneted or decremented when ip_ttl_mode is incr or decr.
			x                                                                                                                                                                       	-ip_ttl_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ip_ttl_step and ip_ttl_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ip_ttl_step and ip_ttl_count.
			x                                                                                                                                                                               		list - Parameter -ip_ttl contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ip_ttl_step
			x                                                                                                                                                                           		Step value used to modify ip_ttl when ip_ttl_mode is incr or decr.
			x                                                                                                                                                                       	-ip_ttl_tracking
			x                                                                                                                                                                               		0 - disable tracking by ip_ttl
			x                                                                                                                                                                               		1 - enable tracking by ip_ttl
			x                                                                                                                                                                       	-ipv6_auth_next_header
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Next header in the authentication extention header. Range 0 - 255.
			x                                                                                                                                                                       	-ipv6_auth_next_header_count
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Numeric value which configures the number of times the ipv6_auth_next_header is incremeneted or decremented when ipv6_auth_next_header_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_auth_next_header_mode
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_auth_next_header_step and ipv6_auth_next_header_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_auth_next_header_step and ipv6_auth_next_header_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_auth_next_header contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_auth_next_header_step
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Step value used to modify ipv6_auth_next_header when ipv6_auth_next_header_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_auth_next_header_tracking
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		0 - disable tracking by ipv6_auth_next_header
			x                                                                                                                                                                               		1 - enable tracking by ipv6_auth_next_header
			x                                                                                                                                                                       	-ipv6_auth_padding
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Configure padding for authentication extension header. HEX values accepted.
			x                                                                                                                                                                       	-ipv6_auth_padding_count
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Numeric value which configures the number of times the ipv6_auth_padding is incremeneted or decremented when ipv6_auth_padding_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_auth_padding_mode
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_auth_padding_step and ipv6_auth_padding_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_auth_padding_step and ipv6_auth_padding_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_auth_padding contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_auth_padding_step
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Step value used to modify ipv6_auth_padding when ipv6_auth_padding_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_auth_padding_tracking
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		0 - disable tracking by ipv6_auth_padding
			x                                                                                                                                                                               		1 - enable tracking by ipv6_auth_padding
			x                                                                                                                                                                       	-ipv6_auth_payload_len
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication". The length of the authentication data, expressed in 32-bit words.
			x                                                                                                                                                                       	-ipv6_auth_payload_len_count
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Numeric value which configures the number of times the ipv6_auth_payload_len is incremeneted or decremented when ipv6_auth_payload_len_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_auth_payload_len_mode
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_auth_payload_len_step and ipv6_auth_payload_len_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_auth_payload_len_step and ipv6_auth_payload_len_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_auth_payload_len contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_auth_payload_len_step
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Step value used to modify ipv6_auth_payload_len when ipv6_auth_payload_len_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_auth_payload_len_tracking
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		0 - disable tracking by ipv6_auth_payload_len
			x                                                                                                                                                                               		1 - enable tracking by ipv6_auth_payload_len
			x                                                                                                                                                                       	-ipv6_auth_reserved
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Configure the 2 byte reserved field in the authetication extension header.
			x                                                                                                                                                                       	-ipv6_auth_reserved_count
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Numeric value which configures the number of times the ipv6_auth_reserved is incremeneted or decremented when ipv6_auth_reserved_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_auth_reserved_mode
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_auth_reserved_step and ipv6_auth_reserved_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_auth_reserved_step and ipv6_auth_reserved_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_auth_reserved contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_auth_reserved_step
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Step value used to modify ipv6_auth_reserved when ipv6_auth_reserved_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_auth_reserved_tracking
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		0 - disable tracking by ipv6_auth_reserved
			x                                                                                                                                                                               		1 - enable tracking by ipv6_auth_reserved
			x                                                                                                                                                                       	-ipv6_auth_seq_num
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication". This is only for "-ipv6_extension_header authentication". A sequence counter for the authentication header.
			x                                                                                                                                                                       	-ipv6_auth_seq_num_count
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Numeric value which configures the number of times the ipv6_auth_seq_num is incremeneted or decremented when ipv6_auth_seq_num_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_auth_seq_num_mode
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_auth_seq_num_step and ipv6_auth_seq_num_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_auth_seq_num_step and ipv6_auth_seq_num_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_auth_seq_num contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_auth_seq_num_step
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Step value used to modify ipv6_auth_seq_num when ipv6_auth_seq_num_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_auth_seq_num_tracking
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		0 - disable tracking by ipv6_auth_seq_num
			x                                                                                                                                                                               		1 - enable tracking by ipv6_auth_seq_num
			x                                                                                                                                                                       	-ipv6_auth_spi
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication". The security parameter index (SPI) associated with the authentication header.
			x                                                                                                                                                                       	-ipv6_auth_spi_count
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Numeric value which configures the number of times the ipv6_auth_spi is incremeneted or decremented when ipv6_auth_spi_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_auth_spi_mode
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_auth_spi_step and ipv6_auth_spi_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_auth_spi_step and ipv6_auth_spi_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_auth_spi contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_auth_spi_step
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Step value used to modify ipv6_auth_spi when ipv6_auth_spi_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_auth_spi_tracking
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		0 - disable tracking by ipv6_auth_spi
			x                                                                                                                                                                               		1 - enable tracking by ipv6_auth_spi
			x                                                                                                                                                                       	-ipv6_auth_string
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication". A variable length string containing the packets integrity check value (ICV). With traffic_generator ixnetwork_540 this parameter is deprecated. Use ipv6_auth_md5sha1_string instead.
			x                                                                                                                                                                       	-ipv6_auth_string_count
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication". This parameter is deprecated. Use ipv6_auth_md5sha1_string_count instead.
			x                                                                                                                                                                       	-ipv6_auth_string_mode
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication". This parameter is deprecated. Use ipv6_auth_md5sha1_string_mode instead.
			x                                                                                                                                                                       	-ipv6_auth_string_step
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication". This parameter is deprecated. Use ipv6_auth_md5sha1_string_step instead.
			x                                                                                                                                                                       	-ipv6_auth_string_tracking
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication". This parameter is deprecated. Use ipv6_auth_md5sha1_string_tracking instead.
			x                                                                                                                                                                       	-ipv6_auth_type
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		md5 - default
			x                                                                                                                                                                               		sha1 - SHA1
			x                                                                                                                                                                       	-ipv6_auth_md5sha1_string
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication". When ipv6_auth_type is 'md5' this represents the IPv6 Authentication MD5 field. The length must be 16 bytes at most. When ipv6_auth_type is 'sha1' this represents the IPv6 Authentication SHA1 field. The length must be 20 bytes at most. The field will be calculated automatically if the parameter is not specified.
			x                                                                                                                                                                       	-ipv6_auth_md5sha1_string_count
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Numeric value which configures the number of times the ipv6_auth_md5sha1_string is incremeneted or decremented when ipv6_auth_md5sha1_string_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_auth_md5sha1_string_mode
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_auth_md5sha1_string_step and ipv6_auth_md5sha1_string_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_auth_md5sha1_string_step and ipv6_auth_md5sha1_string_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_auth_md5sha1_string contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_auth_md5sha1_string_step
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".Step value used to modify ipv6_auth_md5sha1_string when ipv6_auth_md5sha1_string_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_auth_md5sha1_string_tracking
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header authentication".
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		0 - disable tracking by ipv6_auth_md5sha1_string
			x                                                                                                                                                                               		1 - enable tracking by ipv6_auth_md5sha1_string
			x                                                                                                                                                                       	-ipv6_dst_mask
			x                                                                                                                                                                           		Specify IPv6 mask to be used for ipv6_dst_addr to increment. This parameter is ignored with traffic_generator ixnetwork_540. Incrementing and decrementing can be done with any step value with traffic_generator ixnetwork_540.Default value is specific to the ipv6_dst_mode as follows:incr_global_top_level decr_global_top_level: Default 4incr_global_next_level decr_global_next_level: Default 24incr_global_site_level decr_global_site_level incr_local_site_subnet decr_local_site_subnet: Default 48incr_mcast_group decr_mcast_group: Default 96incr_host decr_host incr_intf_id decr_intf_id: Default 96incr_network decr_network: Default 96ipv6_dst_mode specifies how and if the ipv6_dst_addr is incremented.The ipv6_dst_mode depends on the IPv6 address type specified with ipv6_dst_addr parameter.Each ipv6_dst_mode allows a mask from a Mask range to be configured.The mask is configured using the ipv6_dst_mask attributeThe step used for incrementing or decrementing is configued using the ipv6_dst_step attribute which has the form of an IPv6 address.The ipv6_dst_mask attribute specifies which part of the ipv6_dst_step address is used for incrementing as follows:Mask range 4-4, incr_global_top_level decr_global_top_level: xxxx::0Mask range 24-24, incr_global_next_level decr_global_next_level: 0:0xx:xxxx::0Mask range 48-48, incr_global_site_level decr_global_site_level incr_local_site_subnet decr_local_site_subnet: 0:0:0:xxxx::0Mask range 96-96, incr_mcast_group decr_mcast_group: 0::xxxx:xxxxMask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx:xxxx (when mask is 96)Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx(when mask is 112)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0:0 (when mask is 96)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0(when mask is 112)HEX values marked with 'x' in the format above are the ipv6_dst_step HEX values that are used for increment or decrement; HEX values marked with '0' are ignored.
			x                                                                                                                                                                       	-ipv6_dst_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_dst_addr
			x                                                                                                                                                                               		1 - enable tracking by ipv6_dst_addr
			x                                                                                                                                                                       	-ipv6_encap_seq_number
			x                                                                                                                                                                           		Valid only for traffic_generator ixnetwork_540 and -ipv6_extension_header encapsulation.Configure 4 bytes HEX value for 'Sequence Number'.
			x                                                                                                                                                                       	-ipv6_encap_seq_number_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ipv6_encap_seq_number is incremeneted or decremented when ipv6_encap_seq_number_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_encap_seq_number_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_encap_seq_number_step and ipv6_encap_seq_number_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_encap_seq_number_step and ipv6_encap_seq_number_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_encap_seq_number contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_encap_seq_number_step
			x                                                                                                                                                                           		Step value used to modify ipv6_encap_seq_number when ipv6_encap_seq_number_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_encap_seq_number_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_encap_seq_number
			x                                                                                                                                                                               		1 - enable tracking by ipv6_encap_seq_number
			x                                                                                                                                                                       	-ipv6_encap_spi
			x                                                                                                                                                                           		Valid only for traffic_generator ixnetwork_540 and -ipv6_extension_header encapsulation.Configure 'Security Parameters Index' (0-4294967295).
			x                                                                                                                                                                       	-ipv6_encap_spi_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ipv6_encap_spi is incremeneted or decremented when ipv6_encap_spi_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_encap_spi_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_encap_spi_step and ipv6_encap_spi_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_encap_spi_step and ipv6_encap_spi_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_encap_spi contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_encap_spi_step
			x                                                                                                                                                                           		Step value used to modify ipv6_encap_spi when ipv6_encap_spi_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_encap_spi_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_encap_spi
			x                                                                                                                                                                               		1 - enable tracking by ipv6_encap_spi
			x                                                                                                                                                                       	-ipv6_extension_header
			x                                                                                                                                                                           		The type of the next extension header. Valid options are:
			x                                                                                                                                                                           		<choices><choice><choiceName>none </choiceName><choiceText>There is no next header.</choiceText></choice><choice><choiceName>hop_by_hop </choiceName><choiceText>Next header is hop-by-hop options.</choiceText></choice><choice><choiceName>routing </choiceName><choiceText>Next header has routing options.</choiceText></choice><choice><choiceName>destination </choiceName><choiceText>Next header has destination options.</choiceText></choice><choice><choiceName>authentication</choiceName><choiceText>Next header is an IPSEC AH.</choiceText></choice><choice><choiceName>encapsulation</choiceName><choiceText>Next header is encapsulation. </choiceText></choice><choice><choiceName>pseudo </choiceName><choiceText>Next header is pseudo. </choiceText></choice><choice><choiceName>fragment</choiceName><choiceText>Payload is a fragment. </choiceText></choice></choices>
			x                                                                                                                                                                       	-ipv6_flow_label_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ipv6_flow_label is incremeneted or decremented when ipv6_flow_label_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_flow_label_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_flow_label_step and ipv6_flow_label_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_flow_label_step and ipv6_flow_label_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_flow_label contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_flow_label_step
			x                                                                                                                                                                           		Step value used to modify ipv6_flow_label when ipv6_flow_label_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_flow_label_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_flow_label
			x                                                                                                                                                                               		1 - enable tracking by ipv6_flow_label
			x                                                                                                                                                                       	-ipv6_flow_version
			x                                                                                                                                                                           		Configure flow version of the IPv6 header.
			x                                                                                                                                                                       	-ipv6_flow_version_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ipv6_flow_version is incremeneted or decremented when ipv6_flow_version_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_flow_version_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_flow_version_step and ipv6_flow_version_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_flow_version_step and ipv6_flow_version_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_flow_version contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_flow_version_step
			x                                                                                                                                                                           		Step value used to modify ipv6_flow_version when ipv6_flow_version_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_flow_version_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_flow_version
			x                                                                                                                                                                               		1 - enable tracking by ipv6_flow_version
			x                                                                                                                                                                       	-ipv6_frag_id_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ipv6_frag_id is incremeneted or decremented when ipv6_frag_id_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_frag_id_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_frag_id_step and ipv6_frag_id_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_frag_id_step and ipv6_frag_id_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_frag_id contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_frag_id_step
			x                                                                                                                                                                           		Step value used to modify ipv6_frag_id when ipv6_frag_id_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_frag_id_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_frag_id
			x                                                                                                                                                                               		1 - enable tracking by ipv6_frag_id
			x                                                                                                                                                                       	-ipv6_frag_more_flag_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		list - Parameter -ipv6_frag_more_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_frag_more_flag_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_frag_more_flag
			x                                                                                                                                                                               		1 - enable tracking by ipv6_frag_more_flag
			x                                                                                                                                                                       	-ipv6_frag_offset_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ipv6_frag_offset is incremeneted or decremented when ipv6_frag_offset_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_frag_offset_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_frag_offset_step and ipv6_frag_offset_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_frag_offset_step and ipv6_frag_offset_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_frag_offset contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_frag_offset_step
			x                                                                                                                                                                           		Step value used to modify ipv6_frag_offset when ipv6_frag_offset_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_frag_offset_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_frag_offset
			x                                                                                                                                                                               		1 - enable tracking by ipv6_frag_offset
			x                                                                                                                                                                       	-ipv6_frag_res_2bit
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header fragment". A 2-bit reserved field.
			x                                                                                                                                                                       	-ipv6_frag_res_2bit_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ipv6_frag_res_2bit is incremeneted or decremented when ipv6_frag_res_2bit_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_frag_res_2bit_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_frag_res_2bit_step and ipv6_frag_res_2bit_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_frag_res_2bit_step and ipv6_frag_res_2bit_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_frag_res_2bit contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_frag_res_2bit_step
			x                                                                                                                                                                           		Step value used to modify ipv6_frag_res_2bit when ipv6_frag_res_2bit_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_frag_res_2bit_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_frag_res_2bit
			x                                                                                                                                                                               		1 - enable tracking by ipv6_frag_res_2bit
			x                                                                                                                                                                       	-ipv6_frag_res_8bit
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header fragment". An 8-bit reserved field.
			x                                                                                                                                                                       	-ipv6_frag_res_8bit_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ipv6_frag_res_8bit is incremeneted or decremented when ipv8_frag_res_2bit_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_frag_res_8bit_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_frag_res_8bit_step and ipv6_frag_res_8bit_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_frag_res_8bit_step and ipv6_frag_res_8bit_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_frag_res_8bit contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_frag_res_8bit_step
			x                                                                                                                                                                           		Step value used to modify ipv6_frag_res_8bit when ipv6_frag_res_8bit_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_frag_res_8bit_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_frag_res_8bit
			x                                                                                                                                                                               		1 - enable tracking by ipv6_frag_res_8bit
			x                                                                                                                                                                       	-ipv6_hop_by_hop_options
			x                                                                                                                                                                           		This is only for "-ipv6_extension_header hop_by_hop". This option will represent a list of keyed values. See Return Values table following -tx_ports_list. The following types are accepted with ixnetwork_540 traffic generator: pad1 - valid with traffic_generator ixos and ixnetwork_540padn - valid with traffic_generator ixos and ixnetwork_540user_defined - valid only with traffic generator ixnetwork_540.
			x                                                                                                                                                                       	-ipv6_hop_limit_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ipv6_hop_limit is incremeneted or decremented when ipv6_hop_limit_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_hop_limit_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_hop_limit_step and ipv6_hop_limit_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_hop_limit_step and ipv6_hop_limit_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_hop_limit contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_hop_limit_step
			x                                                                                                                                                                           		Step value used to modify ipv6_hop_limit when ipv6_hop_limit_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_hop_limit_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_hop_limit
			x                                                                                                                                                                               		1 - enable tracking by ipv6_hop_limit
			x                                                                                                                                                                       	-ipv6_next_header_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ipv6_next_header is incremeneted or decremented when ipv6_next_header_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_next_header_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_next_header_step and ipv6_next_header_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_next_header_step and ipv6_next_header_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_next_header contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_next_header_step
			x                                                                                                                                                                           		Step value used to modify ipv6_next_header when ipv6_next_header_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_next_header_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_next_header
			x                                                                                                                                                                               		1 - enable tracking by ipv6_next_header
			x                                                                                                                                                                       	-ipv6_pseudo_dst_addr
			x                                                                                                                                                                           		Valid only for traffic_generator ixnetwork_540 and -ipv6_extension_header pseudo.Configure IPv6 destination address for pseudo extension header.
			x                                                                                                                                                                       	-ipv6_pseudo_dst_addr_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ipv6_pseudo_dst_addr is incremeneted or decremented when ipv6_pseudo_dst_addr_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_pseudo_dst_addr_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_pseudo_dst_addr_step and ipv6_pseudo_dst_addr_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_pseudo_dst_addr_step and ipv6_pseudo_dst_addr_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_pseudo_dst_addr contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_pseudo_dst_addr_step
			x                                                                                                                                                                           		Step value used to modify ipv6_pseudo_dst_addr when ipv6_pseudo_dst_addr_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_pseudo_dst_addr_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_pseudo_dst_addr
			x                                                                                                                                                                               		1 - enable tracking by ipv6_pseudo_dst_addr
			x                                                                                                                                                                       	-ipv6_pseudo_src_addr
			x                                                                                                                                                                           		Valid only for traffic_generator ixnetwork_540 and -ipv6_extension_header pseudo.Configure IPv6 destination address for pseudo extension header.
			x                                                                                                                                                                       	-ipv6_pseudo_src_addr_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ipv6_pseudo_src_addr is incremeneted or decremented when ipv6_pseudo_src_addr_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_pseudo_src_addr_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_pseudo_src_addr_step and ipv6_pseudo_src_addr_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_pseudo_src_addr_step and ipv6_pseudo_src_addr_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_pseudo_src_addr contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_pseudo_src_addr_step
			x                                                                                                                                                                           		Step value used to modify ipv6_pseudo_src_addr when ipv6_pseudo_src_addr_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_pseudo_src_addr_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_pseudo_src_addr
			x                                                                                                                                                                               		1 - enable tracking by ipv6_pseudo_src_addr
			x                                                                                                                                                                       	-ipv6_pseudo_uppper_layer_pkt_length
			x                                                                                                                                                                           		Valid only for traffic_generator ixnetwork_540 and -ipv6_extension_header pseudo.Configure Upper-Layer Packet Length for pseudo extension header.
			x                                                                                                                                                                       	-ipv6_pseudo_uppper_layer_pkt_length_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ipv6_pseudo_uppper_layer_pkt_length is incremeneted or decremented when ipv6_pseudo_uppper_layer_pkt_length_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_pseudo_uppper_layer_pkt_length_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_pseudo_uppper_layer_pkt_length_step and ipv6_pseudo_uppper_layer_pkt_length_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_pseudo_uppper_layer_pkt_length_step and ipv6_pseudo_uppper_layer_pkt_length_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_pseudo_uppper_layer_pkt_length contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_pseudo_uppper_layer_pkt_length_step
			x                                                                                                                                                                           		Step value used to modify ipv6_pseudo_uppper_layer_pkt_length when ipv6_pseudo_uppper_layer_pkt_length_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_pseudo_uppper_layer_pkt_length_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_pseudo_uppper_layer_pkt_length
			x                                                                                                                                                                               		1 - enable tracking by ipv6_pseudo_uppper_layer_pkt_length
			x                                                                                                                                                                       	-ipv6_pseudo_zero_number
			x                                                                                                                                                                           		Valid only for traffic_generator ixnetwork_540 and -ipv6_extension_header pseudo.Configure 4 bytes HEX 'Zero' field for pseudo extension header.
			x                                                                                                                                                                       	-ipv6_pseudo_zero_number_count
			x                                                                                                                                                                           		Numeric value which configures the number of times the ipv6_pseudo_zero_number is incremeneted or decremented when ipv6_pseudo_zero_number_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_pseudo_zero_number_mode
			x                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                               		incr - the value is incremented as specified with ipv6_pseudo_zero_number_step and ipv6_pseudo_zero_number_count.
			x                                                                                                                                                                               		decr - the value is decremented as specified with ipv6_pseudo_zero_number_step and ipv6_pseudo_zero_number_count.
			x                                                                                                                                                                               		list - Parameter -ipv6_pseudo_zero_number contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                       	-ipv6_pseudo_zero_number_step
			x                                                                                                                                                                           		Step value used to modify ipv6_pseudo_zero_number when ipv6_pseudo_zero_number_mode is incr or decr.
			x                                                                                                                                                                       	-ipv6_pseudo_zero_number_tracking
			x                                                                                                                                                                               		0 - disable tracking by ipv6_pseudo_zero_number
			x                                                                                                                                                                               		1 - enable tracking by ipv6_pseudo_zero_number
			x                                                                                                                                                                       	-ipv6_routing_node_list
			x                                                                                                                                                                           	-ipv6_routing_res
			x                                                                                                                                                                               		This is only for "-ipv6_extension_header routing". A 32-bit reserved field. <4 HEX BYTES separated by ":" or ".">
			x                                                                                                                                                                           	-ipv6_routing_res_count
			x                                                                                                                                                                               		Numeric value which configures the number of times the ipv6_routing_res is incremeneted or decremented when ipv6_routing_res_mode is incr or decr.
			x                                                                                                                                                                           	-ipv6_routing_res_mode
			x                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                   		incr - the value is incremented as specified with ipv6_routing_res_step and ipv6_routing_res_count.
			x                                                                                                                                                                                   		decr - the value is decremented as specified with ipv6_routing_res_step and ipv6_routing_res_count.
			x                                                                                                                                                                                   		list - Parameter -ipv6_routing_res contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                           	-ipv6_routing_res_step
			x                                                                                                                                                                               		Step value used to modify ipv6_routing_res when ipv6_routing_res_mode is incr or decr.
			x                                                                                                                                                                           	-ipv6_routing_res_tracking
			x                                                                                                                                                                                   		0 - disable tracking by ipv6_routing_res
			x                                                                                                                                                                                   		1 - enable tracking by ipv6_routing_res
			x                                                                                                                                                                           	-ipv6_routing_type
			x                                                                                                                                                                               		This is only for "-ipv6_extension_header routing".Configure routing type (range 0-255) for 'routing' extension header.
			x                                                                                                                                                                           	-ipv6_routing_type_count
			x                                                                                                                                                                               		Numeric value which configures the number of times the ipv6_routing_type is incremeneted or decremented when ipv6_routing_type_mode is incr or decr.
			x                                                                                                                                                                           	-ipv6_routing_type_mode
			x                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                   		incr - the value is incremented as specified with ipv6_routing_type_step and ipv6_routing_type_count.
			x                                                                                                                                                                                   		decr - the value is decremented as specified with ipv6_routing_type_step and ipv6_routing_type_count.
			x                                                                                                                                                                                   		list - Parameter -ipv6_routing_type contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                           	-ipv6_routing_type_step
			x                                                                                                                                                                               		Step value used to modify ipv6_routing_type when ipv6_routing_type_mode is incr or decr.
			x                                                                                                                                                                           	-ipv6_routing_type_tracking
			x                                                                                                                                                                                   		0 - disable tracking by ipv6_routing_type
			x                                                                                                                                                                                   		1 - enable tracking by ipv6_routing_type
			x                                                                                                                                                                           	-ipv6_src_mask
			x                                                                                                                                                                               		This parameter is ignored with traffic_generator ixnetwork_540. Incrementing and decrementing can be done with any step value with traffic_generator ixnetwork_540.Specify IPv6 mask to be used for ipv6_src_addr to increment. Default value is minimum value specified in ipv6_src_mode (it depends on address type and increment mode).ipv6_src_mode specifies how and if the ipv6_src_addr is incremented.The ipv6_src_mode depends on the IPv6 address type specified with ipv6_src_addr parameter.Each ipv6_src_mode allows a mask from a Mask range to be configured.The mask is configured using the ipv6_src_mask attributeThe step used for incrementing or decrementing is configued using the ipv6_src_step attribute which has the form of an IPv6 address.The ipv6_src_mask attribute specifies which part of the ipv6_src_step address is used for incrementing as follows:Mask range 4-4, incr_global_top_level decr_global_top_level: xxxx::0Mask range 24-24, incr_global_next_level decr_global_next_level: 0:0xx:xxxx::0Mask range 48-48, incr_global_site_level decr_global_site_level incr_local_site_subnet decr_local_site_subnet: 0:0:0:xxxx::0Mask range 96-96, incr_mcast_group decr_mcast_group: 0::xxxx:xxxxMask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx:xxxx (when mask is 96)Mask range 96-128, incr_host decr_host incr_intf_id decr_intf_id: 0::xxxx(when mask is 112)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0:0 (when mask is 96)Mask range 0-128, incr_network decr_network: 0::xxxx:xxxx:0(when mask is 112)HEX values marked with 'x' in the format above are the ipv6_src_step HEX values that are used for increment or decrement; HEX values marked with '0' are ignored.
			x                                                                                                                                                                           	-ipv6_src_tracking
			x                                                                                                                                                                                   		0 - disable tracking by ipv6_src_addr.
			x                                                                                                                                                                                   		1 - enable tracking by ipv6_src_addr.
			x                                                                                                                                                                           	-ipv6_traffic_class_count
			x                                                                                                                                                                               		Numeric value which configures the number of times the ipv6_traffic_class is incremeneted or decremented when ipv6_traffic_class_mode is incr or decr.
			x                                                                                                                                                                           	-ipv6_traffic_class_mode
			x                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                   		incr - the value is incremented as specified with ipv6_traffic_class_step and ipv6_traffic_class_count.
			x                                                                                                                                                                                   		decr - the value is decremented as specified with ipv6_traffic_class_step and ipv6_traffic_class_count.
			x                                                                                                                                                                                   		list - Parameter -ipv6_traffic_class contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                           	-ipv6_traffic_class_step
			x                                                                                                                                                                               		Step value used to modify ipv6_traffic_class when ipv6_traffic_class_mode is incr or decr.
			x                                                                                                                                                                           	-ipv6_traffic_class_tracking
			x                                                                                                                                                                                   		0 - disable tracking by ipv6_traffic_class
			x                                                                                                                                                                                   		1 - enable tracking by ipv6_traffic_class
			x                                                                                                                                                                           	-isl
			x                                                                                                                                                                               		Whether to enable ISL on the stream. You can then configure ISL with options "isl_frame_type", "isl_vlan_id", "isl_user_priority", "isl_bpdu", and "isl_index". Valid only for traffic_generator ixos and ixnetwork_540. 0 - Disable ISL.1 - Enable ISL.
			x                                                                                                                                                                           	-isl_bpdu
			x                                                                                                                                                                               		Whether to enable encapsulation of all Bridge Protocol Data Units by the ISL packet. Valid only for traffic_generator ixos and ixnetwork_540.
			x                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                   		0 - Disabled
			x                                                                                                                                                                                   		1 - Enabled
			x                                                                                                                                                                           	-isl_bpdu_count
			x                                                                                                                                                                               		Numeric value which configures the number of times the isl_bpdu is incremeneted or decremented when isl_bpdu_mode is incr or decr.
			x                                                                                                                                                                           	-isl_bpdu_mode
			x                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                   		incr - the value is incremented as specified with isl_bpdu_step and isl_bpdu_count.
			x                                                                                                                                                                                   		decr - the value is decremented as specified with isl_bpdu_step and isl_bpdu_count.
			x                                                                                                                                                                                   		list - Parameter -isl_bpdu contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                           	-isl_bpdu_step
			x                                                                                                                                                                               		Step value used to modify isl_bpdu when isl_bpdu_mode is incr or decr.
			x                                                                                                                                                                           	-isl_bpdu_tracking
			x                                                                                                                                                                                   		0 - disable tracking by isl_bpdu
			x                                                                                                                                                                                   		1 - enable tracking by isl_bpdu
			x                                                                                                                                                                           	-isl_frame_type
			x                                                                                                                                                                               		Valid only for traffic_generator ixos and ixnetwork_540.Type of frame that is encapsulated. Valid options are:ethernet (default)atmfdditoken_ring
			x                                                                                                                                                                           	-isl_frame_type_mode
			x                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                   		list - Parameter -isl_frame_type contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                           	-isl_frame_type_tracking
			x                                                                                                                                                                                   		0 - disable tracking by isl_frame_type
			x                                                                                                                                                                                   		1 - enable tracking by isl_frame_type
			x                                                                                                                                                                           	-isl_index
			x                                                                                                                                                                               		Value of the selected register.
			x                                                                                                                                                                           	-isl_index_count
			x                                                                                                                                                                               		Numeric value which configures the number of times the isl_index is incremeneted or decremented when isl_index_mode is incr or decr.
			x                                                                                                                                                                           	-isl_index_mode
			x                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                   		incr - the value is incremented as specified with isl_index_step and isl_index_count.
			x                                                                                                                                                                                   		decr - the value is decremented as specified with isl_index_step and isl_index_count.
			x                                                                                                                                                                                   		list - Parameter -isl_index contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                           	-isl_index_step
			x                                                                                                                                                                               		Step value used to modify isl_index when isl_index_mode is incr
			x                                                                                                                                                                           	-isl_index_tracking
			x                                                                                                                                                                                   		0 - disable tracking by isl_index
			x                                                                                                                                                                                   		1 - enable tracking by isl_index
			x                                                                                                                                                                           	-isl_mac_dst
			x                                                                                                                                                                               		Mac address used to configure the destination mac address from the ISL header. This is not a real MAC Address, this is actually a 40 bits hex.(DEFAULT 00.00.00.00.00)
			x                                                                                                                                                                           	-isl_mac_dst_count
			x                                                                                                                                                                               		Numeric value which configures the number of times the isl_mac_dst is incremeneted or decremented when isl_mac_dst_mode is incr or decr.
			x                                                                                                                                                                           	-isl_mac_dst_mode
			x                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                   		incr - the value is incremented as specified with isl_mac_dst_step and isl_mac_dst_count.
			x                                                                                                                                                                                   		decr - the value is decremented as specified with isl_mac_dst_step and isl_mac_dst_count.
			x                                                                                                                                                                                   		list - Parameter -isl_mac_dst contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                           	-isl_mac_dst_step
			x                                                                                                                                                                               		Mac address step value used to modify isl_mac_dst when isl_mac_dst_mode is incr or decr. This is not actually a mac address, this is a 40 bits hex.
			x                                                                                                                                                                           	-isl_mac_dst_tracking
			x                                                                                                                                                                                   		0 - disable tracking by isl_mac_dst
			x                                                                                                                                                                                   		1 - enable tracking by isl_mac_dst
			x                                                                                                                                                                           	-isl_mac_src_high
			x                                                                                                                                                                               		Hex value used to configure the high 24 bits of the source mac address from the Cisco ISL header.(DEFAULT 0x000000)
			x                                                                                                                                                                           	-isl_mac_src_high_count
			x                                                                                                                                                                               		Numeric value which configures the number of times the isl_mac_src_high is incremeneted or decremented when isl_mac_src_high_mode is incr or decr.
			x                                                                                                                                                                           	-isl_mac_src_high_mode
			x                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                   		incr - the value is incremented as specified with isl_mac_src_high_step and isl_mac_src_high_count.
			x                                                                                                                                                                                   		decr - the value is decremented as specified with isl_mac_src_high_step and isl_mac_src_high_count.
			x                                                                                                                                                                                   		list - Parameter -isl_mac_src_high contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                           	-isl_mac_src_high_step
			x                                                                                                                                                                               		Hex step value used to modify isl_mac_src_high when isl_mac_src_high_mode is incr or decr.
			x                                                                                                                                                                           	-isl_mac_src_high_tracking
			x                                                                                                                                                                                   		0 - disable tracking by isl_mac_src_high
			x                                                                                                                                                                                   		1 - enable tracking by isl_mac_src_high
			x                                                                                                                                                                           	-isl_mac_src_low
			x                                                                                                                                                                               		Hex value used to configure the low 24 bits of the source mac address from the Cisco ISL header.(DEFAULT 0x000000)
			x                                                                                                                                                                           	-isl_mac_src_low_count
			x                                                                                                                                                                               		Numeric value which configures the number of times the isl_mac_src_low is incremeneted or decremented when isl_mac_src_low_mode is incr or decr.
			x                                                                                                                                                                           	-isl_mac_src_low_mode
			x                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                   		incr - the value is incremented as specified with isl_mac_src_low_step and isl_mac_src_low_count.
			x                                                                                                                                                                                   		decr - the value is decremented as specified with isl_mac_src_low_step and isl_mac_src_low_count.
			x                                                                                                                                                                                   		list - Parameter -isl_mac_src_low contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                           	-isl_mac_src_low_step
			x                                                                                                                                                                               		Hex step value used to modify isl_mac_src_low when isl_mac_src_low_mode is incr or decr.
			x                                                                                                                                                                           	-isl_mac_src_low_tracking
			x                                                                                                                                                                                   		0 - disable tracking by isl_mac_src_low
			x                                                                                                                                                                                   		1 - enable tracking by isl_mac_src_low
			x                                                                                                                                                                           	-isl_user_priority
			x                                                                                                                                                                               		Low order two bits of this value specify the priority of the packet as inclusive.
			x                                                                                                                                                                           	-isl_user_priority_count
			x                                                                                                                                                                               		Numeric value which configures the number of times the isl_user_priority is incremeneted or decremented when isl_user_priority_mode is incr or decr.
			x                                                                                                                                                                           	-isl_user_priority_mode
			x                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                   		incr - the value is incremented as specified with isl_user_priority_step and isl_user_priority_count.
			x                                                                                                                                                                                   		decr - the value is decremented as specified with isl_user_priority_step and isl_user_priority_count.
			x                                                                                                                                                                                   		list - Parameter -isl_user_priority contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                           	-isl_user_priority_step
			x                                                                                                                                                                               		Step value used to modify isl_user_priority when isl_user_priority_mode is incr or decr.
			x                                                                                                                                                                           	-isl_user_priority_tracking
			x                                                                                                                                                                                   		0 - disable tracking by isl_user_priority
			x                                                                                                                                                                                   		1 - enable tracking by isl_user_priority
			x                                                                                                                                                                           	-isl_vlan_id
			x                                                                                                                                                                               		Virtual LAN identification.
			x                                                                                                                                                                           	-isl_vlan_id_count
			x                                                                                                                                                                               		Numeric value which configures the number of times the isl_vlan_id is incremeneted or decremented when isl_vlan_id_mode is incr or decr.
			x                                                                                                                                                                           	-isl_vlan_id_mode
			x                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                   		incr - the value is incremented as specified with isl_vlan_id_step and isl_vlan_id_count.
			x                                                                                                                                                                                   		decr - the value is decremented as specified with isl_vlan_id_step and isl_vlan_id_count.
			x                                                                                                                                                                                   		list - Parameter -isl_vlan_id contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                           	-isl_vlan_id_step
			x                                                                                                                                                                               		Step value used to modify isl_vlan_id when isl_vlan_id_mode is incr or decr.
			x                                                                                                                                                                           	-isl_vlan_id_tracking
			x                                                                                                                                                                                   		0 - disable tracking by isl_vlan_id
			x                                                                                                                                                                                   		1 - enable tracking by isl_vlan_id
			x                                                                                                                                                                           	-l3_length_step
			x                                                                                                                                                                               	-lan_range_count
			x                                                                                                                                                                                   		This option is used to specify the number of LAN static endpoint ranges. It can take any numeric value. Valid only for traffic_generator ixnetwork when configuring L2VPN traffic.
			x                                                                                                                                                                               	-latency_bins
			x                                                                                                                                                                                   		Configure the number of bins. for the traffic item being configured. For this configuration to be valid latency bins, jitter or delay measurement global statistics must be enabled with ::<namespace>::traffic_control.
			x                                                                                                                                                                               	-latency_bins_enable
			x                                                                                                                                                                                   		Enable or disable latency_bins for the traffic item being configured. Valid options are:0 - Default1 -For this configuration to be valid latency bins, jitter or delay measurement global statistics must be enabled with ::<namespace>::traffic_control.
			x                                                                                                                                                                               	-latency_values
			x                                                                                                                                                                                   		The splitting values for the bins. 0 and Max will be the absolute end points. A list of {1.5 3 6.8} would create these four bins {0 - 1.5} {1.5 3} {3 6.8} {6.8 MAX}. It is always greater than the lower value and equal to or less than the upper value.Otherwise, it will be ignored. For this configuration to be valid latency bins, jitter or delay measurement global statistics must be enabled with ::<namespace>::traffic_control.
			x                                                                                                                                                                               	-loop_count
			x                                                                                                                                                                                   		When in packet mode and stream is set to return to id for a count, this is the count value for how many times to loop before stopping.
			x                                                                                                                                                                               	-mac_dst_count_step
			x                                                                                                                                                                                   		This option is used to specify the step between the value of the MAC address count of each the LAN static endpoint range. It can take any numeric value. Valid for traffic_generator ixnetwork when configuring L2VPN traffic.
			x                                                                                                                                                                               	-mac_dst_tracking
			x                                                                                                                                                                                       		-
			x                                                                                                                                                                                       		1 - enable tracking by mac_dst
			x                                                                                                                                                                               	-mac_src_tracking
			x                                                                                                                                                                                       		-
			x                                                                                                                                                                                       		1 - enable tracking by mac_src
			x                                                                                                                                                                               	-merge_destinations
			x                                                                                                                                                                                       		0 - disable merging of traffic item destinations
			x                                                                                                                                                                                       		1 - enable merging of traffic item destinations
			x                                                                                                                                                                               	-min_gap_bytes
			x                                                                                                                                                                                   		The minimum gap, in bytes, between sending packets.
			x                                                                                                                                                                               	-mpls
			x                                                                                                                                                                                   		Whether to enable MPLS on a particular stream. When enabled, configure the MPLS parameters by usgin the options "mpls_labels", "mpls_ttl", "mpls_exp_bit", "mpls_bottom_of_stack", and "mpls_type". Refer to Section "Scripts Samples" for an example.
			x                                                                                                                                                                               	-mpls_bottom_stack_bit
			x                                                                                                                                                                                   		Whether to enable the bottom of the stack bit. This bit is set to true for the last entry in the label stack (for the bottom of the stack) and false for all other label stack entries.
			x                                                                                                                                                                               	-mpls_bottom_stack_bit_count
			x                                                                                                                                                                                   		Numeric value which configures the number of times the mpls_bottom_stack_bit is incremeneted or decremented when mpls_labels_mode is incr or decr.
			x                                                                                                                                                                               	-mpls_bottom_stack_bit_step
			x                                                                                                                                                                                   		Step value used to modify mpls_bottom_stack_bit when mpls_bottom_stack_bit_mode is incr or decr.
			x                                                                                                                                                                               	-mpls_bottom_stack_bit_mode
			x                                                                                                                                                                                   		This parameter configures
			x                                                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                                                       		-
			x                                                                                                                                                                                       		incr - the value is incremented as specified with mpls_bottom_stack_bit_step and mpls_bottom_stack_bit_count.
			x                                                                                                                                                                                       		decr - the value is decremented as specified with mpls_bottom_stack_bit_step and mpls_bottom_stack_bit_count.
			x                                                                                                                                                                                       		list - Parameter -mpls_bottom_stack_bit contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                               	-mpls_bottom_stack_bit_tracking
			x                                                                                                                                                                                       		-
			x                                                                                                                                                                                       		1 - enable tracking by mpls_bottom_stack_bit
			x                                                                                                                                                                               	-mpls_exp_bit
			x                                                                                                                                                                                   		inclusive. If mpls_exp_bit_mode is list, you can use a list of values from 0-7 (example: 0,1,2,3,4). When modifying this parameter the user must set the mpls attribute to enable.
			x                                                                                                                                                                               	-mpls_exp_bit_count
			x                                                                                                                                                                                   		Numeric value which configures the number of times the mpls_exp_bit is incremeneted or decremented when mpls_exp_bit_mode is incr or decr.
			x                                                                                                                                                                               	-mpls_exp_bit_mode
			x                                                                                                                                                                                   		This parameter configures
			x                                                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                                                       		-
			x                                                                                                                                                                                       		incr - the value is incremented as specified with mpls_exp_bit_step and mpls_exp_bit_count.
			x                                                                                                                                                                                       		decr - the value is decremented as specified with mpls_exp_bit_step and mpls_exp_bit_count.
			x                                                                                                                                                                                       		list - Parameter -mpls_exp_bit contains a list of values (example: 0,2,3,5,7). Each packet
			x                                                                                                                                                                               	-mpls_exp_bit_step
			x                                                                                                                                                                                   		Step value used to modify mpls_exp_bit when mpls_exp_bit_mode is incr or decr.
			x                                                                                                                                                                               	-mpls_exp_bit_tracking
			x                                                                                                                                                                                       		-
			x                                                                                                                                                                                       		1 - enable tracking by mpls_exp_bit
			x                                                                                                                                                                               	-mpls_labels_count
			x                                                                                                                                                                                   		Numeric value which configures the number of times the mpls_labels is incremeneted or decremented when mpls_labels_mode is incr or decr.
			x                                                                                                                                                                               	-mpls_labels_mode
			x                                                                                                                                                                                   		This parameter configures
			x                                                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                                                       		-
			x                                                                                                                                                                                       		incr - the value is incremented as specified with mpls_labels_step and mpls_labels_count.
			x                                                                                                                                                                                       		decr - the value is decremented as specified with mpls_labels_step and mpls_labels_count.
			x                                                                                                                                                                                       		list - Parameter -mpls_labels contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                               	-mpls_labels_step
			x                                                                                                                                                                                   		Step value used to modify mpls_labels when mpls_labels_mode is incr or decr.
			x                                                                                                                                                                               	-mpls_labels_tracking
			x                                                                                                                                                                                       		-
			x                                                                                                                                                                                       		1 - enable tracking by mpls_labels
			x                                                                                                                                                                               	-mpls_ttl
			x                                                                                                                                                                                   		Time-to-live value for a particular tag in a stream.
			x                                                                                                                                                                               	-mpls_ttl_count
			x                                                                                                                                                                                   		Numeric value which configures the number of times the mpls_ttl is incremeneted or decremented when mpls_ttl_mode is incr or decr.
			x                                                                                                                                                                               	-mpls_ttl_mode
			x                                                                                                                                                                                   		This parameter configures
			x                                                                                                                                                                                   		Valid choices are:
			x                                                                                                                                                                                       		-
			x                                                                                                                                                                                       		incr - the value is incremented as specified with mpls_ttl_step and mpls_ttl_count.
			x                                                                                                                                                                                       		decr - the value is decremented as specified with mpls_ttl_step and mpls_ttl_count.
			x                                                                                                                                                                                       		list - Parameter -mpls_ttl contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                               	-mpls_ttl_step
			x                                                                                                                                                                                   		Step value used to modify mpls_ttl when mpls_ttl_mode is incr or decr.
			x                                                                                                                                                                               	-mpls_ttl_tracking
			x                                                                                                                                                                                       		-
			x                                                                                                                                                                                       		1 - enable tracking by mpls_ttl
			x                                                                                                                                                                               	-mpls_type
			x                                                                                                                                                                                   	-multiple_queues
			x                                                                                                                                                                                       	-name
			x                                                                                                                                                                                           		Stream string identifier/name. For ixnetwork 540+ traffic, if this name contains spaces, the spaces will be translated to underscores and a warning will be displayed. The string name must not contain commas. After when -name is used with -mode modify (and the name changes), the stream_id key needs to be refreshed (since its value is the name of the traffic item).
			x                                                                                                                                                                                       	-no_write
			x                                                                                                                                                                                           	-num_dst_ports
			x                                                                                                                                                                                               		This argument can be used to specify the number of ports on which the video server will be running in Triple Play tests. Valid only for traffic_generator ixnetwork, mode create/modify, circuit_endpoint_type ipv4_application_traffic/ipv6_application_traffic.
			x                                                                                                                                                                                           	-number_of_packets_per_stream
			x                                                                                                                                                                                               		Number of maximum frames in the stream.
			x                                                                                                                                                                                           	-number_of_packets_tx
			x                                                                                                                                                                                               		The number of packets that are to be transmitted in the stream
			x                                                                                                                                                                                           	-override_value_list
			x                                                                                                                                                                                               		This argument can be used to specify the list of tracking values that will be used to label the generated traffic.Valid only for traffic_generator ixnetwork and with the assured_forwarding_phb, class_selector_phb, default_phb, expedited_forwarding_phb, tos, raw_priority, inner_vlan, custom_8bit, custom_16bit, custom_24bit and custom_32bit choices of the -track_by argument.The list has the following structure:assured_forwarding_phb: {{unused_bits af_class codepoint} {unused_bitsaf_class codepoint} ...}where:unused_bits- 2 bit integer valueaf_class- integer value in the [1,4] intervalcodepoint- value in the {low,medium,high} setclass_selector_phb: {{unused_bits precedence} {unused_bits precedence} ...}where:unused_bits- 2 bit integer valueprecedence- integer value in the [1,7] intervaldefault_phb: {{unused_bits codepoint} {unused_bits codepoint} ...}where:unused_bits- 2 bit integer valuecodepoint- 6 bit integer value, in decimal formatexpedited_forwarding_phb: {{unused_bits codepoint} {unused_bits codepoint} ...}where:unused_bits- 2 bit integer valuecodepoint- 6 bit integer value, in decimal formattos: {{unused_bit monetary reliability throughput delay precedence} {unused_bit monetary reliability throughput delay precedence} ...}where:unused_bit- 1 bit valuemonetary- value in the {normal,minimize} setreliability- value in the {normal,high} setthroughput- value in the {normal,high} setdelay- value in the {normal,low} setprecedence- value in the {routine,priority,immediate,flash,,flash_override,critical_ecp,internetwork_contol,network_contol} setraw_priority: {raw_priority raw_priority ...}where:raw_priority- 8 bit integer value, in decimal formatinner_vlan: {{vlan_id cfi user_priority} {vlan_id cfi user_priority} ...}where:vlan_id- 12 bit integer value, in decimal formatcfi- 1 bit valueuser_priority- 3 bit integer valuecustom_8bit: {custom_value custom_value ...}where:unused_bit- 8 bit integer value, in decimal formatcustom_16bit: {custom_value custom_value ...}where:unused_bit- 16 bit integer value, in decimal formatcustom_24bit: {custom_value custom_value ...}where:unused_bit- 24 bit integer value, in decimal formatcustom_32bit: {custom_value custom_value ...}where:unused_bit- 32 bit integer value, in decimal format
			x                                                                                                                                                                                           	-pause_control_time
			x                                                                                                                                                                                               	-pending_operations_timeout
			x                                                                                                                                                                                                   		The amount of time (in seconds) to wait for the async protocols operations to finish (starting of clasic PPP sessions).
			x                                                                                                                                                                                               	-pgid_offset
			x                                                                                                                                                                                                   	-pgid_value
			x                                                                                                                                                                                                       		Unique value used to identify one packet group for another. Up to 57344 different packet groups may be defined. This parameter can take a list of values as follows: when traffic is configured bidirectional and this parameter has one value, this value will be set on both streams. When this parameter has a list of two values the first value will be assigned to the first stream and the second value to the second stream.(DEFAULT = current stream id)
			x                                                                                                                                                                                                   	-preamble_size_mode
			x                                                                                                                                                                                                       		Used to set the preamble mode on a high level stream.auto - Automatic preamble size.custom - Preamble size will be given by parameter preamble_custom_size.
			x                                                                                                                                                                                                   	-preamble_custom_size
			x                                                                                                                                                                                                       		Provides the preamble size (measured in bytes) for a high level stream only when the preamble size mode is set to custom. The default value is 6.
			x                                                                                                                                                                                                   	-pt_handle
			x                                                                                                                                                                                                       		The protocol template handle used to manipulate headers. This handle is obtained when using mode "get_available_protocol_templates" and it is presented in a user friendly format.
			x                                                                                                                                                                                                   	-public_port_ip
			x                                                                                                                                                                                                       	-pvc_count
			x                                                                                                                                                                                                           		This option is used to specify the number of PVCs created on the first ATM static endpoint range. It can take any value in the 0-4294967295 range.
			x                                                                                                                                                                                                       	-pvc_count_step
			x                                                                                                                                                                                                           		This option is used to specify the step between the number of PVCs created on each ATM static endpoint range. It can take any numeric value.
			x                                                                                                                                                                                                       	-qos_byte
			x                                                                                                                                                                                                           		The combined value for the precedence, delay, throughput, reliability, reserved and cost bits. This is only for PPP, L2TP and L2TPv3 traffic when using traffic_generator ixnetwork.
			x                                                                                                                                                                                                       	-qos_byte_count
			x                                                                                                                                                                                                           		Numeric value which configures the number of times the qos_byte is incremeneted or decremented when qos_byte_mode is incr or decr.
			x                                                                                                                                                                                                       	-qos_byte_mode
			x                                                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                               		incr - the value is incremented as specified with qos_byte_step and qos_byte_count.
			x                                                                                                                                                                                                               		decr - the value is decremented as specified with qos_byte_step and qos_byte_count.
			x                                                                                                                                                                                                               		list - Parameter -qos_byte contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                       	-qos_byte_step
			x                                                                                                                                                                                                           		Step value used to modify qos_byte when qos_byte_mode is incr or decr.
			x                                                                                                                                                                                                       	-qos_byte_tracking
			x                                                                                                                                                                                                               		0 - disable tracking by qos_byte
			x                                                                                                                                                                                                               		1 - enable tracking by qos_byte
			x                                                                                                                                                                                                       	-qos_ipv6_flow_label
			x                                                                                                                                                                                                           		The IPv6 flow label, from 0 through 1,048,575. Valid only if -encap is an ethernet encapsulation.
			x                                                                                                                                                                                                       	-qos_ipv6_traffic_class
			x                                                                                                                                                                                                           		The IPv6 traffic class, from 0 through 255. Valid only if -encap is an ethernet encapsulation.
			x                                                                                                                                                                                                       	-qos_type_ixn
			x                                                                                                                                                                                                           		Sets the Quality of Service type. Possible values include:
			x                                                                                                                                                                                                           		<choices><choice><choiceName>custom</choiceName><choiceText>A custom QoS type. With traffic_generator ixnetwork_540 use this in combination with parameters: qos_value_ixn, qos_value_ixn_mode, qos_value_ixn_step, qos_value_ixn_count, qos_value_ixn_tracking.</choiceText></choice><choice><choiceName>dscp</choiceName><choiceText>User DSCP as the QoS. With traffic_generator ixnetwork_540 use this in combination with parameters: qos_value_ixn. The rest of the depending parameters are specified based on the value of qos_value_ixn.</choiceText></choice><choice><choiceName>tos</choiceName><choiceText>Use ToS as the QoS.With traffic_generator ixnetwork_540 configure precedence using qos_value_ixn, qos_value_ixn_mode, qos_value_ixn_step, qos_value_ixn_count, qos_value_ixn_tracking OR ip_precedence, ip_precedence_mode, ip_precedence_step, ip_precedence_count, ip_precedence_tracking. The rest of the TOS bits are configured using parameters: ip_delay, ip_delay_mode, ip_delay_tracking, ip_throughput, ip_throughput_mode, ip_throughput_tracking, ip_reliability, ip_reliability_mode, ip_reliability_tracking ip_cost, ip_cost_mode, ip_cost_tracking.</choiceText></choice><choice><choiceName>ipv6</choiceName><choiceText>Use IPv6 as the QoS. (used when circuit_endpoint_type is ipv6. Only for traffic_generator ixnetwork)</choiceText></choice></choices>
			x                                                                                                                                                                                                       	-qos_value_ixn
			x                                                                                                                                                                                                           		The QoS value for this traffic stream. Depending on what type of QoS is selected the following values are accepted:
			x                                                                                                                                                                                                           		 1. When -qos_type_ixn tos = a value in the [0 - 7] range specifying ToS traffic priority
			x                                                                                                                                                                                                           		
			x                                                                                                                                                                                                           		- "0" = Routine
			x                                                                                                                                                                                                           		- "1" = Priority
			x                                                                                                                                                                                                           		- "2" = Immediate
			x                                                                                                                                                                                                           		- "3" = Flash
			x                                                                                                                                                                                                           		- "4" = Flash Override
			x                                                                                                                                                                                                           		- "5" = CRITIC/ECP
			x                                                                                                                                                                                                           		- "6" = Internet Control
			x                                                                                                                                                                                                           		- "7" = Network Control
			x                                                                                                                                                                                                           		
			x                                                                                                                                                                                                           		With traffic_generator ixnetwork_540 configure precedence using qos_value_ixn, qos_value_ixn_mode, qos_value_ixn_step, qos_value_ixn_count, qos_value_ixn_tracking OR ip_precedence, ip_precedence_mode, ip_precedence_step, ip_precedence_count, ip_precedence_tracking. The rest of the TOS bits are configured using parameters: ip_delay, ip_delay_mode, ip_delay_tracking, ip_throughput, ip_throughput_mode, ip_throughput_tracking, ip_reliability, ip_reliability_mode, ip_reliability_tracking ip_cost, ip_cost_mode, ip_cost_tracking.
			x                                                                                                                                                                                                           		2. When -qos_type_ixn dscp"dscp_default" (DEFAULT) = any traffic that does not meet the requirements of any of the other defined classes is placed in the default PHB. Typically, the default PHB has best-effort forwarding characteristics. For traffic_generator ixnetwork_540 with qos_value_ixn 'dscp_default' the following parameters can also be configured: ip_dscp, ip_dscp_mode, ip_dscp_count, ip_dscp_step, ip_dscp_tracking, ip_cu, ip_cu_mode, ip_cu_count, ip_cu_step, ip_cu_tracking.Assured Fowarding PHB allows the operator to provide assurance of delivery as long as the traffic does not exceed some subscribed rate.Traffic that exceeds the subscription rate faces a higher probability of being dropped if congestion occurs. The following AF options are available:
			x                                                                                                                                                                                                           		
			x                                                                                                                                                                                                           		- "af_class1_low_precedence" (Assured Forwarding PHB, Class 1, Low Precendence)
			x                                                                                                                                                                                                           		- "af_class1_medium_precedence" (Assured Forwarding PHB, Class 1, Medium Precendence)
			x                                                                                                                                                                                                           		- "af_class1_high_precedence" (Assured Forwarding PHB, Class 1, High Precendence)
			x                                                                                                                                                                                                           		- "af_class2_low_precedence" (Assured Forwarding PHB, Class 2, Low Precendence)
			x                                                                                                                                                                                                           		- "af_class2_medium_precedence" (Assured Forwarding PHB, Class 2, Medium Precendence)
			x                                                                                                                                                                                                           		- "af_class2_high_precedence" (Assured Forwarding PHB, Class 2, High Precendence)
			x                                                                                                                                                                                                           		- "af_class3_low_precedence" (Assured Forwarding PHB, Class 3, Low Precendence)
			x                                                                                                                                                                                                           		- "af_class3_medium_precedence" (Assured Forwarding PHB, Class 3, Medium Precendence)
			x                                                                                                                                                                                                           		- "af_class3_high_precedence" (Assured Forwarding PHB, Class 3, High Precendence)
			x                                                                                                                                                                                                           		- "af_class4_low_precedence" (Assured Forwarding PHB, Class 4, Low Precendence)
			x                                                                                                                                                                                                           		- "af_class4_medium_precedence" (Assured Forwarding PHB, Class 4, Medium Precendence)
			x                                                                                                                                                                                                           		- "af_class4_high_precedence" (Assured Forwarding PHB, Class 4, High Precendence)
			x                                                                                                                                                                                                           		- "ef" - the EF PHB has the characteristics of low delay, low loss and low jitter. These characteristics are suitable for voice, video and other realtime services. EF traffic is often given strict priority queuing above all other traffic classes. Because an overload of EF traffic will cause queuing delays and affect the jitter and delay tolerances within the class, EF traffic is often strictly controlled through admission control, policing and other mechanisms.
			x                                                                                                                                                                                                           		
			x                                                                                                                                                                                                           		Class Selector PHB is used to maintain backward compatibility with network devices that still use the Precedence field, giving the following options:
			x                                                                                                                                                                                                           		
			x                                                                                                                                                                                                           		- "cs_precedence1" (Class Selector PHB, Precedence 1)
			x                                                                                                                                                                                                           		- "cs_precedence2" (Class Selector PHB, Precedence 2)
			x                                                                                                                                                                                                           		- "cs_precedence3" (Class Selector PHB, Precedence 3)
			x                                                                                                                                                                                                           		- "cs_precedence4" (Class Selector PHB, Precedence 4)
			x                                                                                                                                                                                                           		- "cs_precedence5" (Class Selector PHB, Precedence 5)
			x                                                                                                                                                                                                           		- "cs_precedence6" (Class Selector PHB, Precedence 6)
			x                                                                                                                                                                                                           		- "cs_precedence7" (Class Selector PHB, Precedence 7)
			x                                                                                                                                                                                                           		
			x                                                                                                                                                                                                           		3. When -qos_type_ixn customa value in the [0 - 255] range (DEFAULT 0). With traffic_generator ixnetwork_540 the following parameters are also available: qos_type_ixn_mode, qos_type_ixn_step, qos_type_ixn_count, qos_type_ixn_tracking.
			x                                                                                                                                                                                                           		4. When -qos_type_ixn ipv6a value in the [0 - 255] range (DEFAULT 0) (Only available with traffic_generator ixnetwork_540.An error is returned if qos_value_ixn does not have any of the choices above.qos_value_ixn is set to default if it is one of the choices above but not one that is valid for the configured qos_type_ixn.
			x                                                                                                                                                                                                       	-qos_value_ixn_count
			x                                                                                                                                                                                                           		Numeric value which configures the number of times the qos_value_ixn is incremeneted or decremented when qos_value_ixn_mode is incr or decr.
			x                                                                                                                                                                                                       	-qos_value_ixn_mode
			x                                                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                               		incr - the value is incremented as specified with qos_value_ixn_step and qos_value_ixn_count.
			x                                                                                                                                                                                                               		decr - the value is decremented as specified with qos_value_ixn_step and qos_value_ixn_count.
			x                                                                                                                                                                                                               		list - Parameter -qos_value_ixn contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                       	-qos_value_ixn_step
			x                                                                                                                                                                                                           		Step value used to modify qos_value_ixn when qos_value_ixn_mode is incr or decr.
			x                                                                                                                                                                                                       	-qos_value_ixn_tracking
			x                                                                                                                                                                                                               		0 - disable tracking by qos_value_ixn
			x                                                                                                                                                                                                               		1 - enable tracking by qos_value_ixn
			x                                                                                                                                                                                                       	-queue_id
			x                                                                                                                                                                                                           	-ramp_up_percentage
			x                                                                                                                                                                                                               		This argument can be used to specify how fast the objective value is to be ramped up. Valid only for traffic_generator ixnetwork, mode create/modify and circuit_endpoint_type ipv4_application_traffic or ipv6_application_traffic. The -enable_test_objective argument must be set to 1 in order for the value of this argument to be used.
			x                                                                                                                                                                                                           	-range_per_spoke
			x                                                                                                                                                                                                               		This option can be used to specify the number of LAN static endpoints that are going to be connected through one ATM or Frame Relay endpoint.Valid only for traffic_generator ixnetwork when configuring L2VPN trafficand only if the -indirect option is enabled.
			x                                                                                                                                                                                                           	-rate_kbps
			x                                                                                                                                                                                                               		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>. Traffic rate to send in kbps.
			x                                                                                                                                                                                                           	-rate_mbps
			x                                                                                                                                                                                                               		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>. Traffic rate to send in mbps.
			x                                                                                                                                                                                                           	-rate_byteps
			x                                                                                                                                                                                                               		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>. Traffic rate to send in bytes per sec.
			x                                                                                                                                                                                                           	-rate_kbyteps
			x                                                                                                                                                                                                               		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>. Traffic rate to send in kbytes per sec.
			x                                                                                                                                                                                                           	-rate_mbyteps
			x                                                                                                                                                                                                               		This parameter can be updated while the traffic is running with -mode 'dynamic_update' and -stream_id <traffic_item_handle>. Traffic rate to send in mbytes per sec.
			x                                                                                                                                                                                                           	-rate_mode
			x                                                                                                                                                                                                               		This parameter denotes which rate parameter will be used.
			x                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                   		first_option_provided - The first provided parameter will be used. The order in which the parameters are provided is the following: -rate_bps, -rate_kbps, -rate_mbps, -rate_byteps, -rate_kbyteps, -rate_mbyteps, -rate_percent, -rate_pps
			x                                                                                                                                                                                                                   		bps - The -rate_bps parameter will be used. If it doesn't exist, the first parameter from the list specified in the first_option_provided will be used.
			x                                                                                                                                                                                                                   		kbps - The -rate_kbps parameter will be used. If it doesn't exist, the first parameter from the list specified in the first_option_provided will be used.
			x                                                                                                                                                                                                                   		mbps - The -rate_mbps parameter will be used. If it doesn't exist, the first parameter from the list specified in the first_option_provided will be used.
			x                                                                                                                                                                                                                   		byteps - The -rate_byteps parameter will be used. If it doesn't exist, the first parameter from the list specified in the first_option_provided will be used.
			x                                                                                                                                                                                                                   		kbyteps - The -rate_kbyteps parameter will be used. If it doesn't exist, the first parameter from the list specified in the first_option_provided will be used.
			x                                                                                                                                                                                                                   		mbyteps - The -rate_mbyteps parameter will be used. If it doesn't exist, the first parameter from the list specified in the first_option_provided will be used.
			x                                                                                                                                                                                                                   		percent - The -rate_percent parameter will used. If it doesn't exist, the first parameter from the list specified in the first_option_provided will be used.
			x                                                                                                                                                                                                                   		pps - The -rate_pps percent parameter will used. If it doesn't exist, the first parameter from the list specified in the first_option_provided will be used.
			x                                                                                                                                                                                                           	-return_to_id
			x                                                                                                                                                                                                               		When in packet mode, tells this stream to return to a specific stream it after it is sent
			x                                                                                                                                                                                                           	-rip_command
			x                                                                                                                                                                                                               		For option "l4_protocol" set to "rip", this option defines the RIP command for a particular stream.Valid options are:requestresponsetrace_ontrace_offreserved
			x                                                                                                                                                                                                           	-rip_command_mode
			x                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                   		list - Parameter -rip_command contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                           	-rip_command_tracking
			x                                                                                                                                                                                                                   		0 - disable tracking by rip_command
			x                                                                                                                                                                                                                   		1 - enable tracking by rip_command
			x                                                                                                                                                                                                           	-rip_rte_addr_family_id
			x                                                                                                                                                                                                               		Valid only for traffic_generator ixnetwork_540 and l4_protocol set to rip. Configure 2 bytes HEX Routing Table Entry Address Family Identifier. To configureAddress Family Identifier for multiple Routing Table Entries specify this parameter as list.
			x                                                                                                                                                                                                           	-rip_rte_addr_family_id_count
			x                                                                                                                                                                                                               		Numeric value which configures the number of times the rip_rte_addr_family_id is incremeneted or decremented when rip_rte_addr_family_id_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_addr_family_id_mode
			x                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                   		incr - the value is incremented as specified with rip_rte_addr_family_id_step and rip_rte_addr_family_id_count.
			x                                                                                                                                                                                                                   		decr - the value is decremented as specified with rip_rte_addr_family_id_step and rip_rte_addr_family_id_count.
			x                                                                                                                                                                                                           	-rip_rte_addr_family_id_step
			x                                                                                                                                                                                                               		Step value used to modify rip_rte_addr_family_id when rip_rte_addr_family_id_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_addr_family_id_tracking
			x                                                                                                                                                                                                                   		0 - disable tracking by rip_rte_addr_family_id
			x                                                                                                                                                                                                                   		1 - enable tracking by rip_rte_addr_family_id
			x                                                                                                                                                                                                           	-rip_rte_ipv4_addr
			x                                                                                                                                                                                                               		Valid only for traffic_generator ixnetwork_540 and l4_protocol set to rip. Configure Routing Table Entry IPv4 Address field. To configureIPv4 Address for multiple Routing Table Entries specify this parameter as list.
			x                                                                                                                                                                                                           	-rip_rte_ipv4_addr_count
			x                                                                                                                                                                                                               		Numeric value which configures the number of times the rip_rte_ipv4_addr is incremeneted or decremented when rip_rte_ipv4_addr_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_ipv4_addr_mode
			x                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                   		incr - the value is incremented as specified with rip_rte_ipv4_addr_step and rip_rte_ipv4_addr_count.
			x                                                                                                                                                                                                                   		decr - the value is decremented as specified with rip_rte_ipv4_addr_step and rip_rte_ipv4_addr_count.
			x                                                                                                                                                                                                           	-rip_rte_ipv4_addr_step
			x                                                                                                                                                                                                               		Step value used to modify rip_rte_ipv4_addr when rip_rte_ipv4_addr_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_ipv4_addr_tracking
			x                                                                                                                                                                                                                   		0 - disable tracking by rip_rte_ipv4_addr
			x                                                                                                                                                                                                                   		1 - enable tracking by rip_rte_ipv4_addr
			x                                                                                                                                                                                                           	-rip_rte_metric
			x                                                                                                                                                                                                               		Valid only for traffic_generator ixnetwork_540 and l4_protocol. Configure Routing Table Entry Metric field. To configureMetric for multiple Routing Table Entries specify this parameter as list.
			x                                                                                                                                                                                                           	-rip_rte_metric_count
			x                                                                                                                                                                                                               		Numeric value which configures the number of times the rip_rte_metric is incremeneted or decremented when rip_rte_metric_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_metric_mode
			x                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                   		incr - the value is incremented as specified with rip_rte_metric_step and rip_rte_metric_count.
			x                                                                                                                                                                                                                   		decr - the value is decremented as specified with rip_rte_metric_step and rip_rte_metric_count.
			x                                                                                                                                                                                                                   		list - Parameter -rip_rte_metric contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                           	-rip_rte_metric_step
			x                                                                                                                                                                                                               		Step value used to modify rip_rte_metric when rip_rte_metric_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_metric_tracking
			x                                                                                                                                                                                                                   		0 - disable tracking by rip_rte_metric
			x                                                                                                                                                                                                                   		1 - enable tracking by rip_rte_metric
			x                                                                                                                                                                                                           	-rip_rte_v1_unused2
			x                                                                                                                                                                                                               		Valid only for traffic_generator ixnetwork_540 and l4_protocol set to rip and and rip_version 1. Configure Routing Table Entry Unused2 field. To configureUnused2 for multiple Routing Table Entries specify this parameter as list.
			x                                                                                                                                                                                                           	-rip_rte_v1_unused2_count
			x                                                                                                                                                                                                               		Numeric value which configures the number of times the rip_rte_v1_unused2 is incremeneted or decremented when rip_rte_v1_unused2_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_v1_unused2_mode
			x                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                   		incr - the value is incremented as specified with rip_rte_v1_unused2_step and rip_rte_v1_unused2_count.
			x                                                                                                                                                                                                                   		decr - the value is decremented as specified with rip_rte_v1_unused2_step and rip_rte_v1_unused2_count.
			x                                                                                                                                                                                                           	-rip_rte_v1_unused2_step
			x                                                                                                                                                                                                               		Step value used to modify rip_rte_v1_unused2 when rip_rte_v1_unused2_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_v1_unused2_tracking
			x                                                                                                                                                                                                                   		0 - disable tracking by rip_rte_v1_unused2
			x                                                                                                                                                                                                                   		1 - enable tracking by rip_rte_v1_unused2
			x                                                                                                                                                                                                           	-rip_rte_v1_unused3
			x                                                                                                                                                                                                               		Valid only for traffic_generator ixnetwork_540 and l4_protocol set to rip and and rip_version 1. Configure Routing Table Entry Unused3 field. To configureUnused3 for multiple Routing Table Entries specify this parameter as list.
			x                                                                                                                                                                                                           	-rip_rte_v1_unused3_count
			x                                                                                                                                                                                                               		Numeric value which configures the number of times the rip_rte_v1_unused3 is incremeneted or decremented when rip_rte_v1_unused3_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_v1_unused3_mode
			x                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                   		incr - the value is incremented as specified with rip_rte_v1_unused3_step and rip_rte_v1_unused3_count.
			x                                                                                                                                                                                                                   		decr - the value is decremented as specified with rip_rte_v1_unused3_step and rip_rte_v1_unused3_count.
			x                                                                                                                                                                                                           	-rip_rte_v1_unused3_step
			x                                                                                                                                                                                                               		Step value used to modify rip_rte_v1_unused3 when rip_rte_v1_unused3_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_v1_unused3_tracking
			x                                                                                                                                                                                                                   		0 - disable tracking by rip_rte_v1_unused3
			x                                                                                                                                                                                                                   		1 - enable tracking by rip_rte_v1_unused3
			x                                                                                                                                                                                                           	-rip_rte_v1_unused4
			x                                                                                                                                                                                                               		Valid only for traffic_generator ixnetwork_540 and l4_protocol set to rip and and rip_version 1. Configure Routing Table Entry Unused4 field. To configureUnused4 for multiple Routing Table Entries specify this parameter as list.
			x                                                                                                                                                                                                           	-rip_rte_v1_unused4_count
			x                                                                                                                                                                                                               		Numeric value which configures the number of times the rip_rte_v1_unused4 is incremeneted or decremented when rip_rte_v1_unused4_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_v1_unused4_mode
			x                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                   		incr - the value is incremented as specified with rip_rte_v1_unused4_step and rip_rte_v1_unused4_count.
			x                                                                                                                                                                                                                   		decr - the value is decremented as specified with rip_rte_v1_unused4_step and rip_rte_v1_unused4_count.
			x                                                                                                                                                                                                           	-rip_rte_v1_unused4_step
			x                                                                                                                                                                                                               		Step value used to modify rip_rte_v1_unused4 when rip_rte_v1_unused4_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_v1_unused4_tracking
			x                                                                                                                                                                                                                   		0 - disable tracking by rip_rte_v1_unused4
			x                                                                                                                                                                                                                   		1 - enable tracking by rip_rte_v1_unused4
			x                                                                                                                                                                                                           	-rip_rte_v2_next_hop
			x                                                                                                                                                                                                               		Valid only for traffic_generator ixnetwork_540 and l4_protocol rip and and rip_version 2. Configure Routing Table Entry Next Hop IP address. To configureNext Hop for multiple Routing Table Entries specify this parameter as list.
			x                                                                                                                                                                                                           	-rip_rte_v2_next_hop_count
			x                                                                                                                                                                                                               		Numeric value which configures the number of times the rip_rte_v2_next_hop is incremeneted or decremented when rip_rte_v2_next_hop_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_v2_next_hop_mode
			x                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                   		incr - the value is incremented as specified with rip_rte_v2_next_hop_step and rip_rte_v2_next_hop_count.
			x                                                                                                                                                                                                                   		decr - the value is decremented as specified with rip_rte_v2_next_hop_step and rip_rte_v2_next_hop_count.
			x                                                                                                                                                                                                           	-rip_rte_v2_next_hop_step
			x                                                                                                                                                                                                               		Step value used to modify rip_rte_v2_next_hop when rip_rte_v2_next_hop_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_v2_next_hop_tracking
			x                                                                                                                                                                                                                   		0 - disable tracking by rip_rte_v2_next_hop
			x                                                                                                                                                                                                                   		1 - enable tracking by rip_rte_v2_next_hop
			x                                                                                                                                                                                                           	-rip_rte_v2_route_tag
			x                                                                                                                                                                                                               		Valid only for traffic_generator ixnetwork_540 and l4_protocol rip and and rip_version 2. Configure Routing Table Entry Route Tag. To configureRoute Tag for multiple Routing Table Entries specify this parameter as list.
			x                                                                                                                                                                                                           	-rip_rte_v2_route_tag_count
			x                                                                                                                                                                                                               		Numeric value which configures the number of times the rip_rte_v2_route_tag is incremeneted or decremented when rip_rte_v2_route_tag_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_v2_route_tag_mode
			x                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                   		incr - the value is incremented as specified with rip_rte_v2_route_tag_step and rip_rte_v2_route_tag_count.
			x                                                                                                                                                                                                                   		decr - the value is decremented as specified with rip_rte_v2_route_tag_step and rip_rte_v2_route_tag_count.
			x                                                                                                                                                                                                           	-rip_rte_v2_route_tag_step
			x                                                                                                                                                                                                               		Step value used to modify rip_rte_v2_route_tag when rip_rte_v2_route_tag_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_v2_route_tag_tracking
			x                                                                                                                                                                                                                   		0 - disable tracking by rip_rte_v2_route_tag
			x                                                                                                                                                                                                                   		1 - enable tracking by rip_rte_v2_route_tag
			x                                                                                                                                                                                                           	-rip_rte_v2_subnet_mask
			x                                                                                                                                                                                                               		Valid only for traffic_generator ixnetwork_540 and l4_protocol rip and and rip_version 2. Configure Routing Table Entry Subnet Mask. To configureSubnet Mask for multiple Routing Table Entries specify this parameter as list.
			x                                                                                                                                                                                                           	-rip_rte_v2_subnet_mask_count
			x                                                                                                                                                                                                               		Numeric value which configures the number of times the rip_rte_v2_subnet_mask is incremeneted or decremented when rip_rte_v2_subnet_mask_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_v2_subnet_mask_mode
			x                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                   		incr - the value is incremented as specified with rip_rte_v2_subnet_mask_step and rip_rte_v2_subnet_mask_count.
			x                                                                                                                                                                                                                   		decr - the value is decremented as specified with rip_rte_v2_subnet_mask_step and rip_rte_v2_subnet_mask_count.
			x                                                                                                                                                                                                                   		list - Parameter -rip_rte_v2_subnet_mask contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                           	-rip_rte_v2_subnet_mask_step
			x                                                                                                                                                                                                               		Step value used to modify rip_rte_v2_subnet_mask when rip_rte_v2_subnet_mask_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_rte_v2_subnet_mask_tracking
			x                                                                                                                                                                                                                   		0 - disable tracking by rip_rte_v2_subnet_mask
			x                                                                                                                                                                                                                   		1 - enable tracking by rip_rte_v2_subnet_mask
			x                                                                                                                                                                                                           	-rip_unused
			x                                                                                                                                                                                                               		For option "l4_protocol" set to "rip", this option defines the RIP "Unused" field.
			x                                                                                                                                                                                                           	-rip_unused_count
			x                                                                                                                                                                                                               		Numeric value which configures the number of times the rip_unused is incremeneted or decremented when rip_unused_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_unused_mode
			x                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                   		incr - the value is incremented as specified with rip_unused_step and rip_unused_count.
			x                                                                                                                                                                                                                   		decr - the value is decremented as specified with rip_unused_step and rip_unused_count.
			x                                                                                                                                                                                                                   		list - Parameter -rip_unused contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                           	-rip_unused_step
			x                                                                                                                                                                                                               		Step value used to modify rip_unused when rip_unused_mode is incr or decr.
			x                                                                                                                                                                                                           	-rip_unused_tracking
			x                                                                                                                                                                                                                   		0 - disable tracking by rip_unused
			x                                                                                                                                                                                                                   		1 - enable tracking by rip_unused
			x                                                                                                                                                                                                           	-rip_version
			x                                                                                                                                                                                                               		For option "l4_protocol" set to "rip", this option defines the RIP version for a particular stream.1 - Version 1.2 - Version 2.
			x                                                                                                                                                                                                           	-route_mesh
			x                                                                                                                                                                                                               		Specifies the mapping between source routes and destination routes.fully- full mesh, every source route is mapped to every destination route. This is the default when traffic_generator ixnetworkone_to_one - each source route is mapped with only one destination route. This is the default when traffic_generator ixnetwork_540
			x                                                                                                                                                                                                           	-session_aware_traffic
			x                                                                                                                                                                                                               		The session aware traffic field for a traffic item. The only available choice is ppp. When session_aware_traffic is set to ppp, the kill bit will be enabled. Also, when session_aware_traffic is set to ppp, the value of the dynamic_update_field parameter will be automatically set to ppp.
			x                                                                                                                                                                                                           	-signature
			x                                                                                                                                                                                                               	-signature_length
			x                                                                                                                                                                                                                   	-signature_offset
			x                                                                                                                                                                                                                       	-site_id
			x                                                                                                                                                                                                                           		This option is used to specify the site id value for the first LAN static endpoint range. It can take decimal values in the 0-4294967295 range. Valid for traffic_generator ixnetwork when configuring L2VPN traffic.
			x                                                                                                                                                                                                                       	-site_id_enable
			x                                                                                                                                                                                                                           		This option is used to specify whether the site id will be configured for the LAN static endpoint range. Valid for traffic_generator ixnetwork when configuring L2VPN traffic.
			x                                                                                                                                                                                                                       	-site_id_step
			x                                                                                                                                                                                                                           		This option is used to specify the step between the value of the site ip of each the LAN static endpoint range. It can take any numeric value. Valid for traffic_generator ixnetwork when configuring L2VPN traffic.
			x                                                                                                                                                                                                                       	-skip_frame_size_validation
			x                                                                                                                                                                                                                           		This flag is used to reduce the configuration time for the ixia::traffic_config by skipingthe computation of the frame_size.
			x                                                                                                                                                                                                                       	-source_filter
			x                                                                                                                                                                                                                           		This parameter filter on the available source endpoints that can be provided with emulation_src_handle.
			x                                                                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                                                                               		all - There are no filters applied
			x                                                                                                                                                                                                                               		ethernet - Ethernet endpoints only (for raw trafic only)
			x                                                                                                                                                                                                                               		atm - ATM endpoints only (for raw trafic only)
			x                                                                                                                                                                                                                               		framerelay - Frame Relay endpoints only (for raw trafic only)
			x                                                                                                                                                                                                                               		hdlc - HDLC endpoints only (for raw trafic only)
			x                                                                                                                                                                                                                               		ppp - PPP endpoints only (for raw trafic only)
			x                                                                                                                                                                                                                               		none - non MPLS endpoints only
			x                                                                                                                                                                                                                               		l2vpn - L2VPN endpoints only
			x                                                                                                                                                                                                                               		l3vpn - L3VPN endpoints only
			x                                                                                                                                                                                                                               		mpls - MPLS endpoints only
			x                                                                                                                                                                                                                               		6pe - 6PE endpoints only
			x                                                                                                                                                                                                                               		6vpe - 6VPE endpoints only
			x                                                                                                                                                                                                                               		bgpvpls - VPLS endpoints only
			x                                                                                                                                                                                                                               		mac_in_mac - MAC in MAC endpoints only
			x                                                                                                                                                                                                                               		data_center_bridging - Data Center and Bridging endpoints only
			x                                                                                                                                                                                                                       	-src_dest_mesh
			x                                                                                                                                                                                                                           		Specifies the mapping between source and destination. The choice 'fully' used along with traffic_generator ixnetwork is equivalent to the choice 'many_to_many' used along with traffic_generator ixnetwork_540. Valid options are:
			x                                                                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                                                                               		none - It acts as if there were no endpoints (for meshing purposes); all sources and all destinations are treated as one big endpoint.
			x                                                                                                                                                                                                                               		fully - Full mesh, every source is combined with every destination. This is the default value when using traffic_generator ixnetwork.
			x                                                                                                                                                                                                                               		one_to_one - One to one, each source has one destination. This is the default value when using traffic_generator ixnetwork_540.
			x                                                                                                                                                                                                                               		many_to_many - Only for traffic_generator ixnetwork_540. many-to-many matching occurs between each Source Endpoints and all of the Destination Endpoints. One traffic flow is created for each Source/Destination pair. For example:First pair: First Source Endpoint and first Destination Endpoint.; Second pair: First Source Endpoint and second Destination Endpoint.; Third pair: First Source Endpoint and third Destination Endpoint.
			x                                                                                                                                                                                                                       	-stream_packing
			x                                                                                                                                                                                                                           		This argument can be used to specify the way the streams generated for a traffic item are packed.This parameter is deprecated for traffic_generator ixnetwork_540, use transmit_distribution instead. If traffic_generator is ixnetwork_540 and both parameters stream_packing will be
			x                                                                                                                                                                                                                           		ignored. Valid choices are:
			x                                                                                                                                                                                                                           		<choices><choice><choiceName>merge_destination_ranges </choiceName><choiceText>combine alike destinations, such as route ranges, into one stream. With traffic_generator ixnetwork_540 this option will perform the same action as transmit_distribution 'endpoint_pair'.</choiceText></choice><choice><choiceName>one_stream_per_endpoint_pair</choiceName><choiceText>one stream will be created per source/destination endpoint pair. With traffic_generator ixnetwork_540 this option will perform the same action as transmit_distribution 'endpoint_pair'.</choiceText></choice><choice><choiceName>optimal_packing </choiceName><choiceText>each source endpoint and its destination ranges will be packed together into a single stream. With traffic_generator ixnetwork_540 this option will perform the same action as transmit_distribution 'none'.</choiceText></choice></choices>
			x                                                                                                                                                                                                                       	-table_udf_column_name
			x                                                                                                                                                                                                                           	-table_udf_column_offset
			x                                                                                                                                                                                                                               		List of column offsets in bytes from the beginning of the packet. If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                           	-table_udf_column_size
			x                                                                                                                                                                                                                               		List of column sizes in bytes. If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                           	-table_udf_column_type
			x                                                                                                                                                                                                                               		List of column types: hex ascii binary decimal mac ipv4 ipv6 and also a custom type. The custom type can be a combination of numbers and a,b,d, and x (eg: "8b,3d,16x") and is not valid with traffic_generator ixnetwork_540. a - ascii; b - binary; d - decimal; x - hex. If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                           	-table_udf_rows
			x                                                                                                                                                                                                                               		A keyed list of rows that need to be added to the table UDF. The rows must respect column order, size and type. The keyed list should have the format below for n columns and m rows:{row_1 {column_value_11 ... column_value_1n}}{row_2 {column_value_21 ... column_value_2n}}...........................................{row_m {column_value_m1 ... column_value_mn}}If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                           	-tcp_ack_flag_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_ack_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_ack_flag_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_ack_flag
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_ack_flag
			x                                                                                                                                                                                                                           	-tcp_ack_num_count
			x                                                                                                                                                                                                                               		Numeric value which configures the number of times the tcp_ack_num is incremeneted or decremented when tcp_ack_num_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_ack_num_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		incr - the value is incremented as specified with tcp_ack_num_step and tcp_ack_num_count.
			x                                                                                                                                                                                                                                   		decr - the value is decremented as specified with tcp_ack_num_step and tcp_ack_num_count.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_ack_num contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_ack_num_step
			x                                                                                                                                                                                                                               		Step value used to modify tcp_ack_num when tcp_ack_num_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_ack_num_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_ack_num
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_ack_num
			x                                                                                                                                                                                                                           	-tcp_checksum
			x                                                                                                                                                                                                                               		Configure the TCP Checksum field (2 bytes HEX).
			x                                                                                                                                                                                                                           	-tcp_checksum_count
			x                                                                                                                                                                                                                               		Numeric value which configures the number of times the tcp_checksum is incremeneted or decremented when tcp_checksum_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_checksum_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		incr - the value is incremented as specified with tcp_checksum_step and tcp_checksum_count.
			x                                                                                                                                                                                                                                   		decr - the value is decremented as specified with tcp_checksum_step and tcp_checksum_count.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_checksum contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_checksum_step
			x                                                                                                                                                                                                                               		Step value used to modify tcp_checksum when tcp_checksum_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_checksum_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_checksum
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_checksum
			x                                                                                                                                                                                                                           	-tcp_cwr_flag
			x                                                                                                                                                                                                                               		Configure the TCP ECN CWR bit.
			x                                                                                                                                                                                                                           	-tcp_cwr_flag_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_cwr_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_cwr_flag_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_cwr_flag
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_cwr_flag
			x                                                                                                                                                                                                                           	-tcp_data_offset
			x                                                                                                                                                                                                                               		Configure the TCP Data Offset field (0-15).
			x                                                                                                                                                                                                                           	-tcp_data_offset_count
			x                                                                                                                                                                                                                               		Numeric value which configures the number of times the tcp_data_offset is incremeneted or decremented when tcp_data_offset_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_data_offset_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		incr - the value is incremented as specified with tcp_data_offset_step and tcp_data_offset_count.
			x                                                                                                                                                                                                                                   		decr - the value is decremented as specified with tcp_data_offset_step and tcp_data_offset_count.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_data_offset contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_data_offset_step
			x                                                                                                                                                                                                                               		Step value used to modify tcp_data_offset when tcp_data_offset_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_data_offset_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_data_offset
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_data_offset
			x                                                                                                                                                                                                                           	-tcp_dst_port_count
			x                                                                                                                                                                                                                               		Numeric value which configures the number of times the tcp_dst_port is incremeneted or decremented when tcp_dst_port_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_dst_port_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		incr - the value is incremented as specified with tcp_dst_port_step and tcp_dst_port_count.
			x                                                                                                                                                                                                                                   		decr - the value is decremented as specified with tcp_dst_port_step and tcp_dst_port_count.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_dst_port contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_dst_port_step
			x                                                                                                                                                                                                                               		Step value used to modify tcp_dst_port when tcp_dst_port_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_dst_port_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_dst_port
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_dst_port
			x                                                                                                                                                                                                                           	-tcp_ecn_echo_flag
			x                                                                                                                                                                                                                               		Configure the TCP ECN Echo bit.
			x                                                                                                                                                                                                                           	-tcp_ecn_echo_flag_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_ecn_echo_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_ecn_echo_flag_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_ecn_echo_flag
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_ecn_echo_flag
			x                                                                                                                                                                                                                           	-tcp_fin_flag_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_fin_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_fin_flag_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_fin_flag
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_fin_flag
			x                                                                                                                                                                                                                           	-tcp_ns_flag
			x                                                                                                                                                                                                                               		Configure the TCP ECN NS bit.
			x                                                                                                                                                                                                                           	-tcp_ns_flag_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_ns_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_ns_flag_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_ns_flag
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_ns_flag
			x                                                                                                                                                                                                                           	-tcp_psh_flag_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_psh_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_psh_flag_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_psh_flag
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_psh_flag
			x                                                                                                                                                                                                                           	-tcp_reserved_count
			x                                                                                                                                                                                                                               		Numeric value which configures the number of times the tcp_reserved is incremeneted or decremented when tcp_reserved_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_reserved_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		incr - the value is incremented as specified with tcp_reserved_step and tcp_reserved_count.
			x                                                                                                                                                                                                                                   		decr - the value is decremented as specified with tcp_reserved_step and tcp_reserved_count.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_reserved contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_reserved_step
			x                                                                                                                                                                                                                               		Step value used to modify tcp_reserved when tcp_reserved_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_reserved_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_reserved
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_reserved
			x                                                                                                                                                                                                                           	-tcp_rst_flag_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_rst_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_rst_flag_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_rst_flag
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_rst_flag
			x                                                                                                                                                                                                                           	-tcp_seq_num_count
			x                                                                                                                                                                                                                               		Numeric value which configures the number of times the tcp_seq_num is incremeneted or decremented when tcp_seq_num_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_seq_num_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		incr - the value is incremented as specified with tcp_seq_num_step and tcp_seq_num_count.
			x                                                                                                                                                                                                                                   		decr - the value is decremented as specified with tcp_seq_num_step and tcp_seq_num_count.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_seq_num contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_seq_num_step
			x                                                                                                                                                                                                                               		Step value used to modify tcp_seq_num when tcp_seq_num_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_seq_num_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_seq_num
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_seq_num
			x                                                                                                                                                                                                                           	-tcp_src_port_count
			x                                                                                                                                                                                                                               		Numeric value which configures the number of times the tcp_src_port is incremeneted or decremented when tcp_src_port_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_src_port_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		incr - the value is incremented as specified with tcp_src_port_step and tcp_src_port_count.
			x                                                                                                                                                                                                                                   		decr - the value is decremented as specified with tcp_src_port_step and tcp_src_port_count.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_src_port contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_src_port_step
			x                                                                                                                                                                                                                               		Step value used to modify tcp_src_port when tcp_src_port_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_src_port_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_src_port
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_src_port
			x                                                                                                                                                                                                                           	-tcp_syn_flag_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_syn_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_syn_flag_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_syn_flag
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_syn_flag
			x                                                                                                                                                                                                                           	-tcp_urg_flag_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_urg_flag contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_urg_flag_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_urg_flag
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_urg_flag
			x                                                                                                                                                                                                                           	-tcp_urgent_ptr_count
			x                                                                                                                                                                                                                               		Numeric value which configures the number of times the tcp_urgent_ptr is incremeneted or decremented when tcp_urgent_ptr_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_urgent_ptr_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		incr - the value is incremented as specified with tcp_urgent_ptr_step and tcp_urgent_ptr_count.
			x                                                                                                                                                                                                                                   		decr - the value is decremented as specified with tcp_urgent_ptr_step and tcp_urgent_ptr_count.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_urgent_ptr contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_urgent_ptr_step
			x                                                                                                                                                                                                                               		Step value used to modify tcp_urgent_ptr when tcp_urgent_ptr_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_urgent_ptr_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_urgent_ptr
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_urgent_ptr
			x                                                                                                                                                                                                                           	-tcp_window_count
			x                                                                                                                                                                                                                               		Numeric value which configures the number of times the tcp_window is incremeneted or decremented when tcp_window_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_window_mode
			x                                                                                                                                                                                                                               		This parameter configures
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                   		incr - the value is incremented as specified with tcp_window_step and tcp_window_count.
			x                                                                                                                                                                                                                                   		decr - the value is decremented as specified with tcp_window_step and tcp_window_count.
			x                                                                                                                                                                                                                                   		list - Parameter -tcp_window contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                           	-tcp_window_step
			x                                                                                                                                                                                                                               		Step value used to modify tcp_window when tcp_window_mode is incr or decr.
			x                                                                                                                                                                                                                           	-tcp_window_tracking
			x                                                                                                                                                                                                                                   		0 - disable tracking by tcp_window
			x                                                                                                                                                                                                                                   		1 - enable tracking by tcp_window
			x                                                                                                                                                                                                                           	-test_objective_value
			x                                                                                                                                                                                                                               		Valid only for traffic_generator ixnetwork, mode create/modify and circuit_endpoint_type ipv4_application_traffic ot ipv6_application_traffic. The -enable_test_objective argument must be set to 1 in order for the value of this argument to be used.
			x                                                                                                                                                                                                                           	-track_by
			x                                                                                                                                                                                                                               		This argument can be used to specify the method of tracking the generated traffic in order to gather traffic statistics.With traffic_generator ixnetwork_540 the values specified with -track_by on mode modify will be appended to the existing track_byvalues of the traffic item.For traffic_generator ixnetwork_540 we support all available IxNetwork low level API choices. Valid choices are:
			x                                                                                                                                                                                                                                   		assured_forwarding_phb - QoS assured forwarding PHB will be used as the tracking item.When traffic_generator is ixnetwork_540 this is valid only when qos_type_ixn is configured to af_class1_low_precedence or af_class2_low_precedence or af_class3_low_precedence or af_class4_low_precedence or af_class1_medium_precedence or af_class2_medium_precedence or af_class3_medium_precedence or af_class4_medium_precedence or af_class1_high_precedence or af_class2_high_precedence or af_class3_high_precedence or af_class4_high_precedence.
			x                                                                                                                                                                                                                                   		class_selector_phb- QoS class selector PHB will be used as the tracking item.When traffic_generator is ixnetwork_540 this is valid only when qos_type_ixn is configured to cs_precedence1 or cs_precedence2 or cs_precedence3 cs_precedence4 or cs_precedence5 or cs_precedence6 cs_precedence7.
			x                                                                                                                                                                                                                                   		default_phb - QoS default PHB will be used as the tracking item.When traffic_generator is ixnetwork_540 this is valid only when qos_type_ixn is configured to dscp_default or qos_type_ixn is not specified and ip_dscp is specified.
			x                                                                                                                                                                                                                                   		expedited_forwarding_phb- QoS expedited forwarding PHB will be used as the tracking item.When traffic_generator is ixnetwork_540 this is valid only when qos_type_ixn is configured to 'ef'.
			x                                                                                                                                                                                                                                   		endpoint_pair- Tracking per source/destination endpoint pair.
			x                                                                                                                                                                                                                                   		tos- IP header TOS values will be used as the tracking item.When traffic_generator is ixnetwork_540 this is valid only when qos_type_ixn is configured to 'tos' or qos_type_ixn, qos_byte and ip_dscp are not specified and ip_precedence is configured.
			x                                                                                                                                                                                                                                   		dest_ip- The Destination IP address will be used as the tracking item.
			x                                                                                                                                                                                                                                   		source_ip - The Source IP address will be used as the tracking item.
			x                                                                                                                                                                                                                                   		ipv6_flow_label - The IPv6 flow label address will be used as the tracking item.
			x                                                                                                                                                                                                                                   		mpls_label - Available only for traffic that uses MPLS labels. The MPLS label will be used as the tracking item.
			x                                                                                                                                                                                                                                   		mpls_mpls_exp - Available only for traffic that uses MPLS labels. The MPLS Exp Bit will be used as the tracking item.
			x                                                                                                                                                                                                                                   		mpls_flow_descriptor - Available only for traffic that uses MPLS labels. The MPLS flow descriptor will be used as the tracking item.
			x                                                                                                                                                                                                                                   		inner_vlan - The VLAN ID will be used as the tracking item. This can be also combined with enable_override_value and override_value_list arguments.
			x                                                                                                                                                                                                                                   		dst_mac - The Destination MAC address will be used as the tracking item.
			x                                                                                                                                                                                                                                   		src_mac - The Source MAC address will be used as the tracking item.
			x                                                                                                                                                                                                                                   		dlci - The FrameRelay DLCI address will be used as the tracking item.
			x                                                                                                                                                                                                                                   		raw_priority- IP header raq qos values will be used as the tracking item.When traffic_generator is ixnetwork_540 this is valid only when qos_type_ixn is configured to 'custom' or qos_type_ixn is not specified and qos_byte is configured.
			x                                                                                                                                                                                                                                   		custom_8bit - A custom-defined 8bit value (or values) will be used as the tracking item.
			x                                                                                                                                                                                                                                   		custom_16bit - A custom-defined 16bit value (or values) will be used as the tracking item
			x                                                                                                                                                                                                                                   		custom_24bit - A custom-defined 24bit value (or values) will be used as the tracking item
			x                                                                                                                                                                                                                                   		custom_32bit - A custom-defined 32bit value (or values) will be used as the tracking item
			x                                                                                                                                                                                                                                   		b_src_mac - Valid when -circuit_type is mac_in_mac
			x                                                                                                                                                                                                                                   		b_dest_mac - Valid when -circuit_type is mac_in_mac
			x                                                                                                                                                                                                                                   		b_vlan - Valid when -circuit_type is mac_in_mac
			x                                                                                                                                                                                                                                   		i_tag_isid - Valid when -circuit_type is mac_in_mac
			x                                                                                                                                                                                                                                   		c_src_mac - Valid when -circuit_type is mac_in_mac
			x                                                                                                                                                                                                                                   		c_dest_mac - Valid when -circuit_type is mac_in_mac
			x                                                                                                                                                                                                                                   		s_vlan - Valid when -circuit_type is mac_in_mac
			x                                                                                                                                                                                                                                   		c_vlan - Valid when -circuit_type is mac_in_mac
			x                                                                                                                                                                                                                                   		none - No tracking will be implemented on the receiving port.
			x                                                                                                                                                                                                                                   		Valid choices only for ixnetwork_540:-
			x                                                                                                                                                                                                                                   		cisco_frame_relay_dlci_high_order_bits- If selected, flows are tracked by cisco_frame_relay_dlci_high_order_bits.
			x                                                                                                                                                                                                                                   		cisco_frame_relay_dlci_low_order_bits- If selected, flows are tracked by cisco_frame_relay_dlci_low_order_bits.
			x                                                                                                                                                                                                                                   		dest_endpoint- If selected, flows are tracked by destination endpoints as per route ranges configured under destination endpoint.
			x                                                                                                                                                                                                                                   		dest_mac- If selected, flows are tracked by the Ethernet II Destination MAC Address.
			x                                                                                                                                                                                                                                   		dest_port- If selected, flows are tracked by the Ethernet II Source MAC Address.
			x                                                                                                                                                                                                                                   		ethernet_ii_ether_type- If selected, flows are tracked by Ethernet II Ethernet Type.
			x                                                                                                                                                                                                                                   		ethernet_ii_pfc_queue- If selected, flows are tracked by Ethernet II PFC Queue.
			x                                                                                                                                                                                                                                   		fcoe_cs_ctl- If selected, the FCoE flows are tracked by CS_CTL Priority.CS_CTL field is controlled by the CS_CTL/Priority Enable bit (F_CTL, bit 17).When the CS_CTL/Priority Enable bit is set to zero and word 1, bits 31-24 are interpreted to be CS_CTL information.When the CS_CTL/Priority Enable bit is set to one and word 1, bits 31-24 is interpreted to be Priority information.When bit 17 of F_CTL is set to zero and Word 1, bits 31-24 of the Frame_Header is defined as the CS_CTL field. It contains management information for the class of service identified by the SOF. The meaning of the CS_CTL field is dependent on the class of service.
			x                                                                                                                                                                                                                                   		fcoe_dest_id- If selected, the FCoE flows are tracked by destination ID.
			x                                                                                                                                                                                                                                   		fcoe_ox_id- If selected, the FCoE flows are tracked by OX ID.The Originator Exchange_ID (OX_ID) is a two-byte field (Word 4, Bits 31-16) that identifies the Exchange_ID assigned by the Originator of the Exchange. Each Exchange is assigned an identifier unique to the Originator or Originator-Responder pair. If the Originator enforces uniqueness through the OX_ID mechanism, it sets a unique value for OX_ID other than FF FFh in the first Data frame of the first Sequence of an Exchange. An OX_ID of FF FFh indicates that the OX_ID is unassigned and that the Originator is not enforcing uniqueness through the OX_ID mechanism. If an Originator uses the unassigned value of FF FFh to identify the Exchange, it has only one Exchange (OX_ID set to FF FFh) with a given Responder.
			x                                                                                                                                                                                                                                   		fcoe_src_id- If selected, the FCoE flows are tracked by source ID.
			x                                                                                                                                                                                                                                   		fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_cs_ctl_priority- If selected, flows are tracked by the fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_cs_ctl_priority
			x                                                                                                                                                                                                                                   		fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_did- If selected, flows are tracked by the fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_did
			x                                                                                                                                                                                                                                   		fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_ox_id- If selected, flows are tracked by the fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_ox_id
			x                                                                                                                                                                                                                                   		fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_sid- If selected, flows are tracked by the fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_sid
			x                                                                                                                                                                                                                                   		fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_cs_ctl_priority- If selected, flows are tracked by the fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_cs_ctl_priority
			x                                                                                                                                                                                                                                   		fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_did- If selected, flows are tracked by the fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_did
			x                                                                                                                                                                                                                                   		fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_ox_id- If selected, flows are tracked by the fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_ox_id
			x                                                                                                                                                                                                                                   		fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_sid- If selected, flows are tracked by the fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_sid
			x                                                                                                                                                                                                                                   		fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_cs_ctl_priority- If selected, flows are tracked by the fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_cs_ctl_priority
			x                                                                                                                                                                                                                                   		fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_did- If selected, flows are tracked by the fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_did
			x                                                                                                                                                                                                                                   		fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_ox_id- If selected, flows are tracked by the fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_ox_id
			x                                                                                                                                                                                                                                   		fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_sid- If selected, flows are tracked by the fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_sid
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_cs_ctl_priority- If selected, flows are tracked by the fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_cs_ctl_priority
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_did- If selected, flows are tracked by the fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_did
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_ox_id- If selected, flows are tracked by the fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_ox_id
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_sid- If selected, flows are tracked by the fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_sid
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_cs_ctl_priority- If selected, flows are tracked by the fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_cs_ctl_priority
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_did- If selected, flows are tracked by the fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_did
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_ox_id- If selected, flows are tracked by the fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_ox_id
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_sid- If selected, flows are tracked by the fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_sid
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_cs_ctl_priority- If selected, flows are tracked by the fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_cs_ctl_priority
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_did- If selected, flows are tracked by the fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_did
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_ox_id- If selected, flows are tracked by the fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_ox_id
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_sid- If selected, flows are tracked by the fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_sid
			x                                                                                                                                                                                                                                   		frame_relay_dlci_high_order_bits- If selected, flows are tracked by the frame_relay_dlci_high_order_bits
			x                                                                                                                                                                                                                                   		frame_relay_dlci_low_order_bits- If selected, flows are tracked by the frame_relay_dlci_low_order_bits
			x                                                                                                                                                                                                                                   		ipv6_source_ip- If selected, flows are tracked by the IPv4 Destination Address as per the route ranges configured under destination endpoint.
			x                                                                                                                                                                                                                                   		ipv4_source_ip - If selected, flows are tracked by the IPv4 Source Address as per the route ranges configured under source endpoint.
			x                                                                                                                                                                                                                                   		ipv6_source_ip- If selected, flows are tracked by the IPv6 Source Address as per the route ranges configured under source endpoint.
			x                                                                                                                                                                                                                                   		ipv6_dest_ip- If selected, flows are tracked by the IPv6 Destination Address as per the route ranges configured under destination endpoint.
			x                                                                                                                                                                                                                                   		ipv6_trafficclass- If selected, flows are tracked by the IPv6 Traffic Class.
			x                                                                                                                                                                                                                                   		l2tpv2_data_message_tunnel_id- If selected, flows are tracked by the l2tpv2_data_message_tunnel_id
			x                                                                                                                                                                                                                                   		mac_in_mac_priority- If selected, flows are tracked by the mac_in_mac_priority
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_bdest_address- If selected, flows are tracked by the mac_in_mac_v42_bdest_address
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_bsrc_address- If selected, flows are tracked by the mac_in_mac_v42_bsrc_address
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_btag_pcp- If selected, flows are tracked by the mac_in_mac_v42_btag_pcp
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_cdest_address- If selected, flows are tracked by the mac_in_mac_v42_cdest_address
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_csrc_address- If selected, flows are tracked by the mac_in_mac_v42_csrc_address
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_isid- If selected, flows are tracked by the mac_in_mac_v42_isid
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_priority- If selected, flows are tracked by the mac_in_mac_v42_priority
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_stag_pcp- If selected, flows are tracked by the mac_in_mac_v42_stag_pcp
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_stag_vlan_id- If selected, flows are tracked by the mac_in_mac_v42_stag_vlan_id
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_vlan_id- If selected, flows are tracked by the mac_in_mac_v42_vlan_id
			x                                                                                                                                                                                                                                   		b_vlan_user_priority- If selected, flows are tracked by the b_vlan_user_priority
			x                                                                                                                                                                                                                                   		mac_in_mac_ether_type_i_tag- If selected, flows are tracked by the mac_in_mac_ether_type_i_tag
			x                                                                                                                                                                                                                                   		s_vlan_user_priority- If selected, flows are tracked by the s_vlan_user_priority
			x                                                                                                                                                                                                                                   		c_vlan_user_priority- If selected, flows are tracked by the c_vlan_user_priority
			x                                                                                                                                                                                                                                   		mpls_mpls_exp- If selected, flows are tracked by the mpls_mpls_exp
			x                                                                                                                                                                                                                                   		pppoe_session_sessionid- If selected, flows are tracked by the pppoe_session_sessionid
			x                                                                                                                                                                                                                                   		source_dest_port_pair- If selected, flows are tracked by source and destination port pairs. This flow tracking option is effective if there is a combination of multiple Rx and Tx ports.
			x                                                                                                                                                                                                                                   		source_dest_value_pair- If selected, flows are tracked as per the route ranges configured under source and destination endpoint sets.
			x                                                                                                                                                                                                                                   		source_endpoint- If selected, flows are tracked by the source and destination pairs.
			x                                                                                                                                                                                                                                   		source_port- If selected, flows are tracked by the source_port
			x                                                                                                                                                                                                                                   		tcp_tcp_dst_prt- If selected, flows are tracked by the tcp_tcp_dst_prt
			x                                                                                                                                                                                                                                   		tcp_tcp_src_prt- If selected, flows are tracked by the tcp_tcp_src_prt
			x                                                                                                                                                                                                                                   		traffic_group- If selected, flows are tracked by traffic groups as per the configuration to filter out endpoint set traffic configuration.
			x                                                                                                                                                                                                                                   		udp_udp_dst_prt- If selected, flows are tracked by the udp_udp_dst_prt
			x                                                                                                                                                                                                                                   		udp_udp_src_prt- If selected, flows are tracked by the udp_udp_src_prt
			x                                                                                                                                                                                                                                   		vlan_vlan_user_priority- If selected, flows are tracked by the vlan_vlan_user_priority
			x                                                                                                                                                                                                                                   		traffic_item- If selected, flows are tracked by traffic item.
			x                                                                                                                                                                                                                           	-traffic_generate
			x                                                                                                                                                                                                                               		If 1, the learned information (MAC addresses, MPLS labels) needed for configuring traffic is retrieved for each traffic item. This will make the process of configuring traffic items slower.
			x                                                                                                                                                                                                                           	-traffic_generator
			x                                                                                                                                                                                                                               		Selects the Ixia product that will be used for configuring traffic.Valid options are ixos, ixnetwork, ixnetwork_540.
			x                                                                                                                                                                                                                               		ixos - The traffic will be generated using IxOS.ixnetwork (DEPRECATED) - The traffic will be generated using IxNetwork. This choice is available only when using IxTclNetwork 5.30 or greater. The IxNetwork API is a higher level API, that will allow to configure traffic for protocol suites (OSPF, ISIS, BGP, LDP, RSVP, L3VPN, L2VPN/VPLS, MVPN, etc.) faster than before, just by specifying the protocol emulation handles for traffic source and destination (through parameters -emulation_src_handle and -emulation_dst_handle). The layer 2,3 parameters will be configured automatically.ixnetwork_540 - This choice is available when using IxTclNetwork 5.40 or or greater. It provides backwards compatibility for almost all the parameters and traffic_generator values. It also brings many new features like -mode 'append_header', 'prepend_header', 'replace_header' which allows customization of the packet, -tracking by multiple fields from the packets, egress tracking at predefined offsets and many others. There are three ways in which traffic can be created.ixos backwards compatibility way (DEPRECATED) - use port_handle to confiure the originating port for the traffic. Optionally use port_handle2 to configure the destination port for the traffic. If port_handle2 is missing, the paremter -allow_self_destined is forced to '1' and the destination port will be the same with port_handle. The protocol headers that will be added to the packet are triggered by the port type (ethernet, atm), the atm_encapsulation, vlan, mpls, isl, l2_encap, l3_protocol, l4_protocol.ixaccess backwards compatibility way - use emulation_src_handle or emulation_dst_handle parameter to configure the src/dst pppox or l2tpox handle that will originate/terminate the traffic. Use ip_dst_addr/ip_src_addr parameters to configure the fixed IP addresses that will end/originate the traffic. When using emulation_src_handle port_handle2 parameter can be specified to configure the terminating port for the traffic. In this case an interface with ip_dst_addr IP address will be searched on that port to use. Similary for emulation_dst_handle and port_handle and ip_src_addr parameters.ixnetwork backwards compatibility way - use emulation_src_handle and emulation_dst_handle to configure the source and destination for the traffic pair.For all the configuration styles presented, the following applies: the parameters that configure packet fields (ip_src_addr, ethernet_type, tcp_port etc.) will override the fields with the values passed with the parameters.
			x                                                                                                                                                                                                                           	-transmit_distribution
			x                                                                                                                                                                                                                               		Valid only for traffic_generator ixnetwork_540 and -mode 'create'. It configures how many streams will be created to accommodate the traffic item. For example, if a traffic item configuration has 5 source mac addresses, and transmit_distribution is eth_ii_destination_address then the traffic item will have 5 streams. This parameter accepts a combination of choices. If -transmit_distribution is [list eth_ii_destination_address ip_src_addr] then the distribution of streams within the traffic item will take into account both criteria. For traffic_generator ixnetwork_540 we support all available IxNetwork low level API choices.
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		none - disable transmit distribution
			x                                                                                                                                                                                                                                   		assured_forwarding_phb - assured_forwarding_phb
			x                                                                                                                                                                                                                                   		b_dest_mac - b_dest_mac
			x                                                                                                                                                                                                                                   		b_src_mac - b_src_mac
			x                                                                                                                                                                                                                                   		b_vlan - b_vlan
			x                                                                                                                                                                                                                                   		c_dest_mac - c_dest_mac
			x                                                                                                                                                                                                                                   		c_src_mac - c_src_mac
			x                                                                                                                                                                                                                                   		c_vlan - c_vlan
			x                                                                                                                                                                                                                                   		class_selector_phb - class_selector_phb
			x                                                                                                                                                                                                                                   		default_phb - default_phb
			x                                                                                                                                                                                                                                   		dest_ip - dest_ip
			x                                                                                                                                                                                                                                   		dest_mac - dest_mac
			x                                                                                                                                                                                                                                   		ethernet_ii_ether_type - ethernet_ii_ether_type
			x                                                                                                                                                                                                                                   		ethernet_ii_pfc_queue - ethernet_ii_pfc_queue
			x                                                                                                                                                                                                                                   		expedited_forwarding_phb - expedited_forwarding_phb
			x                                                                                                                                                                                                                                   		fcoe_cs_ctl - fcoe_cs_ctl
			x                                                                                                                                                                                                                                   		fcoe_dest_id - fcoe_dest_id
			x                                                                                                                                                                                                                                   		fcoe_ox_id - fcoe_ox_id
			x                                                                                                                                                                                                                                   		fcoe_src_id - fcoe_src_id
			x                                                                                                                                                                                                                                   		fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_cs_ctl_priority - fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_cs_ctl_priority
			x                                                                                                                                                                                                                                   		fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_did - fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_did
			x                                                                                                                                                                                                                                   		fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_ox_id - fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_ox_id
			x                                                                                                                                                                                                                                   		fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_sid - fip_flogi_ls_acc_fcf_fip_flogi_descriptor_fibre_channel_sid
			x                                                                                                                                                                                                                                   		fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_cs_ctl_priority - fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_cs_ctl_priority
			x                                                                                                                                                                                                                                   		fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_did - fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_did
			x                                                                                                                                                                                                                                   		fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_ox_id - fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_ox_id
			x                                                                                                                                                                                                                                   		fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_sid - fip_flogi_ls_rjt_fcf_fip_flogi_descriptor_fibre_channel_sid
			x                                                                                                                                                                                                                                   		fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_cs_ctl_priority - fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_cs_ctl_priority
			x                                                                                                                                                                                                                                   		fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_did - fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_did
			x                                                                                                                                                                                                                                   		fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_ox_id - fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_ox_id
			x                                                                                                                                                                                                                                   		fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_sid - fip_flogi_request_enode_fip_flogi_descriptor_fibre_channel_sid
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_cs_ctl_priority - fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_cs_ctl_priority
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_did - fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_did
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_ox_id - fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_ox_id
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_sid - fip_npiv_fdisc_ls_acc_fcf_fip_npiv_fdisc_descriptor_fibre_channel_sid
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_cs_ctl_priority - fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_cs_ctl_priority
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_did - fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_did
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_ox_id - fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_ox_id
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_sid - fip_npiv_fdisc_ls_rjt_fcf_fip_npiv_fdisc_descriptor_fibre_channel_sid
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_cs_ctl_priority - fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_cs_ctl_priority
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_did - fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_did
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_ox_id - fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_ox_id
			x                                                                                                                                                                                                                                   		fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_sid - fip_npiv_fdisc_request_enode_fip_npiv_fdisc_descriptor_fibre_channel_sid
			x                                                                                                                                                                                                                                   		frame_size - frame_size
			x                                                                                                                                                                                                                                   		i_tag_isid - i_tag_isid
			x                                                                                                                                                                                                                                   		inner_vlan - inner_vlan
			x                                                                                                                                                                                                                                   		ipv4_dest_ip - ipv4_dest_ip
			x                                                                                                                                                                                                                                   		ipv4_precedence - ipv4_precedence
			x                                                                                                                                                                                                                                   		ipv4_source_ip - ipv4_source_ip
			x                                                                                                                                                                                                                                   		ipv6_dest_ip - ipv6_dest_ip
			x                                                                                                                                                                                                                                   		ipv6_flow_label - ipv6_flow_label
			x                                                                                                                                                                                                                                   		ipv6_flowlabel - ipv6_flowlabel
			x                                                                                                                                                                                                                                   		ipv6_source_ip - ipv6_source_ip
			x                                                                                                                                                                                                                                   		ipv6_trafficclass - ipv6_trafficclass
			x                                                                                                                                                                                                                                   		l2tpv2_data_message_tunnel_id - l2tpv2_data_message_tunnel_id
			x                                                                                                                                                                                                                                   		mac_in_mac_priority - mac_in_mac_priority
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_bdest_address - mac_in_mac_v42_bdest_address
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_bsrc_address - mac_in_mac_v42_bsrc_address
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_btag_pcp - mac_in_mac_v42_btag_pcp
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_cdest_address - mac_in_mac_v42_cdest_address
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_csrc_address - mac_in_mac_v42_csrc_address
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_isid - mac_in_mac_v42_isid
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_priority - mac_in_mac_v42_priority
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_stag_pcp - mac_in_mac_v42_stag_pcp
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_stag_vlan_id - mac_in_mac_v42_stag_vlan_id
			x                                                                                                                                                                                                                                   		mac_in_mac_v42_vlan_id - mac_in_mac_v42_vlan_id
			x                                                                                                                                                                                                                                   		mac_in_mac_vlan_user_priority - mac_in_mac_vlan_user_priority
			x                                                                                                                                                                                                                                   		mpls_label - mpls_label
			x                                                                                                                                                                                                                                   		mpls_mpls_exp - mpls_mpls_exp
			x                                                                                                                                                                                                                                   		mpls_flow_descriptor - mpls_flow_descriptor
			x                                                                                                                                                                                                                                   		pppoe_session_sessionid - pppoe_session_sessionid
			x                                                                                                                                                                                                                                   		raw_priority - raw_priority
			x                                                                                                                                                                                                                                   		rx_port - rx_port
			x                                                                                                                                                                                                                                   		s_vlan - s_vlan
			x                                                                                                                                                                                                                                   		source_ip - source_ip
			x                                                                                                                                                                                                                                   		srcDestEndpointPair - srcDestEndpointPair
			x                                                                                                                                                                                                                                   		src_mac - src_mac
			x                                                                                                                                                                                                                                   		tcp_tcp_dst_prt - tcp_tcp_dst_prt
			x                                                                                                                                                                                                                                   		tcp_tcp_src_prt - tcp_tcp_src_prt
			x                                                                                                                                                                                                                                   		tos - tos
			x                                                                                                                                                                                                                                   		udp_udp_dst_prt - udp_udp_dst_prt
			x                                                                                                                                                                                                                                   		udp_udp_src_prt - udp_udp_src_prt
			x                                                                                                                                                                                                                                   		vlan_vlan_user_priority - vlan_vlan_user_priority
			x                                                                                                                                                                                                                           	-tx_delay
			x                                                                                                                                                                                                                               		This argument can be used to specify the delay to the start of the scheduled stream.
			x                                                                                                                                                                                                                           	-tx_delay_unit
			x                                                                                                                                                                                                                               		This argument can be used to specify the delay unit for tx_delay
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		bytes - bytes.
			x                                                                                                                                                                                                                                   		ns - nano seconds.
			x                                                                                                                                                                                                                           	-tx_mode
			x                                                                                                                                                                                                                               		Configure transmit mode of traffic item on -mode create and modify. If this parameter is not provided, the transmit mode of the traffic item will be configured to match the transmit mode of the first transmitting port of the traffic item. The port transmit mode is configured using procedure ::<namespace>::interface_config with parameter -transmit_mode.
			x                                                                                                                                                                                                                               		Valid choices are:
			x                                                                                                                                                                                                                                   		advanced - interleaved.
			x                                                                                                                                                                                                                                   		stream - sequential.
			x                                                                                                                                                                                                                           	-udf1_cascade_type
			x                                                                                                                                                                                                                               	-udf1_chain_from
			x                                                                                                                                                                                                                                   		Allows the user to select what UDF the current UDF should chain from. When this option is employed, the UDF will stay in its initial value until the UDF it is chained from reaches its terminating value.If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                               	-udf1_counter_init_value
			x                                                                                                                                                                                                                                   		The initial value of the counter.This field is a list of hex numbers for range_list mode; a hex number for all other modes.If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                               	-udf1_counter_mode
			x                                                                                                                                                                                                                                   	-udf1_counter_repeat_count
			x                                                                                                                                                                                                                                       		The counter is incremented or decremented the number of times based on this option. If counter_mode is continuous, then this value is ignored.If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                                   	-udf1_counter_step
			x                                                                                                                                                                                                                                       		The step size for counter up/down. If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                                   	-udf1_counter_type
			x                                                                                                                                                                                                                                       		Describes the size of the UDF field in bits.The choices are:8 16 24 32 If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                                   	-udf1_counter_up_down
			x                                                                                                                                                                                                                                       		This option describes whether the UDF counters are to be incremented or decremented.choices are:up, down. If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                                   	-udf1_enable_cascade
			x                                                                                                                                                                                                                                       	-udf1_inner_repeat_count
			x                                                                                                                                                                                                                                           		The number of times the inner loop is repeated. Used when UDF mode is set to nested.If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                                       	-udf1_inner_repeat_value
			x                                                                                                                                                                                                                                           		The number of times each value in the inner loop is repeated. Used when UDF mode is set to nested.If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                                       	-udf1_inner_step
			x                                                                                                                                                                                                                                           		The steps size between inner loop values. Used when UDF mode is set to nested.If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                                       	-udf1_mask_select
			x                                                                                                                                                                                                                                           		This is a 32-bit mask that enables, on a bit-by-bit basis, use of the absolute counter value bits as defined by mask_val option. To be used for udf1_mode random. (DEFAULT = {00 00}) If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                                       	-udf1_mask_val
			x                                                                                                                                                                                                                                           		A 32-bit mask of absolute values for this UDF counter. It is used in association with the mask_select; bits must be set 'on' or the bits in mask_select will be ignored. To be used for udf1_mode random. (DEFAULT = {00 00}) If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                                       	-udf1_mode
			x                                                                                                                                                                                                                                           		The mode of operation of the counter. If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'. Valid options are:
			x                                                                                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                                                                                               		counter - Normal up-down counter as controlled by counter_mode, counter_type, counter_init_value, mask_select, mask_val, random, counter_repeat_count, counter_step, counter_up_down and cascade_type options.
			x                                                                                                                                                                                                                                               		random - Generates random values, based on the values in counter_type, mask_select and mask_val.
			x                                                                                                                                                                                                                                               		value_list - A list of distinct values, based on the values of counter_type, value_list and cascade_type.
			x                                                                                                                                                                                                                                               		nested - Two nested counters may be used to build complex sequences, based on the values of counter_type, counter_init_value, inner_repeat_count, inner_repeat_value, inner_step, counter_repeat_count, counter_step, and cascade_type options.
			x                                                                                                                                                                                                                                               		range_list - A list of value ranges, based on counter_type, cascade_type and ranges. Ranges are specified with counter_init_value, counter_repeat_count, and counter_step.
			x                                                                                                                                                                                                                                               		ipv4 - A counter which facilitates generation of IPv4 addresses, based on counter_init_value, counter_repeat_count, counter_type, inner_repeat_value, inner_step, skip_zeros_and_ones, and skip_mask_bits options.
			x                                                                                                                                                                                                                                       	-udf1_offset
			x                                                                                                                                                                                                                                           		The absolute offset to insert this UDF into the frame. Note that DA and SA use the fixed offsets at 0 and 6, respectively. This option applies to all UDF modes.If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                                       	-udf1_skip_mask_bits
			x                                                                                                                                                                                                                                           		If UDF mode is ipv4 and skip_zeros_and_ones is set to true (1), this is the number of low order bits to check when looking for all 0s and all 1s. This normally corresponds to network broadcast addresses.If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                                       	-udf1_skip_zeros_and_ones
			x                                                                                                                                                                                                                                           		If UDF mode is ipv4 and this option is set to true (1), then values of all 0s and all 1s as masked by skip_mask_bits will be skipped when generating values.This normally corresponds to network broadcast addresses.If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                                       	-udf1_value_list
			x                                                                                                                                                                                                                                           		A list of hex numbers which holds the values to be used when mode is set to value_list. If traffic_generator is ixnetwork_540, circuit_type must be configured to 'quick_flows'.
			x                                                                                                                                                                                                                                       	-udf2_cascade_type
			x                                                                                                                                                                                                                                           	-udf2_chain_from
			x                                                                                                                                                                                                                                               		Allows the user to select what UDF the current UDF should chain from. When this option is employed, the UDF will stay in its initial value until the UDF it is chained from reaches its terminating value.
			x                                                                                                                                                                                                                                           	-udf2_counter_init_value
			x                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                           	-udf2_counter_mode
			x                                                                                                                                                                                                                                               	-udf2_counter_repeat_count
			x                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                               	-udf2_counter_step
			x                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                               	-udf2_counter_type
			x                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                               	-udf2_counter_up_down
			x                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                               	-udf2_enable_cascade
			x                                                                                                                                                                                                                                                   	-udf2_inner_repeat_count
			x                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                   	-udf2_inner_repeat_value
			x                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                   	-udf2_inner_step
			x                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                   	-udf2_mask_select
			x                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                   	-udf2_mask_val
			x                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                   	-udf2_mode
			x                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                   	-udf2_offset
			x                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                   	-udf2_skip_mask_bits
			x                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                   	-udf2_skip_zeros_and_ones
			x                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                   	-udf2_value_list
			x                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                   	-udf3_cascade_type
			x                                                                                                                                                                                                                                                       	-udf3_chain_from
			x                                                                                                                                                                                                                                                           		Allows the user to select what UDF the current UDF should chain from. When this option is employed, the UDF will stay in its initial value until the UDF it is chained from reaches its terminating value.
			x                                                                                                                                                                                                                                                       	-udf3_counter_init_value
			x                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                       	-udf3_counter_mode
			x                                                                                                                                                                                                                                                           	-udf3_counter_repeat_count
			x                                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                                           	-udf3_counter_step
			x                                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                                           	-udf3_counter_type
			x                                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                                           	-udf3_counter_up_down
			x                                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                                           	-udf3_enable_cascade
			x                                                                                                                                                                                                                                                               	-udf3_inner_repeat_count
			x                                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                                               	-udf3_inner_repeat_value
			x                                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                                               	-udf3_inner_step
			x                                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                                               	-udf3_mask_select
			x                                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                                               	-udf3_mask_val
			x                                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                                               	-udf3_mode
			x                                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                                               	-udf3_offset
			x                                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                                               	-udf3_skip_mask_bits
			x                                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                                               	-udf3_skip_zeros_and_ones
			x                                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                                               	-udf3_value_list
			x                                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                                               	-udf4_cascade_type
			x                                                                                                                                                                                                                                                                   	-udf4_chain_from
			x                                                                                                                                                                                                                                                                       		Allows the user to select what UDF the current UDF should chain from. When this option is employed, the UDF will stay in its initial value until the UDF it is chained from reaches its terminating value.
			x                                                                                                                                                                                                                                                                   	-udf4_counter_init_value
			x                                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                   	-udf4_counter_mode
			x                                                                                                                                                                                                                                                                       	-udf4_counter_repeat_count
			x                                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                       	-udf4_counter_step
			x                                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                       	-udf4_counter_type
			x                                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                       	-udf4_counter_up_down
			x                                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                       	-udf4_enable_cascade
			x                                                                                                                                                                                                                                                                           	-udf4_inner_repeat_count
			x                                                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                           	-udf4_inner_repeat_value
			x                                                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                           	-udf4_inner_step
			x                                                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                           	-udf4_mask_select
			x                                                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                           	-udf4_mask_val
			x                                                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                           	-udf4_mode
			x                                                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                           	-udf4_offset
			x                                                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                           	-udf4_skip_mask_bits
			x                                                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                           	-udf4_skip_zeros_and_ones
			x                                                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                           	-udf4_value_list
			x                                                                                                                                                                                                                                                                               		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                           	-udf5_cascade_type
			x                                                                                                                                                                                                                                                                               	-udf5_chain_from
			x                                                                                                                                                                                                                                                                                   		Allows the user to select what UDF the current UDF should chain from. When this option is employed, the UDF will stay in its initial value until the UDF it is chained from reaches its terminating value.
			x                                                                                                                                                                                                                                                                               	-udf5_counter_init_value
			x                                                                                                                                                                                                                                                                                   		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                               	-udf5_counter_mode
			x                                                                                                                                                                                                                                                                                   	-udf5_counter_repeat_count
			x                                                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                                   	-udf5_counter_step
			x                                                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                                   	-udf5_counter_type
			x                                                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                                   	-udf5_counter_up_down
			x                                                                                                                                                                                                                                                                                       		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                                   	-udf5_enable_cascade
			x                                                                                                                                                                                                                                                                                       	-udf5_inner_repeat_count
			x                                                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                                       	-udf5_inner_repeat_value
			x                                                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                                       	-udf5_inner_step
			x                                                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                                       	-udf5_mask_select
			x                                                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                                       	-udf5_mask_val
			x                                                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                                       	-udf5_mode
			x                                                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                                       	-udf5_offset
			x                                                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                                       	-udf5_skip_mask_bits
			x                                                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                                       	-udf5_skip_zeros_and_ones
			x                                                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                                       	-udf5_value_list
			x                                                                                                                                                                                                                                                                                           		See description for this item same as udf1
			x                                                                                                                                                                                                                                                                                       	-udp_checksum_value
			x                                                                                                                                                                                                                                                                                           		Value to be set for UDP checksum if "-udp_checksum 0" is specified.
			x                                                                                                                                                                                                                                                                                       	-udp_checksum_value_tracking
			x                                                                                                                                                                                                                                                                                               		0 - disable tracking by udp_checksum_value
			x                                                                                                                                                                                                                                                                                               		1 - enable tracking by udp_checksum_value
			x                                                                                                                                                                                                                                                                                       	-udp_dst_port_count
			x                                                                                                                                                                                                                                                                                           		Numeric value which configures the number of times the udp_dst_port is incremeneted or decremented when udp_dst_port_mode is incr or decr.
			x                                                                                                                                                                                                                                                                                       	-udp_dst_port_mode
			x                                                                                                                                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                                                                               		incr - the value is incremented as specified with udp_dst_port_step and udp_dst_port_count.
			x                                                                                                                                                                                                                                                                                               		decr - the value is decremented as specified with udp_dst_port_step and udp_dst_port_count.
			x                                                                                                                                                                                                                                                                                               		list - Parameter -udp_dst_port contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                                                                                       	-udp_dst_port_step
			x                                                                                                                                                                                                                                                                                           		Step value used to modify udp_dst_port when udp_dst_port_mode is incr or decr.
			x                                                                                                                                                                                                                                                                                       	-udp_dst_port_tracking
			x                                                                                                                                                                                                                                                                                               		0 - disable tracking by udp_dst_port
			x                                                                                                                                                                                                                                                                                               		1 - enable tracking by udp_dst_port
			x                                                                                                                                                                                                                                                                                       	-udp_length
			x                                                                                                                                                                                                                                                                                           		Valid only for traffic_generator ixnetwork_540 and when -l4_protocol is udp. Configure the Length field of the UDP header.
			x                                                                                                                                                                                                                                                                                       	-udp_length_count
			x                                                                                                                                                                                                                                                                                           		Numeric value which configures the number of times the udp_length is incremeneted or decremented when udp_length_mode is incr or decr.
			x                                                                                                                                                                                                                                                                                       	-udp_length_mode
			x                                                                                                                                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                                                                               		incr - the value is incremented as specified with udp_length_step and udp_length_count.
			x                                                                                                                                                                                                                                                                                               		decr - the value is decremented as specified with udp_length_step and udp_length_count.
			x                                                                                                                                                                                                                                                                                               		list - Parameter -udp_length contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                                                                                       	-udp_length_step
			x                                                                                                                                                                                                                                                                                           		Step value used to modify udp_length when udp_length_mode is incr or decr.
			x                                                                                                                                                                                                                                                                                       	-udp_length_tracking
			x                                                                                                                                                                                                                                                                                               		0 - disable tracking by udp_length
			x                                                                                                                                                                                                                                                                                               		1 - enable tracking by udp_length
			x                                                                                                                                                                                                                                                                                       	-udp_src_port_count
			x                                                                                                                                                                                                                                                                                           		Numeric value which configures the number of times the udp_src_port is incremeneted or decremented when udp_src_port_mode is incr or decr.
			x                                                                                                                                                                                                                                                                                       	-udp_src_port_mode
			x                                                                                                                                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                                                                               		incr - the value is incremented as specified with udp_src_port_step and udp_src_port_count.
			x                                                                                                                                                                                                                                                                                               		decr - the value is decremented as specified with udp_src_port_step and udp_src_port_count.
			x                                                                                                                                                                                                                                                                                               		list - Parameter -udp_src_port contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                                                                                       	-udp_src_port_step
			x                                                                                                                                                                                                                                                                                           		Step value used to modify udp_src_port when udp_src_port_mode is incr or decr.
			x                                                                                                                                                                                                                                                                                       	-udp_src_port_tracking
			x                                                                                                                                                                                                                                                                                               		0 - disable tracking by udp_src_port
			x                                                                                                                                                                                                                                                                                               		1 - enable tracking by udp_src_port
			x                                                                                                                                                                                                                                                                                       	-use_all_ip_subnets
			x                                                                                                                                                                                                                                                                                           		This argument can be used to enable the use of all advertised subnets will be used to simulate application traffic when the profile objective is rate-based, -enable_test_objective argument must be set to 1 in order for the value of this argument to be used.Valid only for traffic_generator ixnetwork, mode create/modify, circuit_endpoint_type ipv4_application_traffic or ipv6_application_traffic.
			x                                                                                                                                                                                                                                                                                       	-use_cp_size
			x                                                                                                                                                                                                                                                                                           		If enabled, the traffic item will use control plane's size (if available).
			x                                                                                                                                                                                                                                                                                       	-use_cp_rate
			x                                                                                                                                                                                                                                                                                           		If enabled, the traffic item will use control plane's rate (if available).
			x                                                                                                                                                                                                                                                                                       	-vci_increment
			x                                                                                                                                                                                                                                                                                           		This option is used to specify the VCI increment of the first ATM static endpoint range. It can take any value in the 0-4294967295 range. Valid only for traffic_generator ixnetwork when configuring L2VPN traffic.
			x                                                                                                                                                                                                                                                                                       	-vci_increment_step
			x                                                                                                                                                                                                                                                                                           		This option is used to specify the step between the VCI increment of each ATM static endpoint range. It can take any numeric value.Valid only for traffic_generator ixnetwork when configuring L2VPN traffic.
			x                                                                                                                                                                                                                                                                                       	-vlan
			x                                                                                                                                                                                                                                                                                           		This option will enable/disable VLAN and stacked VLAN (QinQ)on the interface to be configured. If vlan is disable and vlan_id or other vlan options are provided then these options will be ignored.
			x                                                                                                                                                                                                                                                                                       	-vlan_cfi_count
			x                                                                                                                                                                                                                                                                                           		Numeric value which configures the number of times the vlan_cfi is incremeneted or decremented when vlan_cfi_mode is incr or decr.
			x                                                                                                                                                                                                                                                                                       	-vlan_cfi_mode
			x                                                                                                                                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                                                                                                                                               		-
			x                                                                                                                                                                                                                                                                                               		incr - the value is incremented as specified with vlan_cfi_step and vlan_cfi_count.
			x                                                                                                                                                                                                                                                                                               		decr - the value is decremented as specified with vlan_cfi_step and vlan_cfi_count.
			x                                                                                                                                                                                                                                                                                               		list - Parameter -vlan_cfi contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                                                                                       	-vlan_cfi_step
			x                                                                                                                                                                                                                                                                                           		Step value used to modify vlan_cfi when vlan_cfi_mode is incr or decr.
			x                                                                                                                                                                                                                                                                                       	-vlan_cfi_tracking
			x                                                                                                                                                                                                                                                                                               		0 - disable tracking by vlan_cfi
			x                                                                                                                                                                                                                                                                                               		1 - enable tracking by vlan_cfi
			x                                                                                                                                                                                                                                                                                       	-vlan_enable
			x                                                                                                                                                                                                                                                                                           		This option is used to specify whether the VLAN id will be configured for the LAN static endpoint range.
			x                                                                                                                                                                                                                                                                                       	-vlan_id_tracking
			x                                                                                                                                                                                                                                                                                               		0 - disable tracking by vlan_id
			x                                                                                                                                                                                                                                                                                               		1 - enable tracking by vlan_id
			x                                                                                                                                                                                                                                                                                       	-vlan_protocol_tag_id
			x                                                                                                                                                                                                                                                                                           		The protocol ID field of the VLAN tag. It can be any 4 digit hex number. Example: 8100, 9100, 9200. For stacked VLAN (QinQ) this parameter will be provided as a list of values, each of them representing the protocol ID field of the VLAN tagExample: {8100 9100 9200 9100}Valid only for traffic_generator ixos and ixnetwork_540.When configuring traffic over PPP sessions this parameter is considered to be the VLAN protocol tag ID for the downstream (the traffic from network port to access port).
			x                                                                                                                                                                                                                                                                                       	-vlan_protocol_tag_id_count
			x                                                                                                                                                                                                                                                                                           		Numeric value which configures the number of times the vlan_protocol_tag_id is incremeneted or decremented when vlan_protocol_tag_id_mode is incr or decr.
			x                                                                                                                                                                                                                                                                                       	-vlan_protocol_tag_id_mode
			x                                                                                                                                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                                                                               		incr - the value is incremented as specified with vlan_protocol_tag_id_step and vlan_protocol_tag_id_count.
			x                                                                                                                                                                                                                                                                                               		decr - the value is decremented as specified with vlan_protocol_tag_id_step and vlan_protocol_tag_id_count.
			x                                                                                                                                                                                                                                                                                               		list - Parameter -vlan_protocol_tag_id contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                                                                                       	-vlan_protocol_tag_id_step
			x                                                                                                                                                                                                                                                                                           		Hex step value used to modify vlan_protocol_tag_id when vlan_protocol_tag_id_mode is incr or decr.
			x                                                                                                                                                                                                                                                                                       	-vlan_protocol_tag_id_tracking
			x                                                                                                                                                                                                                                                                                               		-
			x                                                                                                                                                                                                                                                                                               		1 - enable tracking by vlan_protocol_tag_id
			x                                                                                                                                                                                                                                                                                       	-vlan_user_priority_count
			x                                                                                                                                                                                                                                                                                           		Numeric value which configures the number of times the vlan_user_priority is incremeneted or decremented when vlan_user_priority_mode is incr or decr.
			x                                                                                                                                                                                                                                                                                       	-vlan_user_priority_mode
			x                                                                                                                                                                                                                                                                                           		This parameter configures
			x                                                                                                                                                                                                                                                                                           		Valid choices are:
			x                                                                                                                                                                                                                                                                                               		fixed - the value is left unchanged for all packets.
			x                                                                                                                                                                                                                                                                                               		incr - the value is incremented as specified with vlan_user_priority_step and vlan_user_priority_count.
			x                                                                                                                                                                                                                                                                                               		decr - the value is decremented as specified with vlan_user_priority_step and vlan_user_priority_count.
			x                                                                                                                                                                                                                                                                                               		list - Parameter -vlan_user_priority contains a list of values. Each packet will use one of the values from the list.
			x                                                                                                                                                                                                                                                                                       	-vlan_user_priority_step
			x                                                                                                                                                                                                                                                                                           		Step value used to modify vlan_user_priority when vlan_user_priority_mode is incr or decr.
			x                                                                                                                                                                                                                                                                                       	-vlan_user_priority_tracking
			x                                                                                                                                                                                                                                                                                               		0 - disable tracking by vlan_user_priority
			x                                                                                                                                                                                                                                                                                               		1 - enable tracking by vlan_user_priority
			x                                                                                                                                                                                                                                                                                       	-vpi_increment
			x                                                                                                                                                                                                                                                                                           		This option is used to specify the VPI increment of the first ATM static endpoint range. It can take any value in the 0-4294967295 range.
			x                                                                                                                                                                                                                                                                                       	-vpi_increment_step
			x                                                                                                                                                                                                                                                                                           		This option is used to specify the step between the VPI increment of each ATM static endpoint range. It can take any numeric value.
			n                                                                                                                                                                                                                                                                                       	-csrc_list
			n                                                                                                                                                                                                                                                                                           		Specifies the CSRC list which identifies the contributing sources for the payload contained in this packet. The number of identifiers is given by the CC field. If there are more than 15 contributing sources, only 15 may be identified. CSRC identifiers are inserted by mixers, using the SSRC identifiers of contributing sources. Note: 0 to 15 items, 32 bits each and is required if csrc_count is > 0
			n                                                                                                                                                                                                                                                                                       	-dlci_repeat_count_step
			n                                                                                                                                                                                                                                                                                           		Repeat count step for dlci_value. The valid range is 0-4294967295. Valid only for traffic_generator ixnetwork for L2VPN traffic, but is not supported in this release.
			n                                                                                                                                                                                                                                                                                       	-dlci_value_step
			n                                                                                                                                                                                                                                                                                           		Data Link Connection Identifier step. Depending on the traffic_generator value, this option has different value ranges. Valid choices are ixos - Valid range is 0-65535.ixnetwork (not supported in this release) - Valid range is 0-4294967295. The option can only be used for L2VPN traffic.
			n                                                                                                                                                                                                                                                                                       	-fr_range_count
			n                                                                                                                                                                                                                                                                                           		This option is used to specify the number of Frame relay static endpoint ranges. It can take any numeric value. This option is available only when using the ixnetwork traffic generator for L2VPN traffic, but is not supported in this release.
			n                                                                                                                                                                                                                                                                                       	-intf_handle
			n                                                                                                                                                                                                                                                                                           		This option is used to specify the interface handle to be associated with the IP static endpoints that are going to be created.
			n                                                                                                                                                                                                                                                                                       	-ip_bit_flags
			n                                                                                                                                                                                                                                                                                       	-ip_dst_count_step
			n                                                                                                                                                                                                                                                                                           		This option is used to specify the step between the value of the first address count value of each the IP static endpoint range. It can take any numeric value. This option is available only when using the ixnetwork traffic generator for L2VPN traffic, but is not supported in this release.
			n                                                                                                                                                                                                                                                                                       	-ip_dst_increment
			n                                                                                                                                                                                                                                                                                           		This option is used to specify the value of the increment of the first IP static endpoint range. It can take any numeric value in the 1-4294967295 range. This option is available only when using the ixnetwork traffic generator for L2VPN traffic, but is not supported in this release.
			n                                                                                                                                                                                                                                                                                       	-ip_dst_increment_step
			n                                                                                                                                                                                                                                                                                           		This option is used to specify the step between the value of the first address increment value of each the IP static endpoint range. It can take any numeric value. This option is available only when using the ixnetwork traffic generator for L2VPN traffic, but is not supported in this release.
			n                                                                                                                                                                                                                                                                                       	-ip_dst_prefix_len
			n                                                                                                                                                                                                                                                                                           		This option is used to specify the value of the prefix length of the first IP static endpoint range. This option is available only when using the ixnetwork traffic generator for L2VPN traffic, but is not supported in this release.
			n                                                                                                                                                                                                                                                                                       	-ip_dst_prefix_len_step
			n                                                                                                                                                                                                                                                                                           		This option is used to specify the step between the value of the first prefix lenght of each the IP static endpoint range. It can take any an numeric value. This option is available only when using the ixnetwork traffic generator for L2VPN traffic, but is not supported in this release.
			n                                                                                                                                                                                                                                                                                       	-ip_dst_range_step
			n                                                                                                                                                                                                                                                                                           		This option is used to specify the step between the value of the first IP of each the IP static endpoint range. It can take an IP value. This option is available only when using the ixnetwork traffic generator for L2VPN traffic, but is not supported in this release.
			n                                                                                                                                                                                                                                                                                       	-ip_dst_skip_broadcast
			n                                                                                                                                                                                                                                                                                       	-ip_dst_skip_multicast
			n                                                                                                                                                                                                                                                                                       	-ip_mbz
			n                                                                                                                                                                                                                                                                                       	-ip_range_count
			n                                                                                                                                                                                                                                                                                           		This option is used to specify the number of IP static endpoint ranges. It can take any numeric value.
			n                                                                                                                                                                                                                                                                                       	-ip_src_skip_broadcast
			n                                                                                                                                                                                                                                                                                       	-ip_src_skip_multicast
			n                                                                                                                                                                                                                                                                                       	-ip_tos_count
			n                                                                                                                                                                                                                                                                                       	-ip_tos_field
			n                                                                                                                                                                                                                                                                                       	-ip_tos_step
			n                                                                                                                                                                                                                                                                                       	-ipv6_checksum
			n                                                                                                                                                                                                                                                                                       	-ipv6_frag_next_header
			n                                                                                                                                                                                                                                                                                           		Next header in the fragmentation extention header.
			n                                                                                                                                                                                                                                                                                       	-ipv6_length
			n                                                                                                                                                                                                                                                                                       	-mac_discovery_gw
			n                                                                                                                                                                                                                                                                                           		Default for -mac_dst_mode discovery is to use the interface gateway.
			n                                                                                                                                                                                                                                                                                       	-mac_dst2_count
			n                                                                                                                                                                                                                                                                                       	-mac_dst2_mode
			n                                                                                                                                                                                                                                                                                       	-mac_dst2_step
			n                                                                                                                                                                                                                                                                                       	-mac_src2_count
			n                                                                                                                                                                                                                                                                                       	-mac_src2_mode
			n                                                                                                                                                                                                                                                                                       	-mac_src2_step
			n                                                                                                                                                                                                                                                                                       	-ppp_session_id
			n                                                                                                                                                                                                                                                                                       	-rtp_csrc_count
			n                                                                                                                                                                                                                                                                                           		Specifies the CSRC count contains the number of CSRC identifiers that follow the fixed header: Note: 4 bits
			n                                                                                                                                                                                                                                                                                       	-rtp_payload_type
			n                                                                                                                                                                                                                                                                                           		Specifies the format of the RTP payload and determines its interpretation by the application - Note: 7 bits, G.729 codec is payload type 18
			n                                                                                                                                                                                                                                                                                       	-ssrc
			n                                                                                                                                                                                                                                                                                           		Specifies the synchronization source
			n                                                                                                                                                                                                                                                                                       	-timestamp_initial_value
			n                                                                                                                                                                                                                                                                                           		Specifies the initial value of the timestamp
			n                                                                                                                                                                                                                                                                                       	-enable_egress_only_tracking
			n                                                                                                                                                                                                                                                                                           		It will enable the Egress Only Tracking option under quickflows
			                                                                                                                                                                                                                                                                                        	-egress_only_tracking_port
			                                                                                                                                                                                                                                                                                            		Egress only Tracking can be configured on one or multiple ports.egress_only_tracking_port can be a list for mode Create and for mode Modify it will be single port.
			x                                                                                                                                                                                                                                                                                       	-egress_only_tracking_signature_value
			x                                                                                                                                                                                                                                                                                           		Specifies the signature value of the egress only Tracking
			x                                                                                                                                                                                                                                                                                       	-egress_only_tracking_signature_offset
			x                                                                                                                                                                                                                                                                                           		Specifies the signature offset of the egress only Tracking
			x                                                                                                                                                                                                                                                                                       	-egress1_offset
			x                                                                                                                                                                                                                                                                                           		Specifies the egress 1 offset of the egress only Tracking
			x                                                                                                                                                                                                                                                                                       	-egress1_mask
			x                                                                                                                                                                                                                                                                                           		Specifies the egress 1 mask of the egress only Tracking
			x                                                                                                                                                                                                                                                                                       	-egress2_offset
			x                                                                                                                                                                                                                                                                                           		Specifies the egress 2 offset of the egress only Tracking
			x                                                                                                                                                                                                                                                                                       	-egress2_mask
			x                                                                                                                                                                                                                                                                                           		Specifies the egress 2 mask of the egress only Tracking
			x                                                                                                                                                                                                                                                                                       	-egress3_offset
			x                                                                                                                                                                                                                                                                                           		Specifies the egress 3 offset of the egress only Tracking
			x                                                                                                                                                                                                                                                                                       	-egress3_mask
			x                                                                                                                                                                                                                                                                                           		Specifies the egress 3 mask of the egress only Tracking
		                                                                                                                                                                                                                                                                                   
		                                                                                                                                                                                                                                                                                   Return Values:
		                                                                                                                                                                                                                                                                                       $::SUCCESS | $::FAILURE
			                                                                                                                                                                                                                                                                                        key:status                               value:$::SUCCESS | $::FAILURE
		                                                                                                                                                                                                                                                                                       On status of failure, gives detailed information. On status of success, gives possible warnings.
			                                                                                                                                                                                                                                                                                        key:log                                  value:On status of failure, gives detailed information. On status of success, gives possible warnings.
		                                                                                                                                                                                                                                                                                       Stream identifier when not bidirectional. When traffic_generator is ixnetwork_540 this key returns the name of the traffic item created.
			                                                                                                                                                                                                                                                                                        key:stream_id                            value:Stream identifier when not bidirectional. When traffic_generator is ixnetwork_540 this key returns the name of the traffic item created.
		                                                                                                                                                                                                                                                                                       Valid only for traffic_generator ixnetwork_540. This key returns the object reference of the traffic item created.
			                                                                                                                                                                                                                                                                                        key:traffic_item                         value:Valid only for traffic_generator ixnetwork_540. This key returns the object reference of the traffic item created.
		                                                                                                                                                                                                                                                                                       Valid only for traffic_generator ixnetwork_540. Returns the list of the packet headers configured in <traffic_item>. <traffic_item> is returned by key 'traffic_item'.
			                                                                                                                                                                                                                                                                                        key:<traffic_item>.headers               value:Valid only for traffic_generator ixnetwork_540. Returns the list of the packet headers configured in <traffic_item>. <traffic_item> is returned by key 'traffic_item'.
		                                                                                                                                                                                                                                                                                       Valid only for traffic_generator ixnetwork_540. Returns the list of the flow groups created for <traffic_item>. <traffic_item> is returned by key 'traffic_item'.
			                                                                                                                                                                                                                                                                                        key:<traffic_item>.stream_ids            value:Valid only for traffic_generator ixnetwork_540. Returns the list of the flow groups created for <traffic_item>. <traffic_item> is returned by key 'traffic_item'.
		                                                                                                                                                                                                                                                                                       Valid only for traffic_generator ixnetwork_540. Returns the list of the packet headers created for <flow_group>. <flow_group> is one of the flow groups returned by key '<traffic_item>.stream_ids'.
			                                                                                                                                                                                                                                                                                        key:<traffic_item>.<flow_group>.headers  value:Valid only for traffic_generator ixnetwork_540. Returns the list of the packet headers created for <flow_group>. <flow_group> is one of the flow groups returned by key '<traffic_item>.stream_ids'.
		                                                                                                                                                                                                                                                                                       Protocol Template handle (or list) returned when mode is "get_available_protocol_templates".
			                                                                                                                                                                                                                                                                                        key:pt_handle                            value:Protocol Template handle (or list) returned when mode is "get_available_protocol_templates".
		                                                                                                                                                                                                                                                                                       Returns available fields or field handles when mode is "get_available_fields", "add_field_level" or "remove_field_level".
			                                                                                                                                                                                                                                                                                        key:handle                               value:Returns available fields or field handles when mode is "get_available_fields", "add_field_level" or "remove_field_level".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_activeFieldChoice              value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_auto                           value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_countValue                     value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_defaultValue                   value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_displayName                    value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_enumValues                     value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_fieldChoice                    value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_fieldValue                     value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_fullMesh                       value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_id                             value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_length                         value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_level                          value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_name                           value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_offset                         value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_offsetFromRoot                 value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_optional                       value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_optionalEnabled                value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_rateVaried                     value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_readOnly                       value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_requiresUdf                    value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_singleValue                    value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_startValue                     value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_stepValue                      value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_trackingEnabled                value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_valueFormat                    value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_valueList                      value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "get_field_values".
			                                                                                                                                                                                                                                                                                        key:field_valueType                      value:Specific value for this key when mode is "get_field_values".
		                                                                                                                                                                                                                                                                                       Specific value for this key when mode is "append_header"/"prepend_header"/"replace_header"/"modify_or_insert"/"modify".
			                                                                                                                                                                                                                                                                                        key:last_stack                           value:Specific value for this key when mode is "append_header"/"prepend_header"/"replace_header"/"modify_or_insert"/"modify".
		                                                                                                                                                                                                                                                                                   
		                                                                                                                                                                                                                                                                                   Examples:
		                                                                                                                                                                                                                                                                                   
		                                                                                                                                                                                                                                                                                   Sample Input:
		                                                                                                                                                                                                                                                                                   
		                                                                                                                                                                                                                                                                                   Sample Output:
		                                                                                                                                                                                                                                                                                   
		                                                                                                                                                                                                                                                                                   Notes:
		                                                                                                                                                                                                                                                                                       1. Coded versus functional specification.
		                                                                                                                                                                                                                                                                                       2. In order to use QoS groups, parameter -variable_user_rate must be set to 1 in traffic_config calls. The maximum number of qos groups that can be created is 7.  After the maximum number of QoS groups is exceeded, the sessions that will be created will belong to the first group that has the same qos_byte value. If there is no group with the same qos_byte value, then a random group is chosen.
		                                                                                                                                                                                                                                                                                       3. When using QinQ (stacked Vlan):- the parameters: vlan_id, vlan_id_mode, vlan_user_priority, vlan_cfi, vlan_id_count, vlan_id_step, vlan_protocol_tag_id, must be passed as a list of values (Example provided at their description).- Each value from the list will be associated with a vlan from the stack- If a parameter is not provided, then that parameter will take it's default value and will be replicated for each vlan from the stack.- Otherwise, when the parameter is provided, it should have the exact same number of values in the list as the number of vlan's from the stack. If this condition is not met the procedure will return an error.- Traffic is not supported over flapping sessions.  After the first session falls, the new session that arises will have a different session ID and the traffic created for the first session will not work.
		                                                                                                                                                                                                                                                                                       4. When using IxNetwork, traffic configurations will be done using previously created handles (IP interfaces, PPP ranges, L2TP ranges, Protocol Route Ranges etc.) as sources (parameter -emulation_src_handle) and destinations (-emulation_dst_handle). The port_handle parameter is not necessary anymore.
		                                                                                                                                                                                                                                                                                       5. When using IxNetwork, traffic can only be configured between Ixia endpoints.
		                                                                                                                                                                                                                                                                                       6. When using Perl the user must use ixiatcl::set in order to provide scalable sources and scalable destinations to the traffic_config command. Example:
		                                                                                                                                                                                                                                                                                       my %ti_srcs = ();
		                                                                                                                                                                                                                                                                                       my %ti_dsts = ();
		                                                                                                                                                                                                                                                                                       $ti_srcs{'EndpointSet-1'} = '';
		                                                                                                                                                                                                                                                                                       $ti_dsts{'EndpointSet-1'} = '';
		                                                                                                                                                                                                                                                                                       ixiatcl::set('ti_scalable_srcs(EndpointSet-1)', ['/topology:1/deviceGroup:1/ethernet:1/ipv4:1', '/topology:1/deviceGroup:2/ethernet:1/ipv4:1']);
		                                                                                                                                                                                                                                                                                       ixiatcl::set('ti_scalable_srcs_port_start(EndpointSet-1)', [1, 1]);
		                                                                                                                                                                                                                                                                                       ixiatcl::set('ti_scalable_srcs_port_count(EndpointSet-1)', [1, 1]);
		                                                                                                                                                                                                                                                                                       ixiatcl::set('ti_scalable_srcs_intf_start(EndpointSet-1)', [1, 1]);
		                                                                                                                                                                                                                                                                                       ixiatcl::set('ti_scalable_srcs_intf_count(EndpointSet-1)', [1, 1]);
		                                                                                                                                                                                                                                                                                       ixiatcl::set('ti_scalable_dsts(EndpointSet-1)', ['/topology:1/deviceGroup:1/ethernet:1/ipv4:1', '/topology:1/deviceGroup:2/ethernet:1/ipv4:1']);
		                                                                                                                                                                                                                                                                                       ixiatcl::set('ti_scalable_dsts_port_start(EndpointSet-1)', [1, 1]);
		                                                                                                                                                                                                                                                                                       ixiatcl::set('ti_scalable_dsts_port_count(EndpointSet-1)', [1, 1]);
		                                                                                                                                                                                                                                                                                       ixiatcl::set('ti_scalable_dsts_intf_start(EndpointSet-1)', [1, 1]);
		                                                                                                                                                                                                                                                                                       ixiatcl::set('ti_scalable_dsts_intf_count(EndpointSet-1)', [1, 1]);
		                                                                                                                                                                                                                                                                                       $_result_ = ixiahlt::traffic_config({
		                                                                                                                                                                                                                                                                                       ......
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_handle => 'ti_scalable_srcs',
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_port_start => 'ti_scalable_srcs_port_start',
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_port_count => 'ti_scalable_srcs_port_count',
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_intf_start => 'ti_scalable_srcs_intf_start',
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_intf_count => 'ti_scalable_srcs_intf_count',
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_handle => 'ti_scalable_dsts',
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_port_start => 'ti_scalable_dsts_port_start',
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_port_count => 'ti_scalable_dsts_port_count',
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_intf_start => 'ti_scalable_dsts_intf_start',
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_intf_count => 'ti_scalable_dsts_intf_count',
		                                                                                                                                                                                                                                                                                       ...... 
		                                                                                                                                                                                                                                                                                       });
		                                                                                                                                                                                                                                                                                       7. When using Python the user must use ixiatcl.set_py in order to provide scalable sources and scalable destinations to the traffic_config command. Example:
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_handle = ['/topology:2/deviceGroup:1/ethernet:1/ipv4:1'],
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_port_start = [1],
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_port_count = [1],
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_intf_start = [5],
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_intf_count = [1],
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_handle = ['/topology:1/deviceGroup:2/ethernet:1/ipv4:1'],
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_port_start = [1],
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_port_count = [1],
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_intf_start = [4],
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_intf_count = [1],
		                                                                                                                                                                                                                                                                                       ixiatcl.set_py('ti_scalable_srcs(EndpointSet-1)', ['/topology:1/deviceGroup:2/ethernet:1/ipv4:1'])
		                                                                                                                                                                                                                                                                                       ixiatcl.set_py('ti_scalable_srcs_port_start(EndpointSet-1)', [1])
		                                                                                                                                                                                                                                                                                       ixiatcl.set_py('ti_scalable_srcs_port_count(EndpointSet-1)', [1])
		                                                                                                                                                                                                                                                                                       ixiatcl.set_py('ti_scalable_srcs_intf_start(EndpointSet-1)', [1])
		                                                                                                                                                                                                                                                                                       ixiatcl.set_py('ti_scalable_srcs_intf_count(EndpointSet-1)', [1])
		                                                                                                                                                                                                                                                                                       ixiatcl.set_py('ti_scalable_dsts(EndpointSet-1)', ['/topology:2/deviceGroup:1/ethernet:1/ipv4:1'])
		                                                                                                                                                                                                                                                                                       ixiatcl.set_py('ti_scalable_dsts_port_start(EndpointSet-1)', [1])
		                                                                                                                                                                                                                                                                                       ixiatcl.set_py('ti_scalable_dsts_port_count(EndpointSet-1)', [1])
		                                                                                                                                                                                                                                                                                       ixiatcl.set_py('ti_scalable_dsts_intf_start(EndpointSet-1)', [1])
		                                                                                                                                                                                                                                                                                       ixiatcl.set_py('ti_scalable_dsts_intf_count(EndpointSet-1)', [1])
		                                                                                                                                                                                                                                                                                       result = ixiahlt.traffic_config(
		                                                                                                                                                                                                                                                                                       ......
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_handle='ti_scalable_srcs',
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_port_start='ti_scalable_srcs_port_start',
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_port_count='ti_scalable_srcs_port_count',
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_intf_start='ti_scalable_srcs_intf_start',
		                                                                                                                                                                                                                                                                                       emulation_scalable_src_intf_count='ti_scalable_srcs_intf_count',
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_handle='ti_scalable_dsts',
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_port_start='ti_scalable_dsts_port_start',
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_port_count='ti_scalable_dsts_port_count',
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_intf_start='ti_scalable_dsts_intf_start',
		                                                                                                                                                                                                                                                                                       emulation_scalable_dst_intf_count='ti_scalable_dsts_intf_count',
		                                                                                                                                                                                                                                                                                       ......
		                                                                                                                                                                                                                                                                                       )
		                                                                                                                                                                                                                                                                                   
		                                                                                                                                                                                                                                                                                   See Also:
		                                                                                                                                                                                                                                                                                   
		"""
		return self._run_keyword("traffic_config", kwargs)

	def traffic_control(self, **kwargs):
		""" This procedure manages traffic flow on the specified test ports. You can start and stop traffic, reset the traffic generator and result counters.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: traffic_control
			 	-action                                      ANY
			 	[-latency_values                             ANY]
			 	[-latency_enable                             ANY]
			x	[-cpdp_convergence_enable                    ANY]
			x	[-cpdp_ctrl_plane_events_enable              ANY]
			x	[-cpdp_data_plane_events_rate_monitor_enable ANY]
			x	[-cpdp_data_plane_threshold                  ANY]
			x	[-cpdp_data_plane_jitter                     ANY]
			x	[-delay_variation_enable                     ANY]
			x	[-disable_latency_bins                       ANY]
			x	[-disable_jitter_bins                        ANY]
			x	[-duration                                   ANY]
			x	[-handle                                     ANY]
			x	[-instantaneous_stats_enable                 ANY]
			x	[-jitter_bins                                ANY]
			x	[-jitter_values                              ANY]
			x	[-large_seq_number_err_threshold             ANY]
			x	[-l1_rate_stats_enable                       ANY]
			x	[-misdirected_per_flow                       ANY]
			x	[-latency_bins                               ANY]
			x	[-latency_control                            ANY]
			x	[-max_wait_timer                             ANY]
			x	[-packet_loss_duration_enable                ANY]
			x	[-stats_mode                                 ANY]
			x	[-type                                       CHOICES l23 l47
			x                                             DEFAULT l23]
		
		Arguments:
			 	-action
			 		Action to take. Valid choices are:
			    		sync_run- Action sync_run performs both actions: clear_stats and start traffic. This option should be used, when per stream stats or packet group stats need to be retrieved. If this option is used with large IxNetwork configs, it takes some time to configure the traffic and apply the traffic to the Ixia port. In this case, the sync_run option should be used with -max_wait_timer.If used with the handle argument it will start only the traffic sources specified by handle. If the type argument is not used, l23 traffic will be started.
			    		run-Starts the generators and all configured traffic sources (starts traffic). If this option is used with large IxNetwork configs, it takes some time to configure the traffic and apply the traffic to the Ixia port. In this case, the run option should be used with -max_wait_timer (usually takes less than 120 seconds).If used with the handle argument it will start only the traffic sources specified by handle. If the type argument is not used, l23 traffic will be started.This choice is valid with IxNetwork traffic generators.
			    		stop -Stops the generators. If used with the handle argument it will start only the traffic sources specified by handle. If the type argument is not used, l23 traffic will be started.This choice is valid with IxNetwork traffic generators.
Note: Add a time delay after the traffic stop call, before doing other things such as cleanup or modify configuration. Stopping a classic protocol usually takes less than 10 seconds; stopping traffic takes about 30 seconds.
			    		poll -Polls the generators to determine whether they are stopped or running. This choice is valid with IxNetwork traffic generators. 
			Note: If action -poll is issued immediately after action -start, then the poll action may return stopped 1 when the correct status should be stopped 0.This happens when the chassis is very busy.Adding a little delay (one second) between -action start and -action poll call should resolve this problem.
			    		reset-Clears generators to power up state and clears all traffic sources.
			    		destroy - Destroys the generators.
			    		clear_stats- Clears all stats and timestamps.
			    		regenerate- Regenerates traffic items. If the argument handle is not used, all traffic items will be regenerated. Valid only for traffic generator ixnetwork_540.
			    		apply- Applies traffic configuration to the Ixia ports. If the argument type is not used, l23 traffic will be applied.Valid only for traffic generator ixnetwork_540.
			 	-latency_values
			 		The splitting values for the bins. 0 and Max will be the absolute end points. A list of {1.5 3 6.8} would create these four bins {0 - 1.5} {1.5 3} {3 6.8} {6.8 MAX}.Latency statistics, in the global traffic options, will be enabled. This parameter takes effect only if used in combination with the latency_bins argument.The traffic items that do not have latency bins enabled will be modified: latency bins will be enabled and latency bins configuration will be changed according to the value of latency_values. The traffic items that already have latency bins enabled will not be modified.This argument cannot be used if: delay_variation_enable is enabled, both cpdp_convergence_enable and cpdp_data_plane_events_rate_monitor_enable are enabled, both jitter_bins and jitter_values have been configured. Note: If jitter_bins, jitter_values and latency_bins, latency_values are used in the same command, the jitter arguments will be ignored.
			 	-latency_enable
			 		This options enables or disables latency statistics in the global traffic options.
			 		Valid choices are:
			    		0 - Disable latency statistics
			    		1 - Enable latency statistics
			x	-cpdp_convergence_enable
			x		Valid only for traffic_generator ixnetwork_540. This option enables/disables global control plane and data plane integrated time stamping for calculating convergence measurements.
			x		Valid choices are:
			x   		0 - Disables control plane and data plane integrated time stamping
			x   		1 - Enables control plane and data plane integrated time stamping
			x	-cpdp_ctrl_plane_events_enable
			x		Valid only for traffic_generator ixnetwork_540. This options enables/disables Control Plane (Protocol) State Change or Event timestamps used for convergence measurements. This argument can be used only if cpdp_convergence_enable is enabled.
			x		Valid choices are:
			x   		0 - Disables Control Plane state change or event timestamps
			x   		1 - Enables Control Plane state change or event timestamps
			x	-cpdp_data_plane_events_rate_monitor_enable
			x		Valid only for traffic_generator ixnetwork_540. This option enables/disables receiving ports rate monitoring to detect convergence event and capture timestamp. This argument can be used only if cpdp_convergence_enable is enabled. This parameter cannot be used if: delay_variation_enable is enabled, both jitter_bins and jitter_values have been configured, both latency_bins and latency_values have been configured, latency_enable is enabled.
			x		Valid choices are:
			x   		0 - Disablesreceive ports rate monitoring
			x   		1 - Enables receive ports rate monitoring
			x	-cpdp_data_plane_threshold
			x		Valid only for traffic_generator ixnetwork_540. This option configures the data loss threshold percentage for CP/DP events at the prompt. This argument can be used only if cpdp_convergence_enable is enabled.
			x	-cpdp_data_plane_jitter
			x		Valid only for traffic_generator ixnetwork_540. This option configures the precision time interval to be used for rate calculation on the receive side. This argument can be used only if cpdp_convergence_enable is enabled. Valid options are: 1.3, 2.6, 5.2, 10, 21, 42, 84, 168, 336, 671.
			x	-delay_variation_enable
			x		Valid only for traffic_generator ixnetwork_540. This option enables/disables one-way per packet delay measurements and delay variation measurement from output port to input port. This argument cannot be used if: latency_enable is enabled, both cpdp_convergence_enable and cpdp_data_plane_events_rate_monitor_enable are enabled, both jitter_bins and jitter_values have been configured, both latency_bins and latency_values have been configured.
			x		Valid choices are:
			x   		0- Disables global one-way per packet delay measurement.
			x   		1 - Enables global one-way per packet delay measurement.
			x	-disable_latency_bins
			x		Valid only for traffic_generator ixnetwork_540. This option disables latency statistics in the global traffic options.
			x	-disable_jitter_bins
			x		Valid only for traffic_generator ixnetwork_540. This option disables inter-arrival time/rate in the global traffic options.
			x	-duration
			x		Duration in seconds of traffic to run.To set the duration of the traffic use the procedure ::<namespace>::traffic_config with the parameter -duration set to a value in seconds to run frame size or mix of frame sizes. Valid only for traffic_generator ixos/ixnetwork_540.
			x	-handle
			x		The handle that is used to identify an individual traffic item. It can be a list of traffic item names, traffic item handles, or items that have as ancestor a traffic item.This argument is valid in combination with the following actions: run, stop, sync_run, regenerate. Valid only for traffic_generator ixnetwork_540.
			x	-instantaneous_stats_enable
			x		Enables/disables instantaneous mode for statistics retrieval. When it is set to a different value from the one currently configured in IxNetwork, all the traffic items will be regenerated. Valid only for traffic_generator ixnetwork_540.
			x	-jitter_bins
			x		Valid only for traffic_generator ixnetwork_540.Otherwise, it will be ignored.If a value is provided it represents the number of jitter bins that will be configured on the traffic items. If the value enabled is provided, the number of jitter bins will be determined based on the length of the jitter_value list.
			x		This parameters is valid if used in combination with jitter_values. Inter-arrival time/rate in the global traffic options will be enabled. The traffic items that do not have latency_bins enabled will be modified: latency_bins will be enabled and latency bins configuration will change according to the value of jitter_values. The traffic items that already have latency bins enabled will not be modified. This argument cannot be used if: delay_variation_enable is enabled, latency_enable is enabled, both cpdp_convergence_enable and cpdp_data_plane_events_rate_monitor_enable are enabled, both latency_values and latency_bins have been configured.
			x		Note: If jitter_bins, jitter_values and latency_bins, latency_values are used in the same command, the jitter arguments will be ignored.
			x	-jitter_values
			x		The splitting values for the bins. 0 and Max will be the absolute end points. A list of {1.5 3 6.8} would create these four bins {0 - 1.5} {1.5 3} {3 6.8} {6.8 MAX}. This parameter takes effect only if used in combination with the jitter_bins argument. Inter-arrival time/rate statistics, from the global traffic options, will be enabled. The traffic items that do not have latency bins enabled will be modified: latency bins will be enabled and latency bins configuration will be changed according to the value of jitter_values. The traffic items that already have latency bins enabled will not be modified.This argument cannot be used if: delay_variation_enable is enabled, latency_enable is enabled, both cpdp_convergence_enable and cpdp_data_plane_events_rate_monitor_enable are enabled, both latency_bins and latency_values are have been configured.Note: If jitter_bins, jitter_values and latency_bins, latency_values are used in the same command, the jitter arguments will be ignored.
			x	-large_seq_number_err_threshold
			x		Valid only for traffic_generator ixnetwork_540. This option configures the threshold value used to determine error levels for out-of-sequence, received packets. This argument can be used only if delay_variation_enable has been enabled.
			x	-l1_rate_stats_enable
			x		When this option is enabled the Layer 1 Rate Statistics will be returned when using traffic_stats with mode aggregate or all.
			x		Not specifying this parameter will cause the Layer 1 Rate Statistics to be returned only if the "Enable L1 Rate Statistics" option was enabled "Traffic Options" in the GUI.
			x		Setting this parameters from HLT API will also be reflected in IxNetwork GUI. This parameter is valid only when action is one of the following: run, sync_run, stop and reset.
			x		This parameter applies globally, not per traffic item. Valid only for traffic_generator ixnetwork_540.
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-misdirected_per_flow
			x		When this option is enabled the Misdirected Per Flow Statistics will be returned when using traffic_stats with mode flow, traffic_item, data_plane_port or all.
			x		Not specifying this parameter will cause the Layer 1 Rate Statistics to be returned only if the "Misdirected Per Flow Statistics" option was enabled "Traffic Options" in the GUI.
			x		Setting this parameters from HLT API will also be reflected in IxNetwork GUI. This parameter is valid only when action is one of the following: run, sync_run, stop and reset.
			x		This parameter applies globally, not per traffic item. Valid only for traffic_generator ixnetwork_540.
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-latency_bins
			x		The number of latency bins. Valid for traffic_generator ixos/ixnetwork_540. 
			x		Otherwise, it will be ignored. When -traffic_generator is ixnetwork_540 this option will configure latency bins for all traffic items that have -port_handle as a receiving port. If port_handle is not specified, it will configure latency on all traffic items. If latency was previously configured on a traffic item with ::ixia::traffic_config procedure, then latency bins will not be reconfigured. With traffic_generator ixnetwork_540 this option along with latency_values parameter triggers enable of global latency bins statistics.
			x		For ixnetwork_540 there is special value "enabled" which specifies that latency bins statistics will be enabled using the latency values and bins curently configured for each traffic item (no need to specify the latency_values).Latency cannot be enabled in the following conditions:
			x		
			x		- delay_variation_enable is 1.
			x		- jitter_bins and jitter_values are specified.
			x		- cpdp_convergence_enable is 1 and cpdp_data_plane_events_rate_monitor_enable is 1.
			x		
			x	-latency_control
			x		Valid only for traffic_generator ixos/ixnetwork_540 and delay_variation_enable is '1' or latency_bins and latency_values parameters are present and disable_latency_bins is not present.Otherwise, it will be ignored. Not all options are supported on all ports.
			x		Valid choices are:
			x   		Check cut_through - the time interval between the first data bit out of the Ixia transmit port and the first data bit received by the Ixia receive port is measured.
			x   		store_and_forward-the time interval between the last data bit out of the Ixia transmit port and the first data bit received by the Ixia receive port is measured.
			x   		store_and_forward_preamble- (for Ethernet modules only with traffic_generator ixos) As with store and forward, but measured with respect to the preamble to the Ethernet frame. In this case, the time interval between the last data bit out of the Ixia transmit port and the first preamble data bit received by the Ixia receive port is measured.
			x   		mef_frame_delay- valid only for traffic_generator ixnetwork_540. Standard MEF 10.1 and RFC 3393. The time interval starting when the First bit of the input frame reaches the input port and ending when the last bit of the output frame is seen on the output port (FILO)
			x   		forwarding_delay- - valid only for traffic_generator ixnetwork_540. Standard RFC 4689. The time interval starting when the last bit of the input frame reaches the input port and ending when the last bit of the output frame is seen on the output port (LILO)
			x	-max_wait_timer
			x		The maximum amount of time (in seconds) that HLT waits for the traffic command to take effect. For example after starting traffic HLT will wait for the traffic to actually start but no more than <max_wait_timer> seconds. When using many ports this parameter has to be higher.Default value is 0 (don't wait).Valid only for traffic_generator ixnetwork.
			x	-packet_loss_duration_enable
			x		Valid only for traffic_generator ixnetwork_540. Estimated time without received packets, calculated by frames delta at the
			x		Valid choices are:
			x   		0 - disable
			x   		1 - enable
			x	-stats_mode
			x		Valid only for traffic_generator ixnetwork_540 when delay_variation is '1'.
			x		Valid choices are:
			x   		rx_delay_variation_avg - rx delay variation with latency ave/min/max. Delay
			x   		x - rx delay variation with latency ave/min/max. Delay
			x   		rx_delay_variation_err_and_rate - rx delay variation with sequence errors and
			x   		rx_delay_variation_min_max_and_rate - rx delay variation with latency min/max and
			x	-type
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status      value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log         value:On status of failure, gives detailed information.
		0 if traffic is running, or 1 if traffic is stopped. This key is returned when option -action is set on run, sync_run or stop.
			 key:stopped     value:0 if traffic is running, or 1 if traffic is stopped. This key is returned when option -action is set on run, sync_run or stop.
		<RANGE 0-4294967295> This applies to jumbo type. The payload for the IPv6 Hop by Hop option. Valid only for traffic_generator ixos.
			 key:payload     value:<RANGE 0-4294967295> This applies to jumbo type. The payload for the IPv6 Hop by Hop option. Valid only for traffic_generator ixos.
		<RANGE 0-65535> This applies to mipv6_unique_id_sub type. A unique ID for the binding request. Valid only for traffic_generator ixos.
			 key:sub_unique  value:<RANGE 0-65535> This applies to mipv6_unique_id_sub type. A unique ID for the binding request. Valid only for traffic_generator ixos.
		<CHOICES mld rsvp active_net> This applies to router_alert type. Specifies the type of router alert to include with  the packet. Valid only for traffic_generator ixos.
			 key:alert_type  value:<CHOICES mld rsvp active_net> This applies to router_alert type. Specifies the type of router alert to include with  the packet. Valid only for traffic_generator ixos.
		<CHOICES 0 1>  This applies to binding_update type. This flag sets the Acknowledge (A) bit to indicate that the sending  mobile node is requesting that a Binding Acknowledgement be sent by the receiving node when it gets the Binding Update.  Valid only for traffic_generator ixos.
			 key:ack         value:<CHOICES 0 1>  This applies to binding_update type. This flag sets the Acknowledge (A) bit to indicate that the sending  mobile node is requesting that a Binding Acknowledgement be sent by the receiving node when it gets the Binding Update.  Valid only for traffic_generator ixos. 
		<CHOICES 0 1> This applies to binding_update type. Enables the bicasting flag for the Binding Update header. Valid only for traffic_generator ixos. (DEFAULT = 0)
			 key:bicast      value:<CHOICES 0 1> This applies to binding_update type. Enables the bicasting flag for the Binding Update header. Valid only for traffic_generator ixos. (DEFAULT = 0)
		<CHOICES 0 1> This applies to binding_update type. This flag sets the Duplicate Address Detection (D) bit, to indicate that the sending node wants the receiving node to perform Duplicate Address Detection for the mobile node's home address in this  binding. The H and A bits MUST also be set for this action to be performed. Valid only for traffic_generator ixos. (DEFAULT = 0)
			 key:duplicate   value:<CHOICES 0 1> This applies to binding_update type. This flag sets the Duplicate Address Detection (D) bit, to indicate that the sending node wants the receiving node to perform Duplicate Address Detection for the mobile node's home address in this  binding. The H and A bits MUST also be set for this action to be performed. Valid only for traffic_generator ixos. (DEFAULT = 0)
		<CHOICES 0 1> This applies to binding_update type. This flag sets the Home Registration (H) bit to indicate that the  sending node wants the receiving node to act as its home agent. Valid only for traffic_generator ixos. (DEFAULT = 0)
			 key:home        value:<CHOICES 0 1> This applies to binding_update type. This flag sets the Home Registration (H) bit to indicate that the  sending node wants the receiving node to act as its home agent. Valid only for traffic_generator ixos. (DEFAULT = 0)
		<CHOICES 0 1> This applies to binding_update type. Enables the map flag for the Binding Update header. Valid only for traffic_generator ixos. (DEFAULT = 0)
			 key:map         value:<CHOICES 0 1> This applies to binding_update type. Enables the map flag for the Binding Update header. Valid only for traffic_generator ixos. (DEFAULT = 0)
		<CHOICES 0 1> This applies to binding_update type. This flag indicates if the binding cache entry is for a mobile node advertised as a router by this node, on the behalf of the mobile node, in proxy Neighbor Advertisements. Valid only for traffic_generator ixos. (DEFAULT = 0)
			 key:router      value:<CHOICES 0 1> This applies to binding_update type. This flag indicates if the binding cache entry is for a mobile node advertised as a router by this node, on the behalf of the mobile node, in proxy Neighbor Advertisements. Valid only for traffic_generator ixos. (DEFAULT = 0)
		<RANGE 0-255> This applies to binding_update type. If the H-bit is set, this is the length of the routing prefix  for the home address. Valid only for traffic_generator ixos.
			 key:prefix_len  value:<RANGE 0-255> This applies to binding_update type. If the H-bit is set, this is the length of the routing prefix  for the home address. Valid only for traffic_generator ixos.
		<RANGE 0-4294967295> This applies to binding_update, binding_ack types. (32-bit integer) The number of seconds  remaining for the Binding Cache entry.  When the value reaches zero, the binding MUST be  considered expired and the Binding Cache entry MUST be  deleted for the mobile node. Valid only for traffic_generator ixos.
			 key:life_time   value:<RANGE 0-4294967295> This applies to binding_update, binding_ack types. (32-bit integer) The number of seconds  remaining for the Binding Cache entry.  When the value reaches zero, the binding MUST be  considered expired and the Binding Cache entry MUST be  deleted for the mobile node. Valid only for traffic_generator ixos.
		<RANGE 0-65535> This applies to binding_update, binding_ack types. For type binding_update: The mobile node uses this  number in the  Binding Update. The receiving node uses the same number in its Binding Acknowledgement, for matching. The Sequence number in each  Binding Update to one destination address must be greater than the last. For type binding_ack: This integer is copied from the received Binding  Update into the corresponding Binding ACK message. Valid only for traffic_generator ixos.
			 key:seq_num     value:<RANGE 0-65535> This applies to binding_update, binding_ack types. For type binding_update: The mobile node uses this  number in the  Binding Update. The receiving node uses the same number in its Binding Acknowledgement, for matching. The Sequence number in each  Binding Update to one destination address must be greater than the last. For type binding_ack: This integer is copied from the received Binding  Update into the corresponding Binding ACK message. Valid only for traffic_generator ixos.
		<RANGE 0-255> This applies to binding_ack type. This value indicates the disposition of the Binding Update:  0-127=  Binding Update was accepted.  >/= 128 = Binding Update was rejected. Valid only for traffic_generator ixos.
			 key:status      value:<RANGE 0-255> This applies to binding_ack type. This value indicates the disposition of the Binding Update:  0-127=  Binding Update was accepted.  >/= 128 = Binding Update was rejected. Valid only for traffic_generator ixos. 
		<RANGE 0-4294967295> This applies to binding_ack type. The mobile node SHOULD send a new Binding Update at this  recommended interval, to refresh the binding. The receiving node  (the node which sends the Binding ACK) determines the refresh interval (in  seconds). Valid only for traffic_generator ixos.
			 key:refresh     value:<RANGE 0-4294967295> This applies to binding_ack type. The mobile node SHOULD send a new Binding Update at this  recommended interval, to refresh the binding. The receiving node  (the node which sends the Binding ACK) determines the refresh interval (in  seconds). Valid only for traffic_generator ixos.
		<IPV6> The IPv6 address for mipv6_alternative_coa_sub type. Valid only for traffic_generator ixos.
			 key:address     value:<IPV6> The IPv6 address for mipv6_alternative_coa_sub type. Valid only for traffic_generator ixos.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		1) Coded versus functional specification.
		2) When using traffic_stats -mode stream or -packet_group_id options, then traffic_control with -action clear_stats or -action sync_run should be called first.
		
		See Also:
		
		"""
		return self._run_keyword("traffic_control", kwargs)

	def traffic_l47_config(self, **kwargs):
		""" This generic procedure configures application flows from a set of predefined application flows. This will create, modify and delete appication flows on top of NGPF End Points.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: traffic_l47_config
			x	-mode                               CHOICES create
			x                                    CHOICES modify
			x                                    CHOICES delete
			x                                    CHOICES enable
			x                                    CHOICES disable
			x                                    CHOICES get
			x                                    DEFAULT create]
			x	[-stream_id                         ANY
			x                                    DEFAULT none]
			x	[-l47_configuration                 CHOICES modify_profile_parameters
			x                                    CHOICES modify_flow_percentage
			x                                    CHOICES modify_flow_parameter
			x                                    CHOICES modify_flow_connection_parameter
			x                                    CHOICES override_flows
			x                                    CHOICES append_flow
			x                                    CHOICES remove_flow
			x                                    CHOICES distribute_flows_percentage_evenly
			x                                    CHOICES get_available_flows]
			x	[-name                              ANY]
			x	[-circuit_endpoint_type             CHOICES ipv4_application_traffic
			x                                    CHOICES ipv6_application_traffic
			x                                    DEFAULT ipv4_application_traffic]
			x	[-emulation_src_handle              ANY]
			x	[-emulation_dst_handle              ANY]
			x	[-emulation_scalable_src_handle     ANY]
			x	[-emulation_scalable_src_port_start NUMERIC]
			x	[-emulation_scalable_src_port_count NUMERIC]
			x	[-emulation_scalable_src_intf_start NUMERIC]
			x	[-emulation_scalable_src_intf_count NUMERIC]
			x	[-emulation_scalable_dst_handle     ANY]
			x	[-emulation_scalable_dst_port_start NUMERIC]
			x	[-emulation_scalable_dst_port_count NUMERIC]
			x	[-emulation_scalable_dst_intf_start NUMERIC]
			x	[-emulation_scalable_dst_intf_count NUMERIC]
			x	[-objective_type                    CHOICES users tputkb tputmb tputgb
			x                                    DEFAULT users]
			x	[-objective_value                   NUMERIC]
			x	[-objective_distribution            CHOICES apply_full_objective_to_each_port
			x                                    CHOICES split_objective_evenly_among_ports
			x                                    DEFAULT apply_full_objective_to_each_port]
			x	[-enable_per_ip_stats               CHOICES 0 1]
			x	[-flows                             ANY]
			x	[-flow_percentage                   ANY]
			x	[-flow_id                           ANY]
			x	[-connection_id                     NUMERIC]
			x	[-parameter_id                      ANY]
			x	[-parameter_option                  CHOICES value choice range]
			x	[-parameter_value                   CHOICES numeric
			x                                    CHOICES bool
			x                                    CHOICES string
			x                                    CHOICES hex
			x                                    CHOICES choice
			x                                    CHOICES range]
		
		Arguments:
			x	-mode
			x		Mode of the procedure call.Valid options are:
			x		create
			x		modify
			x		delete
			x		enable
			x		disable
			x		get
			x		Valid choices are:
			x   		create - Create only one stream/traffic item.
			x   		modify - Modify only one existing stream/traffic item.
			x   		delete - Remove/disable an existing stream/traffic item.
			x   		enable - Enables an existing stream/traffic item.
			x   		disable - Disables an existing stream/traffic item.
			x   		get - Get available flows for existing stream/traffic item.
			x	-stream_id
			x		Required for -mode modify/remove/enable/disable/get calls.
			x		Stream ID returned from the traffic_l47_config handles.
			x		Stream ID is not required for configuring a stream for the first time. In this case, the stream ID is returned by the call..
			x		Valid for Application Library Traffic.
			x	-l47_configuration
			x		Required for -mode modify and -stream_id traffic_item_handler calls
			x		Valid for Application Library Traffic.
			x		Valid choices are:
			x   		modify_profile_parameters - Modify the profile parameter for stream/traffic item.
			x   		modify_flow_percentage - Modify the flow percentage for a given flow.
			x   		modify_flow_parameter - Modify the flow parameters for a given flow.
			x   		modify_flow_connection_parameter - Modify the flow connection parameter for a given flow.
			x   		override_flows - Override flow from existing stream/traffic item.
			x   		append_flow - Add a new flow to existing stream/traffic item.
			x   		remove_flow - Remove flow from existing stream/traffic item.
			x   		distribute_flows_percentage_evenly - Distribute flow percentage equally among the configured flows in given stream/traffic item.
			x   		get_available_flows - Get all the configured flows in a given stream/traffic item.
			x	-name
			x		Stream string identifier/name. If this name contains spaces,
			x		the spaces will be translated to underscores and a warning
			x		will be displayed. The string name must not contain commas.
			x	-circuit_endpoint_type
			x		This argument can be used to specify the endpoint type that will be
			x		used to generate traffic.
			x		Valid choices are:
			x   		ipv4_application_traffic - Select this option if the endpoint supports IPv4 application traffic generation.
			x   		ipv6_application_traffic - Select this option if the endpoint supports IPv6 application traffic generation.
			x	-emulation_src_handle
			x		The handle used to retrieve information for L2 or L3 source addresses and use them to configure the sources for traffic.
			x		This should be the emulation handle that was obtained after configuring NGPF protocols.
			x		This parameter can be provided with a list or with a list of lists elements.
			x	-emulation_dst_handle
			x		The handle used to retrieve information for L2 or L3 source addresses and use them to configure the destinations for traffic.
			x		This should be the emulation handle that was obtained after configuring NGPF protocols.
			x		This parameter can be provided with a list or with a list of lists elements.
			x	-emulation_scalable_src_handle
			x		An array which contains lists of handles used to retrieve information for L3
			x		src addresses, indexed by the endpointset to which they correspond.
			x		This should be a handle that was obtained after configuring protocols with
			x		commands from the ::ixia_hlapi_framework:: namespace.
			x		This parameter can be used in conjunction with emulation_src_handle.
			x	-emulation_scalable_src_port_start
			x		An array which contains lists of numbers that encode the index of the first
			x		port on which the corresponding endpointset will be configured.
			x		This parameter will be ignored if no corresponding value is specified for
			x		emulation_scalable_src_handle.
			x	-emulation_scalable_src_port_count
			x		An array which contains lists of numbers that encode the number of ports on
			x		which the corresponding endpointset will be configured.
			x		This parameter will be ignored if no corresponding value is specified for
			x		emulation_scalable_src_handle.
			x	-emulation_scalable_src_intf_start
			x		An array which contains lists of numbers that encode the index of the first
			x		interface on which the corresponding endpointset will be configured.
			x		This parameter will be ignored if no corresponding value is specified for
			x		emulation_scalable_src_handle.
			x	-emulation_scalable_src_intf_count
			x		An array which contains lists of numbers that encode the number of interfaces
			x		on which the corresponding endpointset will be configured.
			x		This parameter will be ignored if no corresponding value is specified for
			x		emulation_scalable_src_handle.
			x	-emulation_scalable_dst_handle
			x		An array which contains lists of handles used to retrieve information for L3
			x		dst addresses, indexed by the endpointset to which they correspond.
			x		This should be a handle that was obtained after configuring protocols with
			x		commands from the ::ixia_hlapi_framework:: namespace.
			x		This parameter can be used in conjunction with emulation_dst_handle.
			x	-emulation_scalable_dst_port_start
			x		An array which contains lists of numbers that encode the index of the first
			x		port on which the corresponding endpointset will be configured.
			x		This parameter will be ignored if no corresponding value is specified for
			x		emulation_scalable_dst_handle.
			x	-emulation_scalable_dst_port_count
			x		An array which contains lists of numbers that encode the number of ports on
			x		which the corresponding endpointset will be configured.
			x		This parameter will be ignored if no corresponding value is specified for
			x		emulation_scalable_dst_handle.
			x	-emulation_scalable_dst_intf_start
			x		An array which contains lists of numbers that encode the index of the first
			x		interface on which the corresponding endpointset will be configured.
			x		This parameter will be ignored if no corresponding value is specified for
			x		emulation_scalable_dst_handle.
			x	-emulation_scalable_dst_intf_count
			x		An array which contains lists of numbers that encode the number of interfaces
			x		on which the corresponding endpointset will be configured.
			x		This parameter will be ignored if no corresponding value is specified for
			x		emulation_scalable_dst_handle.
			x	-objective_type
			x		sets objective type.
			x		Valid choices are:
			x   		users -
			x   		tputkb -
			x   		tputmb -
			x   		tputgb -
			x	-objective_value
			x		sets objective value.
			x	-objective_distribution
			x		sets objective distribution.
			x		Valid choices are:
			x   		apply_full_objective_to_each_port -
			x   		split_objective_evenly_among_ports -
			x	-enable_per_ip_stats
			x		enables/disables per IP statistics.
			x	-flows
			x		sets flows to be configured when create a traffic application profile.
			x	-flow_percentage
			x		Amount of traffic to be generated for this flow in percentage.
			x	-flow_id
			x		Name of the Application Library flow ( e.g. HTTP_Request).
			x	-connection_id
			x		Application library flow connection identifier ( e.g. 1).
			x	-parameter_id
			x		Application library flow parameter identifier ( e.g. enableProxyPort).
			x	-parameter_option
			x		Each parameter has one or multiple options.
			x		This options are: value, choice and range.
			x		Valid choices are:
			x   		value - single value. To be used when parameter takesa single value.
			x   		choice - choice of values. To be used when parameter takes a value from choice of values.
			x   		range - range of value. To be used when parameter takes a value between range of values.
			x	-parameter_value
			x		For each parameter a value can be assigned.
			x		The parameters are runtime specific and can accommodate the following types:
			x		Valid choices are:
			x   		numeric - when the value is in number format
			x   		bool - when the value is a boolean value, true or false
			x   		string - when the value is a word
			x   		hex - when the value is in hex format
			x   		choice - when the value is selected from a list of available options
			x   		range - when specifying a range value, this value must be in format min-max, 
where min and max are numeric values
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                                             value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                                                value:On status of failure, gives detailed information.
		A list containing the handles of L47 traffic items that were added by the command (if any). This key is returned only when the command is issued with -mode create.
			xkey:traffic_l47_handle                                 value:A list containing the handles of L47 traffic items that were added by the command (if any). This key is returned only when the command is issued with -mode create.
		This key returns the list of initiator ports configured in the traffic item mentioned by <traffic_l47_handle>.
			xkey:<traffic_l47_handle>.initiator_ports               value:This key returns the list of initiator ports configured in the traffic item mentioned by <traffic_l47_handle>.
		This key returns the list of responder ports configured in the traffic item mentioned by <traffic_l47_handle>.
			xkey:<traffic_l47_handle>.responder_ports               value:This key returns the list of responder ports configured in the traffic item mentioned by <traffic_l47_handle>.
		This key returns the applib handle configured in the traffic item mentioned by <traffic_l47_handle>.
			xkey:<traffic_l47_handle>.applib_profile                value:This key returns the applib handle configured in the traffic item mentioned by <traffic_l47_handle>.
		This key returns the applib flows configured in the traffic item mentioned by <traffic_l47_handle> and the AppLib profile mentioned by the <applib_profile> handle.
			xkey:<traffic_l47_handle>.<applib_profile>.applib_flow  value:This key returns the applib flows configured in the traffic item mentioned by <traffic_l47_handle> and the AppLib profile mentioned by the <applib_profile> handle.
		A list of the available flows. This key is returned only when the command is issued with -mode get.
			xkey:available_flows                                    value:A list of the available flows. This key is returned only when the command is issued with -mode get.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("traffic_l47_config", kwargs)

	def traffic_stats(self, **kwargs):
		""" This procedure retrieves statistical information about traffic streams by a specific port.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: traffic_stats
			 	[-mode                                         CHOICES all
			                                                CHOICES add_atm_stats
			                                                CHOICES add_atm_stats_tx
			                                                CHOICES add_atm_stats_rx
			                                                CHOICES aggregate
			                                                CHOICES application_FTP
			                                                CHOICES application_HTTP
			                                                CHOICES application_IMAP
			                                                CHOICES application_POP3
			                                                CHOICES application_RTSP
			                                                CHOICES application_SIP
			                                                CHOICES application_SMTP
			                                                CHOICES application_TELNET
			                                                CHOICES application_TriplePlay
			                                                CHOICES application_Video
			                                                CHOICES data_plane_port
			                                                CHOICES egress_by_flow
			                                                CHOICES egress_by_port
			                                                CHOICES faststream
			                                                CHOICES flow
			                                                CHOICES igmp_over_ppp
			                                                CHOICES l23_test_summary
			                                                CHOICES multicast
			                                                CHOICES out_of_filter
			                                                CHOICES per_port_flows
			                                                CHOICES session
			                                                CHOICES stream
			                                                CHOICES streams
			                                                CHOICES traffic_item
			                                                CHOICES user_defined_stats
			                                                CHOICES L47_traffic_item
			                                                CHOICES L47_flow_initiator
			                                                CHOICES L47_flow_responder
			                                                CHOICES L47_traffic_item_tcp
			                                                CHOICES L47_flow_initiator_tcp
			                                                CHOICES L47_listening_port_tcp]
			 	[-port_handle                                  ANY]
			 	[-streams                                      ANY]
			 	[-stream                                       ANY]
			x	[-atm_counter_vpi_data_item_list               ANY]
			x	[-atm_counter_vci_data_item_list               ANY]
			x	[-atm_counter_vpi_mode                         ANY]
			x	[-atm_counter_vci_mode                         ANY]
			x	[-atm_counter_vpi_type                         ANY]
			x	[-atm_counter_vci_type                         ANY]
			x	[-atm_reassembly_enable_iptcpudp_checksum      ANY]
			x	[-atm_reassembly_enable_ip_qos                 ANY]
			x	[-atm_reassembly_encapsulation                 ANY]
			x	[-csv_path                                     ANY]
			x	[-drill_down_type                              CHOICES per_ips
			x                                               CHOICES per_ports
			x                                               CHOICES per_initiator_flows
			x                                               CHOICES per_responder_flows
			x                                               CHOICES per_ports_per_initiator_flows
			x                                               CHOICES per_ports_per_responder_flows
			x                                               CHOICES per_ports_per_initiator_ips
			x                                               CHOICES per_ports_per_responder_ips
			x                                               CHOICES per_initiator_flows_per_initiator_ports
			x                                               CHOICES per_responder_flows_per_responder_ports
			x                                               CHOICES per_initiator_flows_per_initiator_ips
			x                                               CHOICES per_responder_flows_per_responder_ips
			x                                               CHOICES per_ports_per_initiator_flows_per_initiator_ips
			x                                               CHOICES per_ports_per_responder_flows_per_responder_ips
			x                                               CHOICES per_initiator_flows_per_initiator_ports_per_initiator_ips
			x                                               CHOICES per_responder_flows_per_responder_ports_per_responder_ips
			x                                               CHOICES per_initiator_ports
			x                                               CHOICES per_initiator_ips
			x                                               CHOICES per_initiator_ports_per_initiator_ips
			x                                               CHOICES per_responder_ports
			x                                               CHOICES per_responder_ips
			x                                               CHOICES per_responder_ports_per_responder_ips
			x                                               CHOICES per_listening_ports
			x                                               CHOICES per_listening_ports_per_responder_port
			x                                               CHOICES per_responder_port
			x                                               CHOICES none
			x                                               DEFAULT none]
			x	[-drill_down_traffic_item                      ANY]
			x	[-drill_down_port                              ANY]
			x	[-drill_down_listening_port                    NUMERIC]
			x	[-drill_down_flow                              ANY]
			x	[-egress_mode                                  ANY]
			x	[-egress_stats_list                            ANY]
			x	[-ignore_rate                                  ANY]
			x	[-qos_stats                                    ANY]
			x	[-measure_mode                                 ANY]
			x	[-packet_group_id                              ANY]
			x	[-previous_data                                ANY]
			x	[-return_method                                ANY]
			x	[-uds_action                                   ANY]
			x	[-uds_l23ps_drilldown                          ANY]
			x	[-uds_l23ps_num_results                        ANY]
			x	[-uds_l23ps_sorting_statistic                  ANY]
			x	[-uds_l23ps_sorting_type                       ANY]
			x	[-uds_l23tf_aggregated_across_ports            ANY]
			x	[-uds_l23tf_egress_latency_bin_display         ANY]
			x	[-uds_l23tf_enumeration_sorting_type           ANY]
			x	[-uds_l23tf_filter_type                        ANY]
			x	[-uds_l23tf_tracking_operator                  ANY]
			x	[-uds_l23tf_tracking_value                     ANY]
			x	[-uds_l23tfd_dead_flows_treshold               ANY]
			x	[-uds_l23tfd_flow_type                         ANY]
			x	[-uds_l23tfd_show_egress_flows                 ANY]
			x	[-uds_l23tfd_statistic_all_flows_sort_by       ANY]
			x	[-uds_l23tfd_statistic_all_flows_sorting_type  ANY]
			x	[-uds_l23tfd_statistic_all_flows_num_results   ANY]
			x	[-uds_l23tfd_statistic_dead_flows_sort_by      ANY]
			x	[-uds_l23tfd_statistic_dead_flows_sorting_type ANY]
			x	[-uds_l23tfd_statistic_dead_flows_num_results  ANY]
			x	[-uds_l23tfd_statistic_live_flows_sort_by      ANY]
			x	[-uds_l23tfd_statistic_live_flows_sorting_type ANY]
			x	[-uds_l23tfd_statistic_live_flows_num_results  ANY]
			x	[-uds_l23tfd_statistic_operator                ANY]
			x	[-uds_l23tfd_statistic_value                   ANY]
			x	[-uds_l23tfd_tracking_operator                 ANY]
			x	[-uds_l23tfd_tracking_value                    ANY]
			x	[-uds_port_filter                              ANY]
			x	[-uds_port_filter_count                        ANY]
			x	[-uds_protocol_stack_filter                    ANY]
			x	[-uds_protocol_stack_filter_count              ANY]
			x	[-uds_statistic_filter                         ANY]
			x	[-uds_statistic_filter_count                   ANY]
			x	[-uds_tracking_filter                          ANY]
			x	[-uds_tracking_filter_count                    ANY]
			x	[-uds_traffic_item_filter                      ANY]
			x	[-uds_traffic_item_filter_count                ANY]
			x	[-uds_type                                     ANY]
			x	[-traffic_generator                            ANY]
			x	[-vci                                          ANY]
			x	[-vci_count                                    ANY]
			x	[-vci_step                                     ANY]
			x	[-vpi                                          ANY]
			x	[-vpi_step                                     ANY]
		
		Arguments:
			 	-mode
			 		Type of statistics to collect. Valid choices are:
			    		add_atm_stats - Adds the vpi/vci pair to gather both rx and tx statistics.The number of tx stats that can be tracked is less than the number of rx stats that can be tracked. This option is valid only if -traffic_generator is set to ixos.
			    		add_atm_stats_rx - Adds the vpi/vci pair to gather rx statistics.The number of tx stats that can be tracked is less than the number of rx stats that can be tracked. This option is valid only if -traffic_generator is set to ixos.
			    		add_atm_stats_tx - Adds the vpi/vci pair to gather tx statistics.The number of tx stats that can be tracked is less than the number of rx stats that can be tracked. This option is valid only if -traffic_generator is set to ixos.
			    		aggregate - Gathers per port aggregated stats. This option is valid only if -traffic_generator is set to ixos or ixnetwork or ixnetwork_540 and streams where generated either with IxOS/IxNetwork.
			    		all - Gathers all the statistics available for the specific -traffic_generator option.Note: This mode is applicable only for L2/L3 Traffic.
			    		faststream - Not implemented.
			    		flow - Gathers per flow stats. This option is valid only if -traffic_generator is set to ixnetwork or ixnetwork_540 and streams were generated with IxNetwork.
			    		igmp_over_ppp - Not supported.
			    		l23_test_summary - Available only for IxNetwork TCL API. This mode retrieves layer 2-3 statistics agreagated across all ports (parameter port_handle is ignored in this mode). The equivalent from IxNetwork GUI is "L2-L3 Test Summary Statistics" view. This option is valid only if -traffic_generator is set to ixnetwork_540.
			    		multicast - Not supported.
			    		out_of_filter - Not implemented.
			    		per_port_flows - Ability to retrieve per flow information using HLTAPI. Valid only for traffic generator ixnetwork or ixnetwork_540.session- Not supported.
			    		stream - Gathers per stream stats. This option is valid only if -traffic_generator is set to ixos and streams were generated with IxOS or parameter -traffic_generator is set to ixnetwork or ixnetwork_540 and streams were generated with IxNetwork.
			    		streams - This is the same as stream option. Deprecated.
			    		egress_by_port - Available only for IxNetwork TCL API. Parameter port_handle is mandatory for this mode. If egress tracking was configured on the port_handle port this mode retrieves egress tracking statistics for this port. This is available with -traffic_generator ixnetwork and ixnetwork_540.
			    		egress_by_flow - Available only for IxNetwork TCL API. Parameter port_handle is mandatory for this mode. If egress tracking was configured on the port_handle port this mode retrieves egress tracking statistics for the flows on port_handle port. This is available with -traffic_generator ixnetwork and ixnetwork_540.
			    		data_plane_port - Available only for IxNetwork TCL API with traffic_generator ixnetwork_540. Retrieve per port data plane statistics.
			    		traffic_item - Available only for IxNetwork TCL API with traffic_generator ixnetwork_540. Retrieve statistics per traffic item. The statistics can be filtered using parameter -stream with one or a list of values. The values must be traffic_items returned by procedure ::<namespace>::traffic_config.
			    		user_defined_stats - Available only for IxNetwork TCL API with traffic_generator ixnetwork_540. Retrieve user defined statitics. The statistics can be filtered using parameters starting with -uds_... with one or a list of values. Available starting with HLT API 3.80.
			    		application_FTP - Deprecated value, previously used for AppLib Legacy Traffic
			    		application_HTTP - Deprecated value, previously used for AppLib Legacy Traffic
			    		application_TELNET - Deprecated value, previously used for AppLib Legacy Traffic
			    		application_SMTP - Deprecated value, previously used for AppLib Legacy Traffic
			    		application_IMAP - Deprecated value, previously used for AppLib Legacy Traffic
			    		application_POP3 - Deprecated value, previously used for AppLib Legacy Traffic
			    		application_TriplePlay - Deprecated value, previously used for AppLib Legacy Traffic
			    		application_SIP - Deprecated value, previously used for AppLib Legacy Traffic
			    		application_Video - Deprecated value, previously used for AppLib Legacy Traffic
			    		application_RTSP - Deprecated value, previously used for AppLib Legacy Traffic
			 	-port_handle
			 		Port from which to gather statistics.This parameter is mandatory in the following situations:1. traffic_generator is set to ixos.2. traffic_generator is set to ixnetwork or ixnetwork_540 and -mode is other than stream.Valid for traffic_generator ixos/ixnetwork/ixnetwork_540;
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-streams
			 		Stream ID on which to gather statistics.Valid for traffic_generator ixos/ixnetwork/ixnetwork_540 and -mode set to stream/all. The stream_id is the stream_id returned by traffic_config command. If traffic_generator is ixos, then the stream ID is a numeric value. If traffic_generator is ixnetwork/ixnetwork_540, then the stream ID is a string with the following regular expression: ^TI[0-9]+\-(.)*$.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			 	-stream
			 		Stream ID on which to gather statistics (deprecated).Valid for traffic_generator ixos/ixnetwork/ixnetwork_540 and -mode set to stream/all.If traffic_generator is ixos, then the stream ID is a numeric value. If traffic_generator is ixnetwork/ixnetwork_540, then the stream ID is a string with the following regular expression: ^TI[0-9]+\-(.)*$.
			 		This argument defined by Cisco is not supported for IxNetwork-NGPF implementation.
			x	-atm_counter_vpi_data_item_list
			x	-atm_counter_vci_data_item_list
			x   	-atm_counter_vpi_mode
			x       	-atm_counter_vci_mode
			x           	-atm_counter_vpi_type
			x               	-atm_counter_vci_type
			x                   	-atm_reassembly_enable_iptcpudp_checksum
			x                       	-atm_reassembly_enable_ip_qos
			x                           	-atm_reassembly_encapsulation
			x                               	-csv_path
			x                                   		This parameter represents the path for the generated CSV files. This parameter is used for both Unix and Windows environments, and the path to the directory should be absolute (eg. {/home/user/folder} or {d:/new folder/results}). If -return_method is different from csv, the csv files are created temporarily, for parsing the statistics. After the parsing, these csv files are deleted. In case the csv_path is omitted or the user doesn't have writing permission on the directory, the csv files will be created in the current directory if possible, otherwise the /tmp directory will be used.
			x                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                               	-drill_down_type
			x                                   	-drill_down_traffic_item
			x                                       	-drill_down_port
			x                                           	-drill_down_listening_port
			x                                               	-drill_down_flow
			x                                                   	-egress_mode
			x                                                       		When -mode is egress_by_flow or egress_by_port the statistics can be collected in two ways: conditional or paged. When using conditional, the advantage is that it will return egress statistics only for the rows for which it received values, the disadvantage is that retrieving conditional stats is slower. When using paged mode the advantage is that it's faster (an optimal number of rows per page will be auto configured) but the disadvantage is that it will retrieve statistics for all the egress values that are expected even if nothing was received for a certain egress value. For example: if egress tracking was configured to outer_vlan_id_4 but only 2 values were received, the conditional mode will return 2 separate egress values while the paged mode will return 15 values.When to use egress_mode conditional: when the number of possible egress tracking values is very big but the actual number of egress values is small (e.g. outer_vlan_id_12 and the values received are 1, 10 and 4000).When to use egress_mode paged:Scalability, when the number of expected egress values is big (many ingress flows each having multiple egress flows)When the number of possible egress values is small (inner_vlan_priority has a total number of 7 flows)Valid only for traffic_generator ixnetwork_540.
			x                                                       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                   	-egress_stats_list
			x                                                       		This parameter is valid only for custom egress views only. Using this parameter, the user can select a list. Valid only for traffic_generator ixnetwork_540.
			x                                                       		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                       		Valid choices are:
			x                                                           		tx.total_pkts - Tx Frames
			x                                                           		rx.expected_pkts - Rx Expected Frames
			x                                                           		rx.total_pkts - Rx Frames
			x                                                           		rx.loss_pkts - Frames Delta
			x                                                           		rx.loss_percent - Loss %
			x                                                           		rx.pkt_loss_duration - Packet Loss Duration (ms)
			x                                                           		tx.total_pkt_rate - Tx Frame Rate
			x                                                           		rx.total_pkt_rate - Rx Frame Rate
			x                                                           		rx.total_pkts_bytes - Rx Bytes
			x                                                           		tx.total_pkt_byte_rate - Tx Rate (Bps)
			x                                                           		rx.total_pkt_byte_rate - Rx Rate (Bps)
			x                                                           		tx.total_pkt_bit_rate - Tx Rate (bps)
			x                                                           		rx.total_pkt_bit_rate - Rx Rate (bps)
			x                                                           		tx.total_pkt_kbit_rate - Tx Rate (Kbps)
			x                                                           		rx.total_pkt_kbit_rate - Rx Rate (Kbps)
			x                                                           		tx.total_pkt_mbit_rate - Tx Rate (Mbps)
			x                                                           		rx.total_pkt_mbit_rate - Rx Rate (Mbps)
			x                                                           		rx.avg_delay - Store-Forward Avg Latency (ns)
			x                                                           		rx.min_delay - Store-Forward Min Latency (ns)
			x                                                           		rx.max_delay - Store-Forward Max Latency (ns)
			x                                                           		rx.first_tstamp - First Timestamp
			x                                                           		rx.last_tstamp - Last Timestamp
			x                                                   	-ignore_rate
			x                                                       	-qos_stats
			x                                                           	-measure_mode
			x                                                               		This sets the measuring mode for traffic stats in IxNetwork. The returned statistics will be in accord with this value. If this parameter is not present, the measure mode is not changed from the current value in IxNetwork. Valid only for traffic_generator ixnetwork_540
			x                                                               		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                           	-packet_group_id
			x                                                               	-previous_data
			x                                                                   		If this parameter is given with the reset value allthe arrays that were previously allocated will be erased.Valid only for traffic_generator ixnetwork_540.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-return_method
			x                                                                   		Valid choices are:
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                                       		keyed_list (default)-always return the stat values as a keyed list, no matter how long it takes.
			x                                                                       		keyed_list_or_array- when more than 2000 statistics values need to be retrieved, the keyhandle will be returned instead of all the keyed list items specified in the section dedicated for returned values. This key, handle, represents the name of the array to be used for reading the stats. This key is returned when more than 2000 statistics values need to be retrieved. The indices of this array are the keys that you'll find explained in the returned values section, and the values are the statistics values. This method has been introduced to increase performance when returning and reading stats. Returning a huge list in the tcl console can make the console hang.
			x                                                                       		array- the key handle will be returned instead of all the keyed list items specified in the section dedicated for returned values. This key, handle, represents the name of the array to be used for reading the stats. The indices of this array are the keys that you'll find explained in the returned values section, and the values are the statistics values. This method has been introduced to increase performance when returning and reading stats. Returning a huge list in the tcl console can make the console hang.
			x                                                                       		csv-only returns a path to the csv file containing the statsOnly valid if $::<namespace>::snapshot_stats == 1 (Ixia.tcl), otherwise -return_method defaults to keyed_list. Parameter -mode must be different than all, otherwise it defaults on aggregate. This option is available only when mode is aggregate, all, data_plane_port, flow,per_port_flows, stream, streams, traffic_item, l23_test_summary, egress_by_flow, egress_by_port, user_defined_stats and for L47 Application Traffic (application_FTP, application_HTTP, etc).Valid for traffic_generator ixos/ixnetwork/ixnetwork_540.
			x                                                               	-uds_action
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                                   		Valid choices are:
			x                                                                       		get_available_port_filters-returns the available port filters that can be applied for filtering traffic
			x                                                                       		statisticsget_available_protocol_stack_filters-returns the available protocol stack filters (PPP ranges, L2TP ranges etc) that can be applied for filtering traffic
			x                                                                       		statisticsget_available_statistic_filters-returns the available statistic filters (Tx Frames, Rx Frames etc) that can be applied for filtering traffic
			x                                                                       		statisticsget_available_stats-returns the available statistic names (Tx Frames, Rx Frames etc) that can be retrieved for a specified user defined statistic
			x                                                                       		typeget_available_traffic_item_filters-returns the available traffic item filters that can be applied for filtering traffic
			x                                                                       		statisticsget_available_tracking_filters- - returns the available tracking filters that can be applied for filtering traffic statistics. The list of tracking filters should contain the tracked fields when configuring traffic.
			x                                                                       		get_stats- - (DEFAULT), returns the statistics values. When retrieving stats, filters can be applied depending on the uds_type parameter. If no filter is provided by the user, then all possible and available filters are applied.
			x                                                               	-uds_l23ps_drilldown
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_protocol_stack. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. per_session - (DEFAULT), retrieves per session protocol stack statisticsper_range - retrieves per range protocol stack statistics
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23ps_num_results
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_protocol_stack. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. This parameter indicates the number of results per page to be retrieved in teh corresponding user defined statistics view.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23ps_sorting_statistic
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_protocol_stack. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. This parameter indicates the statistic to use for sorting the results.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23ps_sorting_type
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_protocol_stack. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. This parameter indicates the sorting type: ascending or decending, for the uds_l23ps_sorting_statistic parameter.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tf_aggregated_across_ports
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. When retrieving traffic flow statistics, this parameter indicates whether the flows should be aggregated across ports or not.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tf_egress_latency_bin_display
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. Determines what type of latency statistics should be inluded in the list of retrieved statistics. none - no latency statistics are includedshow_egress_flat_view - egress flat view statistics are includedshow_egress_rows - egress statistics are includedshow_latency_bin_stats - latency bin statistics are included
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tf_enumeration_sorting_type
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow, uds_l23tf_filter_type enumeration, uds_tracking_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. This parameter accepts a list of values, exactly like uds_l23tf_filter_type parameter. If the corresponding index of uds_l23tf_filter_type has the value tracking, then this parameter's value should be null. ascending - the sorting for the enumeration filter is ascendingdescending - the sorting for the enumeration filter is descendingnull - used when uds_l23tf_filter_type is tracking
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tf_filter_type
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow, uds_tracking_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. The traffic flow filter type: enumeration or tracking.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tf_tracking_operator
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow, uds_tracking_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. The uds_tracking_filter parameter is provided with a list of fields that are used for filtering. An operator and a value are applied on the specified field. This parameter specifies the operator that is applied: is_any_of is_different is_equal is_equal_or_greater is_equal_or_smaller is_greater is_in_any_range is_none_of is_smaller null.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tf_tracking_value
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow, uds_tracking_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. The uds_tracking_filter parameter is provided with a list of fields that are used for filtering. An operator and a value are applied on the specified field. This parameter specifies the value that is used for comparison.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_dead_flows_treshold
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow_detective. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_flow_type
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow_detective. This parameter is valid for IxTclNetwork 5.40+ API.all_flows - retrieved stats are for all flowslive_flows - retrieved stats are for live flowsdead_flows - retrieved stats are for dead flows
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_show_egress_flows
			x                                                                   		Display the egress flows similar to a Flat Egress view. Using this option will ease the visualisation of failed flows.Valid only for traffic_generator ixnetwork_540.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_statistic_all_flows_sort_by
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow_detective, uds_statistic_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. This parameter specifies the field by which the statistics are sorted.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_statistic_all_flows_sorting_type
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow_detective, uds_statistic_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. This parameter specifies the type of sorting for the statistics.ascending - sort statistics in ascending orderdescending - sort statistics in descending orderworst_performers - sort statistics by worst performersbest_performers - sort statistics by best performers
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_statistic_all_flows_num_results
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow_detective, uds_statistic_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. This parameter specifies the number of results to be displayed per page in the statistic view that is created.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_statistic_dead_flows_sort_by
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow_detective, uds_statistic_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. This parameter specifies the field by which the statistics are sorted.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_statistic_dead_flows_sorting_type
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow_detective, uds_statistic_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. This parameter specifies the type of sorting for the statistics.ascending - sort statistics in ascending orderdescending - sort statistics in descending orderworst_performers - sort statistics by worst performersbest_performers - sort statistics by best performers
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_statistic_dead_flows_num_results
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow_detective, uds_statistic_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. This parameter specifies the number of results to be displayed per page in the statistic view that is created.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_statistic_live_flows_sort_by
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow_detective, uds_statistic_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. This parameter specifies the field by which the statistics are sorted.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_statistic_live_flows_sorting_type
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow_detective, uds_statistic_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. This parameter specifies the type of sorting for the statistics.ascending - sort statistics in ascending orderdescending - sort statistics in descending orderworst_performers - sort statistics by worst performersbest_performers - sort statistics by best performers
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_statistic_live_flows_num_results
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow_detective, uds_statistic_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. This parameter specifies the number of results to be displayed per page in the statistic view that is created.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_statistic_operator
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow_detective, uds_statistic_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. The uds_statistic_filter parameter is provided with a list of fields that are used for filtering. An operator and a value are applied on the specified field. This parameter specifies the operator that is applied: is_different is_equal is_equal_or_greater is_equal_or_smaller is_greater is_smaller null.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_statistic_value
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow_detective, uds_statistic_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. The uds_statistic_filter parameter is provided with a list of fields that are used for filtering. An operator and a value are applied on the specified field. This parameter specifies the value that is used for comparison.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_tracking_operator
			x                                                                   		mode user_defined_stats, uds_type l23_traffic_flow_detective, uds_tracking_filter should be present. This parameter is valid for traffic_generator ixnetwork_540. Available starting with HLT API 3.80. The uds_tracking_filter parameter is provided with a list of fields that are used for filtering. An operator and a value are applied on the specified field. This parameter specifies the operator that is applied: is_different is_equal is_equal_or_greater is_equal_or_smaller is_greater is_smaller null.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_l23tfd_tracking_value
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type l23_traffic_flow_detective, uds_tracking_filter should be present. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. The uds_tracking_filter parameter is provided with a list of fields that are used for filtering. An operator and a value are applied on the specified field. This parameter specifies the value that is used for comparison.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_port_filter
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type: l23_protocol_port, l23_traffic_flow, l23_traffic_flow_detective, l23_traffic_port. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. Represents the port filters that should be applied when retrieving statistics.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_port_filter_count
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type: l23_protocol_port, l23_traffic_flow, l23_traffic_flow_detective, l23_traffic_port. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. Represents the number of port filters that should be applied when retrieving statistics (the length of the list provided to uds_port_filter). This parameter is extremely useful when the names of the filters contain spaces.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_protocol_stack_filter
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type: l23_protocol_stack. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. Represents the protocol stack filters that should be applied when retrieving statistics.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_protocol_stack_filter_count
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type: l23_protocol_stack. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. Represents the number of protocol stack filters that should be applied when retrieving statistics (the length of the list provided to uds_protocol_stack_filter). This parameter is extremely useful when the names of the filters contain spaces.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_statistic_filter
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type: l23_traffic_flow_detective. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. Represents the statistic filters that should be applied when retrieving statistics.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_statistic_filter_count
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type: l23_traffic_flow_detective. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. Represents the number of statistic filters that should be applied when retrieving statistics (the length of the list provided to uds_statistic_filter). This parameter is extremely useful when the names of the filters contain spaces.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_tracking_filter
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type: l23_traffic_flow, l23_traffic_flow_detective. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. Represents the tracking filters that should be applied when retrieving statistics.If uds_type is l23_traffic_flow, parameters uds_l23tf_tracking_operator and uds_l23tf_tracking_value must be provided. If uds_type is l23_traffic_flow_detective, parameters uds_l23tfd_tracking_operator and uds_l23tfd_tracking_value must be provided.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_tracking_filter_count
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type: l23_traffic_flow, l23_traffic_flow_detective. This parameter is valid for IxTclNetwork 5.40+ API. Represents the number of tracking filters that should be applied when retrieving statistics (the length of the list provided to uds_tracking_filter). This parameter is extremely useful when the names of the filters contain spaces.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_traffic_item_filter
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type: l23_traffic_flow, l23_traffic_flow_detective, l23_traffic_item. When uds_type is l23_traffic_flow, l23_traffic_flow_detective, only one filter can be applied at a time. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80. Represents the traffic item filters that should be applied when retrieving statistics.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_traffic_item_filter_count
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats, uds_type: l23_traffic_flow, l23_traffic_flow_detective, l23_traffic_item. This parameter is valid for IxTclNetwork 5.40+ API. Represents the number of traffic item filters that should be applied when retrieving statistics (the length of the list provided to uds_traffic_item_filter). This parameter is extremely useful when the names of the filters contain spaces.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-uds_type
			x                                                                   		This parameter is valid for traffic_generator ixnetwork_540, mode user_defined_stats. This parameter is valid for IxTclNetwork 5.40+ API. Available starting with HLT API 3.80.
			x                                                                   		l23_protocol_port - (DEFAULT) retrieve per port protocol statistics.l23_protocol_stack - retrieve per session or per range protocol statisticsl23_traffic_flow - retrieve per flow statisticsl23_traffic_flow_detective - retrieve flow detective statisticsl23_traffic_item - retrieve per traffic item statisticsl23_traffic_port - retrieve per port traffic statistics
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-traffic_generator
			x                                                                   		The Ixia product that was used for configuring traffic.ixos - The traffic was generated using IxOS and will be used further also with IxOS.ixnetwork - The traffic was generated using IxNetwork and will be used further also with IxNetwork. This option is valid only IxTclNetwork 5.30 or greater is loaded.ixnetwork_540 - The traffic was generated using IxNetwork and will be used further also with IxNetwork. This option is valid only IxTclNetwork 5.40 or greater is loaded.
			x                                                                   		This argument defined by Ixia is not supported for IxNetwork-NGPF implementation.
			x                                                               	-vci
			x                                                                   	-vci_count
			x                                                                       	-vci_step
			x                                                                           	-vpi
			x                                                                               	-vpi_step
		                                                                               
		                                                                               Return Values:
		                                                                                   $::SUCCESS | $::FAILURE
			                                                                                    key:status                                                                                                                            value:$::SUCCESS | $::FAILURE
		                                                                                   On status of failure, gives detailed information.
			                                                                                    key:log                                                                                                                               value:On status of failure, gives detailed information.
		                                                                                   The name of the array to be used for reading the stats. This key is returned when more than 2000 statistics values need to be retrieved. The indices of this array are the keys that you'll find explained below, and the values are the statistics values. This method has been introduced to increase performance when returning and reading stats. Returning a huge list in the tcl console can make the console hang.
			                                                                                    key:handle                                                                                                                            value:The name of the array to be used for reading the stats. This key is returned when more than 2000 statistics values need to be retrieved. The indices of this array are the keys that you'll find explained below, and the values are the statistics values. This method has been introduced to increase performance when returning and reading stats. Returning a huge list in the tcl console can make the console hang.
		                                                                                   Time when the data was fetched from the hardware. The value is of local significance to the chassis.
			                                                                                    key:clicks                                                                                                                            value:Time when the data was fetched from the hardware. The value is of local significance to the chassis.
		                                                                                   Time when the data was fetched from the hardware. The value is the chassis' current time, in seconds since 1/1/1970 0:0:0.
			                                                                                    key:seconds                                                                                                                           value:Time when the data was fetched from the hardware. The value is the chassis' current time, in seconds since 1/1/1970 0:0:0.
		                                                                                   Returned only when traffic_generator is ixnetwork_540 (NextGen Traffic). If traffic statistics have arrived this key will be 0, otherwise it will be 1.
			                                                                                    key:waiting_for_stats                                                                                                                 value:Returned only when traffic_generator is ixnetwork_540 (NextGen Traffic). If traffic statistics have arrived this key will be 0, otherwise it will be 1.
		                                                                                   csv file path(s) if -return_method is csv
			                                                                                    key:csv_file                                                                                                                          value:csv file path(s) if -return_method is csv
		                                                                                   detected traffic stats measure mode, the returned stats are according to this value
			                                                                                    key:measure_mode                                                                                                                      value:detected traffic stats measure mode, the returned stats are according to this value
			                                                                                    key:<port_handle>.aggregate.tx.elapsed_time                                                                                           value:
		                                                                                   Number of all data plane packets sent|received. 0 for disabled streams.
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.pkt_count                                                                                         value:Number of all data plane packets sent|received. 0 for disabled streams.
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.pkt_byte_count                                                                                    value:
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.pkt_rate                                                                                          value:
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.pkt_bit_rate                                                                                      value:
		                                                                                   Total number of packets sent. The sum of all packets sent for all flows.
			                                                                                    key:<port_handle>.aggregate.tx.total_pkts                                                                                             value:Total number of packets sent. The sum of all packets sent for all flows.
			                                                                                    key:<port_handle>.aggregate.tx.total_pkt_rate                                                                                         value:
			                                                                                    key:<port_handle>.aggregate.rx.uds<1-2>_count                                                                                         value:
		                                                                                   Ixia only. Number of all packets (control plane and data plane) sent|received.
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.raw_pkt_count                                                                                     value:Ixia only. Number of all packets (control plane and data plane) sent|received.
		                                                                                   Ixia only. Number of protocol packets sent|received
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.protocol_pkt_count                                                                                value:Ixia only. Number of protocol packets sent|received
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.raw_pkt_rate                                                                                      value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.protocol_pkt_rate                                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.pkt_bit_count                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.collisions_count                                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.crc_errors_count                                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.dribble_errors_count                                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.oversize_count                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.undersize_count                                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.vlan_pkts_count                                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.qos<0-7>_count                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.data_int_frames_count                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.data_int_errors_count                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.sequence_frames_count                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.sequence_errors_count                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.pkt_byte_rate                                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.uds<1-2>_rate                                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.collisions_rate                                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.crc_errors_rate                                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.dribble_errors_rate                                                                                    value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.oversize_rate                                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.undersize_rate                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.vlan_pkts_rate                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.qos<0-7>_rate                                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.data_int_frames_rate                                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.data_int_errors_rate                                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.sequence_frames_rate                                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.sequence_errors_rate                                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.<vpi>.<vci>.rx_aal5_crc_errors_count                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.<vpi>.<vci>.rx_aal5_frames_count                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.<vpi>.<vci>.rx_aal5_length_errors_count                                                                value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.<vpi>.<vci>.rx_aal5_timeout_errors_count                                                               value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.<vpi>.<vci>.rx_atm_cells_count                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.<vpi>.<vci>.tx_aal5_bytes_count                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.<vpi>.<vci>.tx_aal5_frames_count                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.<vpi>.<vci>.tx_aal5_scheduled_cells_count                                                              value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.<vpi>.<vci>.tx_aal5_scheduled_frames_count                                                             value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.<vpi>.<vci>.tx_atm_cells_count                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.<vpi>.<vci>.rx_aal5_crc_errors_rate                                                                    value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.<vpi>.<vci>.rx_aal5_frames_rate                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.<vpi>.<vci>.rx_aal5_length_errors_rate                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.<vpi>.<vci>.rx_aal5_timeout_errors_rate                                                                value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.<vpi>.<vci>.rx_atm_cells_rate                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.<vpi>.<vci>.tx_aal5_bytes_rate                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.<vpi>.<vci>.tx_aal5_frames_rate                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.<vpi>.<vci>.tx_aal5_scheduled_cells_rate                                                               value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.<vpi>.<vci>.tx_aal5_scheduled_frames_rate                                                              value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.<vpi>.<vci>.tx_atm_cells_rate                                                                          value:Ixia only
		                                                                                   Tx Total Packet Bytes (Not Supported)
			                                                                                    key:<port_handle>.aggregate.tx.total_pkt_bytes                                                                                        value:Tx Total Packet Bytes (Not Supported)
		                                                                                   Elapsed time for transmission on the specified port
			                                                                                    key:<port_handle>.aggregate.tx.elapsed_time                                                                                           value:Elapsed time for transmission on the specified port
		                                                                                   Number of all data plane packets sent|received. 0 for disabled streams.
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.pkt_count                                                                                         value:Number of all data plane packets sent|received. 0 for disabled streams.
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.pkt_byte_count                                                                                    value:
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.pkt_rate                                                                                          value:
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.pkt_bit_rate                                                                                      value:
		                                                                                   Number of all packets (control plane and data plane) sent|received.
			                                                                                    key:<port_handle>.aggregate.tx.total_pkts                                                                                             value:Number of all packets (control plane and data plane) sent|received.
			                                                                                    key:<port_handle>.aggregate.tx.total_pkt_rate                                                                                         value:
		                                                                                   Ixia only. Number of all packets (control plane and data plane) sent|received.
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.raw_pkt_count                                                                                     value:Ixia only. Number of all packets (control plane and data plane) sent|received.
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.scheduled_pkt_count                                                                                    value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.scheduled_pkt_rate                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.line_speed                                                                                             value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.pkt_kbit_rate                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.pkt_mbit_rate                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.pkt_bit_count                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.collisions_count                                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.data_int_frames_count                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.data_int_errors_count                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.<tx|rx>.pkt_byte_rate                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.rx_aal5_frames_count                                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.rx_atm_cells_count                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.tx_aal5_bytes_count                                                                                    value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.tx_aal5_frames_count                                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.tx_aal5_scheduled_cells_count                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.tx_aal5_scheduled_frames_count                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.tx_atm_cells_count                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.rs_fec_corrected_error_count                                                                           value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.rs_fec_corrected_error_count_rate                                                                      value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.rs_fec_uncorrected_error_count                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.rs_fec_uncorrected_error_count_rate                                                                    value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.rx_aal5_frames_rate                                                                                    value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.rx_atm_cells_rate                                                                                      value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.tx_aal5_bytes_rate                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.tx_aal5_frames_rate                                                                                    value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.tx_aal5_scheduled_cells_rate                                                                           value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.tx_aal5_scheduled_frames_rate                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.tx_atm_cells_rate                                                                                      value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.total_pkt_bytes                                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.uds<1-6>.frame_rate                                                                                    value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.uds<1-6>.frame_count                                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.port_name                                                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.duplex_mode                                                                                               value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.rx.control_frames                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.aggregate.tx.control_frames                                                                                         value:Ixia only
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_aal5_frames_count.min                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_aal5_frames_count.max                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_aal5_frames_count.avg                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_aal5_frames_count.sum                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_aal5_frames_count.count                                                                                           value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_aal5_frames_rate.min                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_aal5_frames_rate.max                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_aal5_frames_rate.avg                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_aal5_frames_rate.sum                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_aal5_frames_rate.count                                                                                            value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_frames_count.min                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_frames_count.max                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_frames_count.avg                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_frames_count.sum                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_frames_count.count                                                                                           value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_frames_rate.min                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_frames_rate.max                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_frames_rate.avg                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_frames_rate.sum                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_frames_rate.count                                                                                            value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_bytes_count.min                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_bytes_count.max                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_bytes_count.avg                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_bytes_count.sum                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_bytes_count.count                                                                                            value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_bytes_rate.min                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_bytes_rate.max                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_bytes_rate.avg                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_bytes_rate.sum                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_bytes_rate.count                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_atm_cells_count.min                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_atm_cells_count.max                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_atm_cells_count.avg                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_atm_cells_count.sum                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_atm_cells_count.count                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_atm_cells_rate.min                                                                                                value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_atm_cells_rate.max                                                                                                value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_atm_cells_rate.avg                                                                                                value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_atm_cells_rate.sum                                                                                                value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.rx_atm_cells_rate.count                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_atm_cells_count.min                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_atm_cells_count.max                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_atm_cells_count.avg                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_atm_cells_count.sum                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_atm_cells_count.count                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_atm_cells_rate.min                                                                                                value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_atm_cells_rate.max                                                                                                value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_atm_cells_rate.avg                                                                                                value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_atm_cells_rate.sum                                                                                                value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_atm_cells_rate.count                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_byte_count.min                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_byte_count.max                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_byte_count.avg                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_byte_count.sum                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_byte_count.count                                                                                                 value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_byte_rate.min                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_byte_rate.max                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_byte_rate.avg                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_byte_rate.sum                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_byte_rate.count                                                                                                  value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_byte_count.min                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_byte_count.max                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_byte_count.avg                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_byte_count.sum                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_byte_count.count                                                                                                 value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_byte_rate.min                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_byte_rate.max                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_byte_rate.avg                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_byte_rate.sum                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_byte_rate.count                                                                                                  value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.collisions_count.min                                                                                                 value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.collisions_count.max                                                                                                 value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.collisions_count.avg                                                                                                 value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.collisions_count.sum                                                                                                 value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.collisions_count.count                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.control_frames.min                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.control_frames.max                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.control_frames.avg                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.control_frames.sum                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.control_frames.count                                                                                                 value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.control_frames.min                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.control_frames.max                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.control_frames.avg                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.control_frames.sum                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.control_frames.count                                                                                                 value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.data_int_errors_count.min                                                                                            value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.data_int_errors_count.max                                                                                            value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.data_int_errors_count.avg                                                                                            value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.data_int_errors_count.sum                                                                                            value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.data_int_errors_count.count                                                                                          value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.data_int_frames_count.min                                                                                            value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.data_int_frames_count.max                                                                                            value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.data_int_frames_count.avg                                                                                            value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.data_int_frames_count.sum                                                                                            value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.data_int_frames_count.count                                                                                          value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.port_name.count                                                                                                         value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.duplex_mode.count                                                                                                       value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.raw_pkt_count.min                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.raw_pkt_count.max                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.raw_pkt_count.avg                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.raw_pkt_count.sum                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.raw_pkt_count.count                                                                                                  value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.misdirected_packet_count.min                                                                                         value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.misdirected_packet_count.max                                                                                         value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.misdirected_packet_count.avg                                                                                         value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.misdirected_packet_count.sum                                                                                         value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.misdirected_packet_count.count                                                                                       value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.crc_errors.min                                                                                                       value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.crc_errors.max                                                                                                       value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.crc_errors.avg                                                                                                       value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.crc_errors.sum                                                                                                       value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.crc_errors.count                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.total_pkts.min                                                                                                       value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.total_pkts.max                                                                                                       value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.total_pkts.avg                                                                                                       value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.total_pkts.sum                                                                                                       value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.total_pkts.count                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_rate.min                                                                                                         value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_rate.max                                                                                                         value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_rate.avg                                                                                                         value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_rate.sum                                                                                                         value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_rate.count                                                                                                       value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.total_pkt_rate.min                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.total_pkt_rate.max                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.total_pkt_rate.avg                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.total_pkt_rate.sum                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.total_pkt_rate.count                                                                                                 value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.line_speed.count                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_kbit_rate.min                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_kbit_rate.max                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_kbit_rate.avg                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_kbit_rate.sum                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_kbit_rate.count                                                                                                  value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_mbit_rate.min                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_mbit_rate.max                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_mbit_rate.avg                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_mbit_rate.sum                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_mbit_rate.count                                                                                                  value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_bit_rate.min                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_bit_rate.max                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_bit_rate.avg                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_bit_rate.sum                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_bit_rate.count                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_cells_count.min                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_cells_count.max                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_cells_count.avg                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_cells_count.sum                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_cells_count.count                                                                                  value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_cells_rate.min                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_cells_rate.max                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_cells_rate.avg                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_cells_rate.sum                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_cells_rate.count                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.scheduled_pkt_count.min                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.scheduled_pkt_count.max                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.scheduled_pkt_count.avg                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.scheduled_pkt_count.sum                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.scheduled_pkt_count.count                                                                                            value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_frames_count.min                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_frames_count.max                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_frames_count.avg                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_frames_count.sum                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_frames_count.count                                                                                 value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.scheduled_pkt_rate.min                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.scheduled_pkt_rate.max                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.scheduled_pkt_rate.avg                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.scheduled_pkt_rate.sum                                                                                               value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.scheduled_pkt_rate.count                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_frames_rate.min                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_frames_rate.max                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_frames_rate.avg                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_frames_rate.sum                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.tx_aal5_scheduled_frames_rate.count                                                                                  value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_kbit_rate.min                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_kbit_rate.max                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_kbit_rate.avg                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_kbit_rate.sum                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_kbit_rate.count                                                                                                  value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_mbit_rate.min                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_mbit_rate.max                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_mbit_rate.avg                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_mbit_rate.sum                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_mbit_rate.count                                                                                                  value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_bit_rate.min                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_bit_rate.max                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_bit_rate.avg                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_bit_rate.sum                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.pkt_bit_rate.count                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.raw_pkt_count.min                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.raw_pkt_count.max                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.raw_pkt_count.avg                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.raw_pkt_count.sum                                                                                                    value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.raw_pkt_count.count                                                                                                  value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_rate.min                                                                                                         value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_rate.max                                                                                                         value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_rate.avg                                                                                                         value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_rate.sum                                                                                                         value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.pkt_rate.count                                                                                                       value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.uds<1-6>_frame_rate.sum                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.uds<1-6>_frame_rate.avg                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.uds<1-6>_frame_rate.max                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.uds<1-6>_frame_rate.count                                                                                            value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.uds<1-6>_frame_rate.min                                                                                              value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.uds<1-6>_frame_count.count                                                                                           value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.uds<1-6>_frame_count.avg                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.uds<1-6>_frame_count.max                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.uds<1-6>_frame_count.min                                                                                             value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.raw_pkt_rate.max                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.raw_pkt_rate.count                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.raw_pkt_rate.min                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.raw_pkt_rate.sum                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.rx.raw_pkt_rate.avg                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.elapsed_time.sum                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.elapsed_time.avg                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.elapsed_time.max                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.elapsed_time.count                                                                                                   value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only. Aggregated across ports.
			                                                                                    key:aggregate.tx.elapsed_time.min                                                                                                     value:Ixia only. Aggregated across ports.
		                                                                                   Ixia only
			                                                                                    key:l23_test_summary.rx.l1_bit_rate                                                                                                   value:Ixia only
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:l23_test_summary.rx.avg_latency                                                                                                   value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:l23_test_summary.rx.max_latency                                                                                                   value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:l23_test_summary.rx.min_latency                                                                                                   value:Ixia only(nanoseconds)
		                                                                                   Ixia only
			                                                                                    key:l23_test_summary.rx.pkt_byte_rate                                                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:l23_test_summary.rx.pkt_bit_rate                                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:l23_test_summary.rx.pkt_rate                                                                                                      value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:l23_test_summary.rx.pkt_kbit_rate                                                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:l23_test_summary.rx.pkt_mbit_rate                                                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:l23_test_summary.tx.l1_bit_rate                                                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:l23_test_summary.tx.pkt_byte_rate                                                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:l23_test_summary.tx.pkt_bit_rate                                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:l23_test_summary.tx.pkt_rate                                                                                                      value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:l23_test_summary.tx.pkt_kbit_rate                                                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:l23_test_summary.tx.pkt_mbit_rate                                                                                                 value:Ixia only
			                                                                                    key:<port_handle>.stream.<id>.tx.elapsed_time                                                                                         value:
			                                                                                    key:<port_handle>.stream.<id>.<tx|rx>.total_pkts                                                                                      value:
			                                                                                    key:<port_handle>.stream.<id>.<tx|rx>.total_pkt_rate                                                                                  value:
			                                                                                    key:<port_handle>.stream.<id>.rx.total_pkts_bytes                                                                                     value:
			                                                                                    key:<port_handle>.stream.<id>.rx.total_pkt_bytes                                                                                      value:
			                                                                                    key:<port_handle>.stream.<id>.rx.total_pkt_bit_rate                                                                                   value:
		                                                                                   (nanoseconds)
			                                                                                    key:<port_handle>.stream.<id>.rx.avg_delay                                                                                            value:(nanoseconds)
		                                                                                   (nanoseconds)
			                                                                                    key:<port_handle>.stream.<id>.rx.min_delay                                                                                            value:(nanoseconds)
		                                                                                   (nanoseconds)
			                                                                                    key:<port_handle>.stream.<id>.rx.max_delay                                                                                            value:(nanoseconds)
			                                                                                    key:<port_handle>.stream.<id>.rx.line_rate_percentage                                                                                 value:
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.pkt_bit_rate                                                                value:
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.pkt_byte_rate                                                               value:
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.pkt_frame_rate                                                              value:
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.first_tstamp                                                                value:
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.last_tstamp                                                                 value:
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.max                                                                         value:
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.min                                                                         value:
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.total_pkts                                                                  value:
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.start_time                                                                  value:
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.stop_time                                                                   value:
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.jitter_bin.<bin number>.pkt_bit_rate                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.jitter_bin.<bin number>.pkt_byte_rate                                                                value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.jitter_bin.<bin number>.pkt_frame_rate                                                               value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.jitter_bin.<bin number>.first_tstamp                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.jitter_bin.<bin number>.last_tstamp                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.jitter_bin.<bin number>.max                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.jitter_bin.<bin number>.min                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.jitter_bin.<bin number>.total_pkts                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.jitter_bin.<bin number>.start_time                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.jitter_bin.<bin number>.stop_time                                                                    value:Ixia only
		                                                                                   Tx Total Packets Bytes (Not Supported)
			                                                                                    key:<port_handle>.stream.<id>.tx.total_pkts_bytes                                                                                     value:Tx Total Packets Bytes (Not Supported)
		                                                                                   Tx Total Packet Bytes (Not Supported)
			                                                                                    key:<port_handle>.stream.<id>.tx.total_pkt_bytes                                                                                      value:Tx Total Packet Bytes (Not Supported)
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.first_tstamp                                                                                         value:Ixia only
		                                                                                   Ixia only. Valid for IGMP traffic
			                                                                                    key:<port_handle>.stream.<id>.rx.expected_pkts                                                                                        value:Ixia only. Valid for IGMP traffic
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.last_tstamp                                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.loss_pkts                                                                                            value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.loss_percent                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.total_pkt_byte_rate                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.total_pkt_kbit_rate                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.total_pkt_mbit_rate                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.total_pkts                                                                                              value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.pkt_loss_duration                                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.avg_delay                                                                                               value:Ixia only
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.total_bytes                                                                 value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.pkt_bit_rate                                                                value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.pkt_kbit_rate                                                               value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.pkt_mbit_rate                                                               value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.pkt_byte_rate                                                               value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.pkt_frame_rate                                                              value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.first_tstamp                                                                value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.last_tstamp                                                                 value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.max                                                                         value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.avg                                                                         value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.min                                                                         value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.total_pkts                                                                  value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:<port_handle>.stream.<id>.rx.small_error                                                                                          value:Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:<port_handle>.stream.<id>.rx.big_error                                                                                            value:Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:<port_handle>.stream.<id>.rx.reverse_error                                                                                        value:Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.rx.min_delay                                                                                            value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.total_pkt_rate                                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.stream.<id>.expected_pkts                                                                                           value:Ixia only
		                                                                                   Tx Elapsed Time (Not Supported)
			                                                                                    key:<port_handle>.stream.<id>.tx.elapsed_time                                                                                         value:Tx Elapsed Time (Not Supported)
		                                                                                   Rx Latency Bin Start Time (Not Supported)
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.start_time                                                                  value:Rx Latency Bin Start Time (Not Supported)
		                                                                                   Rx Latency Bin Stop Time (Not Supported)
			                                                                                    key:<port_handle>.stream.<id>.rx.latency_bin.<bin number>.stop_time                                                                   value:Rx Latency Bin Stop Time (Not Supported)
		                                                                                   Tx Total Packets Bytes (Not Supported)
			                                                                                    key:<port_handle>.stream.<id>.tx.total_pkts_bytes                                                                                     value:Tx Total Packets Bytes (Not Supported)
		                                                                                   Tx Total Pkt Bytes (Not Supported)
			                                                                                    key:<port_handle>.stream.<id>.tx.total_pkt_bytes                                                                                      value:Tx Total Pkt Bytes (Not Supported)
		                                                                                   Ixia only. The flow <id> always starts at 1 and continues incrementing till the last flow. The end value depends on how many flows were retrieved.
			                                                                                    key:<port_handle>.flow.<id>.<tx|rx>.flow_name                                                                                         value:Ixia only. The flow <id> always starts at 1 and continues incrementing till the last flow. The end value depends on how many flows were retrieved.
		                                                                                   Ixia only. Valid only for traffic_generator ixnetwork.
			                                                                                    key:<port_handle>.flow.<id>.<tx|rx>.pgid_ value                                                                                       value:Ixia only. Valid only for traffic_generator ixnetwork.
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.flow.<id>.<tx|rx>.total_pkts                                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.flow.<id>.<tx|rx>.total_pkt_rate                                                                                    value:Ixia only
		                                                                                   Ixia only. Valid for IGMP traffic
			                                                                                    key:<port_handle>.flow.<id>.rx.expected_pkts                                                                                          value:Ixia only. Valid for IGMP traffic
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.flow.<id>.rx.total_pkts_bytes                                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.flow.<id>.rx.total_pkt_bytes                                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.flow.<id>.rx.total_pkt_bit_rate                                                                                     value:Ixia only
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:<port_handle>.flow.<id>.rx.avg_delay                                                                                              value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:<port_handle>.flow.<id>.rx.min_delay                                                                                              value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:<port_handle>.flow.<id>.rx.max_delay                                                                                              value:Ixia only(nanoseconds)
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.flow.<id>.rx.first_tstamp                                                                                           value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.flow.<id>.rx.last_tstamp                                                                                            value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.flow.<id>.rx.loss_pkts                                                                                              value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.flow.<id>.rx.loss_percent                                                                                           value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.flow.<id>.rx.total_pkt_byte_rate                                                                                    value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.flow.<id>.rx.total_pkt_kbit_rate                                                                                    value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.flow.<id>.rx.total_pkt_mbit_rate                                                                                    value:Ixia only
		                                                                                   Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:<port_handle>.flow.<id>.rx.small_error                                                                                            value:Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:<port_handle>.flow.<id>.rx.big_error                                                                                              value:Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:<port_handle>.flow.<id>.rx.reverse_error                                                                                          value:Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Ixia only. The flow <id> always starts at 1 and continues incrementing till the last flow. The end value depends on how many flows were retrieved.
			                                                                                    key:flow.<id>.flow_name                                                                                                               value:Ixia only. The flow <id> always starts at 1 and continues incrementing till the last flow. The end value depends on how many flows were retrieved.
		                                                                                   Ixia only. Valid only for traffic_generator ixnetwork.
			                                                                                    key:flow.<id>.pgid_ value                                                                                                             value:Ixia only. Valid only for traffic_generator ixnetwork.
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.<tx|rx>.port                                                                                                            value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.<tx|rx>.total_pkts                                                                                                      value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.<tx|rx>.total_pkt_rate                                                                                                  value:Ixia only
		                                                                                   Ixia only. Valid for IGMP traffic
			                                                                                    key:flow.<id>.rx.expected_pkts                                                                                                        value:Ixia only. Valid for IGMP traffic
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.total_pkts_bytes                                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.total_pkt_bytes                                                                                                      value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.total_pkt_bit_rate                                                                                                   value:Ixia only
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:flow.<id>.rx.avg_delay                                                                                                            value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:flow.<id>.rx.min_delay                                                                                                            value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:flow.<id>.rx.max_delay                                                                                                            value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:flow.<id>.rx.avg_delay_variation                                                                                                  value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:flow.<id>.rx.max_delay_variation                                                                                                  value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:flow.<id>.rx.min_delay_variation                                                                                                  value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:flow.<id>.rx.short_term_avg_delay_variation                                                                                       value:Ixia only(nanoseconds)
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.total_sequence_error                                                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.last_sequence_number                                                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.first_tstamp                                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.last_tstamp                                                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.loss_pkts                                                                                                            value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.pkt_loss_duration                                                                                                    value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.loss_percent                                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.total_pkt_byte_rate                                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.total_pkt_kbit_rate                                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.total_pkt_mbit_rate                                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.tx.total_pkt_mbit_rate                                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.misdirected_pkts                                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.misdirected_rate                                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:flow.<id>.rx.misdirected_ports                                                                                                    value:Ixia only
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:flow.<id>.rx.latency_bin.<bin number>.total_bytes                                                                                 value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:flow.<id>.rx.latency_bin.<bin number>.pkt_bit_rate                                                                                value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:flow.<id>.rx.latency_bin.<bin number>.pkt_kbit_rate                                                                               value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:flow.<id>.rx.latency_bin.<bin number>.pkt_mbit_rate                                                                               value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:flow.<id>.rx.latency_bin.<bin number>.pkt_byte_rate                                                                               value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:flow.<id>.rx.latency_bin.<bin number>.pkt_frame_rate                                                                              value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:flow.<id>.rx.latency_bin.<bin number>.first_tstamp                                                                                value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:flow.<id>.rx.latency_bin.<bin number>.last_tstamp                                                                                 value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:flow.<id>.rx.latency_bin.<bin number>.max                                                                                         value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:flow.<id>.rx.latency_bin.<bin number>.avg                                                                                         value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:flow.<id>.rx.latency_bin.<bin number>.min                                                                                         value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
			                                                                                    key:flow.<id>.rx.latency_bin.<bin number>.total_pkts                                                                                  value:Only for traffic_generator ixnetwork_540. Tracking must be enabled on any value but 'traffic_item' in order to get this statistic.
		                                                                                   Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:flow.<id>.rx.small_error                                                                                                          value:Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:flow.<id>.rx.big_error                                                                                                            value:Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:flow.<id>.rx.reverse_error                                                                                                        value:Only for traffic_generator ixnetwork_540. Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Contains the total number of tracking items.
			                                                                                    key:flow.<id>.tracking.count                                                                                                          value:Contains the total number of tracking items.
		                                                                                   Contains the name of the tracking item. The tracking_id index starts at 1 and is increased until it is equal to flow.<id>.tracking.count
			                                                                                    key:flow.<id>.tracking.<tracking_id>.tracking_name                                                                                    value:Contains the name of the tracking item. The tracking_id index starts at 1 and is increased until it is equal to flow.<id>.tracking.count
		                                                                                   Contains the value of the tracking item or "N/A" if it is not defined.
			                                                                                    key:flow.<id>.tracking.<tracking_id>.tracking_ value                                                                                  value:Contains the value of the tracking item or "N/A" if it is not defined.
		                                                                                   Ixia only. The flow <id> always starts at 1 and continues incrementing till the last flow. The end value depends on how many flows were retrieved.
			                                                                                    key:egress.<id>.flow_name                                                                                                             value:Ixia only. The flow <id> always starts at 1 and continues incrementing till the last flow. The end value depends on how many flows were retrieved.
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.rx.total_pkts                                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.tx.total_pkts                                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.rx.total_pkt_rate                                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.tx.total_pkt_rate                                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.rx.loss_percent                                                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.rx.frames_delta                                                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.rx.total_pkts_bytes                                                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.rx.total_pkt_bit_rate                                                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.tx.total_pkt_bit_rate                                                                                                 value:Ixia only
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:egress.<id>.rx.avg_delay                                                                                                          value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:egress.<id>.rx.min_delay                                                                                                          value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:egress.<id>.rx.max_delay                                                                                                          value:Ixia only(nanoseconds)
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.rx.first_tstamp                                                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.rx.last_tstamp                                                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.rx.total_pkt_byte_rate                                                                                                value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.tx.total_pkt_byte_rate                                                                                                value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.rx.total_pkt_kbit_rate                                                                                                value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.tx.total_pkt_kbit_rate                                                                                                value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.rx.total_pkt_mbit_rate                                                                                                value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.<id>.tx.total_pkt_mbit_rate                                                                                                value:Ixia only
		                                                                                   Ixia only. The name of the flow when mode is egress_by_flow.
			                                                                                    key:egress.<id>.flow_print                                                                                                            value:Ixia only. The name of the flow when mode is egress_by_flow.
		                                                                                   Ixia only. The name of the aggregate id.
			                                                                                    key:egress.<id>.aggregate_id                                                                                                          value:Ixia only. The name of the aggregate id.
		                                                                                   Ixia only. The aggregate <id2> always starts at 1 and continues incrementing till the last aggregated row. The end value depends on how many flows were retrieved.
			                                                                                    key:egress.aggregate.<id2>.rx.total_pkts                                                                                              value:Ixia only. The aggregate <id2> always starts at 1 and continues incrementing till the last aggregated row. The end value depends on how many flows were retrieved.
		                                                                                   Ixia only. The aggregate <id2> always starts at 1 and continues incrementing till the last aggregated row. The end value depends on how many flows were retrieved.
			                                                                                    key:egress.aggregate.<id2>.tx.total_pkts                                                                                              value:Ixia only. The aggregate <id2> always starts at 1 and continues incrementing till the last aggregated row. The end value depends on how many flows were retrieved.
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.rx.total_pkt_rate                                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.tx.total_pkt_rate                                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.rx.frames_delta                                                                                            value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.rx.loss_percent                                                                                            value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.rx.total_pkts_bytes                                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.rx.total_pkt_bit_rate                                                                                      value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.tx.total_pkt_bit_rate                                                                                      value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.rx.small_error                                                                                             value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.rx.big_error                                                                                               value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.rx.reverse_error                                                                                           value:Ixia only
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:egress.aggregate.<id2>.rx.avg_delay                                                                                               value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:egress.aggregate.<id2>.rx.min_delay                                                                                               value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:egress.aggregate.<id2>.rx.max_delay                                                                                               value:Ixia only(nanoseconds)
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.rx.first_tstamp                                                                                            value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.rx.last_tstamp                                                                                             value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.rx.total_pkt_byte_rate                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.tx.total_pkt_byte_rate                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.rx.total_pkt_kbit_rate                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.tx.total_pkt_kbit_rate                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.rx.total_pkt_mbit_rate                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:egress.aggregate.<id2>.tx.total_pkt_mbit_rate                                                                                     value:Ixia only
		                                                                                   Ixia only. The flow <id> always starts at 1 and continues incrementing till the last flow. The end value depends on how many flows were retrieved.
			                                                                                    key:<port_handle>.egress.<id>.flow_name                                                                                               value:Ixia only. The flow <id> always starts at 1 and continues incrementing till the last flow. The end value depends on how many flows were retrieved.
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.rx.total_pkts                                                                                           value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.tx.total_pkts                                                                                           value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.rx.total_pkt_rate                                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.tx.total_pkt_rate                                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.rx.frames_delta                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.rx.loss_percent                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.rx.total_pkts_bytes                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.rx.total_pkt_bit_rate                                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.tx.total_pkt_bit_rate                                                                                   value:Ixia only
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:<port_handle>.egress.<id>.rx.avg_delay                                                                                            value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:<port_handle>.egress.<id>.rx.min_delay                                                                                            value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:<port_handle>.egress.<id>.rx.max_delay                                                                                            value:Ixia only(nanoseconds)
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.rx.first_tstamp                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.rx.last_tstamp                                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.rx.total_pkt_byte_rate                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.tx.total_pkt_byte_rate                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.rx.total_pkt_kbit_rate                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.tx.total_pkt_kbit_rate                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.rx.total_pkt_mbit_rate                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.<id>.tx.total_pkt_mbit_rate                                                                                  value:Ixia only
		                                                                                   Ixia only. The name of the flow when mode is egress_by_flow.
			                                                                                    key:<port_handle>.egress.<id>.flow_print                                                                                              value:Ixia only. The name of the flow when mode is egress_by_flow.
		                                                                                   Ixia only. The name of the aggregate id.
			                                                                                    key:egress.<id>.aggregate_id                                                                                                          value:Ixia only. The name of the aggregate id.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:<port_handle>.egress.<id>.rx.small_error                                                                                          value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:<port_handle>.egress.<id>.rx.big_error                                                                                            value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:<port_handle>.egress.<id>.rx.reverse_error                                                                                        value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Ixia only. The flow <id> always starts at 1 and continues incrementing till the last flow. The end value depends on how many flows were retrieved.
			                                                                                    key:egress.aggregate.<id2>.rx.total_pkts                                                                                              value:Ixia only. The flow <id> always starts at 1 and continues incrementing till the last flow. The end value depends on how many flows were retrieved.
		                                                                                   Ixia only. The flow <id> always starts at 1 and continues incrementing till the last flow. The end value depends on how many flows were retrieved.
			                                                                                    key:egress.aggregate.<id2>.tx.total_pkts                                                                                              value:Ixia only. The flow <id> always starts at 1 and continues incrementing till the last flow. The end value depends on how many flows were retrieved.
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.total_pkt_rate                                                                            value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.tx.total_pkt_rate                                                                            value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.frames_delta                                                                              value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.loss_percent                                                                              value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.total_pkts_bytes                                                                          value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.total_pkt_bit_rate                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.tx.total_pkt_bit_rate                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.small_error                                                                               value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.big_error                                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.reverse_error                                                                             value:Ixia only
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.avg_delay                                                                                 value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.min_delay                                                                                 value:Ixia only(nanoseconds)
		                                                                                   Ixia only(nanoseconds)
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.max_delay                                                                                 value:Ixia only(nanoseconds)
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.first_tstamp                                                                              value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.last_tstamp                                                                               value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.total_pkt_byte_rate                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.tx.total_pkt_byte_rate                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.total_pkt_kbit_rate                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.tx.total_pkt_kbit_rate                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.rx.total_pkt_mbit_rate                                                                       value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.egress.aggregate.<id2>.tx.total_pkt_mbit_rate                                                                       value:Ixia only
		                                                                                   (nanoseconds)
			                                                                                    key:traffic_item.<traffic_item_name>.rx.avg_delay                                                                                     value:(nanoseconds)
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.rx.first_tstamp                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.rx.last_tstamp                                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.rx.loss_percent                                                                                  value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.rx.loss_pkts                                                                                     value:Ixia only
		                                                                                   (nanoseconds)
			                                                                                    key:traffic_item.<traffic_item_name>.rx.max_delay                                                                                     value:(nanoseconds)
		                                                                                   (nanoseconds)
			                                                                                    key:traffic_item.<traffic_item_name>.rx.min_delay                                                                                     value:(nanoseconds)
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.rx.total_pkt_bit_rate                                                                            value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.rx.total_pkt_byte_rate                                                                           value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.rx.total_pkt_bytes                                                                               value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.rx.total_pkt_kbit_rate                                                                           value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.rx.total_pkt_mbit_rate                                                                           value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.rx.total_pkt_rate                                                                                value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.rx.total_pkts                                                                                    value:Ixia only
		                                                                                   Ixia only. Valid for IGMP traffic
			                                                                                    key:traffic_item.<traffic_item_name>.rx.expected_pkts                                                                                 value:Ixia only. Valid for IGMP traffic
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.rx.total_pkts_bytes                                                                              value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.tx.total_pkt_rate                                                                                value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.tx.total_pkts                                                                                    value:Ixia only
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:traffic_item.<traffic_item_name>.rx.small_error                                                                                   value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:traffic_item.<traffic_item_name>.rx.big_error                                                                                     value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.rx.max_delay                                                                                     value:Ixia only
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:traffic_item.<traffic_item_name>.rx.reverse_error                                                                                 value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Ixia only
			                                                                                    key:traffic_item.<traffic_item_name>.rx.pkt_loss_duration                                                                             value:Ixia only
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.avg_delay.min                                                                                           value:(nanoseconds) Aggregated across traffic items.
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.avg_delay.max                                                                                           value:(nanoseconds) Aggregated across traffic items.
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.avg_delay.avg                                                                                           value:(nanoseconds) Aggregated across traffic items.
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.avg_delay.sum                                                                                           value:(nanoseconds) Aggregated across traffic items.
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.avg_delay.count                                                                                         value:(nanoseconds) Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.first_tstamp.count                                                                                      value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.last_tstamp.count                                                                                       value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.loss_percent.min                                                                                        value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.loss_percent.max                                                                                        value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.loss_percent.avg                                                                                        value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.loss_percent.sum                                                                                        value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.loss_percent.count                                                                                      value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.loss_pkts.min                                                                                           value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.loss_pkts.max                                                                                           value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.loss_pkts.avg                                                                                           value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.loss_pkts.sum                                                                                           value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.loss_pkts.count                                                                                         value:Ixia only Aggregated across traffic items.
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.max_delay.min                                                                                           value:(nanoseconds) Aggregated across traffic items.
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.max_delay.max                                                                                           value:(nanoseconds) Aggregated across traffic items.
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.max_delay.avg                                                                                           value:(nanoseconds) Aggregated across traffic items.
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.max_delay.sum                                                                                           value:(nanoseconds) Aggregated across traffic items.
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.max_delay.count                                                                                         value:(nanoseconds) Aggregated across traffic items.
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.min_delay.min                                                                                           value:(nanoseconds) Aggregated across traffic items.
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.min_delay.max                                                                                           value:(nanoseconds) Aggregated across traffic items.
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.min_delay.avg                                                                                           value:(nanoseconds) Aggregated across traffic items.
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.min_delay.sum                                                                                           value:(nanoseconds) Aggregated across traffic items.
		                                                                                   (nanoseconds) Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.min_delay.count                                                                                         value:(nanoseconds) Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_bit_rate.min                                                                                  value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_bit_rate.max                                                                                  value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_bit_rate.avg                                                                                  value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_bit_rate.sum                                                                                  value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_bit_rate.count                                                                                value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_byte_rate.min                                                                                 value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_byte_rate.max                                                                                 value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_byte_rate.avg                                                                                 value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_byte_rate.sum                                                                                 value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_byte_rate.count                                                                               value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_bytes.min                                                                                     value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_bytes.max                                                                                     value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_bytes.avg                                                                                     value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_bytes.sum                                                                                     value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_bytes.count                                                                                   value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_kbit_rate.min                                                                                 value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_kbit_rate.max                                                                                 value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_kbit_rate.avg                                                                                 value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_kbit_rate.sum                                                                                 value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_kbit_rate.count                                                                               value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_mbit_rate.min                                                                                 value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_mbit_rate.max                                                                                 value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_mbit_rate.avg                                                                                 value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_mbit_rate.sum                                                                                 value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_mbit_rate.count                                                                               value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_rate.min                                                                                      value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_rate.max                                                                                      value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_rate.avg                                                                                      value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_rate.sum                                                                                      value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkt_rate.count                                                                                    value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkts.min                                                                                          value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkts.max                                                                                          value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkts.avg                                                                                          value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkts.sum                                                                                          value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkts.count                                                                                        value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items. Valid for IGMP traffic.
			                                                                                    key:traffic_item.aggregate.rx.expected_pkts.min                                                                                       value:Ixia only Aggregated across traffic items. Valid for IGMP traffic.
		                                                                                   Ixia only Aggregated across traffic items. Valid for IGMP traffic.
			                                                                                    key:traffic_item.aggregate.rx.expected_pkts.max                                                                                       value:Ixia only Aggregated across traffic items. Valid for IGMP traffic.
		                                                                                   Ixia only Aggregated across traffic items. Valid for IGMP traffic.
			                                                                                    key:traffic_item.aggregate.rx.expected_pkts.avg                                                                                       value:Ixia only Aggregated across traffic items. Valid for IGMP traffic.
		                                                                                   Ixia only Aggregated across traffic items. Valid for IGMP traffic.
			                                                                                    key:traffic_item.aggregate.rx.expected_pkts.sum                                                                                       value:Ixia only Aggregated across traffic items. Valid for IGMP traffic.
		                                                                                   Ixia only Aggregated across traffic items. Valid for IGMP traffic.
			                                                                                    key:traffic_item.aggregate.rx.expected_pkts.count                                                                                     value:Ixia only Aggregated across traffic items. Valid for IGMP traffic.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkts_bytes.min                                                                                    value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkts_bytes.max                                                                                    value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkts_bytes.avg                                                                                    value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkts_bytes.sum                                                                                    value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.total_pkts_bytes.count                                                                                  value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.tx.total_pkt_rate.min                                                                                      value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.tx.total_pkt_rate.max                                                                                      value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.tx.total_pkt_rate.avg                                                                                      value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.tx.total_pkt_rate.sum                                                                                      value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.tx.total_pkt_rate.count                                                                                    value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.tx.total_pkts.min                                                                                          value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.tx.total_pkts.max                                                                                          value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.tx.total_pkts.avg                                                                                          value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.tx.total_pkts.sum                                                                                          value:Ixia only Aggregated across traffic items.
		                                                                                   Ixia only Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.tx.total_pkts.count                                                                                        value:Ixia only Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.small_error.min                                                                                         value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.small_error.max                                                                                         value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.small_error.avg                                                                                         value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.small_error.sum                                                                                         value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.small_error.count                                                                                       value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.big_error.min                                                                                           value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.big_error.max                                                                                           value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.big_error.avg                                                                                           value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.big_error.sum                                                                                           value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.big_error.count                                                                                         value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.reverse_error.min                                                                                       value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.reverse_error.max                                                                                       value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.reverse_error.avg                                                                                       value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.reverse_error.sum                                                                                       value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
			                                                                                    key:traffic_item.aggregate.rx.reverse_error.count                                                                                     value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'. Aggregated across traffic items.
		                                                                                   Ixia only.
			                                                                                    key:traffic_item.aggregate.rx.pkt_loss_duration.avg                                                                                   value:Ixia only.
		                                                                                   Ixia only.
			                                                                                    key:traffic_item.aggregate.rx.pkt_loss_duration.count                                                                                 value:Ixia only.
		                                                                                   Ixia only.
			                                                                                    key:traffic_item.aggregate.rx.pkt_loss_duration.max                                                                                   value:Ixia only.
		                                                                                   Ixia only.
			                                                                                    key:traffic_item.aggregate.rx.pkt_loss_duration.min                                                                                   value:Ixia only.
		                                                                                   Ixia only.
			                                                                                    key:traffic_item.aggregate.rx.pkt_loss_duration.sum                                                                                   value:Ixia only.
		                                                                                   Ixia only.
			                                                                                    key:traffic_item.aggregate.rx.misdirected_pkts.sum                                                                                    value:Ixia only.
		                                                                                   Ixia only.
			                                                                                    key:traffic_item.aggregate.rx.misdirected_rate.sum                                                                                    value:Ixia only.
			                                                                                    key:<port_handle>.data_plane_port.rx.avg_latency(nanoseconds)                                                                         value:
		                                                                                   (nanoseconds)
			                                                                                    key:<port_handle>.data_plane_port.rx.min_latency                                                                                      value:(nanoseconds)
		                                                                                   (nanoseconds)
			                                                                                    key:<port_handle>.data_plane_port.rx.max_latency                                                                                      value:(nanoseconds)
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.rx.pkt_count                                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.rx.pkt_rate                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.rx.inter_arrival_min_latency                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.rx.inter_arrival_max_latency                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.rx.inter_arrival_avg_latency                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.first_timestamp                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.last_timestamp                                                                                      value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.tx.pkt_count                                                                                        value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.tx.pkt_rate                                                                                         value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.rx.pkt_byte_count                                                                                   value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.rx.pkt_byte_rate                                                                                    value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.rx.pkt_bit_rate                                                                                     value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.rx.pkt_kbit_rate                                                                                    value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.rx.pkt_mbit_rate                                                                                    value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.rx.misdirected_pkts                                                                                 value:Ixia only
		                                                                                   Ixia only
			                                                                                    key:<port_handle>.data_plane_port.rx.misdirected_rate                                                                                 value:Ixia only
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:<port_handle>.data_plane_port.rx.small_error                                                                                      value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:<port_handle>.data_plane_port.rx.big_error                                                                                        value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
			                                                                                    key:<port_handle>.data_plane_port.rx.reverse_error                                                                                    value:Available when traffic was configured with '-frame_sequencing enable and -frame_sequencing_mode rx_threshold'.
		                                                                                   The number of rows returned
			                                                                                    key:row_count                                                                                                                         value:The number of rows returned
		                                                                                   The value of <statistic>. The name <statistic> depends on the type user defined stats retrieved. The list of available statistics can be retrived with uds_action get_available_stats.
			                                                                                    key:<row_number>.<statistic>                                                                                                          value:The value of <statistic>. The name <statistic> depends on the type user defined stats retrieved. The list of available statistics can be retrived with uds_action get_available_stats.
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.responder_tx_rate_bps                                                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.responder_rx_bytes_rate                                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.flows_successful_rate                                                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.connections_initiated                                                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_rx_bytes_rate                                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_tx_rate_bps                                                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.responder_tx_bytes_rate                                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_rx_rate_kbps                                                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.flows_failed                                                                                                       value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_tx_bytes_rate                                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.responder_last_timestamp                                                                                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_tx_rate_kbps                                                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_rx_rate_mbps                                                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.connections_initiated_rate                                                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_tcp_throughput_kbps                                                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.flows_successful                                                                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_rx_bytes                                                                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_tx_rate_mbps                                                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.transactions_successful_rate                                                                                       value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.responder_first_timestamp                                                                                          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_tx_bytes                                                                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.responder_rx_rate_kbps                                                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_first_timestamp                                                                                          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.flows_initiated                                                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.concurrent_connections                                                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.connections_successful_rate                                                                                        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_total_throughput_kbps                                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.responder_rx_rate_mbps                                                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.responder_tx_rate_kbps                                                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.connections_failed                                                                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.responder_tx_rate_mbps                                                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.responder_rx_bytes                                                                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_last_timestamp                                                                                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.running_simulated_users                                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.responder_rx_rate_bps                                                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.connections_successful                                                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.responder_tx_bytes                                                                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_udp_throughput_kbps                                                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
			                                                                                    key:<traffic_item>.initiator_rx_rate_bps                                                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.connections_failed                                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.throughput_kbps                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.udp_throughput_kbps                                                                        value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.connections_successful                                                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.total_udp_bytes                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.total_bytes                                                                                value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.transactions_initiated                                                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.total_bytes_rx                                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.percentage_of_total_traffic                                                                value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.flow_lifetime_ms                                                                           value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.flows_initiated                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.transactions_failed                                                                        value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.total_bytes_tx                                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.connections_successful_rate                                                                value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.percentage                                                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.flows_failed                                                                               value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.connect_time_ms                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.tcp_throughput_kbps                                                                        value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.transactions_successful                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.total_tcp_bytes                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.connections_initiated_rate                                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.running_simulated_users                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.flows_successful                                                                           value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.rx_throughput_kbps                                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.connections_failed_rate                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.tx_throughput_kbps                                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.concurrent_connections                                                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.connections_initiated                                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.flows_successful_rate                                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator
			                                                                                    key:<traffic_item>.<application_flow_name>.transactions_initiated_rate                                                                value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
			                                                                                    key:<traffic_item>.<application_flow_name>.connections_received_rate                                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
			                                                                                    key:<traffic_item>.<application_flow_name>.tx_throughput_kbps                                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
			                                                                                    key:<traffic_item>.<application_flow_name>.connections_received                                                                       value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
			                                                                                    key:<traffic_item>.<application_flow_name>.udp_throughput_kbps                                                                        value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
			                                                                                    key:<traffic_item>.<application_flow_name>.throughput_kbps                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
			                                                                                    key:<traffic_item>.<application_flow_name>.rx_throughput_kbps                                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
			                                                                                    key:<traffic_item>.<application_flow_name>.percentage                                                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
			                                                                                    key:<traffic_item>.<application_flow_name>.tcp_throughput_kbps                                                                        value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.responder_accept_queue_entries                                                                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.initiator_fin_acks_received                                                                                        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.initiator_resets_received                                                                                          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.responder_retries                                                                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.responder_fins_received                                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.responder_resets_sent                                                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.responder_fin_acks_sent                                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.initiator_syns_sent                                                                                                value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.initiator_fins_received                                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.initiator_retries                                                                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.initiator_fin_acks_sent                                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.initiator_resets_sent                                                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.responder_fins_sent                                                                                                value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.responder_listen_queue_drops                                                                                       value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.responder_timeouts                                                                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.initiator_fins_sent                                                                                                value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.responder_syn/syn_acks_received                                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.initiator_syn/syn_acks_received                                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.responder_connection_requests_failed                                                                               value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.initiator_timeouts                                                                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.responder_resets_received                                                                                          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.responder_fin_acks_received                                                                                        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
			                                                                                    key:<traffic_item>.responder_syn_acks_sent                                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.fins_sent                                                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.timeouts                                                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.retries                                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.fins_received                                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.syn/syn_acks_received                                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.syns_sent                                                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.resets_sent                                                                                value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.fin_acks_sent                                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.resets_received                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.fin_acks_received                                                                          value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.fins_sent                                                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.listen_queue_drops                                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.syn/syn_acks_received                                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.timeouts                                                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.connection_requests_failed                                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.syn_acks_sent                                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.fin_acks_received                                                                          value:Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.resets_received                                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.accept_queue_entries                                                                       value:Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.fins_received                                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.retries                                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.fin_acks_sent                                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
			                                                                                    key:<traffic_item>.<application_flow_name>.resets_sent                                                                                value:Only for -traffic_generator ixnetwork_540, -mode L47_listening_port_tcp
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.responder_first_timestamp                                               value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.running_simulated_users                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.responder_tx_bytes                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.initiator_tx_rate_bps                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.initiator_tx_rate_mbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.initiator_first_timestamp                                               value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.responder_rx_bytes                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.responder_tx_rate_mbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.responder_tx_rate_bps                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.responder_last_timestamp                                                value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.initiator_tx_rate_kbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.initiator_rx_rate_mbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.initiator_tx_bytes                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.responder_tx_rate_kbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.responder_rx_rate_mbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.initiator_last_timestamp                                                value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.initiator_rx_rate_bps                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.responder_rx_bytes_rate                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.initiator_rx_bytes_rate                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.initiator_rx_rate_kbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.responder_tx_bytes_rate                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.initiator_tx_bytes_rate                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.initiator_rx_bytes                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.responder_rx_rate_kbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<responder>.responder_rx_rate_bps                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.responder_first_timestamp                                               value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.running_simulated_users                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.responder_tx_bytes                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.initiator_tx_rate_bps                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.initiator_tx_rate_mbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.initiator_first_timestamp                                               value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.responder_rx_bytes                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.responder_tx_rate_mbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.responder_tx_rate_bps                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.responder_last_timestamp                                                value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.initiator_tx_rate_kbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.initiator_rx_rate_mbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.initiator_tx_bytes                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.responder_tx_rate_kbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.responder_rx_rate_mbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.initiator_last_timestamp                                                value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.initiator_rx_rate_bps                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.responder_rx_bytes_rate                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.initiator_rx_bytes_rate                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.initiator_rx_rate_kbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.responder_tx_bytes_rate                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.initiator_tx_bytes_rate                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.initiator_rx_bytes                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.responder_rx_rate_kbps                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<initiator>.responder_rx_rate_bps                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.rx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.tcp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.total_bytes                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_successful      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_sent            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_successful                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_successful                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_initiated                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_failed          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_failed                        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.udp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.concurrent_connections              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_received        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.tx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.rx_bytes tcp_bytes                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.total_bytes                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_successful      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_sent            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.flows_successful                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.flows_successful                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.flows_initiated                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_failed          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.flows_failed                        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.udp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.concurrent_connections              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_received        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.tx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.port                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.role                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.tx_throughput_kbps                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.flows_initiated                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_successful_rate                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_failed                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.tcp_throughput_kbps                                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.total_tcp_bytes                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.running_simulated_users                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_successful                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_failed_rate                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.total_bytes_rx                                                          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_initiated                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.total_bytes_tx                                                          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.flows_successful_rate                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.percentage                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.flows_failed                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_initiated_rate                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.throughput_kbps                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.udp_throughput_kbps                                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.flows_successful                                                        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.total_udp_bytes                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.rx_throughput_kbps                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.total_bytes                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.port                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.role                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.tx_throughput_kbps                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_received_rate                                               value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.tcp_throughput_kbps                                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.percentage                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.throughput_kbps                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.udp_throughput_kbps                                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_received                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.rx_throughput_kbps                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.port                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.role                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.tx_throughput_kbps                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.flows_initiated                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_successful_rate                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_failed                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.tcp_throughput_kbps                                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.total_tcp_bytes                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.running_simulated_users                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_successful                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_failed_rate                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.total_bytes_rx                                                          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_initiated                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.total_bytes_tx                                                          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.flows_successful_rate                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.percentage                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.flows_failed                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_initiated_rate                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.throughput_kbps                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.udp_throughput_kbps                                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.flows_successful                                                        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.total_udp_bytes                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.rx_throughput_kbps                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.total_bytes                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.port                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.role                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.tx_throughput_kbps                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_received_rate                                               value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.tcp_throughput_kbps                                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.percentage                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.throughput_kbps                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.udp_throughput_kbps                                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.connections_received                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.rx_throughput_kbps                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.rx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.tcp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.total_bytes                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_successful      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_sent            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_successful                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_initiated                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_failed          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_failed                        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.udp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.concurrent_connections              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.tx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.tcp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.rx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.total_bytes                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_successful      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_sent            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_failed          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.udp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.concurrent_connections              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_received        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.tx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.tx_throughput_kbps                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.flows_initiated                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.connections_successful_rate                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.connections_failed                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.tcp_throughput_kbps                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.total_tcp_bytes                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.running_simulated_users                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.connections_successful                          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.connections_failed_rate                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.total_bytes_rx                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.connections_initiated                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.total_bytes_tx                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.flows_successful_rate                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.percentage                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.flows_failed                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.connections_initiated_rate                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.throughput_kbps                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.udp_throughput_kbps                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.flows_successful                                value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.total_udp_bytes                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.rx_throughput_kbps                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.total_bytes                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.tx_throughput_kbps                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.connections_received_rate                       value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.tcp_throughput_kbps                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.percentage                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.throughput_kbps                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.udp_throughput_kbps                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.connections_received                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.rx_throughput_kbps                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.rx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.tcp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.total_bytes                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_successful      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_sent            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_successful                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_initiated                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_failed          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_failed                        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.udp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.concurrent_connections              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.tx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_initiator_flows_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.rx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.tcp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.total_bytes                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_successful      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_sent            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_successful                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_initiated                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_failed          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_failed                        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.udp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.concurrent_connections              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.tx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_initiator_flows_per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.tcp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.rx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.total_bytes                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_successful      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_sent            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_failed          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.udp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.concurrent_connections              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_received        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.tx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_ports_per_responder_flows_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.tcp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.rx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.total_bytes                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_successful      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_sent            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_failed          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.udp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.concurrent_connections              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_received        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.tx_bytes                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item and -drill_down_type per_responder_flows_per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.tx_throughput_kbps                            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.flows_initiated                               value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.connections_successful_rate                   value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.connections_failed                            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.tcp_throughput_kbps                           value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.total_tcp_bytes                               value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.running_simulated_users                       value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.connections_successful                        value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.connections_failed_rate                       value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.total_bytes_rx                                value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.connections_initiated                         value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.total_bytes_tx                                value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.flows_successful_rate                         value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.percentage                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.flows_failed                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.connections_initiated_rate                    value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.throughput_kbps                               value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.udp_throughput_kbps                           value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.flows_successful                              value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.total_udp_bytes                               value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.rx_throughput_kbps                            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.total_bytes                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.rx_bytes                          value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.tcp_bytes                         value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.total_bytes                       value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_successful      value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_sent          value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_successful                  value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_initiated                   value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_failed        value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_failed                      value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.udp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.concurrent_connections            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.tx_bytes                          value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.rx_bytes                          value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.tcp_bytes                         value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.total_bytes                       value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_successful      value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_sent          value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_successful                  value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_initiated                   value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_failed        value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_failed                      value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.udp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.concurrent_connections            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
			                                                                                    key:<L47_flow_initiator>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.tx_bytes                          value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator and -drill_down_type per_initiator_ports_per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.tx_throughput_kbps                            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.connections_received_rate                     value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.tcp_throughput_kbps                           value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.percentage                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.throughput_kbps                               value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.udp_throughput_kbps                           value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.connections_received                          value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<application_flow_name>.<port_name>.<responder>.rx_throughput_kbps                            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.tcp_bytes                         value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.rx_bytes                          value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.total_bytes                       value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_successful    value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_sent            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_failed        value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.udp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.concurrent_connections            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_received      value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.tx_bytes                          value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.tcp_bytes                         value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.rx_bytes                          value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.total_bytes                       value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_successful    value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_sent            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_failed        value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.udp_bytes                           value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.concurrent_connections            value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.connection_requests_received      value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
			                                                                                    key:<L47_flow_responder>.<traffic_item>.<port_name>.<application_flow_name>.<responder>.<ipv4_ipv6>.tx_bytes                          value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_responder and -drill_down_type per_responder_ports_per_responder_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.responder_listen_queue_drops                                        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.responder_timeouts                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.responder_resets_received                                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.responder_fin_acks_received                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.responder_syn_acks_sent                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.initiator_resets_received                                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.initiator_fin_acks_received                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.responder_retries                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.responder_fins_received                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.responder_connection_requests_failed                                value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.responder_resets_sent                                               value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.responder_fin_acks_sent                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.initiator_retries                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.initiator_fins_received                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.initiator_syns_sent                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.initiator_resets_sent                                               value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.initiator_fin_acks_sent                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.responder_fins_sent                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.responder_syn/syn_acks_received                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.initiator_fins_sent                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.initiator_timeouts                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.initiator_syn/syn_acks_received                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Responder>.responder_accept_queue_entries                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.responder_listen_queue_drops                                        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.responder_timeouts                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.responder_resets_received                                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.responder_fin_acks_received                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.responder_syn_acks_sent                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.initiator_fin_acks_received                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.initiator_resets_received                                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.responder_retries                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.responder_fins_received                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.responder_connection_requests_failed                                value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.responder_resets_sent                                               value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.responder_fin_acks_sent                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.initiator_syns_sent                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.initiator_fins_received                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.initiator_retries                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.initiator_fin_acks_sent                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.initiator_resets_sent                                               value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.responder_fins_sent                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.initiator_fins_sent                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.responder_syn/syn_acks_received                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.initiator_syn/syn_acks_received                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.initiator_timeouts                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<Initiator>.responder_accept_queue_entries                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<application_flow_name>.timeouts                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<application_flow_name>.retries                                                             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<application_flow_name>.fins_received                                                       value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<application_flow_name>.syn/syn_acks_received                                               value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<application_flow_name>.syns_sent                                                           value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<application_flow_name>.resets_sent                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<application_flow_name>.fin_acks_sent                                                       value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<application_flow_name>.resets_received                                                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<application_flow_name>.fin_acks_received                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows
			                                                                                    key:<L47_traffic_item>.<traffic_item>.<application_flow_name>.fins_sent                                                               value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_flows 
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.tcp_bytes                       value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.transactions_initiated          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.transactions_failed             value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_received    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_initiated                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_successful                value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_sent        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.flows_failed                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_successful  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.tx_bytes                        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.transactions_successful         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.rx_bytes                        value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.total_bytes                     value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.udp_bytes                       value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.connection_requests_failed      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<port_name>.<application_flow_name>.<initiator>.<ipv4_ipv6>.concurrent_connections          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_initiator_ips
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<listening_port>.connection_requests_failed                                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<listening_port>.syn_acks_sent                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<listening_port>.fin_acks_received                                                          value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<listening_port>.resets_received                                                            value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<listening_port>.accept_queue_entries                                                       value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<listening_port>.fins_received                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<listening_port>.retries                                                                    value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<listening_port>.fin_acks_sent                                                              value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<listening_port>.resets_sent                                                                value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<listening_port>.fins_sent                                                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<listening_port>.listen_queue_drops                                                         value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<listening_port>.syn/syn_acks_received                                                      value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
			                                                                                    key:<L47_traffic_item_tcp>.<traffic_item>.<listening_port>.timeouts                                                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_traffic_item_tcp and -drill_down_type per_listening_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator_tcp>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.fin_acks_received                         value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator_tcp>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.resets_received                           value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator_tcp>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.fins_received                             value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator_tcp>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.retries                                   value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator_tcp>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.fin_acks_sent                             value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator_tcp>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.resets_sent                               value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator_tcp>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.fins_sent                                 value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator_tcp>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.syn/syn_acks_received                     value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
		                                                                                   Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
			                                                                                    key:<L47_flow_initiator_tcp>.<traffic_item>.<application_flow_name>.<port_name>.<initiator>.timeouts                                  value:Only for -traffic_generator ixnetwork_540, -mode L47_flow_initiator_tcp and -drill_down_type per_initiator_ports
		                                                                               
		                                                                               Examples:
		                                                                               
		                                                                               Sample Input:
		                                                                               
		                                                                               Sample Output:
		                                                                               
		                                                                               Notes:
		                                                                                   1) Coded versus functional specification.
		                                                                                   2) When using -mode stream the for a  port TX stats are returned for all streams that exist on that port and RX stats are available only if the packets with the stream id are received on the port. If -streams option is used along with -mode stream, then TX and RX stats are returned for all streams in the list with 0 values if stats are not available for a specific stream.
		                                                                                   3) ATM interfaces will not produce statistics on a per stream basis.
		                                                                                   4) When using -mode stream or -packet_group_id options, then traffic_control with -action clear_stats or -action sync_run should be called first.
		                                                                                   5) When using -mode stream or -packet_group_id, if any of the test ports arestill transmitting the statistic collection will be slow for large numberof PGIDs.
		                                                                                   6) Deprecated options are:-mode streams-stream
		                                                                               
		                                                                               See Also:
		                                                                               
		"""
		return self._run_keyword("traffic_stats", kwargs)

	def traffic_tag_config(self, **kwargs):
		""" This procedure is used to configure L23 Data traffic items using traffic tags. These tags need to be set at various end points (IP/IPv6 stack, NetworkGroup IP and etc) from where traffic can be sourced or destined.
		
		API Support:
		   IxNetwork API Support: No
		   IxNetwork-NGPF API Support: Yes
		
		Synopsis: traffic_tag_config
			x	[-handle  ANY]
			 	[-mode    CHOICES create modify delete
			           DEFAULT create]
			x	[-enabled CHOICES 0 1]
			x	[-name    ALPHA]
			x	[-id      NUMERIC]
		
		Arguments:
			x	-handle
			x		For create: protocol stack handle needed to configure traffic tag.
			x		For modify/delete: tag handle that must be modified/deleted
			 	-mode
			 		Which mode is being performed.
			 		Valid choices are:
			    		create - Create a tag for the given protocol
			    		modify - Modify the given tag.
			    		delete - Delete the specified tag.
			x	-enabled
			x		Enables/disables tags
			x	-name
			x		specifies the name of the tag the entity will be part of
			x	-id
			x		the tag ids that this entity will use/publish
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status              value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                 value:On status of failure, gives detailed information.
		A handle that can be used to modify/delete the tag
			 key:traffic_tag_handle  value:A handle that can be used to modify/delete the tag
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("traffic_tag_config", kwargs)

	def uds_config(self, **kwargs):
		""" Configure UDS statistic counters
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: uds_config
			 	-port_handle          ANY
			x	[-uds1                ANY]
			x	[-uds1_SA             ANY]
			x	[-uds1_DA             ANY]
			x	[-uds1_error          ANY]
			x	[-uds1_framesize      ANY]
			x	[-uds1_framesize_from ANY]
			x	[-uds1_framesize_to   ANY]
			x	[-uds1_pattern        ANY]
			x	[-uds2                ANY]
			x	[-uds2_SA             ANY]
			x	[-uds2_DA             ANY]
			x	[-uds2_error          ANY]
			x	[-uds2_framesize      ANY]
			x	[-uds2_framesize_from ANY]
			x	[-uds2_framesize_to   ANY]
			x	[-uds2_pattern        ANY]
			x	[-uds3                ANY]
			x	[-uds3_SA             ANY]
			x	[-uds3_DA             ANY]
			x	[-uds3_error          ANY]
			x	[-uds3_framesize      ANY]
			x	[-uds3_framesize_from ANY]
			x	[-uds3_framesize_to   ANY]
			x	[-uds3_pattern        ANY]
			x	[-uds4                ANY]
			x	[-uds4_SA             ANY]
			x	[-uds4_DA             ANY]
			x	[-uds4_error          ANY]
			x	[-uds4_framesize      ANY]
			x	[-uds4_framesize_from ANY]
			x	[-uds4_framesize_to   ANY]
			x	[-uds4_pattern        ANY]
			x	[-uds5                ANY]
			x	[-uds5_SA             ANY]
			x	[-uds5_DA             ANY]
			x	[-uds5_error          ANY]
			x	[-uds5_framesize      ANY]
			x	[-uds5_framesize_from ANY]
			x	[-uds5_framesize_to   ANY]
			x	[-uds5_pattern        ANY]
			x	[-uds6                ANY]
			x	[-uds6_SA             ANY]
			x	[-uds6_DA             ANY]
			x	[-uds6_error          ANY]
			x	[-uds6_framesize      ANY]
			x	[-uds6_framesize_from ANY]
			x	[-uds6_framesize_to   ANY]
			x	[-uds6_pattern        ANY]
		
		Arguments:
			 	-port_handle
			 		Port handle or list of port handles on which to configure the user defined statistic counters.
			x	-uds1
			x   		0 - disable
			x   		1 - enable
			x	-uds1_SA
			x   		any - (default) count all packets
			x   		SA1 - count packets having the MAC source address configured with
			x   		x - count packets having the MAC source address configured with
			x   		notSA1 - count packets that don't have the MAC source address configured with
			x   		SA2 - count packets having the MAC source address configured with
			x   		notSA2 - count packets that don't have the MAC source address configured with
			x	-uds1_DA
			x   		any - (default) count all packets
			x   		DA1 - count packets having the MAC destination address configured with
			x   		x - count packets having the MAC destination address configured with
			x   		notDA1 - count packets that don't have the MAC destination address configured with
			x   		DA2 - count packets having the MAC destination address configured with
			x   		notDA2 - count packets that don't have the MAC destination address configured with
			x	-uds1_error
			x   		errAnyFrame - (default) count all packets
			x   		errBadCRC - count frames with bad CRC
			x   		errBadFrame - count corrupted frames
			x   		errGoodFrame - count frames with no errors
			x	-uds1_framesize
			x   		any - (default) count all packets
			x   		custom - count frames having framesize in the range configured with uds1_framesize_from and
			x   		x - count frames having framesize in the range configured with uds1_framesize_from and
			x   		jumbo - count frames having framesize in the range 1518-9000
			x   		oversized - count frames having framesize in the range 512-1024
			x   		undersized - count frames having framesize in the range 48-64
			x	-uds1_framesize_from
			x		Configure the starting frame size when uds1_framesize is custom
			x	-uds1_framesize_to
			x		Configure the ending frame size when uds1_framesize is custom
			x	-uds1_pattern
			x		Increment UDS1 counter based on the pattern configured with uds_filter_pallette_config
			x		Valid choices are:
			x   		any - (default) count all packets
			x   		pattern1 - count packets matching pattern1
			x   		notPattern1 - count packets not matching pattern1
			x   		pattern2 - count packets matching pattern2
			x   		notPattern2 - count packets not matching pattern2
			x	-uds2
			x		Same as -uds1. Applies to UDS2
			x	-uds2_SA
			x		Same as -uds1_SA. Applies to UDS2
			x	-uds2_DA
			x		Same as -uds1_DA. Applies to UDS2
			x	-uds2_error
			x		Same as -uds1_error. Applies to UDS2
			x	-uds2_framesize
			x		Same as -uds1_framesize. Applies to UDS2
			x	-uds2_framesize_from
			x		Same as -uds1_framesize_from. Applies to UDS2
			x	-uds2_framesize_to
			x		Same as -uds1_framesize_to. Applies to UDS2
			x	-uds2_pattern
			x		Same as -uds1_pattern. Applies to UDS2
			x	-uds3
			x		Same as -uds1. Applies to UDS3
			x	-uds3_SA
			x		Same as -uds1_SA. Applies to UDS3
			x	-uds3_DA
			x		Same as -uds1_DA. Applies to UDS3
			x	-uds3_error
			x		Same as -uds1_error. Applies to UDS3
			x	-uds3_framesize
			x		Same as -uds1_framesize. Applies to UDS3
			x	-uds3_framesize_from
			x		Same as -uds1_framesize_from. Applies to UDS3
			x	-uds3_framesize_to
			x		Same as -uds1_framesize_to. Applies to UDS3
			x	-uds3_pattern
			x		Same as -uds1_pattern. Applies to UDS3
			x	-uds4
			x		Same as -uds1. Applies to UDS4
			x	-uds4_SA
			x		Same as -uds1_SA. Applies to UDS4
			x	-uds4_DA
			x		Same as -uds1_DA. Applies to UDS4
			x	-uds4_error
			x		Same as -uds1_error. Applies to UDS4
			x	-uds4_framesize
			x		Same as -uds1_framesize. Applies to UDS4
			x	-uds4_framesize_from
			x		Same as -uds1_framesize_from. Applies to UDS4
			x	-uds4_framesize_to
			x		Same as -uds1_framesize_to. Applies to UDS4
			x	-uds4_pattern
			x		Same as -uds1_pattern. Applies to UDS4
			x	-uds5
			x		Same as -uds1. Applies to UDS5
			x	-uds5_SA
			x		Same as -uds1_SA. Applies to UDS5
			x	-uds5_DA
			x		Same as -uds1_DA. Applies to UDS5
			x	-uds5_error
			x		Same as -uds1_error. Applies to UDS5
			x	-uds5_framesize
			x		Same as -uds1_framesize. Applies to UDS5
			x	-uds5_framesize_from
			x		Same as -uds1_framesize_from. Applies to UDS5
			x	-uds5_framesize_to
			x		Same as -uds1_framesize_to. Applies to UDS5
			x	-uds5_pattern
			x		Same as -uds1_pattern. Applies to UDS5
			x	-uds6
			x		Same as -uds1. Applies to UDS6
			x	-uds6_SA
			x		Same as -uds1_SA. Applies to UDS6
			x	-uds6_DA
			x		Same as -uds1_DA. Applies to UDS6
			x	-uds6_error
			x		Same as -uds1_error. Applies to UDS6
			x	-uds6_framesize
			x		Same as -uds1_framesize. Applies to UDS6
			x	-uds6_framesize_from
			x		Same as -uds1_framesize_from. Applies to UDS6
			x	-uds6_framesize_to
			x		Same as -uds1_framesize_to. Applies to UDS6
			x	-uds6_pattern
			x		Same as -uds1_pattern. Applies to UDS6
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("uds_config", kwargs)

	def uds_filter_pallette_config(self, **kwargs):
		""" Configure the UDS filters that are used in uds_config
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: uds_filter_pallette_config
			 	-port_handle           ANY
			x	[-DA1                  ANY]
			x	[-DA2                  ANY]
			x	[-DA_mask1             ANY]
			x	[-DA_mask2             ANY]
			x	[-pattern1             ANY]
			x	[-pattern2             ANY]
			x	[-pattern_mask1        ANY]
			x	[-pattern_mask2        ANY]
			x	[-pattern_offset1      ANY]
			x	[-pattern_offset2      ANY]
			x	[-pattern_offset_type1 ANY]
			x	[-pattern_offset_type2 ANY]
			x	[-SA2                  ANY]
			x	[-SA_mask1             ANY]
			x	[-SA_mask2             ANY]
			x	[-clone_capture_filter ANY]
		
		Arguments:
			 	-port_handle
			 		Port handle or list of port handles on which to configure the user defined statistic counters.
			x	-DA1
			x		Configure the MAC destination address 1 filter.
			x	-DA2
			x		Configure the MAC destination address 2 filter.
			x	-DA_mask1
			x		Configure the MAC destination address 1 mask filter.
			x	-DA_mask2
			x		Configure the MAC destination address 2 mask filter.
			x	-pattern1
			x		Configure the pattern1 hex filter.
			x	-pattern2
			x		Configure the pattern2 hex filter.
			x	-pattern_mask1
			x		Configure the pattern1 mask.
			x	-pattern_mask2
			x		Configure the pattern2 mask.
			x	-pattern_offset1
			x		Offset for pattern1 in bytes.
			x	-pattern_offset2
			x		Offset for pattern2 in bytes.
			x	-pattern_offset_type1
			x   		startOfFrame - (default) Offset from the start of the frame.
			x   		startOfIp - Offset from the start of the IP header
			x   		startOfProtocol - Offset from the start of the protocol
			x   		x - Offset from the start of the protocol
			x   		startOfSonet - Offset from the start of the SONET frame.
			x	-pattern_offset_type2
			x   		startOfFrame - (default) Offset from the start of the frame.
			x   		startOfIp - Offset from the start of the IP header
			x   		startOfProtocol - Offset from the start of the protocol
			x   		x - Offset from the start of the protocol
			x   		startOfSonet - Offset from the start of the SONET frame.
			x	-SA2
			x		Configure the MAC source address 2 filter.
			x	-SA_mask1
			x		Configure the MAC source address 1 mask filter.
			x	-SA_mask2
			x		Configure the MAC source address 2 mask filter.
			x	-clone_capture_filter
			x		Enable copy of the filter pallette configured with ::<namespace>::packet_config_filter.
			x		Valid choices are:
			x   		0 - (default) Do not copy the capture filter pallette
			x   		1 - Copy the capture filter pallette settings for the options that were not specified
			x   		x - Copy the capture filter pallette settings for the options that were not specified
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status  value:$::SUCCESS | $::FAILURE
		If status is failure, detailed information provided.
			 key:log     value:If status is failure, detailed information provided.
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("uds_filter_pallette_config", kwargs)

	def vport_info(self, **kwargs):
		""" This command return and sets information about given virtual ports.
		
		API Support:
		   IxNetwork API Support: Yes
		   IxNetwork-NGPF API Support: No
		
		Synopsis: vport_info
			 	-mode            ANY
			 	[-port_list      ANY]
			 	[-port_name_list ANY]
		
		Arguments:
			 	-mode
			 		get_info - Returns information about the given ports. set_info - Sets port names on the given ports.
			 	-port_list
			 		Ports on which to act. If -port_name_list is specified, it must have the same length.
			 	-port_name_list
			 		Port names to set on the given ports. Must have the same list length as -port_list. This parameter is mandatory when -mode is set_info
		
		Return Values:
		$::SUCCESS | $::FAILURE
			 key:status                          value:$::SUCCESS | $::FAILURE
		On status of failure, gives detailed information.
			 key:log                             value:On status of failure, gives detailed information.
		return real port associated with this handle. N/A if not connected
			 key:<port_handle>.real_port_handle  value:return real port associated with this handle. N/A if not connected
		return port name
			 key:<port_handle>.port_name         value:return port name
		
		Examples:
		
		Sample Input:
		
		Sample Output:
		
		Notes:
		
		See Also:
		
		"""
		return self._run_keyword("vport_info", kwargs)